(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1084663,      50578]*)
(*NotebookOutlinePosition[   1086491,      50637]*)
(*  CellTagsIndexPosition[   1086330,      50628]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Minimization of free energy", "Section",
  CellTags->{"i:60", "c:44"}],

Cell[TextData[{
  "In the section ",
  ButtonBox["Description of Introductory Example",
    ButtonStyle->"AddOnsLink"],
  " the description of the steady-state heat conduction on a \
three-dimensional domain was given. The solution of the same physical problem \
can be obtained also as a minimum of the free energy of the problem. Free \
energy of the heat conduction problem is formulated as\n",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPi] = \[Integral]\_\[CapitalOmega]\((\(1\/2\
\) k\ \[CapitalDelta]\[Phi] . \[CapitalDelta]\[Phi] - \[Phi]\ Q)\) \
\[DifferentialD]\[CapitalOmega]\)]],
  "  \nwhere a \[Phi] indicates temperature, a k is the conductivity and a Q \
is the heat generation per unit volume and \[CapitalOmega] is the domain of \
the problem. "
}], "Text"],

Cell[TextData[{
  "The domain of the example is a cube filled with water ([-.0.5m,0.5m]\
\[Times][-0.5m,0.5m]\[Times][0,1m]). On all sides, apart from the upper \
surface, the constant temperature \[Phi]=0 is maintained. The upper surface \
is isolated so that there is no heat flow over the boundary. There exists a \
constant heat source Q=500 ",
  Cell[BoxData[
      \(TraditionalForm\`W/m\^3\)]],
  " inside the cube. The thermal conductivity of water is 0.58 W/m K. The \
task is to calculate the temperature distribution inside the cube.\nThe \
problem is formulated using the Finite Element Method"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["Finite element method ", "Subsection",
  CellTags->{"b:8.1.2", "c:47"}],

Cell[TextData[{
  "First the finite element mesh 30\[Times]30\[Times]30 is used to obtain \
convergence solution at the central point of the cube. The procedure to \
generate heat-conduction element that is used in this example is explained in \
",
  StyleBox["AceGen",
    FontSlant->"Italic"],
  " manual section  ",
  ButtonBox["Description of FE Characteristic Steps",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.2"],

Cell[BoxData[{
    \(\(<< AceFEM`;\)\), "\[IndentingNewLine]", 
    \(\(start = SessionTime[];\)\), "\[IndentingNewLine]", 
    \(\(SMTInputData[];\)\), "\n", 
    \(k = 0.58; Q = 500;\), "\[IndentingNewLine]", 
    \(\(nn = 30;\)\), "\[IndentingNewLine]", 
    \(\(SMTAddDomain["\<cube\>", "\<heatconduction\>", {k, 0, 0, 
          Q}];\)\), "\n", 
    \(\(SMTAddEssentialBoundary[{"\<X\>" \[Equal] \(-0.5\) || \ "\<X\>" \
\[Equal] 0.5\  || \ "\<Y\>" \[Equal] \(-0.5\)\  || \ "\<Y\>" \[Equal] 
                0.5\  || \ "\<Z\>" \[Equal] 0.  &, 0}];\)\), "\n", 
    \(\(SMTMesh["\<cube\>", "\<H1\>", {nn, nn, 
          nn}, {\[IndentingNewLine]{{{\(-0.5\), \(-0.5\), 0}, {0.5, \(-0.5\), 
                0}}, {{\(-0.5\), 0.5, 0}, {0.5, 0.5, 
                0}}}, {{{\(-0.5\), \(-0.5\), 1}, {0.5, \(-0.5\), 
                1}}, {{\(-0.5\), 0.5, 1}, {0.5, 0.5, 
                1}}}\[IndentingNewLine]}];\)\), "\n", 
    \(\(SMTAnalysis["\<Solver\>" \[Rule] 5];\)\)}], "Input",
  CellLabel->"In[163]:=",
  CellTags->"b:8.1.2"],

Cell[BoxData[{
    \(\(SMTNextStep[0, 1];\)\), "\[IndentingNewLine]", 
    \(\(SMTNewtonIteration[];\)\)}], "Input",
  CellLabel->"In[172]:=",
  CellTags->"b:8.1.2"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SMTPointValues[{0, 0, 0.5}, SMTPost[1]]\), "\[IndentingNewLine]", 
    \(SessionTime[] - start\)}], "Input",
  CellLabel->"In[174]:=",
  CellTags->"b:8.1.2"],

Cell[BoxData[
    \(55.87649002411022`\)], "Output",
  CellLabel->"Out[174]=",
  CellTags->"b:8.1.2"],

Cell[BoxData[
    \(16.8842784`8.377997502329936\)], "Output",
  CellLabel->"Out[175]=",
  CellTags->"b:8.1.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(SMTShowMesh["\<Mesh\>" \[Rule] True, "\<Elements\>" \[Rule] 
          True, "\<Field\>" \[Rule] SMTPost[1], "\<Contour\>" \[Rule] 
          True];\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  CellLabel->"In[176]:=",
  CellTags->"b:8.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85457 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.749777 0.020347 0.749777 [
[ 0 0 0 0 ]
[ 1 .85457 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .85457 L
0 .85457 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.020347 0.773587 0.834227 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.115 0 .563 r
.43665 .59074 m .43705 .57677 L .42216 .58164 L p F P
0 0 0 r
s
.115 0 .563 r
.42216 .58164 m .42169 .59559 L .43665 .59074 L p F P
0 0 0 r
s
.134 0 .891 r
.41334 .57263 m .42216 .58164 L .43705 .57677 L p F P
0 0 0 r
s
.188 0 .528 r
.42169 .59559 m .42216 .58164 L .41334 .57263 L p F P
0 0 0 r
s
.115 0 .563 r
.45169 .58587 m .45203 .57187 L .43705 .57677 L p F P
0 0 0 r
s
.115 0 .563 r
.43705 .57677 m .43665 .59074 L .45169 .58587 L p F P
0 0 0 r
s
.134 0 .891 r
.42829 .56771 m .43705 .57677 L .45203 .57187 L p F P
0 0 0 r
s
.134 0 .891 r
.43705 .57677 m .42829 .56771 L .41334 .57263 L p F P
0 0 0 r
s
.115 0 .563 r
.43624 .60485 m .43665 .59074 L .42169 .59559 L p F P
0 0 0 r
s
.115 0 .563 r
.42169 .59559 m .42122 .60968 L .43624 .60485 L p F P
0 0 0 r
s
.188 0 .528 r
.42122 .60968 m .42169 .59559 L .41283 .58662 L p F P
0 0 0 r
s
.188 0 .528 r
.41334 .57263 m .41283 .58662 L .42169 .59559 L p F P
0 0 0 r
s
.134 0 .891 r
.40443 .56352 m .41334 .57263 L .42829 .56771 L p F P
0 0 0 r
s
.188 0 .528 r
.41283 .58662 m .41334 .57263 L .40443 .56352 L p F P
0 0 0 r
s
.115 0 .563 r
.46682 .58096 m .46709 .56695 L .45203 .57187 L p F P
0 0 0 r
s
.115 0 .563 r
.45203 .57187 m .45169 .58587 L .46682 .58096 L p F P
0 0 0 r
s
.134 0 .891 r
.44332 .56276 m .45203 .57187 L .46709 .56695 L p F P
0 0 0 r
s
.134 0 .891 r
.45203 .57187 m .44332 .56276 L .42829 .56771 L p F P
0 0 0 r
s
.115 0 .563 r
.45135 .59999 m .45169 .58587 L .43665 .59074 L p F P
0 0 0 r
s
.115 0 .563 r
.43665 .59074 m .43624 .60485 L .45135 .59999 L p F P
0 0 0 r
s
.134 0 .891 r
.41944 .55855 m .42829 .56771 L .44332 .56276 L p F P
0 0 0 r
s
.134 0 .891 r
.42829 .56771 m .41944 .55855 L .40443 .56352 L p F P
0 0 0 r
s
.115 0 .563 r
.48204 .57602 m .48225 .56199 L .46709 .56695 L p F P
0 0 0 r
s
.115 0 .563 r
.46709 .56695 m .46682 .58096 L .48204 .57602 L p F P
0 0 0 r
s
.134 0 .891 r
.45844 .55778 m .46709 .56695 L .48225 .56199 L p F P
0 0 0 r
s
.134 0 .891 r
.46709 .56695 m .45844 .55778 L .44332 .56276 L p F P
0 0 0 r
s
.115 0 .563 r
.43583 .61907 m .43624 .60485 L .42122 .60968 L p F P
0 0 0 r
s
.115 0 .563 r
.42122 .60968 m .42074 .62388 L .43583 .61907 L p F P
0 0 0 r
s
.188 0 .528 r
.42074 .62388 m .42122 .60968 L .41232 .60074 L p F P
0 0 0 r
s
.188 0 .528 r
.41283 .58662 m .41232 .60074 L .42122 .60968 L p F P
0 0 0 r
s
.188 0 .528 r
.41232 .60074 m .41283 .58662 L .40388 .57755 L p F P
0 0 0 r
s
.188 0 .528 r
.40443 .56352 m .40388 .57755 L .41283 .58662 L p F P
0 0 0 r
s
.115 0 .563 r
.46655 .5951 m .46682 .58096 L .45169 .58587 L p F P
0 0 0 r
s
.115 0 .563 r
.45169 .58587 m .45135 .59999 L .46655 .5951 L p F P
0 0 0 r
s
.134 0 .891 r
.39543 .55431 m .40443 .56352 L .41944 .55855 L p F P
0 0 0 r
s
.188 0 .528 r
.40388 .57755 m .40443 .56352 L .39543 .55431 L p F P
0 0 0 r
s
.134 0 .891 r
.43452 .55354 m .44332 .56276 L .45844 .55778 L p F P
0 0 0 r
s
.134 0 .891 r
.44332 .56276 m .43452 .55354 L .41944 .55855 L p F P
0 0 0 r
s
.115 0 .563 r
.49736 .57106 m .49749 .55701 L .48225 .56199 L p F P
0 0 0 r
s
.115 0 .563 r
.48225 .56199 m .48204 .57602 L .49736 .57106 L p F P
0 0 0 r
s
.134 0 .891 r
.47366 .55277 m .48225 .56199 L .49749 .55701 L p F P
0 0 0 r
s
.134 0 .891 r
.48225 .56199 m .47366 .55277 L .45844 .55778 L p F P
0 0 0 r
s
.115 0 .563 r
.45101 .61424 m .45135 .59999 L .43624 .60485 L p F P
0 0 0 r
s
.115 0 .563 r
.43624 .60485 m .43583 .61907 L .45101 .61424 L p F P
0 0 0 r
s
.115 0 .563 r
.48184 .59018 m .48204 .57602 L .46682 .58096 L p F P
0 0 0 r
s
.115 0 .563 r
.46682 .58096 m .46655 .5951 L .48184 .59018 L p F P
0 0 0 r
s
.115 0 .563 r
.43541 .63343 m .43583 .61907 L .42074 .62388 L p F P
0 0 0 r
s
.115 0 .563 r
.42074 .62388 m .42026 .63822 L .43541 .63343 L p F P
0 0 0 r
s
.188 0 .528 r
.42026 .63822 m .42074 .62388 L .4118 .61498 L p F P
0 0 0 r
s
.188 0 .528 r
.41232 .60074 m .4118 .61498 L .42074 .62388 L p F P
0 0 0 r
s
.134 0 .891 r
.41048 .54928 m .41944 .55855 L .43452 .55354 L p F P
0 0 0 r
s
.134 0 .891 r
.41944 .55855 m .41048 .54928 L .39543 .55431 L p F P
0 0 0 r
s
.134 0 .891 r
.4497 .54851 m .45844 .55778 L .47366 .55277 L p F P
0 0 0 r
s
.134 0 .891 r
.45844 .55778 m .4497 .54851 L .43452 .55354 L p F P
0 0 0 r
s
.188 0 .528 r
.4118 .61498 m .41232 .60074 L .40332 .5917 L p F P
0 0 0 r
s
.188 0 .528 r
.40388 .57755 m .40332 .5917 L .41232 .60074 L p F P
0 0 0 r
s
.115 0 .563 r
.51276 .56606 m .51282 .552 L .49749 .55701 L p F P
0 0 0 r
s
.115 0 .563 r
.49749 .55701 m .49736 .57106 L .51276 .56606 L p F P
0 0 0 r
s
.134 0 .891 r
.48896 .54773 m .49749 .55701 L .51282 .552 L p F P
0 0 0 r
s
.134 0 .891 r
.49749 .55701 m .48896 .54773 L .47366 .55277 L p F P
0 0 0 r
s
.115 0 .563 r
.46628 .60937 m .46655 .5951 L .45135 .59999 L p F P
0 0 0 r
s
.115 0 .563 r
.45135 .59999 m .45101 .61424 L .46628 .60937 L p F P
0 0 0 r
s
.188 0 .528 r
.40332 .5917 m .40388 .57755 L .39483 .56837 L p F P
0 0 0 r
s
.188 0 .528 r
.39543 .55431 m .39483 .56837 L .40388 .57755 L p F P
0 0 0 r
s
.115 0 .563 r
.49722 .58524 m .49736 .57106 L .48204 .57602 L p F P
0 0 0 r
s
.115 0 .563 r
.48204 .57602 m .48184 .59018 L .49722 .58524 L p F P
0 0 0 r
s
.134 0 .891 r
.38632 .545 m .39543 .55431 L .41048 .54928 L p F P
0 0 0 r
s
.188 0 .528 r
.39483 .56837 m .39543 .55431 L .38632 .545 L p F P
0 0 0 r
s
.115 0 .563 r
.45066 .62861 m .45101 .61424 L .43583 .61907 L p F P
0 0 0 r
s
.115 0 .563 r
.43583 .61907 m .43541 .63343 L .45066 .62861 L p F P
0 0 0 r
s
.134 0 .891 r
.42563 .54422 m .43452 .55354 L .4497 .54851 L p F P
0 0 0 r
s
.134 0 .891 r
.43452 .55354 m .42563 .54422 L .41048 .54928 L p F P
0 0 0 r
s
.134 0 .891 r
.46497 .54344 m .47366 .55277 L .48896 .54773 L p F P
0 0 0 r
s
.134 0 .891 r
.47366 .55277 m .46497 .54344 L .4497 .54851 L p F P
0 0 0 r
s
.115 0 .563 r
.52826 .56104 m .52825 .54695 L .51282 .552 L p F P
0 0 0 r
s
.115 0 .563 r
.51282 .552 m .51276 .56606 L .52826 .56104 L p F P
0 0 0 r
s
.134 0 .891 r
.50435 .54266 m .51282 .552 L .52825 .54695 L p F P
0 0 0 r
s
.134 0 .891 r
.51282 .552 m .50435 .54266 L .48896 .54773 L p F P
0 0 0 r
s
.115 0 .563 r
.48164 .60447 m .48184 .59018 L .46655 .5951 L p F P
0 0 0 r
s
.115 0 .563 r
.46655 .5951 m .46628 .60937 L .48164 .60447 L p F P
0 0 0 r
s
.115 0 .563 r
.435 .64792 m .43541 .63343 L .42026 .63822 L p F P
0 0 0 r
s
.115 0 .563 r
.42026 .63822 m .41977 .65269 L .435 .64792 L p F P
0 0 0 r
s
.188 0 .528 r
.41977 .65269 m .42026 .63822 L .41127 .62936 L p F P
0 0 0 r
s
.188 0 .528 r
.4118 .61498 m .41127 .62936 L .42026 .63822 L p F P
0 0 0 r
s
.188 0 .528 r
.41127 .62936 m .4118 .61498 L .40276 .60598 L p F P
0 0 0 r
s
.188 0 .528 r
.40332 .5917 m .40276 .60598 L .4118 .61498 L p F P
0 0 0 r
s
.115 0 .563 r
.5127 .58026 m .51276 .56606 L .49736 .57106 L p F P
0 0 0 r
s
.115 0 .563 r
.49736 .57106 m .49722 .58524 L .5127 .58026 L p F P
0 0 0 r
s
.134 0 .891 r
.40143 .53992 m .41048 .54928 L .42563 .54422 L p F P
0 0 0 r
s
.134 0 .891 r
.41048 .54928 m .40143 .53992 L .38632 .545 L p F P
0 0 0 r
s
.115 0 .563 r
.466 .62377 m .46628 .60937 L .45101 .61424 L p F P
0 0 0 r
s
.115 0 .563 r
.45101 .61424 m .45066 .62861 L .466 .62377 L p F P
0 0 0 r
s
.134 0 .891 r
.44086 .53913 m .4497 .54851 L .46497 .54344 L p F P
0 0 0 r
s
.134 0 .891 r
.4497 .54851 m .44086 .53913 L .42563 .54422 L p F P
0 0 0 r
s
.188 0 .528 r
.40276 .60598 m .40332 .5917 L .39422 .58256 L p F P
0 0 0 r
s
.188 0 .528 r
.39483 .56837 m .39422 .58256 L .40332 .5917 L p F P
0 0 0 r
s
.134 0 .891 r
.48033 .53835 m .48896 .54773 L .50435 .54266 L p F P
0 0 0 r
s
.134 0 .891 r
.48896 .54773 m .48033 .53835 L .46497 .54344 L p F P
0 0 0 r
s
.115 0 .563 r
.54385 .55598 m .54377 .54188 L .52825 .54695 L p F P
0 0 0 r
s
.115 0 .563 r
.52825 .54695 m .52826 .56104 L .54385 .55598 L p F P
0 0 0 r
s
.134 0 .891 r
.51984 .53756 m .52825 .54695 L .54377 .54188 L p F P
0 0 0 r
s
.134 0 .891 r
.52825 .54695 m .51984 .53756 L .50435 .54266 L p F P
0 0 0 r
s
.115 0 .563 r
.49709 .59955 m .49722 .58524 L .48184 .59018 L p F P
0 0 0 r
s
.115 0 .563 r
.48184 .59018 m .48164 .60447 L .49709 .59955 L p F P
0 0 0 r
s
.188 0 .528 r
.39422 .58256 m .39483 .56837 L .38568 .5591 L p F P
0 0 0 r
s
.188 0 .528 r
.38632 .545 m .38568 .5591 L .39483 .56837 L p F P
0 0 0 r
s
.115 0 .563 r
.45031 .64313 m .45066 .62861 L .43541 .63343 L p F P
0 0 0 r
s
.115 0 .563 r
.43541 .63343 m .435 .64792 L .45031 .64313 L p F P
0 0 0 r
s
.134 0 .891 r
.37711 .53559 m .38632 .545 L .40143 .53992 L p F P
0 0 0 r
s
.188 0 .528 r
.38568 .5591 m .38632 .545 L .37711 .53559 L p F P
0 0 0 r
s
.115 0 .563 r
.52827 .57526 m .52826 .56104 L .51276 .56606 L p F P
0 0 0 r
s
.115 0 .563 r
.51276 .56606 m .5127 .58026 L .52827 .57526 L p F P
0 0 0 r
s
.134 0 .891 r
.41663 .5348 m .42563 .54422 L .44086 .53913 L p F P
0 0 0 r
s
.134 0 .891 r
.42563 .54422 m .41663 .5348 L .40143 .53992 L p F P
0 0 0 r
s
.115 0 .563 r
.48143 .61889 m .48164 .60447 L .46628 .60937 L p F P
0 0 0 r
s
.115 0 .563 r
.46628 .60937 m .466 .62377 L .48143 .61889 L p F P
0 0 0 r
s
.134 0 .891 r
.45619 .53401 m .46497 .54344 L .48033 .53835 L p F P
0 0 0 r
s
.134 0 .891 r
.46497 .54344 m .45619 .53401 L .44086 .53913 L p F P
0 0 0 r
s
.115 0 .563 r
.43457 .66255 m .435 .64792 L .41977 .65269 L p F P
0 0 0 r
s
.115 0 .563 r
.41977 .65269 m .41928 .6673 L .43457 .66255 L p F P
0 0 0 r
s
.188 0 .528 r
.41928 .6673 m .41977 .65269 L .41074 .64387 L p F P
0 0 0 r
s
.188 0 .528 r
.41127 .62936 m .41074 .64387 L .41977 .65269 L p F P
0 0 0 r
s
.134 0 .891 r
.49578 .53322 m .50435 .54266 L .51984 .53756 L p F P
0 0 0 r
s
.134 0 .891 r
.50435 .54266 m .49578 .53322 L .48033 .53835 L p F P
0 0 0 r
s
.115 0 .563 r
.55953 .5509 m .55938 .53677 L .54377 .54188 L p F P
0 0 0 r
s
.115 0 .563 r
.54377 .54188 m .54385 .55598 L .55953 .5509 L p F P
0 0 0 r
s
.134 0 .891 r
.53541 .53243 m .54377 .54188 L .55938 .53677 L p F P
0 0 0 r
s
.134 0 .891 r
.54377 .54188 m .53541 .53243 L .51984 .53756 L p F P
0 0 0 r
s
.188 0 .528 r
.41074 .64387 m .41127 .62936 L .40219 .6204 L p F P
0 0 0 r
s
.188 0 .528 r
.40276 .60598 m .40219 .6204 L .41127 .62936 L p F P
0 0 0 r
s
.115 0 .563 r
.51264 .59459 m .5127 .58026 L .49722 .58524 L p F P
0 0 0 r
s
.115 0 .563 r
.49722 .58524 m .49709 .59955 L .51264 .59459 L p F P
0 0 0 r
s
.115 0 .563 r
.46572 .6383 m .466 .62377 L .45066 .62861 L p F P
0 0 0 r
s
.115 0 .563 r
.45066 .62861 m .45031 .64313 L .46572 .6383 L p F P
0 0 0 r
s
.188 0 .528 r
.40219 .6204 m .40276 .60598 L .39361 .59688 L p F P
0 0 0 r
s
.188 0 .528 r
.39422 .58256 m .39361 .59688 L .40276 .60598 L p F P
0 0 0 r
s
.134 0 .891 r
.39228 .53045 m .40143 .53992 L .41663 .5348 L p F P
0 0 0 r
s
.134 0 .891 r
.40143 .53992 m .39228 .53045 L .37711 .53559 L p F P
0 0 0 r
s
.115 0 .563 r
.54393 .57022 m .54385 .55598 L .52826 .56104 L p F P
0 0 0 r
s
.115 0 .563 r
.52826 .56104 m .52827 .57526 L .54393 .57022 L p F P
0 0 0 r
s
.134 0 .891 r
.43193 .52966 m .44086 .53913 L .45619 .53401 L p F P
0 0 0 r
s
.134 0 .891 r
.44086 .53913 m .43193 .52966 L .41663 .5348 L p F P
0 0 0 r
s
.115 0 .563 r
.49696 .61399 m .49709 .59955 L .48164 .60447 L p F P
0 0 0 r
s
.115 0 .563 r
.48164 .60447 m .48143 .61889 L .49696 .61399 L p F P
0 0 0 r
s
.188 0 .528 r
.39361 .59688 m .39422 .58256 L .38503 .57332 L p F P
0 0 0 r
s
.188 0 .528 r
.38568 .5591 m .38503 .57332 L .39422 .58256 L p F P
0 0 0 r
s
.134 0 .891 r
.47161 .52886 m .48033 .53835 L .49578 .53322 L p F P
0 0 0 r
s
.134 0 .891 r
.48033 .53835 m .47161 .52886 L .45619 .53401 L p F P
0 0 0 r
s
.115 0 .563 r
.44996 .65777 m .45031 .64313 L .435 .64792 L p F P
0 0 0 r
s
.115 0 .563 r
.435 .64792 m .43457 .66255 L .44996 .65777 L p F P
0 0 0 r
s
.134 0 .891 r
.51133 .52807 m .51984 .53756 L .53541 .53243 L p F P
0 0 0 r
s
.134 0 .891 r
.51984 .53756 m .51133 .52807 L .49578 .53322 L p F P
0 0 0 r
s
.188 0 .528 r
.38503 .57332 m .38568 .5591 L .37642 .54972 L p F P
0 0 0 r
s
.188 0 .528 r
.37711 .53559 m .37642 .54972 L .38568 .5591 L p F P
0 0 0 r
s
.115 0 .563 r
.57531 .54578 m .57508 .53164 L .55938 .53677 L p F P
0 0 0 r
s
.115 0 .563 r
.55938 .53677 m .55953 .5509 L .57531 .54578 L p F P
0 0 0 r
s
.134 0 .891 r
.55109 .52727 m .55938 .53677 L .57508 .53164 L p F P
0 0 0 r
s
.134 0 .891 r
.55938 .53677 m .55109 .52727 L .53541 .53243 L p F P
0 0 0 r
s
.115 0 .563 r
.52828 .5896 m .52827 .57526 L .5127 .58026 L p F P
0 0 0 r
s
.115 0 .563 r
.5127 .58026 m .51264 .59459 L .52828 .5896 L p F P
0 0 0 r
s
.115 0 .563 r
.48122 .63345 m .48143 .61889 L .466 .62377 L p F P
0 0 0 r
s
.115 0 .563 r
.466 .62377 m .46572 .6383 L .48122 .63345 L p F P
0 0 0 r
s
.115 0 .563 r
.43415 .67731 m .43457 .66255 L .41928 .6673 L p F P
0 0 0 r
s
.115 0 .563 r
.41928 .6673 m .41878 .68203 L .43415 .67731 L p F P
0 0 0 r
s
.188 0 .528 r
.41878 .68203 m .41928 .6673 L .41021 .65851 L p F P
0 0 0 r
s
.188 0 .528 r
.41074 .64387 m .41021 .65851 L .41928 .6673 L p F P
0 0 0 r
s
.134 0 .891 r
.36781 .52607 m .37711 .53559 L .39228 .53045 L p F P
0 0 0 r
s
.188 0 .528 r
.37642 .54972 m .37711 .53559 L .36781 .52607 L p F P
0 0 0 r
s
.134 0 .891 r
.40754 .52528 m .41663 .5348 L .43193 .52966 L p F P
0 0 0 r
s
.134 0 .891 r
.41663 .5348 m .40754 .52528 L .39228 .53045 L p F P
0 0 0 r
s
.115 0 .563 r
.55968 .56515 m .55953 .5509 L .54385 .55598 L p F P
0 0 0 r
s
.115 0 .563 r
.54385 .55598 m .54393 .57022 L .55968 .56515 L p F P
0 0 0 r
s
.134 0 .891 r
.44731 .52448 m .45619 .53401 L .47161 .52886 L p F P
0 0 0 r
s
.134 0 .891 r
.45619 .53401 m .44731 .52448 L .43193 .52966 L p F P
0 0 0 r
s
.188 0 .528 r
.41021 .65851 m .41074 .64387 L .40161 .63494 L p F P
0 0 0 r
s
.188 0 .528 r
.40219 .6204 m .40161 .63494 L .41074 .64387 L p F P
0 0 0 r
s
.115 0 .563 r
.51257 .60905 m .51264 .59459 L .49709 .59955 L p F P
0 0 0 r
s
.115 0 .563 r
.49709 .59955 m .49696 .61399 L .51257 .60905 L p F P
0 0 0 r
s
.134 0 .891 r
.48712 .52368 m .49578 .53322 L .51133 .52807 L p F P
0 0 0 r
s
.134 0 .891 r
.49578 .53322 m .48712 .52368 L .47161 .52886 L p F P
0 0 0 r
s
.115 0 .563 r
.46544 .65297 m .46572 .6383 L .45031 .64313 L p F P
0 0 0 r
s
.115 0 .563 r
.45031 .64313 m .44996 .65777 L .46544 .65297 L p F P
0 0 0 r
s
.134 0 .891 r
.52697 .52288 m .53541 .53243 L .55109 .52727 L p F P
0 0 0 r
s
.134 0 .891 r
.53541 .53243 m .52697 .52288 L .51133 .52807 L p F P
0 0 0 r
s
.188 0 .528 r
.40161 .63494 m .40219 .6204 L .393 .61133 L p F P
0 0 0 r
s
.188 0 .528 r
.39361 .59688 m .393 .61133 L .40219 .6204 L p F P
0 0 0 r
s
.115 0 .563 r
.59118 .54063 m .59088 .52647 L .57508 .53164 L p F P
0 0 0 r
s
.115 0 .563 r
.57508 .53164 m .57531 .54578 L .59118 .54063 L p F P
0 0 0 r
s
.134 0 .891 r
.56685 .52208 m .57508 .53164 L .59088 .52647 L p F P
0 0 0 r
s
.134 0 .891 r
.57508 .53164 m .56685 .52208 L .55109 .52727 L p F P
0 0 0 r
s
.115 0 .563 r
.54401 .58459 m .54393 .57022 L .52827 .57526 L p F P
0 0 0 r
s
.115 0 .563 r
.52827 .57526 m .52828 .5896 L .54401 .58459 L p F P
0 0 0 r
s
.115 0 .563 r
.49682 .62856 m .49696 .61399 L .48143 .61889 L p F P
0 0 0 r
s
.115 0 .563 r
.48143 .61889 m .48122 .63345 L .49682 .62856 L p F P
0 0 0 r
s
.188 0 .528 r
.393 .61133 m .39361 .59688 L .38437 .58768 L p F P
0 0 0 r
s
.188 0 .528 r
.38503 .57332 m .38437 .58768 L .39361 .59688 L p F P
0 0 0 r
s
.115 0 .563 r
.4496 .67256 m .44996 .65777 L .43457 .66255 L p F P
0 0 0 r
s
.115 0 .563 r
.43457 .66255 m .43415 .67731 L .4496 .67256 L p F P
0 0 0 r
s
.134 0 .891 r
.38303 .52087 m .39228 .53045 L .40754 .52528 L p F P
0 0 0 r
s
.134 0 .891 r
.39228 .53045 m .38303 .52087 L .36781 .52607 L p F P
0 0 0 r
s
.134 0 .891 r
.42289 .52007 m .43193 .52966 L .44731 .52448 L p F P
0 0 0 r
s
.134 0 .891 r
.43193 .52966 m .42289 .52007 L .40754 .52528 L p F P
0 0 0 r
s
.188 0 .528 r
.38437 .58768 m .38503 .57332 L .37573 .56398 L p F P
0 0 0 r
s
.188 0 .528 r
.37642 .54972 m .37573 .56398 L .38503 .57332 L p F P
0 0 0 r
s
.115 0 .563 r
.57554 .56006 m .57531 .54578 L .55953 .5509 L p F P
0 0 0 r
s
.115 0 .563 r
.55953 .5509 m .55968 .56515 L .57554 .56006 L p F P
0 0 0 r
s
.134 0 .891 r
.46279 .51927 m .47161 .52886 L .48712 .52368 L p F P
0 0 0 r
s
.134 0 .891 r
.47161 .52886 m .46279 .51927 L .44731 .52448 L p F P
0 0 0 r
s
.115 0 .563 r
.52829 .60409 m .52828 .5896 L .51264 .59459 L p F P
0 0 0 r
s
.115 0 .563 r
.51264 .59459 m .51257 .60905 L .52829 .60409 L p F P
0 0 0 r
s
.115 0 .563 r
.48101 .64814 m .48122 .63345 L .46572 .6383 L p F P
0 0 0 r
s
.115 0 .563 r
.46572 .6383 m .46544 .65297 L .48101 .64814 L p F P
0 0 0 r
s
.134 0 .891 r
.50273 .51846 m .51133 .52807 L .52697 .52288 L p F P
0 0 0 r
s
.134 0 .891 r
.51133 .52807 m .50273 .51846 L .48712 .52368 L p F P
0 0 0 r
s
.115 0 .563 r
.43372 .69221 m .43415 .67731 L .41878 .68203 L p F P
0 0 0 r
s
.115 0 .563 r
.41878 .68203 m .41828 .69691 L .43372 .69221 L p F P
0 0 0 r
s
.188 0 .528 r
.41828 .69691 m .41878 .68203 L .40966 .67329 L p F P
0 0 0 r
s
.188 0 .528 r
.41021 .65851 m .40966 .67329 L .41878 .68203 L p F P
0 0 0 r
s
.188 0 .528 r
.37573 .56398 m .37642 .54972 L .36707 .54024 L p F P
0 0 0 r
s
.188 0 .528 r
.36781 .52607 m .36707 .54024 L .37642 .54972 L p F P
0 0 0 r
s
.134 0 .891 r
.5427 .51766 m .55109 .52727 L .56685 .52208 L p F P
0 0 0 r
s
.134 0 .891 r
.55109 .52727 m .5427 .51766 L .52697 .52288 L p F P
0 0 0 r
s
.115 0 .563 r
.60715 .53546 m .60677 .52128 L .59088 .52647 L p F P
0 0 0 r
s
.115 0 .563 r
.59088 .52647 m .59118 .54063 L .60715 .53546 L p F P
0 0 0 r
s
.134 0 .891 r
.58271 .51685 m .59088 .52647 L .60677 .52128 L p F P
0 0 0 r
s
.134 0 .891 r
.59088 .52647 m .58271 .51685 L .56685 .52208 L p F P
0 0 0 r
s
.115 0 .563 r
.55984 .57954 m .55968 .56515 L .54393 .57022 L p F P
0 0 0 r
s
.115 0 .563 r
.54393 .57022 m .54401 .58459 L .55984 .57954 L p F P
0 0 0 r
s
.188 0 .528 r
.40966 .67329 m .41021 .65851 L .40103 .64963 L p F P
0 0 0 r
s
.188 0 .528 r
.40161 .63494 m .40103 .64963 L .41021 .65851 L p F P
0 0 0 r
s
.134 0 .891 r
.35839 .51645 m .36781 .52607 L .38303 .52087 L p F P
0 0 0 r
s
.188 0 .528 r
.36707 .54024 m .36781 .52607 L .35839 .51645 L p F P
0 0 0 r
s
.115 0 .563 r
.51251 .62365 m .51257 .60905 L .49696 .61399 L p F P
0 0 0 r
s
.115 0 .563 r
.49696 .61399 m .49682 .62856 L .51251 .62365 L p F P
0 0 0 r
s
.115 0 .563 r
.46516 .66778 m .46544 .65297 L .44996 .65777 L p F P
0 0 0 r
s
.115 0 .563 r
.44996 .65777 m .4496 .67256 L .46516 .66778 L p F P
0 0 0 r
s
.134 0 .891 r
.39835 .51564 m .40754 .52528 L .42289 .52007 L p F P
0 0 0 r
s
.134 0 .891 r
.40754 .52528 m .39835 .51564 L .38303 .52087 L p F P
0 0 0 r
s
.134 0 .891 r
.43834 .51484 m .44731 .52448 L .46279 .51927 L p F P
0 0 0 r
s
.134 0 .891 r
.44731 .52448 m .43834 .51484 L .42289 .52007 L p F P
0 0 0 r
s
.188 0 .528 r
.40103 .64963 m .40161 .63494 L .39238 .62592 L p F P
0 0 0 r
s
.188 0 .528 r
.393 .61133 m .39238 .62592 L .40161 .63494 L p F P
0 0 0 r
s
.115 0 .563 r
.59148 .55493 m .59118 .54063 L .57531 .54578 L p F P
0 0 0 r
s
.115 0 .563 r
.57531 .54578 m .57554 .56006 L .59148 .55493 L p F P
0 0 0 r
s
.134 0 .891 r
.47836 .51403 m .48712 .52368 L .50273 .51846 L p F P
0 0 0 r
s
.134 0 .891 r
.48712 .52368 m .47836 .51403 L .46279 .51927 L p F P
0 0 0 r
s
.115 0 .563 r
.54409 .59909 m .54401 .58459 L .52828 .5896 L p F P
0 0 0 r
s
.115 0 .563 r
.52828 .5896 m .52829 .60409 L .54409 .59909 L p F P
0 0 0 r
s
.134 0 .891 r
.51843 .51322 m .52697 .52288 L .5427 .51766 L p F P
0 0 0 r
s
.134 0 .891 r
.52697 .52288 m .51843 .51322 L .50273 .51846 L p F P
0 0 0 r
s
.115 0 .563 r
.49668 .64327 m .49682 .62856 L .48122 .63345 L p F P
0 0 0 r
s
.115 0 .563 r
.48122 .63345 m .48101 .64814 L .49668 .64327 L p F P
0 0 0 r
s
.188 0 .528 r
.39238 .62592 m .393 .61133 L .38371 .60217 L p F P
0 0 0 r
s
.188 0 .528 r
.38437 .58768 m .38371 .60217 L .393 .61133 L p F P
0 0 0 r
s
.115 0 .563 r
.44925 .68748 m .4496 .67256 L .43415 .67731 L p F P
0 0 0 r
s
.115 0 .563 r
.43415 .67731 m .43372 .69221 L .44925 .68748 L p F P
0 0 0 r
s
.134 0 .891 r
.55853 .51241 m .56685 .52208 L .58271 .51685 L p F P
0 0 0 r
s
.134 0 .891 r
.56685 .52208 m .55853 .51241 L .5427 .51766 L p F P
0 0 0 r
s
.115 0 .563 r
.62321 .53025 m .62276 .51605 L .60677 .52128 L p F P
0 0 0 r
s
.115 0 .563 r
.60677 .52128 m .60715 .53546 L .62321 .53025 L p F P
0 0 0 r
s
.134 0 .891 r
.59867 .5116 m .60677 .52128 L .62276 .51605 L p F P
0 0 0 r
s
.134 0 .891 r
.60677 .52128 m .59867 .5116 L .58271 .51685 L p F P
0 0 0 r
s
.188 0 .528 r
.38371 .60217 m .38437 .58768 L .37502 .57837 L p F P
0 0 0 r
s
.188 0 .528 r
.37573 .56398 m .37502 .57837 L .38437 .58768 L p F P
0 0 0 r
s
.115 0 .563 r
.57577 .57447 m .57554 .56006 L .55968 .56515 L p F P
0 0 0 r
s
.115 0 .563 r
.55968 .56515 m .55984 .57954 L .57577 .57447 L p F P
0 0 0 r
s
.134 0 .891 r
.37367 .51119 m .38303 .52087 L .39835 .51564 L p F P
0 0 0 r
s
.134 0 .891 r
.38303 .52087 m .37367 .51119 L .35839 .51645 L p F P
0 0 0 r
s
.115 0 .563 r
.52829 .61871 m .52829 .60409 L .51257 .60905 L p F P
0 0 0 r
s
.115 0 .563 r
.51257 .60905 m .51251 .62365 L .52829 .61871 L p F P
0 0 0 r
s
.115 0 .563 r
.4808 .66297 m .48101 .64814 L .46544 .65297 L p F P
0 0 0 r
s
.115 0 .563 r
.46544 .65297 m .46516 .66778 L .4808 .66297 L p F P
0 0 0 r
s
.134 0 .891 r
.41375 .51038 m .42289 .52007 L .43834 .51484 L p F P
0 0 0 r
s
.134 0 .891 r
.42289 .52007 m .41375 .51038 L .39835 .51564 L p F P
0 0 0 r
s
.115 0 .563 r
.43328 .70725 m .43372 .69221 L .41828 .69691 L p F P
0 0 0 r
s
.115 0 .563 r
.41828 .69691 m .41778 .71192 L .43328 .70725 L p F P
0 0 0 r
s
.188 0 .528 r
.41778 .71192 m .41828 .69691 L .40912 .68821 L p F P
0 0 0 r
s
.188 0 .528 r
.40966 .67329 m .40912 .68821 L .41828 .69691 L p F P
0 0 0 r
s
.188 0 .528 r
.37502 .57837 m .37573 .56398 L .36632 .55453 L p F P
0 0 0 r
s
.188 0 .528 r
.36707 .54024 m .36632 .55453 L .37573 .56398 L p F P
0 0 0 r
s
.134 0 .891 r
.45387 .50957 m .46279 .51927 L .47836 .51403 L p F P
0 0 0 r
s
.134 0 .891 r
.46279 .51927 m .45387 .50957 L .43834 .51484 L p F P
0 0 0 r
s
.115 0 .563 r
.60753 .54977 m .60715 .53546 L .59118 .54063 L p F P
0 0 0 r
s
.115 0 .563 r
.59118 .54063 m .59148 .55493 L .60753 .54977 L p F P
0 0 0 r
s
.134 0 .891 r
.49403 .50876 m .50273 .51846 L .51843 .51322 L p F P
0 0 0 r
s
.134 0 .891 r
.50273 .51846 m .49403 .50876 L .47836 .51403 L p F P
0 0 0 r
s
.188 0 .528 r
.36632 .55453 m .36707 .54024 L .35761 .53065 L p F P
0 0 0 r
s
.188 0 .528 r
.35839 .51645 m .35761 .53065 L .36707 .54024 L p F P
0 0 0 r
s
.115 0 .563 r
.56 .59407 m .55984 .57954 L .54401 .58459 L p F P
0 0 0 r
s
.115 0 .563 r
.54401 .58459 m .54409 .59909 L .56 .59407 L p F P
0 0 0 r
s
.188 0 .528 r
.40912 .68821 m .40966 .67329 L .40044 .66445 L p F P
0 0 0 r
s
.188 0 .528 r
.40103 .64963 m .40044 .66445 L .40966 .67329 L p F P
0 0 0 r
s
.134 0 .891 r
.53423 .50794 m .5427 .51766 L .55853 .51241 L p F P
0 0 0 r
s
.134 0 .891 r
.5427 .51766 m .53423 .50794 L .51843 .51322 L p F P
0 0 0 r
s
.115 0 .563 r
.51244 .63838 m .51251 .62365 L .49682 .62856 L p F P
0 0 0 r
s
.115 0 .563 r
.49682 .62856 m .49668 .64327 L .51244 .63838 L p F P
0 0 0 r
s
.115 0 .563 r
.46487 .68272 m .46516 .66778 L .4496 .67256 L p F P
0 0 0 r
s
.115 0 .563 r
.4496 .67256 m .44925 .68748 L .46487 .68272 L p F P
0 0 0 r
s
.134 0 .891 r
.57446 .50713 m .58271 .51685 L .59867 .5116 L p F P
0 0 0 r
s
.134 0 .891 r
.58271 .51685 m .57446 .50713 L .55853 .51241 L p F P
0 0 0 r
s
.188 0 .528 r
.40044 .66445 m .40103 .64963 L .39175 .64064 L p F P
0 0 0 r
s
.188 0 .528 r
.39238 .62592 m .39175 .64064 L .40103 .64963 L p F P
0 0 0 r
s
.134 0 .891 r
.34887 .50672 m .35839 .51645 L .37367 .51119 L p F P
0 0 0 r
s
.188 0 .528 r
.35761 .53065 m .35839 .51645 L .34887 .50672 L p F P
0 0 0 r
s
.115 0 .563 r
.63938 .52501 m .63885 .51079 L .62276 .51605 L p F P
0 0 0 r
s
.115 0 .563 r
.62276 .51605 m .62321 .53025 L .63938 .52501 L p F P
0 0 0 r
s
.134 0 .891 r
.61473 .50631 m .62276 .51605 L .63885 .51079 L p F P
0 0 0 r
s
.134 0 .891 r
.62276 .51605 m .61473 .50631 L .59867 .5116 L p F P
0 0 0 r
s
.115 0 .563 r
.59179 .56936 m .59148 .55493 L .57554 .56006 L p F P
0 0 0 r
s
.115 0 .563 r
.57554 .56006 m .57577 .57447 L .59179 .56936 L p F P
0 0 0 r
s
.134 0 .891 r
.38905 .5059 m .39835 .51564 L .41375 .51038 L p F P
0 0 0 r
s
.134 0 .891 r
.39835 .51564 m .38905 .5059 L .37367 .51119 L p F P
0 0 0 r
s
.115 0 .563 r
.54418 .61373 m .54409 .59909 L .52829 .60409 L p F P
0 0 0 r
s
.115 0 .563 r
.52829 .60409 m .52829 .61871 L .54418 .61373 L p F P
0 0 0 r
s
.134 0 .891 r
.42926 .50509 m .43834 .51484 L .45387 .50957 L p F P
0 0 0 r
s
.134 0 .891 r
.43834 .51484 m .42926 .50509 L .41375 .51038 L p F P
0 0 0 r
s
.188 0 .528 r
.39175 .64064 m .39238 .62592 L .38304 .6168 L p F P
0 0 0 r
s
.188 0 .528 r
.38371 .60217 m .38304 .6168 L .39238 .62592 L p F P
0 0 0 r
s
.115 0 .563 r
.49654 .65813 m .49668 .64327 L .48101 .64814 L p F P
0 0 0 r
s
.115 0 .563 r
.48101 .64814 m .4808 .66297 L .49654 .65813 L p F P
0 0 0 r
s
.115 0 .563 r
.44888 .70254 m .44925 .68748 L .43372 .69221 L p F P
0 0 0 r
s
.115 0 .563 r
.43372 .69221 m .43328 .70725 L .44888 .70254 L p F P
0 0 0 r
s
.134 0 .891 r
.46951 .50427 m .47836 .51403 L .49403 .50876 L p F P
0 0 0 r
s
.134 0 .891 r
.47836 .51403 m .46951 .50427 L .45387 .50957 L p F P
0 0 0 r
s
.115 0 .563 r
.62367 .54458 m .62321 .53025 L .60715 .53546 L p F P
0 0 0 r
s
.115 0 .563 r
.60715 .53546 m .60753 .54977 L .62367 .54458 L p F P
0 0 0 r
s
.134 0 .891 r
.50979 .50345 m .51843 .51322 L .53423 .50794 L p F P
0 0 0 r
s
.134 0 .891 r
.51843 .51322 m .50979 .50345 L .49403 .50876 L p F P
0 0 0 r
s
.188 0 .528 r
.38304 .6168 m .38371 .60217 L .37431 .5929 L p F P
0 0 0 r
s
.188 0 .528 r
.37502 .57837 m .37431 .5929 L .38371 .60217 L p F P
0 0 0 r
s
.115 0 .563 r
.576 .58901 m .57577 .57447 L .55984 .57954 L p F P
0 0 0 r
s
.115 0 .563 r
.55984 .57954 m .56 .59407 L .576 .58901 L p F P
0 0 0 r
s
.134 0 .891 r
.55012 .50263 m .55853 .51241 L .57446 .50713 L p F P
0 0 0 r
s
.134 0 .891 r
.55853 .51241 m .55012 .50263 L .53423 .50794 L p F P
0 0 0 r
s
.115 0 .563 r
.5283 .63346 m .52829 .61871 L .51251 .62365 L p F P
0 0 0 r
s
.115 0 .563 r
.51251 .62365 m .51244 .63838 L .5283 .63346 L p F P
0 0 0 r
s
.115 0 .563 r
.48059 .67793 m .4808 .66297 L .46516 .66778 L p F P
0 0 0 r
s
.115 0 .563 r
.46516 .66778 m .46487 .68272 L .48059 .67793 L p F P
0 0 0 r
s
.188 0 .528 r
.37431 .5929 m .37502 .57837 L .36557 .56896 L p F P
0 0 0 r
s
.188 0 .528 r
.36632 .55453 m .36557 .56896 L .37502 .57837 L p F P
0 0 0 r
s
.134 0 .891 r
.59048 .50181 m .59867 .5116 L .61473 .50631 L p F P
0 0 0 r
s
.134 0 .891 r
.59867 .5116 m .59048 .50181 L .57446 .50713 L p F P
0 0 0 r
s
.115 0 .563 r
.43285 .72243 m .43328 .70725 L .41778 .71192 L p F P
0 0 0 r
s
.115 0 .563 r
.41778 .71192 m .41727 .72708 L .43285 .72243 L p F P
0 0 0 r
s
.188 0 .528 r
.41727 .72708 m .41778 .71192 L .40857 .70327 L p F P
0 0 0 r
s
.188 0 .528 r
.40912 .68821 m .40857 .70327 L .41778 .71192 L p F P
0 0 0 r
s
.134 0 .891 r
.36421 .5014 m .37367 .51119 L .38905 .5059 L p F P
0 0 0 r
s
.134 0 .891 r
.37367 .51119 m .36421 .5014 L .34887 .50672 L p F P
0 0 0 r
s
.115 0 .563 r
.65564 .51973 m .65504 .5055 L .63885 .51079 L p F P
0 0 0 r
s
.115 0 .563 r
.63885 .51079 m .63938 .52501 L .65564 .51973 L p F P
0 0 0 r
s
.134 0 .891 r
.63088 .50099 m .63885 .51079 L .65504 .5055 L p F P
0 0 0 r
s
.134 0 .891 r
.63885 .51079 m .63088 .50099 L .61473 .50631 L p F P
0 0 0 r
s
.115 0 .563 r
.60791 .56422 m .60753 .54977 L .59148 .55493 L p F P
0 0 0 r
s
.115 0 .563 r
.59148 .55493 m .59179 .56936 L .60791 .56422 L p F P
0 0 0 r
s
.134 0 .891 r
.40451 .50058 m .41375 .51038 L .42926 .50509 L p F P
0 0 0 r
s
.134 0 .891 r
.41375 .51038 m .40451 .50058 L .38905 .5059 L p F P
0 0 0 r
s
.115 0 .563 r
.56016 .60873 m .56 .59407 L .54409 .59909 L p F P
0 0 0 r
s
.115 0 .563 r
.54409 .59909 m .54418 .61373 L .56016 .60873 L p F P
0 0 0 r
s
.188 0 .528 r
.40857 .70327 m .40912 .68821 L .39985 .67941 L p F P
0 0 0 r
s
.188 0 .528 r
.40044 .66445 m .39985 .67941 L .40912 .68821 L p F P
0 0 0 r
s
.188 0 .528 r
.36557 .56896 m .36632 .55453 L .35681 .54498 L p F P
0 0 0 r
s
.188 0 .528 r
.35761 .53065 m .35681 .54498 L .36632 .55453 L p F P
0 0 0 r
s
.115 0 .563 r
.51238 .65326 m .51244 .63838 L .49668 .64327 L p F P
0 0 0 r
s
.115 0 .563 r
.49668 .64327 m .49654 .65813 L .51238 .65326 L p F P
0 0 0 r
s
.134 0 .891 r
.44486 .49976 m .45387 .50957 L .46951 .50427 L p F P
0 0 0 r
s
.134 0 .891 r
.45387 .50957 m .44486 .49976 L .42926 .50509 L p F P
0 0 0 r
s
.115 0 .563 r
.46458 .69781 m .46487 .68272 L .44925 .68748 L p F P
0 0 0 r
s
.115 0 .563 r
.44925 .68748 m .44888 .70254 L .46458 .69781 L p F P
0 0 0 r
s
.134 0 .891 r
.48524 .49894 m .49403 .50876 L .50979 .50345 L p F P
0 0 0 r
s
.134 0 .891 r
.49403 .50876 m .48524 .49894 L .46951 .50427 L p F P
0 0 0 r
s
.188 0 .528 r
.39985 .67941 m .40044 .66445 L .39112 .65551 L p F P
0 0 0 r
s
.188 0 .528 r
.39175 .64064 m .39112 .65551 L .40044 .66445 L p F P
0 0 0 r
s
.188 0 .528 r
.35681 .54498 m .35761 .53065 L .34804 .52095 L p F P
0 0 0 r
s
.188 0 .528 r
.34887 .50672 m .34804 .52095 L .35761 .53065 L p F P
0 0 0 r
s
.115 0 .563 r
.63991 .53936 m .63938 .52501 L .62321 .53025 L p F P
0 0 0 r
s
.115 0 .563 r
.62321 .53025 m .62367 .54458 L .63991 .53936 L p F P
0 0 0 r
s
.134 0 .891 r
.52565 .49811 m .53423 .50794 L .55012 .50263 L p F P
0 0 0 r
s
.134 0 .891 r
.53423 .50794 m .52565 .49811 L .50979 .50345 L p F P
0 0 0 r
s
.115 0 .563 r
.5921 .58392 m .59179 .56936 L .57577 .57447 L p F P
0 0 0 r
s
.115 0 .563 r
.57577 .57447 m .576 .58901 L .5921 .58392 L p F P
0 0 0 r
s
.134 0 .891 r
.56611 .49729 m .57446 .50713 L .59048 .50181 L p F P
0 0 0 r
s
.134 0 .891 r
.57446 .50713 m .56611 .49729 L .55012 .50263 L p F P
0 0 0 r
s
.115 0 .563 r
.54426 .62851 m .54418 .61373 L .52829 .61871 L p F P
0 0 0 r
s
.115 0 .563 r
.52829 .61871 m .5283 .63346 L .54426 .62851 L p F P
0 0 0 r
s
.188 0 .528 r
.39112 .65551 m .39175 .64064 L .38236 .63156 L p F P
0 0 0 r
s
.188 0 .528 r
.38304 .6168 m .38236 .63156 L .39175 .64064 L p F P
0 0 0 r
s
.115 0 .563 r
.4964 .67312 m .49654 .65813 L .4808 .66297 L p F P
0 0 0 r
s
.115 0 .563 r
.4808 .66297 m .48059 .67793 L .4964 .67312 L p F P
0 0 0 r
s
.134 0 .891 r
.33925 .49688 m .34887 .50672 L .36421 .5014 L p F P
0 0 0 r
s
.188 0 .528 r
.34804 .52095 m .34887 .50672 L .33925 .49688 L p F P
0 0 0 r
s
.134 0 .891 r
.6066 .49647 m .61473 .50631 L .63088 .50099 L p F P
0 0 0 r
s
.134 0 .891 r
.61473 .50631 m .6066 .49647 L .59048 .50181 L p F P
0 0 0 r
s
.115 0 .563 r
.44852 .71774 m .44888 .70254 L .43328 .70725 L p F P
0 0 0 r
s
.115 0 .563 r
.43328 .70725 m .43285 .72243 L .44852 .71774 L p F P
0 0 0 r
s
.134 0 .891 r
.37964 .49605 m .38905 .5059 L .40451 .50058 L p F P
0 0 0 r
s
.134 0 .891 r
.38905 .5059 m .37964 .49605 L .36421 .5014 L p F P
0 0 0 r
s
.115 0 .563 r
.67201 .51443 m .67132 .50017 L .65504 .5055 L p F P
0 0 0 r
s
.115 0 .563 r
.65504 .5055 m .65564 .51973 L .67201 .51443 L p F P
0 0 0 r
s
.134 0 .891 r
.64713 .49564 m .65504 .5055 L .67132 .50017 L p F P
0 0 0 r
s
.134 0 .891 r
.65504 .5055 m .64713 .49564 L .63088 .50099 L p F P
0 0 0 r
s
.134 0 .891 r
.42008 .49523 m .42926 .50509 L .44486 .49976 L p F P
0 0 0 r
s
.134 0 .891 r
.42926 .50509 m .42008 .49523 L .40451 .50058 L p F P
0 0 0 r
s
.188 0 .528 r
.38236 .63156 m .38304 .6168 L .3736 .60757 L p F P
0 0 0 r
s
.188 0 .528 r
.37431 .5929 m .3736 .60757 L .38304 .6168 L p F P
0 0 0 r
s
.115 0 .563 r
.62413 .55905 m .62367 .54458 L .60753 .54977 L p F P
0 0 0 r
s
.115 0 .563 r
.60753 .54977 m .60791 .56422 L .62413 .55905 L p F P
0 0 0 r
s
.115 0 .563 r
.57623 .60369 m .576 .58901 L .56 .59407 L p F P
0 0 0 r
s
.115 0 .563 r
.56 .59407 m .56016 .60873 L .57623 .60369 L p F P
0 0 0 r
s
.115 0 .563 r
.52831 .64836 m .5283 .63346 L .51244 .63838 L p F P
0 0 0 r
s
.115 0 .563 r
.51244 .63838 m .51238 .65326 L .52831 .64836 L p F P
0 0 0 r
s
.134 0 .891 r
.46055 .4944 m .46951 .50427 L .48524 .49894 L p F P
0 0 0 r
s
.134 0 .891 r
.46951 .50427 m .46055 .4944 L .44486 .49976 L p F P
0 0 0 r
s
.115 0 .563 r
.48037 .69304 m .48059 .67793 L .46487 .68272 L p F P
0 0 0 r
s
.115 0 .563 r
.46487 .68272 m .46458 .69781 L .48037 .69304 L p F P
0 0 0 r
s
.134 0 .891 r
.50106 .49357 m .50979 .50345 L .52565 .49811 L p F P
0 0 0 r
s
.134 0 .891 r
.50979 .50345 m .50106 .49357 L .48524 .49894 L p F P
0 0 0 r
s
.115 0 .563 r
.4324 .73775 m .43285 .72243 L .41727 .72708 L p F P
0 0 0 r
s
.115 0 .563 r
.41727 .72708 m .41676 .74238 L .4324 .73775 L p F P
0 0 0 r
s
.188 0 .528 r
.41676 .74238 m .41727 .72708 L .40801 .71847 L p F P
0 0 0 r
s
.188 0 .528 r
.40857 .70327 m .40801 .71847 L .41727 .72708 L p F P
0 0 0 r
s
.188 0 .528 r
.3736 .60757 m .37431 .5929 L .36481 .58353 L p F P
0 0 0 r
s
.188 0 .528 r
.36557 .56896 m .36481 .58353 L .37431 .5929 L p F P
0 0 0 r
s
.115 0 .563 r
.65625 .5341 m .65564 .51973 L .63938 .52501 L p F P
0 0 0 r
s
.115 0 .563 r
.63938 .52501 m .63991 .53936 L .65625 .5341 L p F P
0 0 0 r
s
.134 0 .891 r
.54161 .49274 m .55012 .50263 L .56611 .49729 L p F P
0 0 0 r
s
.134 0 .891 r
.55012 .50263 m .54161 .49274 L .52565 .49811 L p F P
0 0 0 r
s
.115 0 .563 r
.6083 .5788 m .60791 .56422 L .59179 .56936 L p F P
0 0 0 r
s
.115 0 .563 r
.59179 .56936 m .5921 .58392 L .6083 .5788 L p F P
0 0 0 r
s
.115 0 .563 r
.56032 .62353 m .56016 .60873 L .54418 .61373 L p F P
0 0 0 r
s
.115 0 .563 r
.54418 .61373 m .54426 .62851 L .56032 .62353 L p F P
0 0 0 r
s
.188 0 .528 r
.36481 .58353 m .36557 .56896 L .35601 .55945 L p F P
0 0 0 r
s
.188 0 .528 r
.35681 .54498 m .35601 .55945 L .36557 .56896 L p F P
0 0 0 r
s
.134 0 .891 r
.5822 .49192 m .59048 .50181 L .6066 .49647 L p F P
0 0 0 r
s
.134 0 .891 r
.59048 .50181 m .5822 .49192 L .56611 .49729 L p F P
0 0 0 r
s
.188 0 .528 r
.40801 .71847 m .40857 .70327 L .39925 .69451 L p F P
0 0 0 r
s
.188 0 .528 r
.39985 .67941 m .39925 .69451 L .40857 .70327 L p F P
0 0 0 r
s
.115 0 .563 r
.51231 .66827 m .51238 .65326 L .49654 .65813 L p F P
0 0 0 r
s
.115 0 .563 r
.49654 .65813 m .4964 .67312 L .51231 .66827 L p F P
0 0 0 r
s
.134 0 .891 r
.35464 .4915 m .36421 .5014 L .37964 .49605 L p F P
0 0 0 r
s
.134 0 .891 r
.36421 .5014 m .35464 .4915 L .33925 .49688 L p F P
0 0 0 r
s
.134 0 .891 r
.62282 .49109 m .63088 .50099 L .64713 .49564 L p F P
0 0 0 r
s
.134 0 .891 r
.63088 .50099 m .62282 .49109 L .6066 .49647 L p F P
0 0 0 r
s
.115 0 .563 r
.46429 .71303 m .46458 .69781 L .44888 .70254 L p F P
0 0 0 r
s
.115 0 .563 r
.44888 .70254 m .44852 .71774 L .46429 .71303 L p F P
0 0 0 r
s
.134 0 .891 r
.39517 .49067 m .40451 .50058 L .42008 .49523 L p F P
0 0 0 r
s
.134 0 .891 r
.40451 .50058 m .39517 .49067 L .37964 .49605 L p F P
0 0 0 r
s
.115 0 .563 r
.68847 .50909 m .6877 .49481 L .67132 .50017 L p F P
0 0 0 r
s
.115 0 .563 r
.67132 .50017 m .67201 .51443 L .68847 .50909 L p F P
0 0 0 r
s
.134 0 .891 r
.66349 .49025 m .67132 .50017 L .6877 .49481 L p F P
0 0 0 r
s
.134 0 .891 r
.67132 .50017 m .66349 .49025 L .64713 .49564 L p F P
0 0 0 r
s
.188 0 .528 r
.39925 .69451 m .39985 .67941 L .39048 .67051 L p F P
0 0 0 r
s
.188 0 .528 r
.39112 .65551 m .39048 .67051 L .39985 .67941 L p F P
0 0 0 r
s
.188 0 .528 r
.35601 .55945 m .35681 .54498 L .34719 .53532 L p F P
0 0 0 r
s
.188 0 .528 r
.34804 .52095 m .34719 .53532 L .35681 .54498 L p F P
0 0 0 r
s
.134 0 .891 r
.43573 .48984 m .44486 .49976 L .46055 .4944 L p F P
0 0 0 r
s
.134 0 .891 r
.44486 .49976 m .43573 .48984 L .42008 .49523 L p F P
0 0 0 r
s
.115 0 .563 r
.64045 .55385 m .63991 .53936 L .62367 .54458 L p F P
0 0 0 r
s
.115 0 .563 r
.62367 .54458 m .62413 .55905 L .64045 .55385 L p F P
0 0 0 r
s
.115 0 .563 r
.59241 .59863 m .5921 .58392 L .576 .58901 L p F P
0 0 0 r
s
.115 0 .563 r
.576 .58901 m .57623 .60369 L .59241 .59863 L p F P
0 0 0 r
s
.115 0 .563 r
.54435 .64343 m .54426 .62851 L .5283 .63346 L p F P
0 0 0 r
s
.115 0 .563 r
.5283 .63346 m .52831 .64836 L .54435 .64343 L p F P
0 0 0 r
s
.134 0 .891 r
.47634 .48901 m .48524 .49894 L .50106 .49357 L p F P
0 0 0 r
s
.134 0 .891 r
.48524 .49894 m .47634 .48901 L .46055 .4944 L p F P
0 0 0 r
s
.115 0 .563 r
.49626 .68825 m .4964 .67312 L .48059 .67793 L p F P
0 0 0 r
s
.115 0 .563 r
.48059 .67793 m .48037 .69304 L .49626 .68825 L p F P
0 0 0 r
s
.188 0 .528 r
.39048 .67051 m .39112 .65551 L .38168 .64646 L p F P
0 0 0 r
s
.188 0 .528 r
.38236 .63156 m .38168 .64646 L .39112 .65551 L p F P
0 0 0 r
s
.188 0 .528 r
.34719 .53532 m .34804 .52095 L .33836 .51114 L p F P
0 0 0 r
s
.188 0 .528 r
.33925 .49688 m .33836 .51114 L .34804 .52095 L p F P
0 0 0 r
s
.134 0 .891 r
.51698 .48817 m .52565 .49811 L .54161 .49274 L p F P
0 0 0 r
s
.134 0 .891 r
.52565 .49811 m .51698 .48817 L .50106 .49357 L p F P
0 0 0 r
s
.115 0 .563 r
.44815 .73309 m .44852 .71774 L .43285 .72243 L p F P
0 0 0 r
s
.115 0 .563 r
.43285 .72243 m .4324 .73775 L .44815 .73309 L p F P
0 0 0 r
s
.115 0 .563 r
.6727 .52882 m .67201 .51443 L .65564 .51973 L p F P
0 0 0 r
s
.115 0 .563 r
.65564 .51973 m .65625 .5341 L .6727 .52882 L p F P
0 0 0 r
s
.134 0 .891 r
.55766 .48734 m .56611 .49729 L .5822 .49192 L p F P
0 0 0 r
s
.134 0 .891 r
.56611 .49729 m .55766 .48734 L .54161 .49274 L p F P
0 0 0 r
s
.115 0 .563 r
.62459 .57365 m .62413 .55905 L .60791 .56422 L p F P
0 0 0 r
s
.115 0 .563 r
.60791 .56422 m .6083 .5788 L .62459 .57365 L p F P
0 0 0 r
s
.188 0 .528 r
.38168 .64646 m .38236 .63156 L .37287 .62237 L p F P
0 0 0 r
s
.188 0 .528 r
.3736 .60757 m .37287 .62237 L .38236 .63156 L p F P
0 0 0 r
s
.134 0 .891 r
.32951 .48692 m .33925 .49688 L .35464 .4915 L p F P
0 0 0 r
s
.188 0 .528 r
.33836 .51114 m .33925 .49688 L .32951 .48692 L p F P
0 0 0 r
s
.134 0 .891 r
.59838 .48651 m .6066 .49647 L .62282 .49109 L p F P
0 0 0 r
s
.134 0 .891 r
.6066 .49647 m .59838 .48651 L .5822 .49192 L p F P
0 0 0 r
s
.115 0 .563 r
.57647 .61851 m .57623 .60369 L .56016 .60873 L p F P
0 0 0 r
s
.115 0 .563 r
.56016 .60873 m .56032 .62353 L .57647 .61851 L p F P
0 0 0 r
s
.115 0 .563 r
.52832 .66339 m .52831 .64836 L .51238 .65326 L p F P
0 0 0 r
s
.115 0 .563 r
.51238 .65326 m .51231 .66827 L .52832 .66339 L p F P
0 0 0 r
s
.134 0 .891 r
.37013 .48609 m .37964 .49605 L .39517 .49067 L p F P
0 0 0 r
s
.134 0 .891 r
.37964 .49605 m .37013 .48609 L .35464 .4915 L p F P
0 0 0 r
s
.134 0 .891 r
.63914 .48567 m .64713 .49564 L .66349 .49025 L p F P
0 0 0 r
s
.134 0 .891 r
.64713 .49564 m .63914 .48567 L .62282 .49109 L p F P
0 0 0 r
s
.115 0 .563 r
.48015 .70829 m .48037 .69304 L .46458 .69781 L p F P
0 0 0 r
s
.115 0 .563 r
.46458 .69781 m .46429 .71303 L .48015 .70829 L p F P
0 0 0 r
s
.188 0 .528 r
.37287 .62237 m .3736 .60757 L .36405 .59823 L p F P
0 0 0 r
s
.188 0 .528 r
.36481 .58353 m .36405 .59823 L .3736 .60757 L p F P
0 0 0 r
s
.134 0 .891 r
.41079 .48525 m .42008 .49523 L .43573 .48984 L p F P
0 0 0 r
s
.134 0 .891 r
.42008 .49523 m .41079 .48525 L .39517 .49067 L p F P
0 0 0 r
s
.115 0 .563 r
.43196 .75322 m .4324 .73775 L .41676 .74238 L p F P
0 0 0 r
s
.115 0 .563 r
.41676 .74238 m .41624 .75782 L .43196 .75322 L p F P
0 0 0 r
s
.188 0 .528 r
.41624 .75782 m .41676 .74238 L .40745 .73381 L p F P
0 0 0 r
s
.188 0 .528 r
.40801 .71847 m .40745 .73381 L .41676 .74238 L p F P
0 0 0 r
s
.115 0 .563 r
.70503 .50372 m .70419 .48942 L .6877 .49481 L p F P
0 0 0 r
s
.115 0 .563 r
.6877 .49481 m .68847 .50909 L .70503 .50372 L p F P
0 0 0 r
s
.134 0 .891 r
.67994 .48484 m .6877 .49481 L .70419 .48942 L p F P
0 0 0 r
s
.134 0 .891 r
.6877 .49481 m .67994 .48484 L .66349 .49025 L p F P
0 0 0 r
s
.115 0 .563 r
.65687 .54861 m .65625 .5341 L .63991 .53936 L p F P
0 0 0 r
s
.115 0 .563 r
.63991 .53936 m .64045 .55385 L .65687 .54861 L p F P
0 0 0 r
s
.134 0 .891 r
.45149 .48442 m .46055 .4944 L .47634 .48901 L p F P
0 0 0 r
s
.134 0 .891 r
.46055 .4944 m .45149 .48442 L .43573 .48984 L p F P
0 0 0 r
s
.115 0 .563 r
.60869 .59353 m .6083 .5788 L .5921 .58392 L p F P
0 0 0 r
s
.115 0 .563 r
.5921 .58392 m .59241 .59863 L .60869 .59353 L p F P
0 0 0 r
s
.115 0 .563 r
.56048 .63847 m .56032 .62353 L .54426 .62851 L p F P
0 0 0 r
s
.115 0 .563 r
.54426 .62851 m .54435 .64343 L .56048 .63847 L p F P
0 0 0 r
s
.134 0 .891 r
.49223 .48358 m .50106 .49357 L .51698 .48817 L p F P
0 0 0 r
s
.134 0 .891 r
.50106 .49357 m .49223 .48358 L .47634 .48901 L p F P
0 0 0 r
s
.188 0 .528 r
.40745 .73381 m .40801 .71847 L .39865 .70976 L p F P
0 0 0 r
s
.188 0 .528 r
.39925 .69451 m .39865 .70976 L .40801 .71847 L p F P
0 0 0 r
s
.188 0 .528 r
.36405 .59823 m .36481 .58353 L .3552 .57405 L p F P
0 0 0 r
s
.188 0 .528 r
.35601 .55945 m .3552 .57405 L .36481 .58353 L p F P
0 0 0 r
s
.115 0 .563 r
.51225 .68343 m .51231 .66827 L .4964 .67312 L p F P
0 0 0 r
s
.115 0 .563 r
.4964 .67312 m .49626 .68825 L .51225 .68343 L p F P
0 0 0 r
s
.134 0 .891 r
.533 .48274 m .54161 .49274 L .55766 .48734 L p F P
0 0 0 r
s
.134 0 .891 r
.54161 .49274 m .533 .48274 L .51698 .48817 L p F P
0 0 0 r
s
.115 0 .563 r
.46399 .72841 m .46429 .71303 L .44852 .71774 L p F P
0 0 0 r
s
.115 0 .563 r
.44852 .71774 m .44815 .73309 L .46399 .72841 L p F P
0 0 0 r
s
.115 0 .563 r
.68924 .5235 m .68847 .50909 L .67201 .51443 L p F P
0 0 0 r
s
.115 0 .563 r
.67201 .51443 m .6727 .52882 L .68924 .5235 L p F P
0 0 0 r
s
.134 0 .891 r
.57382 .48191 m .5822 .49192 L .59838 .48651 L p F P
0 0 0 r
s
.134 0 .891 r
.5822 .49192 m .57382 .48191 L .55766 .48734 L p F P
0 0 0 r
s
.188 0 .528 r
.39865 .70976 m .39925 .69451 L .38983 .68566 L p F P
0 0 0 r
s
.188 0 .528 r
.39048 .67051 m .38983 .68566 L .39925 .69451 L p F P
0 0 0 r
s
.188 0 .528 r
.3552 .57405 m .35601 .55945 L .34634 .54982 L p F P
0 0 0 r
s
.188 0 .528 r
.34719 .53532 m .34634 .54982 L .35601 .55945 L p F P
0 0 0 r
s
.115 0 .563 r
.64099 .56847 m .64045 .55385 L .62413 .55905 L p F P
0 0 0 r
s
.115 0 .563 r
.62413 .55905 m .62459 .57365 L .64099 .56847 L p F P
0 0 0 r
s
.134 0 .891 r
.34496 .48149 m .35464 .4915 L .37013 .48609 L p F P
0 0 0 r
s
.134 0 .891 r
.35464 .4915 m .34496 .48149 L .32951 .48692 L p F P
0 0 0 r
s
.134 0 .891 r
.61467 .48107 m .62282 .49109 L .63914 .48567 L p F P
0 0 0 r
s
.134 0 .891 r
.62282 .49109 m .61467 .48107 L .59838 .48651 L p F P
0 0 0 r
s
.115 0 .563 r
.59272 .61347 m .59241 .59863 L .57623 .60369 L p F P
0 0 0 r
s
.115 0 .563 r
.57623 .60369 m .57647 .61851 L .59272 .61347 L p F P
0 0 0 r
s
.115 0 .563 r
.54443 .65849 m .54435 .64343 L .52831 .64836 L p F P
0 0 0 r
s
.115 0 .563 r
.52831 .64836 m .52832 .66339 L .54443 .65849 L p F P
0 0 0 r
s
.134 0 .891 r
.38572 .48065 m .39517 .49067 L .41079 .48525 L p F P
0 0 0 r
s
.134 0 .891 r
.39517 .49067 m .38572 .48065 L .37013 .48609 L p F P
0 0 0 r
s
.134 0 .891 r
.65556 .48023 m .66349 .49025 L .67994 .48484 L p F P
0 0 0 r
s
.134 0 .891 r
.66349 .49025 m .65556 .48023 L .63914 .48567 L p F P
0 0 0 r
s
.115 0 .563 r
.49612 .70353 m .49626 .68825 L .48037 .69304 L p F P
0 0 0 r
s
.115 0 .563 r
.48037 .69304 m .48015 .70829 L .49612 .70353 L p F P
0 0 0 r
s
.188 0 .528 r
.38983 .68566 m .39048 .67051 L .381 .66151 L p F P
0 0 0 r
s
.188 0 .528 r
.38168 .64646 m .381 .66151 L .39048 .67051 L p F P
0 0 0 r
s
.188 0 .528 r
.34634 .54982 m .34719 .53532 L .33747 .52555 L p F P
0 0 0 r
s
.188 0 .528 r
.33836 .51114 m .33747 .52555 L .34719 .53532 L p F P
0 0 0 r
s
.134 0 .891 r
.42651 .47981 m .43573 .48984 L .45149 .48442 L p F P
0 0 0 r
s
.134 0 .891 r
.43573 .48984 m .42651 .47981 L .41079 .48525 L p F P
0 0 0 r
s
.115 0 .563 r
.44778 .74859 m .44815 .73309 L .4324 .73775 L p F P
0 0 0 r
s
.115 0 .563 r
.4324 .73775 m .43196 .75322 L .44778 .74859 L p F P
0 0 0 r
s
.115 0 .563 r
.7217 .49831 m .72078 .484 L .70419 .48942 L p F P
0 0 0 r
s
.115 0 .563 r
.70419 .48942 m .70503 .50372 L .7217 .49831 L p F P
0 0 0 r
s
.134 0 .891 r
.6965 .47938 m .70419 .48942 L .72078 .484 L p F P
0 0 0 r
s
.134 0 .891 r
.70419 .48942 m .6965 .47938 L .67994 .48484 L p F P
0 0 0 r
s
.115 0 .563 r
.6734 .54334 m .6727 .52882 L .65625 .5341 L p F P
0 0 0 r
s
.115 0 .563 r
.65625 .5341 m .65687 .54861 L .6734 .54334 L p F P
0 0 0 r
s
.134 0 .891 r
.46734 .47896 m .47634 .48901 L .49223 .48358 L p F P
0 0 0 r
s
.134 0 .891 r
.47634 .48901 m .46734 .47896 L .45149 .48442 L p F P
0 0 0 r
s
.115 0 .563 r
.62506 .5884 m .62459 .57365 L .6083 .5788 L p F P
0 0 0 r
s
.115 0 .563 r
.6083 .5788 m .60869 .59353 L .62506 .5884 L p F P
0 0 0 r
s
.188 0 .528 r
.381 .66151 m .38168 .64646 L .37214 .63732 L p F P
0 0 0 r
s
.188 0 .528 r
.37287 .62237 m .37214 .63732 L .38168 .64646 L p F P
0 0 0 r
s
.188 0 .528 r
.33747 .52555 m .33836 .51114 L .32857 .50123 L p F P
0 0 0 r
s
.188 0 .528 r
.32951 .48692 m .32857 .50123 L .33836 .51114 L p F P
0 0 0 r
s
.115 0 .563 r
.57671 .63348 m .57647 .61851 L .56032 .62353 L p F P
0 0 0 r
s
.115 0 .563 r
.56032 .62353 m .56048 .63847 L .57671 .63348 L p F P
0 0 0 r
s
.134 0 .891 r
.50821 .47812 m .51698 .48817 L .533 .48274 L p F P
0 0 0 r
s
.134 0 .891 r
.51698 .48817 m .50821 .47812 L .49223 .48358 L p F P
0 0 0 r
s
.115 0 .563 r
.52833 .67857 m .52832 .66339 L .51231 .66827 L p F P
0 0 0 r
s
.115 0 .563 r
.51231 .66827 m .51225 .68343 L .52833 .67857 L p F P
0 0 0 r
s
.115 0 .563 r
.47993 .72369 m .48015 .70829 L .46429 .71303 L p F P
0 0 0 r
s
.115 0 .563 r
.46429 .71303 m .46399 .72841 L .47993 .72369 L p F P
0 0 0 r
s
.134 0 .891 r
.54912 .47728 m .55766 .48734 L .57382 .48191 L p F P
0 0 0 r
s
.134 0 .891 r
.55766 .48734 m .54912 .47728 L .533 .48274 L p F P
0 0 0 r
s
.115 0 .563 r
.43151 .76883 m .43196 .75322 L .41624 .75782 L p F P
0 0 0 r
s
.115 0 .563 r
.41624 .75782 m .41571 .77341 L .43151 .76883 L p F P
0 0 0 r
s
.188 0 .528 r
.41571 .77341 m .41624 .75782 L .40689 .7493 L p F P
0 0 0 r
s
.188 0 .528 r
.40745 .73381 m .40689 .7493 L .41624 .75782 L p F P
0 0 0 r
s
.188 0 .528 r
.37214 .63732 m .37287 .62237 L .36327 .61308 L p F P
0 0 0 r
s
.188 0 .528 r
.36405 .59823 m .36327 .61308 L .37287 .62237 L p F P
0 0 0 r
s
.134 0 .891 r
.31966 .47686 m .32951 .48692 L .34496 .48149 L p F P
0 0 0 r
s
.188 0 .528 r
.32857 .50123 m .32951 .48692 L .31966 .47686 L p F P
0 0 0 r
s
.134 0 .891 r
.59007 .47644 m .59838 .48651 L .61467 .48107 L p F P
0 0 0 r
s
.134 0 .891 r
.59838 .48651 m .59007 .47644 L .57382 .48191 L p F P
0 0 0 r
s
.115 0 .563 r
.70589 .51814 m .70503 .50372 L .68847 .50909 L p F P
0 0 0 r
s
.115 0 .563 r
.68847 .50909 m .68924 .5235 L .70589 .51814 L p F P
0 0 0 r
s
.115 0 .563 r
.6575 .56326 m .65687 .54861 L .64045 .55385 L p F P
0 0 0 r
s
.115 0 .563 r
.64045 .55385 m .64099 .56847 L .6575 .56326 L p F P
0 0 0 r
s
.134 0 .891 r
.36051 .47601 m .37013 .48609 L .38572 .48065 L p F P
0 0 0 r
s
.134 0 .891 r
.37013 .48609 m .36051 .47601 L .34496 .48149 L p F P
0 0 0 r
s
.134 0 .891 r
.63106 .47559 m .63914 .48567 L .65556 .48023 L p F P
0 0 0 r
s
.134 0 .891 r
.63914 .48567 m .63106 .47559 L .61467 .48107 L p F P
0 0 0 r
s
.115 0 .563 r
.60908 .60839 m .60869 .59353 L .59241 .59863 L p F P
0 0 0 r
s
.115 0 .563 r
.59241 .59863 m .59272 .61347 L .60908 .60839 L p F P
0 0 0 r
s
.188 0 .528 r
.36327 .61308 m .36405 .59823 L .35439 .58879 L p F P
0 0 0 r
s
.188 0 .528 r
.3552 .57405 m .35439 .58879 L .36405 .59823 L p F P
0 0 0 r
s
.115 0 .563 r
.56064 .65355 m .56048 .63847 L .54435 .64343 L p F P
0 0 0 r
s
.115 0 .563 r
.54435 .64343 m .54443 .65849 L .56064 .65355 L p F P
0 0 0 r
s
.134 0 .891 r
.4014 .47517 m .41079 .48525 L .42651 .47981 L p F P
0 0 0 r
s
.134 0 .891 r
.41079 .48525 m .4014 .47517 L .38572 .48065 L p F P
0 0 0 r
s
.188 0 .528 r
.40689 .7493 m .40745 .73381 L .39804 .72515 L p F P
0 0 0 r
s
.188 0 .528 r
.39865 .70976 m .39804 .72515 L .40745 .73381 L p F P
0 0 0 r
s
.134 0 .891 r
.67209 .47475 m .67994 .48484 L .6965 .47938 L p F P
0 0 0 r
s
.134 0 .891 r
.67994 .48484 m .67209 .47475 L .65556 .48023 L p F P
0 0 0 r
s
.115 0 .563 r
.51218 .69873 m .51225 .68343 L .49626 .68825 L p F P
0 0 0 r
s
.115 0 .563 r
.49626 .68825 m .49612 .70353 L .51218 .69873 L p F P
0 0 0 r
s
.134 0 .891 r
.44233 .47432 m .45149 .48442 L .46734 .47896 L p F P
0 0 0 r
s
.134 0 .891 r
.45149 .48442 m .44233 .47432 L .42651 .47981 L p F P
0 0 0 r
s
.115 0 .563 r
.46369 .74393 m .46399 .72841 L .44815 .73309 L p F P
0 0 0 r
s
.115 0 .563 r
.44815 .73309 m .44778 .74859 L .46369 .74393 L p F P
0 0 0 r
s
.115 0 .563 r
.73848 .49287 m .73747 .47854 L .72078 .484 L p F P
0 0 0 r
s
.115 0 .563 r
.72078 .484 m .7217 .49831 L .73848 .49287 L p F P
0 0 0 r
s
.134 0 .891 r
.71315 .4739 m .72078 .484 L .73747 .47854 L p F P
0 0 0 r
s
.134 0 .891 r
.72078 .484 m .71315 .4739 L .6965 .47938 L p F P
0 0 0 r
s
.115 0 .563 r
.69002 .53804 m .68924 .5235 L .6727 .52882 L p F P
0 0 0 r
s
.115 0 .563 r
.6727 .52882 m .6734 .54334 L .69002 .53804 L p F P
0 0 0 r
s
.134 0 .891 r
.48329 .47348 m .49223 .48358 L .50821 .47812 L p F P
0 0 0 r
s
.134 0 .891 r
.49223 .48358 m .48329 .47348 L .46734 .47896 L p F P
0 0 0 r
s
.188 0 .528 r
.39804 .72515 m .39865 .70976 L .38918 .70095 L p F P
0 0 0 r
s
.188 0 .528 r
.38983 .68566 m .38918 .70095 L .39865 .70976 L p F P
0 0 0 r
s
.188 0 .528 r
.35439 .58879 m .3552 .57405 L .34548 .56446 L p F P
0 0 0 r
s
.188 0 .528 r
.34634 .54982 m .34548 .56446 L .3552 .57405 L p F P
0 0 0 r
s
.115 0 .563 r
.64154 .58324 m .64099 .56847 L .62459 .57365 L p F P
0 0 0 r
s
.115 0 .563 r
.62459 .57365 m .62506 .5884 L .64154 .58324 L p F P
0 0 0 r
s
.115 0 .563 r
.59304 .62845 m .59272 .61347 L .57647 .61851 L p F P
0 0 0 r
s
.115 0 .563 r
.57647 .61851 m .57671 .63348 L .59304 .62845 L p F P
0 0 0 r
s
.134 0 .891 r
.5243 .47263 m .533 .48274 L .54912 .47728 L p F P
0 0 0 r
s
.134 0 .891 r
.533 .48274 m .5243 .47263 L .50821 .47812 L p F P
0 0 0 r
s
.115 0 .563 r
.54452 .67369 m .54443 .65849 L .52832 .66339 L p F P
0 0 0 r
s
.115 0 .563 r
.52832 .66339 m .52833 .67857 L .54452 .67369 L p F P
0 0 0 r
s
.134 0 .891 r
.56534 .47178 m .57382 .48191 L .59007 .47644 L p F P
0 0 0 r
s
.134 0 .891 r
.57382 .48191 m .56534 .47178 L .54912 .47728 L p F P
0 0 0 r
s
.115 0 .563 r
.49597 .71895 m .49612 .70353 L .48015 .70829 L p F P
0 0 0 r
s
.115 0 .563 r
.48015 .70829 m .47993 .72369 L .49597 .71895 L p F P
0 0 0 r
s
.188 0 .528 r
.38918 .70095 m .38983 .68566 L .3803 .6767 L p F P
0 0 0 r
s
.188 0 .528 r
.381 .66151 m .3803 .6767 L .38983 .68566 L p F P
0 0 0 r
s
.188 0 .528 r
.34548 .56446 m .34634 .54982 L .33656 .54009 L p F P
0 0 0 r
s
.188 0 .528 r
.33747 .52555 m .33656 .54009 L .34634 .54982 L p F P
0 0 0 r
s
.115 0 .563 r
.4474 .76423 m .44778 .74859 L .43196 .75322 L p F P
0 0 0 r
s
.115 0 .563 r
.43196 .75322 m .43151 .76883 L .4474 .76423 L p F P
0 0 0 r
s
.134 0 .891 r
.33517 .47136 m .34496 .48149 L .36051 .47601 L p F P
0 0 0 r
s
.134 0 .891 r
.34496 .48149 m .33517 .47136 L .31966 .47686 L p F P
0 0 0 r
s
.115 0 .563 r
.72264 .51276 m .7217 .49831 L .70503 .50372 L p F P
0 0 0 r
s
.115 0 .563 r
.70503 .50372 m .70589 .51814 L .72264 .51276 L p F P
0 0 0 r
s
.134 0 .891 r
.60643 .47093 m .61467 .48107 L .63106 .47559 L p F P
0 0 0 r
s
.134 0 .891 r
.61467 .48107 m .60643 .47093 L .59007 .47644 L p F P
0 0 0 r
s
.115 0 .563 r
.6741 .55801 m .6734 .54334 L .65687 .54861 L p F P
0 0 0 r
s
.115 0 .563 r
.65687 .54861 m .6575 .56326 L .6741 .55801 L p F P
0 0 0 r
s
.134 0 .891 r
.37616 .47051 m .38572 .48065 L .4014 .47517 L p F P
0 0 0 r
s
.134 0 .891 r
.38572 .48065 m .37616 .47051 L .36051 .47601 L p F P
0 0 0 r
s
.134 0 .891 r
.64755 .47008 m .65556 .48023 L .67209 .47475 L p F P
0 0 0 r
s
.134 0 .891 r
.65556 .48023 m .64755 .47008 L .63106 .47559 L p F P
0 0 0 r
s
.115 0 .563 r
.62554 .60329 m .62506 .5884 L .60869 .59353 L p F P
0 0 0 r
s
.115 0 .563 r
.60869 .59353 m .60908 .60839 L .62554 .60329 L p F P
0 0 0 r
s
.188 0 .528 r
.3803 .6767 m .381 .66151 L .37141 .65241 L p F P
0 0 0 r
s
.188 0 .528 r
.37214 .63732 m .37141 .65241 L .381 .66151 L p F P
0 0 0 r
s
.188 0 .528 r
.33656 .54009 m .33747 .52555 L .32763 .51566 L p F P
0 0 0 r
s
.188 0 .528 r
.32857 .50123 m .32763 .51566 L .33747 .52555 L p F P
0 0 0 r
s
.115 0 .563 r
.57695 .64858 m .57671 .63348 L .56048 .63847 L p F P
0 0 0 r
s
.115 0 .563 r
.56048 .63847 m .56064 .65355 L .57695 .64858 L p F P
0 0 0 r
s
.134 0 .891 r
.41718 .46966 m .42651 .47981 L .44233 .47432 L p F P
0 0 0 r
s
.134 0 .891 r
.42651 .47981 m .41718 .46966 L .4014 .47517 L p F P
0 0 0 r
s
.134 0 .891 r
.68871 .46923 m .6965 .47938 L .71315 .4739 L p F P
0 0 0 r
s
.134 0 .891 r
.6965 .47938 m .68871 .46923 L .67209 .47475 L p F P
0 0 0 r
s
.115 0 .563 r
.52834 .6939 m .52833 .67857 L .51225 .68343 L p F P
0 0 0 r
s
.115 0 .563 r
.51225 .68343 m .51218 .69873 L .52834 .6939 L p F P
0 0 0 r
s
.115 0 .563 r
.47971 .73924 m .47993 .72369 L .46399 .72841 L p F P
0 0 0 r
s
.115 0 .563 r
.46399 .72841 m .46369 .74393 L .47971 .73924 L p F P
0 0 0 r
s
.134 0 .891 r
.45824 .46881 m .46734 .47896 L .48329 .47348 L p F P
0 0 0 r
s
.134 0 .891 r
.46734 .47896 m .45824 .46881 L .44233 .47432 L p F P
0 0 0 r
s
.115 0 .563 r
.75535 .4874 m .75426 .47305 L .73747 .47854 L p F P
0 0 0 r
s
.115 0 .563 r
.73747 .47854 m .73848 .49287 L .75535 .4874 L p F P
0 0 0 r
s
.134 0 .891 r
.72991 .46838 m .73747 .47854 L .75426 .47305 L p F P
0 0 0 r
s
.134 0 .891 r
.73747 .47854 m .72991 .46838 L .71315 .4739 L p F P
0 0 0 r
s
.115 0 .563 r
.43105 .7846 m .43151 .76883 L .41571 .77341 L p F P
0 0 0 r
s
.115 0 .563 r
.41571 .77341 m .41518 .78915 L .43105 .7846 L p F P
0 0 0 r
s
.188 0 .528 r
.41518 .78915 m .41571 .77341 L .40631 .76494 L p F P
0 0 0 r
s
.188 0 .528 r
.40689 .7493 m .40631 .76494 L .41571 .77341 L p F P
0 0 0 r
s
.188 0 .528 r
.37141 .65241 m .37214 .63732 L .36249 .62807 L p F P
0 0 0 r
s
.188 0 .528 r
.36327 .61308 m .36249 .62807 L .37214 .63732 L p F P
0 0 0 r
s
.188 0 .528 r
.32763 .51566 m .32857 .50123 L .31867 .49119 L p F P
0 0 0 r
s
.188 0 .528 r
.31966 .47686 m .31867 .49119 L .32857 .50123 L p F P
0 0 0 r
s
.115 0 .563 r
.70675 .53271 m .70589 .51814 L .68924 .5235 L p F P
0 0 0 r
s
.115 0 .563 r
.68924 .5235 m .69002 .53804 L .70675 .53271 L p F P
0 0 0 r
s
.134 0 .891 r
.49934 .46795 m .50821 .47812 L .5243 .47263 L p F P
0 0 0 r
s
.134 0 .891 r
.50821 .47812 m .49934 .46795 L .48329 .47348 L p F P
0 0 0 r
s
.115 0 .563 r
.65813 .57805 m .6575 .56326 L .64099 .56847 L p F P
0 0 0 r
s
.115 0 .563 r
.64099 .56847 m .64154 .58324 L .65813 .57805 L p F P
0 0 0 r
s
.115 0 .563 r
.60948 .6234 m .60908 .60839 L .59272 .61347 L p F P
0 0 0 r
s
.115 0 .563 r
.59272 .61347 m .59304 .62845 L .60948 .6234 L p F P
0 0 0 r
s
.134 0 .891 r
.54048 .4671 m .54912 .47728 L .56534 .47178 L p F P
0 0 0 r
s
.134 0 .891 r
.54912 .47728 m .54048 .4671 L .5243 .47263 L p F P
0 0 0 r
s
.188 0 .528 r
.36249 .62807 m .36327 .61308 L .35356 .60368 L p F P
0 0 0 r
s
.188 0 .528 r
.35439 .58879 m .35356 .60368 L .36327 .61308 L p F P
0 0 0 r
s
.115 0 .563 r
.56081 .66878 m .56064 .65355 L .54443 .65849 L p F P
0 0 0 r
s
.115 0 .563 r
.54443 .65849 m .54452 .67369 L .56081 .66878 L p F P
0 0 0 r
s
.188 0 .528 r
.40631 .76494 m .40689 .7493 L .39743 .74069 L p F P
0 0 0 r
s
.188 0 .528 r
.39804 .72515 m .39743 .74069 L .40689 .7493 L p F P
0 0 0 r
s
.134 0 .891 r
.3097 .46667 m .31966 .47686 L .33517 .47136 L p F P
0 0 0 r
s
.188 0 .528 r
.31867 .49119 m .31966 .47686 L .3097 .46667 L p F P
0 0 0 r
s
.134 0 .891 r
.58166 .46625 m .59007 .47644 L .60643 .47093 L p F P
0 0 0 r
s
.134 0 .891 r
.59007 .47644 m .58166 .46625 L .56534 .47178 L p F P
0 0 0 r
s
.115 0 .563 r
.51211 .71418 m .51218 .69873 L .49612 .70353 L p F P
0 0 0 r
s
.115 0 .563 r
.49612 .70353 m .49597 .71895 L .51211 .71418 L p F P
0 0 0 r
s
.115 0 .563 r
.46339 .7596 m .46369 .74393 L .44778 .74859 L p F P
0 0 0 r
s
.115 0 .563 r
.44778 .74859 m .4474 .76423 L .46339 .7596 L p F P
0 0 0 r
s
.134 0 .891 r
.35078 .46582 m .36051 .47601 L .37616 .47051 L p F P
0 0 0 r
s
.134 0 .891 r
.36051 .47601 m .35078 .46582 L .33517 .47136 L p F P
0 0 0 r
s
.115 0 .563 r
.73949 .50734 m .73848 .49287 L .7217 .49831 L p F P
0 0 0 r
s
.115 0 .563 r
.7217 .49831 m .72264 .51276 L .73949 .50734 L p F P
0 0 0 r
s
.134 0 .891 r
.62288 .46539 m .63106 .47559 L .64755 .47008 L p F P
0 0 0 r
s
.134 0 .891 r
.63106 .47559 m .62288 .46539 L .60643 .47093 L p F P
0 0 0 r
s
.115 0 .563 r
.69081 .55273 m .69002 .53804 L .6734 .54334 L p F P
0 0 0 r
s
.115 0 .563 r
.6734 .54334 m .6741 .55801 L .69081 .55273 L p F P
0 0 0 r
s
.134 0 .891 r
.3919 .46497 m .4014 .47517 L .41718 .46966 L p F P
0 0 0 r
s
.134 0 .891 r
.4014 .47517 m .3919 .46497 L .37616 .47051 L p F P
0 0 0 r
s
.188 0 .528 r
.39743 .74069 m .39804 .72515 L .38852 .71638 L p F P
0 0 0 r
s
.188 0 .528 r
.38918 .70095 m .38852 .71638 L .39804 .72515 L p F P
0 0 0 r
s
.188 0 .528 r
.35356 .60368 m .35439 .58879 L .34462 .57925 L p F P
0 0 0 r
s
.188 0 .528 r
.34548 .56446 m .34462 .57925 L .35439 .58879 L p F P
0 0 0 r
s
.134 0 .891 r
.66414 .46454 m .67209 .47475 L .68871 .46923 L p F P
0 0 0 r
s
.134 0 .891 r
.67209 .47475 m .66414 .46454 L .64755 .47008 L p F P
0 0 0 r
s
.115 0 .563 r
.6421 .59815 m .64154 .58324 L .62506 .5884 L p F P
0 0 0 r
s
.115 0 .563 r
.62506 .5884 m .62554 .60329 L .6421 .59815 L p F P
0 0 0 r
s
.115 0 .563 r
.59336 .64358 m .59304 .62845 L .57671 .63348 L p F P
0 0 0 r
s
.115 0 .563 r
.57671 .63348 m .57695 .64858 L .59336 .64358 L p F P
0 0 0 r
s
.134 0 .891 r
.43306 .46411 m .44233 .47432 L .45824 .46881 L p F P
0 0 0 r
s
.134 0 .891 r
.44233 .47432 m .43306 .46411 L .41718 .46966 L p F P
0 0 0 r
s
.134 0 .891 r
.70544 .46368 m .71315 .4739 L .72991 .46838 L p F P
0 0 0 r
s
.134 0 .891 r
.71315 .4739 m .70544 .46368 L .68871 .46923 L p F P
0 0 0 r
s
.115 0 .563 r
.54461 .68904 m .54452 .67369 L .52833 .67857 L p F P
0 0 0 r
s
.115 0 .563 r
.52833 .67857 m .52834 .6939 L .54461 .68904 L p F P
0 0 0 r
s
.188 0 .528 r
.38852 .71638 m .38918 .70095 L .3796 .69203 L p F P
0 0 0 r
s
.188 0 .528 r
.3803 .6767 m .3796 .69203 L .38918 .70095 L p F P
0 0 0 r
s
.134 0 .891 r
.47426 .46325 m .48329 .47348 L .49934 .46795 L p F P
0 0 0 r
s
.134 0 .891 r
.48329 .47348 m .47426 .46325 L .45824 .46881 L p F P
0 0 0 r
s
.115 0 .563 r
.49583 .73452 m .49597 .71895 L .47993 .72369 L p F P
0 0 0 r
s
.115 0 .563 r
.47993 .72369 m .47971 .73924 L .49583 .73452 L p F P
0 0 0 r
s
.188 0 .528 r
.34462 .57925 m .34548 .56446 L .33565 .55477 L p F P
0 0 0 r
s
.188 0 .528 r
.33656 .54009 m .33565 .55477 L .34548 .56446 L p F P
0 0 0 r
s
.115 0 .563 r
.77233 .48189 m .77116 .46753 L .75426 .47305 L p F P
0 0 0 r
s
.115 0 .563 r
.75426 .47305 m .75535 .4874 L .77233 .48189 L p F P
0 0 0 r
s
.134 0 .891 r
.74678 .46283 m .75426 .47305 L .77116 .46753 L p F P
0 0 0 r
s
.134 0 .891 r
.75426 .47305 m .74678 .46283 L .72991 .46838 L p F P
0 0 0 r
s
.115 0 .563 r
.44702 .78002 m .4474 .76423 L .43151 .76883 L p F P
0 0 0 r
s
.115 0 .563 r
.43151 .76883 m .43105 .7846 L .44702 .78002 L p F P
0 0 0 r
s
.134 0 .891 r
.51549 .4624 m .5243 .47263 L .54048 .4671 L p F P
0 0 0 r
s
.134 0 .891 r
.5243 .47263 m .51549 .4624 L .49934 .46795 L p F P
0 0 0 r
s
.115 0 .563 r
.72358 .52735 m .72264 .51276 L .70589 .51814 L p F P
0 0 0 r
s
.115 0 .563 r
.70589 .51814 m .70675 .53271 L .72358 .52735 L p F P
0 0 0 r
s
.115 0 .563 r
.67481 .57282 m .6741 .55801 L .6575 .56326 L p F P
0 0 0 r
s
.115 0 .563 r
.6575 .56326 m .65813 .57805 L .67481 .57282 L p F P
0 0 0 r
s
.115 0 .563 r
.62601 .61832 m .62554 .60329 L .60908 .60839 L p F P
0 0 0 r
s
.115 0 .563 r
.60908 .60839 m .60948 .6234 L .62601 .61832 L p F P
0 0 0 r
s
.134 0 .891 r
.55677 .46154 m .56534 .47178 L .58166 .46625 L p F P
0 0 0 r
s
.134 0 .891 r
.56534 .47178 m .55677 .46154 L .54048 .4671 L p F P
0 0 0 r
s
.188 0 .528 r
.3796 .69203 m .3803 .6767 L .37066 .66764 L p F P
0 0 0 r
s
.188 0 .528 r
.37141 .65241 m .37066 .66764 L .3803 .6767 L p F P
0 0 0 r
s
.188 0 .528 r
.33565 .55477 m .33656 .54009 L .32667 .53024 L p F P
0 0 0 r
s
.188 0 .528 r
.32763 .51566 m .32667 .53024 L .33656 .54009 L p F P
0 0 0 r
s
.115 0 .563 r
.57719 .66383 m .57695 .64858 L .56064 .65355 L p F P
0 0 0 r
s
.115 0 .563 r
.56064 .65355 m .56081 .66878 L .57719 .66383 L p F P
0 0 0 r
s
.134 0 .891 r
.32527 .46111 m .33517 .47136 L .35078 .46582 L p F P
0 0 0 r
s
.134 0 .891 r
.33517 .47136 m .32527 .46111 L .3097 .46667 L p F P
0 0 0 r
s
.134 0 .891 r
.59809 .46068 m .60643 .47093 L .62288 .46539 L p F P
0 0 0 r
s
.134 0 .891 r
.60643 .47093 m .59809 .46068 L .58166 .46625 L p F P
0 0 0 r
s
.115 0 .563 r
.52835 .70937 m .52834 .6939 L .51218 .69873 L p F P
0 0 0 r
s
.115 0 .563 r
.51218 .69873 m .51211 .71418 L .52835 .70937 L p F P
0 0 0 r
s
.115 0 .563 r
.47948 .75494 m .47971 .73924 L .46369 .74393 L p F P
0 0 0 r
s
.115 0 .563 r
.46369 .74393 m .46339 .7596 L .47948 .75494 L p F P
0 0 0 r
s
.134 0 .891 r
.36649 .46025 m .37616 .47051 L .3919 .46497 L p F P
0 0 0 r
s
.134 0 .891 r
.37616 .47051 m .36649 .46025 L .35078 .46582 L p F P
0 0 0 r
s
.188 0 .528 r
.37066 .66764 m .37141 .65241 L .36171 .6432 L p F P
0 0 0 r
s
.188 0 .528 r
.36249 .62807 m .36171 .6432 L .37141 .65241 L p F P
0 0 0 r
s
.115 0 .563 r
.75646 .50189 m .75535 .4874 L .73848 .49287 L p F P
0 0 0 r
s
.115 0 .563 r
.73848 .49287 m .73949 .50734 L .75646 .50189 L p F P
0 0 0 r
s
.134 0 .891 r
.63944 .45982 m .64755 .47008 L .66414 .46454 L p F P
0 0 0 r
s
.134 0 .891 r
.64755 .47008 m .63944 .45982 L .62288 .46539 L p F P
0 0 0 r
s
.115 0 .563 r
.43059 .80052 m .43105 .7846 L .41518 .78915 L p F P
0 0 0 r
s
.115 0 .563 r
.41518 .78915 m .41465 .80504 L .43059 .80052 L p F P
0 0 0 r
s
.188 0 .528 r
.41465 .80504 m .41518 .78915 L .40574 .78073 L p F P
0 0 0 r
s
.188 0 .528 r
.40631 .76494 m .40574 .78073 L .41518 .78915 L p F P
0 0 0 r
s
.188 0 .528 r
.32667 .53024 m .32763 .51566 L .31767 .50566 L p F P
0 0 0 r
s
.188 0 .528 r
.31867 .49119 m .31767 .50566 L .32763 .51566 L p F P
0 0 0 r
s
.115 0 .563 r
.70762 .54742 m .70675 .53271 L .69002 .53804 L p F P
0 0 0 r
s
.115 0 .563 r
.69002 .53804 m .69081 .55273 L .70762 .54742 L p F P
0 0 0 r
s
.134 0 .891 r
.40774 .45939 m .41718 .46966 L .43306 .46411 L p F P
0 0 0 r
s
.134 0 .891 r
.41718 .46966 m .40774 .45939 L .3919 .46497 L p F P
0 0 0 r
s
.134 0 .891 r
.68084 .45896 m .68871 .46923 L .70544 .46368 L p F P
0 0 0 r
s
.134 0 .891 r
.68871 .46923 m .68084 .45896 L .66414 .46454 L p F P
0 0 0 r
s
.115 0 .563 r
.65876 .59297 m .65813 .57805 L .64154 .58324 L p F P
0 0 0 r
s
.115 0 .563 r
.64154 .58324 m .6421 .59815 L .65876 .59297 L p F P
0 0 0 r
s
.115 0 .563 r
.60988 .63855 m .60948 .6234 L .59304 .62845 L p F P
0 0 0 r
s
.115 0 .563 r
.59304 .62845 m .59336 .64358 L .60988 .63855 L p F P
0 0 0 r
s
.134 0 .891 r
.44904 .45853 m .45824 .46881 L .47426 .46325 L p F P
0 0 0 r
s
.134 0 .891 r
.45824 .46881 m .44904 .45853 L .43306 .46411 L p F P
0 0 0 r
s
.134 0 .891 r
.72228 .4581 m .72991 .46838 L .74678 .46283 L p F P
0 0 0 r
s
.134 0 .891 r
.72991 .46838 m .72228 .4581 L .70544 .46368 L p F P
0 0 0 r
s
.188 0 .528 r
.36171 .6432 m .36249 .62807 L .35273 .61871 L p F P
0 0 0 r
s
.188 0 .528 r
.35356 .60368 m .35273 .61871 L .36249 .62807 L p F P
0 0 0 r
s
.188 0 .528 r
.31767 .50566 m .31867 .49119 L .30866 .48104 L p F P
0 0 0 r
s
.188 0 .528 r
.3097 .46667 m .30866 .48104 L .31867 .49119 L p F P
0 0 0 r
s
.115 0 .563 r
.56097 .68415 m .56081 .66878 L .54452 .67369 L p F P
0 0 0 r
s
.115 0 .563 r
.54452 .67369 m .54461 .68904 L .56097 .68415 L p F P
0 0 0 r
s
.188 0 .528 r
.40574 .78073 m .40631 .76494 L .39681 .75637 L p F P
0 0 0 r
s
.188 0 .528 r
.39743 .74069 m .39681 .75637 L .40631 .76494 L p F P
0 0 0 r
s
.134 0 .891 r
.49037 .45767 m .49934 .46795 L .51549 .4624 L p F P
0 0 0 r
s
.134 0 .891 r
.49934 .46795 m .49037 .45767 L .47426 .46325 L p F P
0 0 0 r
s
.115 0 .563 r
.51204 .72977 m .51211 .71418 L .49597 .71895 L p F P
0 0 0 r
s
.115 0 .563 r
.49597 .71895 m .49583 .73452 L .51204 .72977 L p F P
0 0 0 r
s
.115 0 .563 r
.78942 .47635 m .78816 .46197 L .77116 .46753 L p F P
0 0 0 r
s
.115 0 .563 r
.77116 .46753 m .77233 .48189 L .78942 .47635 L p F P
0 0 0 r
s
.134 0 .891 r
.76375 .45724 m .77116 .46753 L .78816 .46197 L p F P
0 0 0 r
s
.134 0 .891 r
.77116 .46753 m .76375 .45724 L .74678 .46283 L p F P
0 0 0 r
s
.115 0 .563 r
.46309 .77542 m .46339 .7596 L .4474 .76423 L p F P
0 0 0 r
s
.115 0 .563 r
.4474 .76423 m .44702 .78002 L .46309 .77542 L p F P
0 0 0 r
s
.134 0 .891 r
.53174 .45681 m .54048 .4671 L .55677 .46154 L p F P
0 0 0 r
s
.134 0 .891 r
.54048 .4671 m .53174 .45681 L .51549 .4624 L p F P
0 0 0 r
s
.115 0 .563 r
.74052 .52195 m .73949 .50734 L .72264 .51276 L p F P
0 0 0 r
s
.115 0 .563 r
.72264 .51276 m .72358 .52735 L .74052 .52195 L p F P
0 0 0 r
s
.115 0 .563 r
.6916 .56756 m .69081 .55273 L .6741 .55801 L p F P
0 0 0 r
s
.115 0 .563 r
.6741 .55801 m .67481 .57282 L .6916 .56756 L p F P
0 0 0 r
s
.188 0 .528 r
.39681 .75637 m .39743 .74069 L .38786 .73197 L p F P
0 0 0 r
s
.188 0 .528 r
.38852 .71638 m .38786 .73197 L .39743 .74069 L p F P
0 0 0 r
s
.188 0 .528 r
.35273 .61871 m .35356 .60368 L .34374 .59417 L p F P
0 0 0 r
s
.188 0 .528 r
.34462 .57925 m .34374 .59417 L .35356 .60368 L p F P
0 0 0 r
s
.134 0 .891 r
.29962 .45637 m .3097 .46667 L .32527 .46111 L p F P
0 0 0 r
s
.188 0 .528 r
.30866 .48104 m .3097 .46667 L .29962 .45637 L p F P
0 0 0 r
s
.115 0 .563 r
.64266 .6132 m .6421 .59815 L .62554 .60329 L p F P
0 0 0 r
s
.115 0 .563 r
.62554 .60329 m .62601 .61832 L .64266 .6132 L p F P
0 0 0 r
s
.134 0 .891 r
.57316 .45594 m .58166 .46625 L .59809 .46068 L p F P
0 0 0 r
s
.134 0 .891 r
.58166 .46625 m .57316 .45594 L .55677 .46154 L p F P
0 0 0 r
s
.115 0 .563 r
.59369 .65886 m .59336 .64358 L .57695 .64858 L p F P
0 0 0 r
s
.115 0 .563 r
.57695 .64858 m .57719 .66383 L .59369 .65886 L p F P
0 0 0 r
s
.134 0 .891 r
.34094 .45551 m .35078 .46582 L .36649 .46025 L p F P
0 0 0 r
s
.134 0 .891 r
.35078 .46582 m .34094 .45551 L .32527 .46111 L p F P
0 0 0 r
s
.134 0 .891 r
.61461 .45508 m .62288 .46539 L .63944 .45982 L p F P
0 0 0 r
s
.134 0 .891 r
.62288 .46539 m .61461 .45508 L .59809 .46068 L p F P
0 0 0 r
s
.115 0 .563 r
.54469 .70454 m .54461 .68904 L .52834 .6939 L p F P
0 0 0 r
s
.115 0 .563 r
.52834 .6939 m .52835 .70937 L .54469 .70454 L p F P
0 0 0 r
s
.134 0 .891 r
.38229 .45465 m .3919 .46497 L .40774 .45939 L p F P
0 0 0 r
s
.134 0 .891 r
.3919 .46497 m .38229 .45465 L .36649 .46025 L p F P
0 0 0 r
s
.188 0 .528 r
.38786 .73197 m .38852 .71638 L .37889 .70752 L p F P
0 0 0 r
s
.188 0 .528 r
.3796 .69203 m .37889 .70752 L .38852 .71638 L p F P
0 0 0 r
s
.115 0 .563 r
.49568 .75024 m .49583 .73452 L .47971 .73924 L p F P
0 0 0 r
s
.115 0 .563 r
.47971 .73924 m .47948 .75494 L .49568 .75024 L p F P
0 0 0 r
s
.188 0 .528 r
.34374 .59417 m .34462 .57925 L .33473 .56959 L p F P
0 0 0 r
s
.188 0 .528 r
.33565 .55477 m .33473 .56959 L .34462 .57925 L p F P
0 0 0 r
s
.115 0 .563 r
.77352 .4964 m .77233 .48189 L .75535 .4874 L p F P
0 0 0 r
s
.115 0 .563 r
.75535 .4874 m .75646 .50189 L .77352 .4964 L p F P
0 0 0 r
s
.134 0 .891 r
.65611 .45421 m .66414 .46454 L .68084 .45896 L p F P
0 0 0 r
s
.134 0 .891 r
.66414 .46454 m .65611 .45421 L .63944 .45982 L p F P
0 0 0 r
s
.115 0 .563 r
.44664 .79597 m .44702 .78002 L .43105 .7846 L p F P
0 0 0 r
s
.115 0 .563 r
.43105 .7846 m .43059 .80052 L .44664 .79597 L p F P
0 0 0 r
s
.115 0 .563 r
.72454 .54207 m .72358 .52735 L .70675 .53271 L p F P
0 0 0 r
s
.115 0 .563 r
.70675 .53271 m .70762 .54742 L .72454 .54207 L p F P
0 0 0 r
s
.134 0 .891 r
.42368 .45378 m .43306 .46411 L .44904 .45853 L p F P
0 0 0 r
s
.134 0 .891 r
.43306 .46411 m .42368 .45378 L .40774 .45939 L p F P
0 0 0 r
s
.134 0 .891 r
.69764 .45335 m .70544 .46368 L .72228 .4581 L p F P
0 0 0 r
s
.134 0 .891 r
.70544 .46368 m .69764 .45335 L .68084 .45896 L p F P
0 0 0 r
s
.115 0 .563 r
.67553 .58777 m .67481 .57282 L .65813 .57805 L p F P
0 0 0 r
s
.115 0 .563 r
.65813 .57805 m .65876 .59297 L .67553 .58777 L p F P
0 0 0 r
s
.115 0 .563 r
.6265 .63349 m .62601 .61832 L .60948 .6234 L p F P
0 0 0 r
s
.115 0 .563 r
.60948 .6234 m .60988 .63855 L .6265 .63349 L p F P
0 0 0 r
s
.134 0 .891 r
.46511 .45291 m .47426 .46325 L .49037 .45767 L p F P
0 0 0 r
s
.134 0 .891 r
.47426 .46325 m .46511 .45291 L .44904 .45853 L p F P
0 0 0 r
s
.188 0 .528 r
.37889 .70752 m .3796 .69203 L .36991 .68302 L p F P
0 0 0 r
s
.188 0 .528 r
.37066 .66764 m .36991 .68302 L .3796 .69203 L p F P
0 0 0 r
s
.188 0 .528 r
.33473 .56959 m .33565 .55477 L .32571 .54496 L p F P
0 0 0 r
s
.188 0 .528 r
.32667 .53024 m .32571 .54496 L .33565 .55477 L p F P
0 0 0 r
s
.134 0 .891 r
.73922 .45248 m .74678 .46283 L .76375 .45724 L p F P
0 0 0 r
s
.134 0 .891 r
.74678 .46283 m .73922 .45248 L .72228 .4581 L p F P
0 0 0 r
s
.115 0 .563 r
.57744 .67923 m .57719 .66383 L .56081 .66878 L p F P
0 0 0 r
s
.115 0 .563 r
.56081 .66878 m .56097 .68415 L .57744 .67923 L p F P
0 0 0 r
s
.134 0 .891 r
.50659 .45205 m .51549 .4624 L .53174 .45681 L p F P
0 0 0 r
s
.134 0 .891 r
.51549 .4624 m .50659 .45205 L .49037 .45767 L p F P
0 0 0 r
s
.115 0 .563 r
.52836 .725 m .52835 .70937 L .51211 .71418 L p F P
0 0 0 r
s
.115 0 .563 r
.51211 .71418 m .51204 .72977 L .52836 .725 L p F P
0 0 0 r
s
.115 0 .563 r
.80662 .47078 m .80527 .45637 L .78816 .46197 L p F P
0 0 0 r
s
.115 0 .563 r
.78816 .46197 m .78942 .47635 L .80662 .47078 L p F P
0 0 0 r
s
.134 0 .891 r
.78083 .45161 m .78816 .46197 L .80527 .45637 L p F P
0 0 0 r
s
.134 0 .891 r
.78816 .46197 m .78083 .45161 L .76375 .45724 L p F P
0 0 0 r
s
.115 0 .563 r
.47926 .77078 m .47948 .75494 L .46339 .7596 L p F P
0 0 0 r
s
.115 0 .563 r
.46339 .7596 m .46309 .77542 L .47926 .77078 L p F P
0 0 0 r
s
.115 0 .563 r
.75757 .51651 m .75646 .50189 L .73949 .50734 L p F P
0 0 0 r
s
.115 0 .563 r
.73949 .50734 m .74052 .52195 L .75757 .51651 L p F P
0 0 0 r
s
.134 0 .891 r
.5481 .45118 m .55677 .46154 L .57316 .45594 L p F P
0 0 0 r
s
.134 0 .891 r
.55677 .46154 m .5481 .45118 L .53174 .45681 L p F P
0 0 0 r
s
.188 0 .528 r
.36991 .68302 m .37066 .66764 L .36091 .65847 L p F P
0 0 0 r
s
.188 0 .528 r
.36171 .6432 m .36091 .65847 L .37066 .66764 L p F P
0 0 0 r
s
.188 0 .528 r
.32571 .54496 m .32667 .53024 L .31667 .52028 L p F P
0 0 0 r
s
.188 0 .528 r
.31767 .50566 m .31667 .52028 L .32667 .53024 L p F P
0 0 0 r
s
.115 0 .563 r
.43013 .81659 m .43059 .80052 L .41465 .80504 L p F P
0 0 0 r
s
.115 0 .563 r
.41465 .80504 m .41411 .82108 L .43013 .81659 L p F P
0 0 0 r
s
.188 0 .528 r
.41411 .82108 m .41465 .80504 L .40515 .79667 L p F P
0 0 0 r
s
.188 0 .528 r
.40574 .78073 m .40515 .79667 L .41465 .80504 L p F P
0 0 0 r
s
.115 0 .563 r
.7085 .56227 m .70762 .54742 L .69081 .55273 L p F P
0 0 0 r
s
.115 0 .563 r
.69081 .55273 m .6916 .56756 L .7085 .56227 L p F P
0 0 0 r
s
.134 0 .891 r
.31525 .45074 m .32527 .46111 L .34094 .45551 L p F P
0 0 0 r
s
.134 0 .891 r
.32527 .46111 m .31525 .45074 L .29962 .45637 L p F P
0 0 0 r
s
.115 0 .563 r
.6594 .60805 m .65876 .59297 L .6421 .59815 L p F P
0 0 0 r
s
.115 0 .563 r
.6421 .59815 m .64266 .6132 L .6594 .60805 L p F P
0 0 0 r
s
.134 0 .891 r
.58965 .45031 m .59809 .46068 L .61461 .45508 L p F P
0 0 0 r
s
.134 0 .891 r
.59809 .46068 m .58965 .45031 L .57316 .45594 L p F P
0 0 0 r
s
.115 0 .563 r
.61028 .65385 m .60988 .63855 L .59336 .64358 L p F P
0 0 0 r
s
.115 0 .563 r
.59336 .64358 m .59369 .65886 L .61028 .65385 L p F P
0 0 0 r
s
.134 0 .891 r
.3567 .44987 m .36649 .46025 L .38229 .45465 L p F P
0 0 0 r
s
.134 0 .891 r
.36649 .46025 m .3567 .44987 L .34094 .45551 L p F P
0 0 0 r
s
.115 0 .563 r
.56114 .69968 m .56097 .68415 L .54461 .68904 L p F P
0 0 0 r
s
.115 0 .563 r
.54461 .68904 m .54469 .70454 L .56114 .69968 L p F P
0 0 0 r
s
.188 0 .528 r
.36091 .65847 m .36171 .6432 L .35189 .63388 L p F P
0 0 0 r
s
.188 0 .528 r
.35273 .61871 m .35189 .63388 L .36171 .6432 L p F P
0 0 0 r
s
.134 0 .891 r
.63124 .44944 m .63944 .45982 L .65611 .45421 L p F P
0 0 0 r
s
.134 0 .891 r
.63944 .45982 m .63124 .44944 L .61461 .45508 L p F P
0 0 0 r
s
.188 0 .528 r
.40515 .79667 m .40574 .78073 L .39618 .77221 L p F P
0 0 0 r
s
.188 0 .528 r
.39681 .75637 m .39618 .77221 L .40574 .78073 L p F P
0 0 0 r
s
.188 0 .528 r
.31667 .52028 m .31767 .50566 L .3076 .49555 L p F P
0 0 0 r
s
.188 0 .528 r
.30866 .48104 m .3076 .49555 L .31767 .50566 L p F P
0 0 0 r
s
.115 0 .563 r
.51197 .74552 m .51204 .72977 L .49583 .73452 L p F P
0 0 0 r
s
.115 0 .563 r
.49583 .73452 m .49568 .75024 L .51197 .74552 L p F P
0 0 0 r
s
.134 0 .891 r
.39819 .449 m .40774 .45939 L .42368 .45378 L p F P
0 0 0 r
s
.134 0 .891 r
.40774 .45939 m .39819 .449 L .38229 .45465 L p F P
0 0 0 r
s
.134 0 .891 r
.67288 .44857 m .68084 .45896 L .69764 .45335 L p F P
0 0 0 r
s
.134 0 .891 r
.68084 .45896 m .67288 .44857 L .65611 .45421 L p F P
0 0 0 r
s
.115 0 .563 r
.7907 .49088 m .78942 .47635 L .77233 .48189 L p F P
0 0 0 r
s
.115 0 .563 r
.77233 .48189 m .77352 .4964 L .7907 .49088 L p F P
0 0 0 r
s
.115 0 .563 r
.46278 .79139 m .46309 .77542 L .44702 .78002 L p F P
0 0 0 r
s
.115 0 .563 r
.44702 .78002 m .44664 .79597 L .46278 .79139 L p F P
0 0 0 r
s
.115 0 .563 r
.74156 .53669 m .74052 .52195 L .72358 .52735 L p F P
0 0 0 r
s
.115 0 .563 r
.72358 .52735 m .72454 .54207 L .74156 .53669 L p F P
0 0 0 r
s
.134 0 .891 r
.43972 .44813 m .44904 .45853 L .46511 .45291 L p F P
0 0 0 r
s
.134 0 .891 r
.44904 .45853 m .43972 .44813 L .42368 .45378 L p F P
0 0 0 r
s
.134 0 .891 r
.71455 .4477 m .72228 .4581 L .73922 .45248 L p F P
0 0 0 r
s
.134 0 .891 r
.72228 .4581 m .71455 .4477 L .69764 .45335 L p F P
0 0 0 r
s
.115 0 .563 r
.6924 .58253 m .6916 .56756 L .67481 .57282 L p F P
0 0 0 r
s
.115 0 .563 r
.67481 .57282 m .67553 .58777 L .6924 .58253 L p F P
0 0 0 r
s
.188 0 .528 r
.39618 .77221 m .39681 .75637 L .38719 .74771 L p F P
0 0 0 r
s
.188 0 .528 r
.38786 .73197 m .38719 .74771 L .39681 .75637 L p F P
0 0 0 r
s
.188 0 .528 r
.3076 .49555 m .30866 .48104 L .29853 .47078 L p F P
0 0 0 r
s
.188 0 .528 r
.29962 .45637 m .29853 .47078 L .30866 .48104 L p F P
0 0 0 r
s
.188 0 .528 r
.35189 .63388 m .35273 .61871 L .34286 .60924 L p F P
0 0 0 r
s
.188 0 .528 r
.34374 .59417 m .34286 .60924 L .35273 .61871 L p F P
0 0 0 r
s
.115 0 .563 r
.64322 .6284 m .64266 .6132 L .62601 .61832 L p F P
0 0 0 r
s
.115 0 .563 r
.62601 .61832 m .6265 .63349 L .64322 .6284 L p F P
0 0 0 r
s
.134 0 .891 r
.48129 .44726 m .49037 .45767 L .50659 .45205 L p F P
0 0 0 r
s
.134 0 .891 r
.49037 .45767 m .48129 .44726 L .46511 .45291 L p F P
0 0 0 r
s
.134 0 .891 r
.75626 .44683 m .76375 .45724 L .78083 .45161 L p F P
0 0 0 r
s
.134 0 .891 r
.76375 .45724 m .75626 .44683 L .73922 .45248 L p F P
0 0 0 r
s
.115 0 .563 r
.59401 .67428 m .59369 .65886 L .57719 .66383 L p F P
0 0 0 r
s
.115 0 .563 r
.57719 .66383 m .57744 .67923 L .59401 .67428 L p F P
0 0 0 r
s
.134 0 .891 r
.5229 .44639 m .53174 .45681 L .5481 .45118 L p F P
0 0 0 r
s
.134 0 .891 r
.53174 .45681 m .5229 .44639 L .50659 .45205 L p F P
0 0 0 r
s
.115 0 .563 r
.54478 .72019 m .54469 .70454 L .52835 .70937 L p F P
0 0 0 r
s
.115 0 .563 r
.52835 .70937 m .52836 .725 L .54478 .72019 L p F P
0 0 0 r
s
.115 0 .563 r
.82392 .46516 m .82248 .45074 L .80527 .45637 L p F P
0 0 0 r
s
.115 0 .563 r
.80527 .45637 m .80662 .47078 L .82392 .46516 L p F P
0 0 0 r
s
.134 0 .891 r
.79802 .44595 m .80527 .45637 L .82248 .45074 L p F P
0 0 0 r
s
.134 0 .891 r
.80527 .45637 m .79802 .44595 L .78083 .45161 L p F P
0 0 0 r
s
.115 0 .563 r
.49553 .76612 m .49568 .75024 L .47948 .75494 L p F P
0 0 0 r
s
.115 0 .563 r
.47948 .75494 m .47926 .77078 L .49553 .76612 L p F P
0 0 0 r
s
.188 0 .528 r
.38719 .74771 m .38786 .73197 L .37818 .72315 L p F P
0 0 0 r
s
.188 0 .528 r
.37889 .70752 m .37818 .72315 L .38786 .73197 L p F P
0 0 0 r
s
.188 0 .528 r
.34286 .60924 m .34374 .59417 L .3338 .58455 L p F P
0 0 0 r
s
.188 0 .528 r
.33473 .56959 m .3338 .58455 L .34374 .59417 L p F P
0 0 0 r
s
.134 0 .891 r
.28943 .44595 m .29962 .45637 L .31525 .45074 L p F P
0 0 0 r
s
.188 0 .528 r
.29853 .47078 m .29962 .45637 L .28943 .44595 L p F P
0 0 0 r
s
.115 0 .563 r
.77472 .51104 m .77352 .4964 L .75646 .50189 L p F P
0 0 0 r
s
.115 0 .563 r
.75646 .50189 m .75757 .51651 L .77472 .51104 L p F P
0 0 0 r
s
.134 0 .891 r
.56455 .44552 m .57316 .45594 L .58965 .45031 L p F P
0 0 0 r
s
.134 0 .891 r
.57316 .45594 m .56455 .44552 L .5481 .45118 L p F P
0 0 0 r
s
.115 0 .563 r
.44625 .81207 m .44664 .79597 L .43059 .80052 L p F P
0 0 0 r
s
.115 0 .563 r
.43059 .80052 m .43013 .81659 L .44625 .81207 L p F P
0 0 0 r
s
.115 0 .563 r
.7255 .55694 m .72454 .54207 L .70762 .54742 L p F P
0 0 0 r
s
.115 0 .563 r
.70762 .54742 m .7085 .56227 L .7255 .55694 L p F P
0 0 0 r
s
.134 0 .891 r
.33098 .44508 m .34094 .45551 L .3567 .44987 L p F P
0 0 0 r
s
.134 0 .891 r
.34094 .45551 m .33098 .44508 L .31525 .45074 L p F P
0 0 0 r
s
.115 0 .563 r
.67626 .60287 m .67553 .58777 L .65876 .59297 L p F P
0 0 0 r
s
.115 0 .563 r
.65876 .59297 m .6594 .60805 L .67626 .60287 L p F P
0 0 0 r
s
.134 0 .891 r
.60625 .44464 m .61461 .45508 L .63124 .44944 L p F P
0 0 0 r
s
.134 0 .891 r
.61461 .45508 m .60625 .44464 L .58965 .45031 L p F P
0 0 0 r
s
.115 0 .563 r
.62698 .64881 m .6265 .63349 L .60988 .63855 L p F P
0 0 0 r
s
.115 0 .563 r
.60988 .63855 m .61028 .65385 L .62698 .64881 L p F P
0 0 0 r
s
.134 0 .891 r
.37257 .4442 m .38229 .45465 L .39819 .449 L p F P
0 0 0 r
s
.134 0 .891 r
.38229 .45465 m .37257 .4442 L .3567 .44987 L p F P
0 0 0 r
s
.188 0 .528 r
.37818 .72315 m .37889 .70752 L .36915 .69855 L p F P
0 0 0 r
s
.188 0 .528 r
.36991 .68302 m .36915 .69855 L .37889 .70752 L p F P
0 0 0 r
s
.188 0 .528 r
.3338 .58455 m .33473 .56959 L .32473 .55982 L p F P
0 0 0 r
s
.188 0 .528 r
.32571 .54496 m .32473 .55982 L .33473 .56959 L p F P
0 0 0 r
s
.134 0 .891 r
.64798 .44377 m .65611 .45421 L .67288 .44857 L p F P
0 0 0 r
s
.134 0 .891 r
.65611 .45421 m .64798 .44377 L .63124 .44944 L p F P
0 0 0 r
s
.115 0 .563 r
.57769 .69478 m .57744 .67923 L .56097 .68415 L p F P
0 0 0 r
s
.115 0 .563 r
.56097 .68415 m .56114 .69968 L .57769 .69478 L p F P
0 0 0 r
s
.115 0 .563 r
.52837 .74077 m .52836 .725 L .51204 .72977 L p F P
0 0 0 r
s
.115 0 .563 r
.51204 .72977 m .51197 .74552 L .52837 .74077 L p F P
0 0 0 r
s
.134 0 .891 r
.4142 .44333 m .42368 .45378 L .43972 .44813 L p F P
0 0 0 r
s
.134 0 .891 r
.42368 .45378 m .4142 .44333 L .39819 .449 L p F P
0 0 0 r
s
.115 0 .563 r
.80798 .48532 m .80662 .47078 L .78942 .47635 L p F P
0 0 0 r
s
.115 0 .563 r
.78942 .47635 m .7907 .49088 L .80798 .48532 L p F P
0 0 0 r
s
.134 0 .891 r
.68975 .44289 m .69764 .45335 L .71455 .4477 L p F P
0 0 0 r
s
.134 0 .891 r
.69764 .45335 m .68975 .44289 L .67288 .44857 L p F P
0 0 0 r
s
.115 0 .563 r
.47903 .78679 m .47926 .77078 L .46309 .77542 L p F P
0 0 0 r
s
.115 0 .563 r
.46309 .77542 m .46278 .79139 L .47903 .78679 L p F P
0 0 0 r
s
.188 0 .528 r
.36915 .69855 m .36991 .68302 L .36011 .6739 L p F P
0 0 0 r
s
.188 0 .528 r
.36091 .65847 m .36011 .6739 L .36991 .68302 L p F P
0 0 0 r
s
.115 0 .563 r
.7587 .53128 m .75757 .51651 L .74052 .52195 L p F P
0 0 0 r
s
.115 0 .563 r
.74052 .52195 m .74156 .53669 L .7587 .53128 L p F P
0 0 0 r
s
.134 0 .891 r
.45586 .44245 m .46511 .45291 L .48129 .44726 L p F P
0 0 0 r
s
.134 0 .891 r
.46511 .45291 m .45586 .44245 L .43972 .44813 L p F P
0 0 0 r
s
.115 0 .563 r
.42966 .83282 m .43013 .81659 L .41411 .82108 L p F P
0 0 0 r
s
.115 0 .563 r
.41411 .82108 m .41357 .83728 L .42966 .83282 L p F P
0 0 0 r
s
.188 0 .528 r
.41357 .83728 m .41411 .82108 L .40457 .81277 L p F P
0 0 0 r
s
.188 0 .528 r
.40515 .79667 m .40457 .81277 L .41411 .82108 L p F P
0 0 0 r
s
.188 0 .528 r
.32473 .55982 m .32571 .54496 L .31565 .53503 L p F P
0 0 0 r
s
.188 0 .528 r
.31667 .52028 m .31565 .53503 L .32571 .54496 L p F P
0 0 0 r
s
.134 0 .891 r
.73156 .44201 m .73922 .45248 L .75626 .44683 L p F P
0 0 0 r
s
.134 0 .891 r
.73922 .45248 m .73156 .44201 L .71455 .4477 L p F P
0 0 0 r
s
.115 0 .563 r
.70939 .57726 m .7085 .56227 L .6916 .56756 L p F P
0 0 0 r
s
.115 0 .563 r
.6916 .56756 m .6924 .58253 L .70939 .57726 L p F P
0 0 0 r
s
.115 0 .563 r
.66005 .62327 m .6594 .60805 L .64266 .6132 L p F P
0 0 0 r
s
.115 0 .563 r
.64266 .6132 m .64322 .6284 L .66005 .62327 L p F P
0 0 0 r
s
.134 0 .891 r
.49757 .44158 m .50659 .45205 L .5229 .44639 L p F P
0 0 0 r
s
.134 0 .891 r
.50659 .45205 m .49757 .44158 L .48129 .44726 L p F P
0 0 0 r
s
.134 0 .891 r
.77342 .44114 m .78083 .45161 L .79802 .44595 L p F P
0 0 0 r
s
.134 0 .891 r
.78083 .45161 m .77342 .44114 L .75626 .44683 L p F P
0 0 0 r
s
.115 0 .563 r
.61069 .6693 m .61028 .65385 L .59369 .65886 L p F P
0 0 0 r
s
.115 0 .563 r
.59369 .65886 m .59401 .67428 L .61069 .6693 L p F P
0 0 0 r
s
.115 0 .563 r
.56131 .71535 m .56114 .69968 L .54469 .70454 L p F P
0 0 0 r
s
.115 0 .563 r
.54469 .70454 m .54478 .72019 L .56131 .71535 L p F P
0 0 0 r
s
.188 0 .528 r
.40457 .81277 m .40515 .79667 L .39555 .78821 L p F P
0 0 0 r
s
.188 0 .528 r
.39618 .77221 m .39555 .78821 L .40515 .79667 L p F P
0 0 0 r
s
.188 0 .528 r
.36011 .6739 m .36091 .65847 L .35104 .6492 L p F P
0 0 0 r
s
.188 0 .528 r
.35189 .63388 m .35104 .6492 L .36091 .65847 L p F P
0 0 0 r
s
.188 0 .528 r
.31565 .53503 m .31667 .52028 L .30654 .5102 L p F P
0 0 0 r
s
.188 0 .528 r
.3076 .49555 m .30654 .5102 L .31667 .52028 L p F P
0 0 0 r
s
.134 0 .891 r
.53932 .4407 m .5481 .45118 L .56455 .44552 L p F P
0 0 0 r
s
.134 0 .891 r
.5481 .45118 m .53932 .4407 L .5229 .44639 L p F P
0 0 0 r
s
.115 0 .563 r
.84134 .45952 m .83981 .44508 L .82248 .45074 L p F P
0 0 0 r
s
.115 0 .563 r
.82248 .45074 m .82392 .46516 L .84134 .45952 L p F P
0 0 0 r
s
.134 0 .891 r
.81531 .44026 m .82248 .45074 L .83981 .44508 L p F P
0 0 0 r
s
.134 0 .891 r
.82248 .45074 m .81531 .44026 L .79802 .44595 L p F P
0 0 0 r
s
.115 0 .563 r
.5119 .76143 m .51197 .74552 L .49568 .75024 L p F P
0 0 0 r
s
.115 0 .563 r
.49568 .75024 m .49553 .76612 L .5119 .76143 L p F P
0 0 0 r
s
.134 0 .891 r
.30512 .44026 m .31525 .45074 L .33098 .44508 L p F P
0 0 0 r
s
.134 0 .891 r
.31525 .45074 m .30512 .44026 L .28943 .44595 L p F P
0 0 0 r
s
.115 0 .563 r
.79199 .50554 m .7907 .49088 L .77352 .4964 L p F P
0 0 0 r
s
.115 0 .563 r
.77352 .4964 m .77472 .51104 L .79199 .50554 L p F P
0 0 0 r
s
.134 0 .891 r
.58111 .43982 m .58965 .45031 L .60625 .44464 L p F P
0 0 0 r
s
.134 0 .891 r
.58965 .45031 m .58111 .43982 L .56455 .44552 L p F P
0 0 0 r
s
.115 0 .563 r
.46247 .80752 m .46278 .79139 L .44664 .79597 L p F P
0 0 0 r
s
.115 0 .563 r
.44664 .79597 m .44625 .81207 L .46247 .80752 L p F P
0 0 0 r
s
.115 0 .563 r
.74261 .55159 m .74156 .53669 L .72454 .54207 L p F P
0 0 0 r
s
.115 0 .563 r
.72454 .54207 m .7255 .55694 L .74261 .55159 L p F P
0 0 0 r
s
.134 0 .891 r
.34681 .43938 m .3567 .44987 L .37257 .4442 L p F P
0 0 0 r
s
.134 0 .891 r
.3567 .44987 m .34681 .43938 L .33098 .44508 L p F P
0 0 0 r
s
.115 0 .563 r
.69321 .59765 m .6924 .58253 L .67553 .58777 L p F P
0 0 0 r
s
.115 0 .563 r
.67553 .58777 m .67626 .60287 L .69321 .59765 L p F P
0 0 0 r
s
.134 0 .891 r
.62295 .43894 m .63124 .44944 L .64798 .44377 L p F P
0 0 0 r
s
.134 0 .891 r
.63124 .44944 m .62295 .43894 L .60625 .44464 L p F P
0 0 0 r
s
.188 0 .528 r
.39555 .78821 m .39618 .77221 L .38651 .7636 L p F P
0 0 0 r
s
.188 0 .528 r
.38719 .74771 m .38651 .7636 L .39618 .77221 L p F P
0 0 0 r
s
.188 0 .528 r
.35104 .6492 m .35189 .63388 L .34196 .62446 L p F P
0 0 0 r
s
.188 0 .528 r
.34286 .60924 m .34196 .62446 L .35189 .63388 L p F P
0 0 0 r
s
.188 0 .528 r
.30654 .5102 m .3076 .49555 L .29742 .48532 L p F P
0 0 0 r
s
.188 0 .528 r
.29853 .47078 m .29742 .48532 L .3076 .49555 L p F P
0 0 0 r
s
.115 0 .563 r
.64379 .64374 m .64322 .6284 L .6265 .63349 L p F P
0 0 0 r
s
.115 0 .563 r
.6265 .63349 m .62698 .64881 L .64379 .64374 L p F P
0 0 0 r
s
.134 0 .891 r
.38853 .4385 m .39819 .449 L .4142 .44333 L p F P
0 0 0 r
s
.134 0 .891 r
.39819 .449 m .38853 .4385 L .37257 .4442 L p F P
0 0 0 r
s
.134 0 .891 r
.66482 .43806 m .67288 .44857 L .68975 .44289 L p F P
0 0 0 r
s
.134 0 .891 r
.67288 .44857 m .66482 .43806 L .64798 .44377 L p F P
0 0 0 r
s
.115 0 .563 r
.59434 .68986 m .59401 .67428 L .57744 .67923 L p F P
0 0 0 r
s
.115 0 .563 r
.57744 .67923 m .57769 .69478 L .59434 .68986 L p F P
0 0 0 r
s
.115 0 .563 r
.54487 .73599 m .54478 .72019 L .52836 .725 L p F P
0 0 0 r
s
.115 0 .563 r
.52836 .725 m .52837 .74077 L .54487 .73599 L p F P
0 0 0 r
s
.134 0 .891 r
.4303 .43762 m .43972 .44813 L .45586 .44245 L p F P
0 0 0 r
s
.134 0 .891 r
.43972 .44813 m .4303 .43762 L .4142 .44333 L p F P
0 0 0 r
s
.115 0 .563 r
.82538 .47973 m .82392 .46516 L .80662 .47078 L p F P
0 0 0 r
s
.115 0 .563 r
.80662 .47078 m .80798 .48532 L .82538 .47973 L p F P
0 0 0 r
s
.134 0 .891 r
.70673 .43718 m .71455 .4477 L .73156 .44201 L p F P
0 0 0 r
s
.134 0 .891 r
.71455 .4477 m .70673 .43718 L .68975 .44289 L p F P
0 0 0 r
s
.115 0 .563 r
.49538 .78215 m .49553 .76612 L .47926 .77078 L p F P
0 0 0 r
s
.115 0 .563 r
.47926 .77078 m .47903 .78679 L .49538 .78215 L p F P
0 0 0 r
s
.188 0 .528 r
.38651 .7636 m .38719 .74771 L .37746 .73894 L p F P
0 0 0 r
s
.188 0 .528 r
.37818 .72315 m .37746 .73894 L .38719 .74771 L p F P
0 0 0 r
s
.188 0 .528 r
.34196 .62446 m .34286 .60924 L .33287 .59966 L p F P
0 0 0 r
s
.188 0 .528 r
.3338 .58455 m .33287 .59966 L .34286 .60924 L p F P
0 0 0 r
s
.188 0 .528 r
.29742 .48532 m .29853 .47078 L .28828 .46039 L p F P
0 0 0 r
s
.188 0 .528 r
.28943 .44595 m .28828 .46039 L .29853 .47078 L p F P
0 0 0 r
s
.115 0 .563 r
.77594 .52583 m .77472 .51104 L .75757 .51651 L p F P
0 0 0 r
s
.115 0 .563 r
.75757 .51651 m .7587 .53128 L .77594 .52583 L p F P
0 0 0 r
s
.134 0 .891 r
.47211 .43673 m .48129 .44726 L .49757 .44158 L p F P
0 0 0 r
s
.134 0 .891 r
.48129 .44726 m .47211 .43673 L .45586 .44245 L p F P
0 0 0 r
s
.115 0 .563 r
.44586 .82833 m .44625 .81207 L .43013 .81659 L p F P
0 0 0 r
s
.115 0 .563 r
.43013 .81659 m .42966 .83282 L .44586 .82833 L p F P
0 0 0 r
s
.134 0 .891 r
.74868 .43629 m .75626 .44683 L .77342 .44114 L p F P
0 0 0 r
s
.134 0 .891 r
.75626 .44683 m .74868 .43629 L .73156 .44201 L p F P
0 0 0 r
s
.115 0 .563 r
.72647 .57196 m .7255 .55694 L .7085 .56227 L p F P
0 0 0 r
s
.115 0 .563 r
.7085 .56227 m .70939 .57726 L .72647 .57196 L p F P
0 0 0 r
s
.115 0 .563 r
.67699 .61811 m .67626 .60287 L .6594 .60805 L p F P
0 0 0 r
s
.115 0 .563 r
.6594 .60805 m .66005 .62327 L .67699 .61811 L p F P
0 0 0 r
s
.134 0 .891 r
.51396 .43585 m .5229 .44639 L .53932 .4407 L p F P
0 0 0 r
s
.134 0 .891 r
.5229 .44639 m .51396 .43585 L .49757 .44158 L p F P
0 0 0 r
s
.134 0 .891 r
.79068 .43541 m .79802 .44595 L .81531 .44026 L p F P
0 0 0 r
s
.134 0 .891 r
.79802 .44595 m .79068 .43541 L .77342 .44114 L p F P
0 0 0 r
s
.115 0 .563 r
.62748 .66429 m .62698 .64881 L .61028 .65385 L p F P
0 0 0 r
s
.115 0 .563 r
.61028 .65385 m .61069 .6693 L .62748 .66429 L p F P
0 0 0 r
s
.188 0 .528 r
.37746 .73894 m .37818 .72315 L .36838 .71423 L p F P
0 0 0 r
s
.188 0 .528 r
.36915 .69855 m .36838 .71423 L .37818 .72315 L p F P
0 0 0 r
s
.188 0 .528 r
.33287 .59966 m .3338 .58455 L .32375 .57482 L p F P
0 0 0 r
s
.188 0 .528 r
.32473 .55982 m .32375 .57482 L .3338 .58455 L p F P
0 0 0 r
s
.134 0 .891 r
.27912 .43541 m .28943 .44595 L .30512 .44026 L p F P
0 0 0 r
s
.188 0 .528 r
.28828 .46039 m .28943 .44595 L .27912 .43541 L p F P
0 0 0 r
s
.134 0 .891 r
.55585 .43497 m .56455 .44552 L .58111 .43982 L p F P
0 0 0 r
s
.134 0 .891 r
.56455 .44552 m .55585 .43497 L .53932 .4407 L p F P
0 0 0 r
s
.115 0 .563 r
.57794 .71048 m .57769 .69478 L .56114 .69968 L p F P
0 0 0 r
s
.115 0 .563 r
.56114 .69968 m .56131 .71535 L .57794 .71048 L p F P
0 0 0 r
s
.134 0 .891 r
.3209 .43453 m .33098 .44508 L .34681 .43938 L p F P
0 0 0 r
s
.134 0 .891 r
.33098 .44508 m .3209 .43453 L .30512 .44026 L p F P
0 0 0 r
s
.115 0 .563 r
.85886 .45383 m .85725 .43938 L .83981 .44508 L p F P
0 0 0 r
s
.115 0 .563 r
.83981 .44508 m .84134 .45952 L .85886 .45383 L p F P
0 0 0 r
s
.134 0 .891 r
.83271 .43453 m .83981 .44508 L .85725 .43938 L p F P
0 0 0 r
s
.134 0 .891 r
.83981 .44508 m .83271 .43453 L .81531 .44026 L p F P
0 0 0 r
s
.115 0 .563 r
.52838 .7567 m .52837 .74077 L .51197 .74552 L p F P
0 0 0 r
s
.115 0 .563 r
.51197 .74552 m .5119 .76143 L .52838 .7567 L p F P
0 0 0 r
s
.115 0 .563 r
.80936 .5 m .80798 .48532 L .7907 .49088 L p F P
0 0 0 r
s
.115 0 .563 r
.7907 .49088 m .79199 .50554 L .80936 .5 L p F P
0 0 0 r
s
.134 0 .891 r
.59778 .43408 m .60625 .44464 L .62295 .43894 L p F P
0 0 0 r
s
.134 0 .891 r
.60625 .44464 m .59778 .43408 L .58111 .43982 L p F P
0 0 0 r
s
.115 0 .563 r
.4788 .80294 m .47903 .78679 L .46278 .79139 L p F P
0 0 0 r
s
.115 0 .563 r
.46278 .79139 m .46247 .80752 L .4788 .80294 L p F P
0 0 0 r
s
.115 0 .563 r
.75983 .54619 m .7587 .53128 L .74156 .53669 L p F P
0 0 0 r
s
.115 0 .563 r
.74156 .53669 m .74261 .55159 L .75983 .54619 L p F P
0 0 0 r
s
.134 0 .891 r
.36273 .43364 m .37257 .4442 L .38853 .4385 L p F P
0 0 0 r
s
.134 0 .891 r
.37257 .4442 m .36273 .43364 L .34681 .43938 L p F P
0 0 0 r
s
.115 0 .563 r
.42919 .84921 m .42966 .83282 L .41357 .83728 L p F P
0 0 0 r
s
.115 0 .563 r
.41357 .83728 m .41302 .85364 L .42919 .84921 L p F P
0 0 0 r
s
.188 0 .528 r
.41302 .85364 m .41357 .83728 L .40397 .82902 L p F P
0 0 0 r
s
.188 0 .528 r
.40457 .81277 m .40397 .82902 L .41357 .83728 L p F P
0 0 0 r
s
.188 0 .528 r
.36838 .71423 m .36915 .69855 L .35929 .68948 L p F P
0 0 0 r
s
.188 0 .528 r
.36011 .6739 m .35929 .68948 L .36915 .69855 L p F P
0 0 0 r
s
.188 0 .528 r
.32375 .57482 m .32473 .55982 L .31462 .54993 L p F P
0 0 0 r
s
.188 0 .528 r
.31565 .53503 m .31462 .54993 L .32473 .55982 L p F P
0 0 0 r
s
.115 0 .563 r
.71028 .59241 m .70939 .57726 L .6924 .58253 L p F P
0 0 0 r
s
.115 0 .563 r
.6924 .58253 m .69321 .59765 L .71028 .59241 L p F P
0 0 0 r
s
.134 0 .891 r
.63975 .4332 m .64798 .44377 L .66482 .43806 L p F P
0 0 0 r
s
.134 0 .891 r
.64798 .44377 m .63975 .4332 L .62295 .43894 L p F P
0 0 0 r
s
.115 0 .563 r
.66071 .63864 m .66005 .62327 L .64322 .6284 L p F P
0 0 0 r
s
.115 0 .563 r
.64322 .6284 m .64379 .64374 L .66071 .63864 L p F P
0 0 0 r
s
.134 0 .891 r
.4046 .43276 m .4142 .44333 L .4303 .43762 L p F P
0 0 0 r
s
.134 0 .891 r
.4142 .44333 m .4046 .43276 L .38853 .4385 L p F P
0 0 0 r
s
.134 0 .891 r
.68177 .43231 m .68975 .44289 L .70673 .43718 L p F P
0 0 0 r
s
.134 0 .891 r
.68975 .44289 m .68177 .43231 L .66482 .43806 L p F P
0 0 0 r
s
.115 0 .563 r
.61111 .6849 m .61069 .6693 L .59401 .67428 L p F P
0 0 0 r
s
.115 0 .563 r
.59401 .67428 m .59434 .68986 L .61111 .6849 L p F P
0 0 0 r
s
.188 0 .528 r
.35929 .68948 m .36011 .6739 L .35019 .66467 L p F P
0 0 0 r
s
.188 0 .528 r
.35104 .6492 m .35019 .66467 L .36011 .6739 L p F P
0 0 0 r
s
.115 0 .563 r
.56148 .73118 m .56131 .71535 L .54478 .72019 L p F P
0 0 0 r
s
.115 0 .563 r
.54478 .72019 m .54487 .73599 L .56148 .73118 L p F P
0 0 0 r
s
.134 0 .891 r
.44651 .43187 m .45586 .44245 L .47211 .43673 L p F P
0 0 0 r
s
.134 0 .891 r
.45586 .44245 m .44651 .43187 L .4303 .43762 L p F P
0 0 0 r
s
.188 0 .528 r
.40397 .82902 m .40457 .81277 L .39491 .80436 L p F P
0 0 0 r
s
.188 0 .528 r
.39555 .78821 m .39491 .80436 L .40457 .81277 L p F P
0 0 0 r
s
.188 0 .528 r
.31462 .54993 m .31565 .53503 L .30547 .52499 L p F P
0 0 0 r
s
.188 0 .528 r
.30654 .5102 m .30547 .52499 L .31565 .53503 L p F P
0 0 0 r
s
.115 0 .563 r
.84288 .4741 m .84134 .45952 L .82392 .46516 L p F P
0 0 0 r
s
.115 0 .563 r
.82392 .46516 m .82538 .47973 L .84288 .4741 L p F P
0 0 0 r
s
.134 0 .891 r
.72382 .43143 m .73156 .44201 L .74868 .43629 L p F P
0 0 0 r
s
.134 0 .891 r
.73156 .44201 m .72382 .43143 L .70673 .43718 L p F P
0 0 0 r
s
.115 0 .563 r
.51183 .77748 m .5119 .76143 L .49553 .76612 L p F P
0 0 0 r
s
.115 0 .563 r
.49553 .76612 m .49538 .78215 L .51183 .77748 L p F P
0 0 0 r
s
.115 0 .563 r
.79329 .52035 m .79199 .50554 L .77472 .51104 L p F P
0 0 0 r
s
.115 0 .563 r
.77472 .51104 m .77594 .52583 L .79329 .52035 L p F P
0 0 0 r
s
.134 0 .891 r
.48846 .43098 m .49757 .44158 L .51396 .43585 L p F P
0 0 0 r
s
.134 0 .891 r
.49757 .44158 m .48846 .43098 L .47211 .43673 L p F P
0 0 0 r
s
.115 0 .563 r
.46216 .82381 m .46247 .80752 L .44625 .81207 L p F P
0 0 0 r
s
.115 0 .563 r
.44625 .81207 m .44586 .82833 L .46216 .82381 L p F P
0 0 0 r
s
.134 0 .891 r
.76592 .43054 m .77342 .44114 L .79068 .43541 L p F P
0 0 0 r
s
.134 0 .891 r
.77342 .44114 m .76592 .43054 L .74868 .43629 L p F P
0 0 0 r
s
.115 0 .563 r
.74367 .56662 m .74261 .55159 L .7255 .55694 L p F P
0 0 0 r
s
.115 0 .563 r
.7255 .55694 m .72647 .57196 L .74367 .56662 L p F P
0 0 0 r
s
.188 0 .528 r
.39491 .80436 m .39555 .78821 L .38583 .77964 L p F P
0 0 0 r
s
.188 0 .528 r
.38651 .7636 m .38583 .77964 L .39555 .78821 L p F P
0 0 0 r
s
.188 0 .528 r
.30547 .52499 m .30654 .5102 L .2963 .5 L p F P
0 0 0 r
s
.188 0 .528 r
.29742 .48532 m .2963 .5 L .30654 .5102 L p F P
0 0 0 r
s
.115 0 .563 r
.69403 .61292 m .69321 .59765 L .67626 .60287 L p F P
0 0 0 r
s
.115 0 .563 r
.67626 .60287 m .67699 .61811 L .69403 .61292 L p F P
0 0 0 r
s
.134 0 .891 r
.53045 .43009 m .53932 .4407 L .55585 .43497 L p F P
0 0 0 r
s
.134 0 .891 r
.53932 .4407 m .53045 .43009 L .51396 .43585 L p F P
0 0 0 r
s
.188 0 .528 r
.35019 .66467 m .35104 .6492 L .34106 .63982 L p F P
0 0 0 r
s
.188 0 .528 r
.34196 .62446 m .34106 .63982 L .35104 .6492 L p F P
0 0 0 r
s
.134 0 .891 r
.29487 .42965 m .30512 .44026 L .3209 .43453 L p F P
0 0 0 r
s
.134 0 .891 r
.30512 .44026 m .29487 .42965 L .27912 .43541 L p F P
0 0 0 r
s
.134 0 .891 r
.80805 .42965 m .81531 .44026 L .83271 .43453 L p F P
0 0 0 r
s
.134 0 .891 r
.81531 .44026 m .80805 .42965 L .79068 .43541 L p F P
0 0 0 r
s
.115 0 .563 r
.64437 .65924 m .64379 .64374 L .62698 .64881 L p F P
0 0 0 r
s
.115 0 .563 r
.62698 .64881 m .62748 .66429 L .64437 .65924 L p F P
0 0 0 r
s
.134 0 .891 r
.57248 .4292 m .58111 .43982 L .59778 .43408 L p F P
0 0 0 r
s
.134 0 .891 r
.58111 .43982 m .57248 .4292 L .55585 .43497 L p F P
0 0 0 r
s
.115 0 .563 r
.59468 .70558 m .59434 .68986 L .57769 .69478 L p F P
0 0 0 r
s
.115 0 .563 r
.57769 .69478 m .57794 .71048 L .59468 .70558 L p F P
0 0 0 r
s
.134 0 .891 r
.33679 .42876 m .34681 .43938 L .36273 .43364 L p F P
0 0 0 r
s
.134 0 .891 r
.34681 .43938 m .33679 .42876 L .3209 .43453 L p F P
0 0 0 r
s
.115 0 .563 r
.8765 .44812 m .87479 .43364 L .85725 .43938 L p F P
0 0 0 r
s
.115 0 .563 r
.85725 .43938 m .85886 .45383 L .8765 .44812 L p F P
0 0 0 r
s
.134 0 .891 r
.85023 .42876 m .85725 .43938 L .87479 .43364 L p F P
0 0 0 r
s
.134 0 .891 r
.85725 .43938 m .85023 .42876 L .83271 .43453 L p F P
0 0 0 r
s
.115 0 .563 r
.54496 .75195 m .54487 .73599 L .52837 .74077 L p F P
0 0 0 r
s
.115 0 .563 r
.52837 .74077 m .52838 .7567 L .54496 .75195 L p F P
0 0 0 r
s
.134 0 .891 r
.61455 .42831 m .62295 .43894 L .63975 .4332 L p F P
0 0 0 r
s
.134 0 .891 r
.62295 .43894 m .61455 .42831 L .59778 .43408 L p F P
0 0 0 r
s
.115 0 .563 r
.82684 .49443 m .82538 .47973 L .80798 .48532 L p F P
0 0 0 r
s
.115 0 .563 r
.80798 .48532 m .80936 .5 L .82684 .49443 L p F P
0 0 0 r
s
.115 0 .563 r
.49523 .79834 m .49538 .78215 L .47903 .78679 L p F P
0 0 0 r
s
.115 0 .563 r
.47903 .78679 m .4788 .80294 L .49523 .79834 L p F P
0 0 0 r
s
.188 0 .528 r
.38583 .77964 m .38651 .7636 L .37673 .75488 L p F P
0 0 0 r
s
.188 0 .528 r
.37746 .73894 m .37673 .75488 L .38651 .7636 L p F P
0 0 0 r
s
.188 0 .528 r
.34106 .63982 m .34196 .62446 L .33192 .61492 L p F P
0 0 0 r
s
.188 0 .528 r
.33287 .59966 m .33192 .61492 L .34196 .62446 L p F P
0 0 0 r
s
.188 0 .528 r
.2963 .5 m .29742 .48532 L .28711 .47497 L p F P
0 0 0 r
s
.188 0 .528 r
.28828 .46039 m .28711 .47497 L .29742 .48532 L p F P
0 0 0 r
s
.115 0 .563 r
.77716 .54077 m .77594 .52583 L .7587 .53128 L p F P
0 0 0 r
s
.115 0 .563 r
.7587 .53128 m .75983 .54619 L .77716 .54077 L p F P
0 0 0 r
s
.134 0 .891 r
.37876 .42787 m .38853 .4385 L .4046 .43276 L p F P
0 0 0 r
s
.134 0 .891 r
.38853 .4385 m .37876 .42787 L .36273 .43364 L p F P
0 0 0 r
s
.115 0 .563 r
.44546 .84475 m .44586 .82833 L .42966 .83282 L p F P
0 0 0 r
s
.115 0 .563 r
.42966 .83282 m .42919 .84921 L .44546 .84475 L p F P
0 0 0 r
s
.115 0 .563 r
.72746 .58712 m .72647 .57196 L .70939 .57726 L p F P
0 0 0 r
s
.115 0 .563 r
.70939 .57726 m .71028 .59241 L .72746 .58712 L p F P
0 0 0 r
s
.134 0 .891 r
.65667 .42742 m .66482 .43806 L .68177 .43231 L p F P
0 0 0 r
s
.134 0 .891 r
.66482 .43806 m .65667 .42742 L .63975 .4332 L p F P
0 0 0 r
s
.115 0 .563 r
.67773 .63351 m .67699 .61811 L .66005 .62327 L p F P
0 0 0 r
s
.115 0 .563 r
.66005 .62327 m .66071 .63864 L .67773 .63351 L p F P
0 0 0 r
s
.134 0 .891 r
.42077 .42698 m .4303 .43762 L .44651 .43187 L p F P
0 0 0 r
s
.134 0 .891 r
.4303 .43762 m .42077 .42698 L .4046 .43276 L p F P
0 0 0 r
s
.134 0 .891 r
.69882 .42653 m .70673 .43718 L .72382 .43143 L p F P
0 0 0 r
s
.134 0 .891 r
.70673 .43718 m .69882 .42653 L .68177 .43231 L p F P
0 0 0 r
s
.115 0 .563 r
.62797 .67991 m .62748 .66429 L .61069 .6693 L p F P
0 0 0 r
s
.115 0 .563 r
.61069 .6693 m .61111 .6849 L .62797 .67991 L p F P
0 0 0 r
s
.188 0 .528 r
.37673 .75488 m .37746 .73894 L .36761 .73007 L p F P
0 0 0 r
s
.188 0 .528 r
.36838 .71423 m .36761 .73007 L .37746 .73894 L p F P
0 0 0 r
s
.188 0 .528 r
.28711 .47497 m .28828 .46039 L .27791 .44988 L p F P
0 0 0 r
s
.188 0 .528 r
.27912 .43541 m .27791 .44988 L .28828 .46039 L p F P
0 0 0 r
s
.188 0 .528 r
.33192 .61492 m .33287 .59966 L .32276 .58997 L p F P
0 0 0 r
s
.188 0 .528 r
.32375 .57482 m .32276 .58997 L .33287 .59966 L p F P
0 0 0 r
s
.115 0 .563 r
.57819 .72634 m .57794 .71048 L .56131 .71535 L p F P
0 0 0 r
s
.115 0 .563 r
.56131 .71535 m .56148 .73118 L .57819 .72634 L p F P
0 0 0 r
s
.134 0 .891 r
.46282 .42608 m .47211 .43673 L .48846 .43098 L p F P
0 0 0 r
s
.134 0 .891 r
.47211 .43673 m .46282 .42608 L .44651 .43187 L p F P
0 0 0 r
s
.115 0 .563 r
.8605 .46843 m .85886 .45383 L .84134 .45952 L p F P
0 0 0 r
s
.115 0 .563 r
.84134 .45952 m .84288 .4741 L .8605 .46843 L p F P
0 0 0 r
s
.134 0 .891 r
.74102 .42564 m .74868 .43629 L .76592 .43054 L p F P
0 0 0 r
s
.134 0 .891 r
.74868 .43629 m .74102 .42564 L .72382 .43143 L p F P
0 0 0 r
s
.115 0 .563 r
.52839 .77279 m .52838 .7567 L .5119 .76143 L p F P
0 0 0 r
s
.115 0 .563 r
.5119 .76143 m .51183 .77748 L .52839 .77279 L p F P
0 0 0 r
s
.115 0 .563 r
.81075 .51483 m .80936 .5 L .79199 .50554 L p F P
0 0 0 r
s
.115 0 .563 r
.79199 .50554 m .79329 .52035 L .81075 .51483 L p F P
0 0 0 r
s
.115 0 .563 r
.47856 .81926 m .4788 .80294 L .46247 .80752 L p F P
0 0 0 r
s
.115 0 .563 r
.46247 .80752 m .46216 .82381 L .47856 .81926 L p F P
0 0 0 r
s
.134 0 .891 r
.50491 .42519 m .51396 .43585 L .53045 .43009 L p F P
0 0 0 r
s
.134 0 .891 r
.51396 .43585 m .50491 .42519 L .48846 .43098 L p F P
0 0 0 r
s
.115 0 .563 r
.76098 .56125 m .75983 .54619 L .74261 .55159 L p F P
0 0 0 r
s
.115 0 .563 r
.74261 .55159 m .74367 .56662 L .76098 .56125 L p F P
0 0 0 r
s
.134 0 .891 r
.78326 .42474 m .79068 .43541 L .80805 .42965 L p F P
0 0 0 r
s
.134 0 .891 r
.79068 .43541 m .78326 .42474 L .76592 .43054 L p F P
0 0 0 r
s
.115 0 .563 r
.42871 .86576 m .42919 .84921 L .41302 .85364 L p F P
0 0 0 r
s
.115 0 .563 r
.41302 .85364 m .41246 .87016 L .42871 .86576 L p F P
0 0 0 r
s
.188 0 .528 r
.41246 .87016 m .41302 .85364 L .40337 .84544 L p F P
0 0 0 r
s
.188 0 .528 r
.40397 .82902 m .40337 .84544 L .41302 .85364 L p F P
0 0 0 r
s
.188 0 .528 r
.36761 .73007 m .36838 .71423 L .35848 .70521 L p F P
0 0 0 r
s
.188 0 .528 r
.35929 .68948 m .35848 .70521 L .36838 .71423 L p F P
0 0 0 r
s
.188 0 .528 r
.32276 .58997 m .32375 .57482 L .31358 .56497 L p F P
0 0 0 r
s
.188 0 .528 r
.31462 .54993 m .31358 .56497 L .32375 .57482 L p F P
0 0 0 r
s
.134 0 .891 r
.26868 .42474 m .27912 .43541 L .29487 .42965 L p F P
0 0 0 r
s
.188 0 .528 r
.27791 .44988 m .27912 .43541 L .26868 .42474 L p F P
0 0 0 r
s
.115 0 .563 r
.71119 .6077 m .71028 .59241 L .69321 .59765 L p F P
0 0 0 r
s
.115 0 .563 r
.69321 .59765 m .69403 .61292 L .71119 .6077 L p F P
0 0 0 r
s
.134 0 .891 r
.54704 .4243 m .55585 .43497 L .57248 .4292 L p F P
0 0 0 r
s
.134 0 .891 r
.55585 .43497 m .54704 .4243 L .53045 .43009 L p F P
0 0 0 r
s
.134 0 .891 r
.31071 .42385 m .3209 .43453 L .33679 .42876 L p F P
0 0 0 r
s
.134 0 .891 r
.3209 .43453 m .31071 .42385 L .29487 .42965 L p F P
0 0 0 r
s
.134 0 .891 r
.82554 .42385 m .83271 .43453 L .85023 .42876 L p F P
0 0 0 r
s
.134 0 .891 r
.83271 .43453 m .82554 .42385 L .80805 .42965 L p F P
0 0 0 r
s
.115 0 .563 r
.66137 .65416 m .66071 .63864 L .64379 .64374 L p F P
0 0 0 r
s
.115 0 .563 r
.64379 .64374 m .64437 .65924 L .66137 .65416 L p F P
0 0 0 r
s
.134 0 .891 r
.58922 .4234 m .59778 .43408 L .61455 .42831 L p F P
0 0 0 r
s
.134 0 .891 r
.59778 .43408 m .58922 .4234 L .57248 .4292 L p F P
0 0 0 r
s
.115 0 .563 r
.61152 .70065 m .61111 .6849 L .59434 .68986 L p F P
0 0 0 r
s
.115 0 .563 r
.59434 .68986 m .59468 .70558 L .61152 .70065 L p F P
0 0 0 r
s
.115 0 .563 r
.89425 .44236 m .89245 .42787 L .87479 .43364 L p F P
0 0 0 r
s
.115 0 .563 r
.87479 .43364 m .8765 .44812 L .89425 .44236 L p F P
0 0 0 r
s
.134 0 .891 r
.86786 .42295 m .87479 .43364 L .89245 .42787 L p F P
0 0 0 r
s
.134 0 .891 r
.87479 .43364 m .86786 .42295 L .85023 .42876 L p F P
0 0 0 r
s
.115 0 .563 r
.56165 .74716 m .56148 .73118 L .54487 .73599 L p F P
0 0 0 r
s
.115 0 .563 r
.54487 .73599 m .54496 .75195 L .56165 .74716 L p F P
0 0 0 r
s
.134 0 .891 r
.35278 .42295 m .36273 .43364 L .37876 .42787 L p F P
0 0 0 r
s
.134 0 .891 r
.36273 .43364 m .35278 .42295 L .33679 .42876 L p F P
0 0 0 r
s
.188 0 .528 r
.40337 .84544 m .40397 .82902 L .39426 .82066 L p F P
0 0 0 r
s
.188 0 .528 r
.39491 .80436 m .39426 .82066 L .40397 .82902 L p F P
0 0 0 r
s
.188 0 .528 r
.35848 .70521 m .35929 .68948 L .34932 .6803 L p F P
0 0 0 r
s
.188 0 .528 r
.35019 .66467 m .34932 .6803 L .35929 .68948 L p F P
0 0 0 r
s
.188 0 .528 r
.31358 .56497 m .31462 .54993 L .30438 .53993 L p F P
0 0 0 r
s
.188 0 .528 r
.30547 .52499 m .30438 .53993 L .31462 .54993 L p F P
0 0 0 r
s
.134 0 .891 r
.63143 .42251 m .63975 .4332 L .65667 .42742 L p F P
0 0 0 r
s
.134 0 .891 r
.63975 .4332 m .63143 .42251 L .61455 .42831 L p F P
0 0 0 r
s
.115 0 .563 r
.84444 .48882 m .84288 .4741 L .82538 .47973 L p F P
0 0 0 r
s
.115 0 .563 r
.82538 .47973 m .82684 .49443 L .84444 .48882 L p F P
0 0 0 r
s
.115 0 .563 r
.51176 .7937 m .51183 .77748 L .49538 .78215 L p F P
0 0 0 r
s
.115 0 .563 r
.49538 .78215 m .49523 .79834 L .51176 .7937 L p F P
0 0 0 r
s
.115 0 .563 r
.7946 .5353 m .79329 .52035 L .77594 .52583 L p F P
0 0 0 r
s
.115 0 .563 r
.77594 .52583 m .77716 .54077 L .7946 .5353 L p F P
0 0 0 r
s
.134 0 .891 r
.39489 .42206 m .4046 .43276 L .42077 .42698 L p F P
0 0 0 r
s
.134 0 .891 r
.4046 .43276 m .39489 .42206 L .37876 .42787 L p F P
0 0 0 r
s
.115 0 .563 r
.46184 .84026 m .46216 .82381 L .44586 .82833 L p F P
0 0 0 r
s
.115 0 .563 r
.44586 .82833 m .44546 .84475 L .46184 .84026 L p F P
0 0 0 r
s
.115 0 .563 r
.74474 .58181 m .74367 .56662 L .72647 .57196 L p F P
0 0 0 r
s
.115 0 .563 r
.72647 .57196 m .72746 .58712 L .74474 .58181 L p F P
0 0 0 r
s
.134 0 .891 r
.67369 .42161 m .68177 .43231 L .69882 .42653 L p F P
0 0 0 r
s
.134 0 .891 r
.68177 .43231 m .67369 .42161 L .65667 .42742 L p F P
0 0 0 r
s
.115 0 .563 r
.69486 .62834 m .69403 .61292 L .67699 .61811 L p F P
0 0 0 r
s
.115 0 .563 r
.67699 .61811 m .67773 .63351 L .69486 .62834 L p F P
0 0 0 r
s
.134 0 .891 r
.43704 .42116 m .44651 .43187 L .46282 .42608 L p F P
0 0 0 r
s
.134 0 .891 r
.44651 .43187 m .43704 .42116 L .42077 .42698 L p F P
0 0 0 r
s
.188 0 .528 r
.39426 .82066 m .39491 .80436 L .38514 .79584 L p F P
0 0 0 r
s
.188 0 .528 r
.38583 .77964 m .38514 .79584 L .39491 .80436 L p F P
0 0 0 r
s
.188 0 .528 r
.34932 .6803 m .35019 .66467 L .34015 .65534 L p F P
0 0 0 r
s
.188 0 .528 r
.34106 .63982 m .34015 .65534 L .35019 .66467 L p F P
0 0 0 r
s
.188 0 .528 r
.30438 .53993 m .30547 .52499 L .29517 .51483 L p F P
0 0 0 r
s
.188 0 .528 r
.2963 .5 m .29517 .51483 L .30547 .52499 L p F P
0 0 0 r
s
.134 0 .891 r
.71599 .42071 m .72382 .43143 L .74102 .42564 L p F P
0 0 0 r
s
.134 0 .891 r
.72382 .43143 m .71599 .42071 L .69882 .42653 L p F P
0 0 0 r
s
.115 0 .563 r
.64495 .67489 m .64437 .65924 L .62748 .66429 L p F P
0 0 0 r
s
.115 0 .563 r
.62748 .66429 m .62797 .67991 L .64495 .67489 L p F P
0 0 0 r
s
.115 0 .563 r
.59502 .72147 m .59468 .70558 L .57794 .71048 L p F P
0 0 0 r
s
.115 0 .563 r
.57794 .71048 m .57819 .72634 L .59502 .72147 L p F P
0 0 0 r
s
.134 0 .891 r
.47923 .42026 m .48846 .43098 L .50491 .42519 L p F P
0 0 0 r
s
.134 0 .891 r
.48846 .43098 m .47923 .42026 L .46282 .42608 L p F P
0 0 0 r
s
.134 0 .891 r
.75833 .41981 m .76592 .43054 L .78326 .42474 L p F P
0 0 0 r
s
.134 0 .891 r
.76592 .43054 m .75833 .41981 L .74102 .42564 L p F P
0 0 0 r
s
.115 0 .563 r
.87823 .46273 m .8765 .44812 L .85886 .45383 L p F P
0 0 0 r
s
.115 0 .563 r
.85886 .45383 m .8605 .46843 L .87823 .46273 L p F P
0 0 0 r
s
.115 0 .563 r
.54506 .76806 m .54496 .75195 L .52838 .7567 L p F P
0 0 0 r
s
.115 0 .563 r
.52838 .7567 m .52839 .77279 L .54506 .76806 L p F P
0 0 0 r
s
.115 0 .563 r
.82833 .50928 m .82684 .49443 L .80936 .5 L p F P
0 0 0 r
s
.115 0 .563 r
.80936 .5 m .81075 .51483 L .82833 .50928 L p F P
0 0 0 r
s
.134 0 .891 r
.52147 .41936 m .53045 .43009 L .54704 .4243 L p F P
0 0 0 r
s
.134 0 .891 r
.53045 .43009 m .52147 .41936 L .50491 .42519 L p F P
0 0 0 r
s
.115 0 .563 r
.49507 .81468 m .49523 .79834 L .4788 .80294 L p F P
0 0 0 r
s
.115 0 .563 r
.4788 .80294 m .47856 .81926 L .49507 .81468 L p F P
0 0 0 r
s
.188 0 .528 r
.38514 .79584 m .38583 .77964 L .37599 .77097 L p F P
0 0 0 r
s
.188 0 .528 r
.37673 .75488 m .37599 .77097 L .38583 .77964 L p F P
0 0 0 r
s
.188 0 .528 r
.29517 .51483 m .2963 .5 L .28594 .48969 L p F P
0 0 0 r
s
.188 0 .528 r
.28711 .47497 m .28594 .48969 L .2963 .5 L p F P
0 0 0 r
s
.188 0 .528 r
.34015 .65534 m .34106 .63982 L .33096 .63033 L p F P
0 0 0 r
s
.188 0 .528 r
.33192 .61492 m .33096 .63033 L .34106 .63982 L p F P
0 0 0 r
s
.115 0 .563 r
.7784 .55585 m .77716 .54077 L .75983 .54619 L p F P
0 0 0 r
s
.115 0 .563 r
.75983 .54619 m .76098 .56125 L .7784 .55585 L p F P
0 0 0 r
s
.115 0 .563 r
.44507 .86133 m .44546 .84475 L .42919 .84921 L p F P
0 0 0 r
s
.115 0 .563 r
.42919 .84921 m .42871 .86576 L .44507 .86133 L p F P
0 0 0 r
s
.134 0 .891 r
.28449 .41891 m .29487 .42965 L .31071 .42385 L p F P
0 0 0 r
s
.134 0 .891 r
.29487 .42965 m .28449 .41891 L .26868 .42474 L p F P
0 0 0 r
s
.134 0 .891 r
.80071 .41891 m .80805 .42965 L .82554 .42385 L p F P
0 0 0 r
s
.134 0 .891 r
.80805 .42965 m .80071 .41891 L .78326 .42474 L p F P
0 0 0 r
s
.115 0 .563 r
.72845 .60244 m .72746 .58712 L .71028 .59241 L p F P
0 0 0 r
s
.115 0 .563 r
.71028 .59241 m .71119 .6077 L .72845 .60244 L p F P
0 0 0 r
s
.134 0 .891 r
.56374 .41846 m .57248 .4292 L .58922 .4234 L p F P
0 0 0 r
s
.134 0 .891 r
.57248 .4292 m .56374 .41846 L .54704 .4243 L p F P
0 0 0 r
s
.134 0 .891 r
.84313 .41801 m .85023 .42876 L .86786 .42295 L p F P
0 0 0 r
s
.134 0 .891 r
.85023 .42876 m .84313 .41801 L .82554 .42385 L p F P
0 0 0 r
s
.134 0 .891 r
.32666 .41801 m .33679 .42876 L .35278 .42295 L p F P
0 0 0 r
s
.134 0 .891 r
.33679 .42876 m .32666 .41801 L .31071 .42385 L p F P
0 0 0 r
s
.115 0 .563 r
.67847 .64905 m .67773 .63351 L .66071 .63864 L p F P
0 0 0 r
s
.115 0 .563 r
.66071 .63864 m .66137 .65416 L .67847 .64905 L p F P
0 0 0 r
s
.188 0 .528 r
.28594 .48969 m .28711 .47497 L .27668 .46449 L p F P
0 0 0 r
s
.188 0 .528 r
.27791 .44988 m .27668 .46449 L .28711 .47497 L p F P
0 0 0 r
s
.134 0 .891 r
.60606 .41756 m .61455 .42831 L .63143 .42251 L p F P
0 0 0 r
s
.134 0 .891 r
.61455 .42831 m .60606 .41756 L .58922 .4234 L p F P
0 0 0 r
s
.115 0 .563 r
.62847 .69569 m .62797 .67991 L .61111 .6849 L p F P
0 0 0 r
s
.115 0 .563 r
.61111 .6849 m .61152 .70065 L .62847 .69569 L p F P
0 0 0 r
s
.188 0 .528 r
.37599 .77097 m .37673 .75488 L .36683 .74606 L p F P
0 0 0 r
s
.188 0 .528 r
.36761 .73007 m .36683 .74606 L .37673 .75488 L p F P
0 0 0 r
s
.188 0 .528 r
.33096 .63033 m .33192 .61492 L .32176 .60527 L p F P
0 0 0 r
s
.188 0 .528 r
.32276 .58997 m .32176 .60527 L .33192 .61492 L p F P
0 0 0 r
s
.115 0 .563 r
.91211 .43657 m .91022 .42206 L .89245 .42787 L p F P
0 0 0 r
s
.115 0 .563 r
.89245 .42787 m .89425 .44236 L .91211 .43657 L p F P
0 0 0 r
s
.134 0 .891 r
.8856 .41711 m .89245 .42787 L .91022 .42206 L p F P
0 0 0 r
s
.134 0 .891 r
.89245 .42787 m .8856 .41711 L .86786 .42295 L p F P
0 0 0 r
s
.115 0 .563 r
.57845 .74235 m .57819 .72634 L .56148 .73118 L p F P
0 0 0 r
s
.115 0 .563 r
.56148 .73118 m .56165 .74716 L .57845 .74235 L p F P
0 0 0 r
s
.134 0 .891 r
.36887 .41711 m .37876 .42787 L .39489 .42206 L p F P
0 0 0 r
s
.134 0 .891 r
.37876 .42787 m .36887 .41711 L .35278 .42295 L p F P
0 0 0 r
s
.134 0 .891 r
.64842 .41666 m .65667 .42742 L .67369 .42161 L p F P
0 0 0 r
s
.134 0 .891 r
.65667 .42742 m .64842 .41666 L .63143 .42251 L p F P
0 0 0 r
s
.115 0 .563 r
.5284 .78903 m .52839 .77279 L .51183 .77748 L p F P
0 0 0 r
s
.115 0 .563 r
.51183 .77748 m .51176 .7937 L .5284 .78903 L p F P
0 0 0 r
s
.115 0 .563 r
.86215 .48318 m .8605 .46843 L .84288 .4741 L p F P
0 0 0 r
s
.115 0 .563 r
.84288 .4741 m .84444 .48882 L .86215 .48318 L p F P
0 0 0 r
s
.115 0 .563 r
.81216 .52981 m .81075 .51483 L .79329 .52035 L p F P
0 0 0 r
s
.115 0 .563 r
.79329 .52035 m .7946 .5353 L .81216 .52981 L p F P
0 0 0 r
s
.134 0 .891 r
.41112 .41621 m .42077 .42698 L .43704 .42116 L p F P
0 0 0 r
s
.134 0 .891 r
.42077 .42698 m .41112 .41621 L .39489 .42206 L p F P
0 0 0 r
s
.115 0 .563 r
.47833 .83574 m .47856 .81926 L .46216 .82381 L p F P
0 0 0 r
s
.115 0 .563 r
.46216 .82381 m .46184 .84026 L .47833 .83574 L p F P
0 0 0 r
s
.115 0 .563 r
.76214 .57646 m .76098 .56125 L .74367 .56662 L p F P
0 0 0 r
s
.115 0 .563 r
.74367 .56662 m .74474 .58181 L .76214 .57646 L p F P
0 0 0 r
s
.134 0 .891 r
.69082 .41576 m .69882 .42653 L .71599 .42071 L p F P
0 0 0 r
s
.134 0 .891 r
.69882 .42653 m .69082 .41576 L .67369 .42161 L p F P
0 0 0 r
s
.115 0 .563 r
.42823 .88247 m .42871 .86576 L .41246 .87016 L p F P
0 0 0 r
s
.115 0 .563 r
.41246 .87016 m .4119 .88684 L .42823 .88247 L p F P
0 0 0 r
s
.188 0 .528 r
.4119 .88684 m .41246 .87016 L .40277 .86201 L p F P
0 0 0 r
s
.188 0 .528 r
.40337 .84544 m .40277 .86201 L .41246 .87016 L p F P
0 0 0 r
s
.188 0 .528 r
.36683 .74606 m .36761 .73007 L .35765 .72109 L p F P
0 0 0 r
s
.188 0 .528 r
.35848 .70521 m .35765 .72109 L .36761 .73007 L p F P
0 0 0 r
s
.188 0 .528 r
.27668 .46449 m .27791 .44988 L .26741 .43925 L p F P
0 0 0 r
s
.188 0 .528 r
.26868 .42474 m .26741 .43925 L .27791 .44988 L p F P
0 0 0 r
s
.188 0 .528 r
.32176 .60527 m .32276 .58997 L .31253 .58017 L p F P
0 0 0 r
s
.188 0 .528 r
.31358 .56497 m .31253 .58017 L .32276 .58997 L p F P
0 0 0 r
s
.115 0 .563 r
.7121 .62314 m .71119 .6077 L .69403 .61292 L p F P
0 0 0 r
s
.115 0 .563 r
.69403 .61292 m .69486 .62834 L .7121 .62314 L p F P
0 0 0 r
s
.134 0 .891 r
.45342 .41531 m .46282 .42608 L .47923 .42026 L p F P
0 0 0 r
s
.134 0 .891 r
.46282 .42608 m .45342 .41531 L .43704 .42116 L p F P
0 0 0 r
s
.134 0 .891 r
.73326 .41486 m .74102 .42564 L .75833 .41981 L p F P
0 0 0 r
s
.134 0 .891 r
.74102 .42564 m .73326 .41486 L .71599 .42071 L p F P
0 0 0 r
s
.115 0 .563 r
.66203 .66984 m .66137 .65416 L .64437 .65924 L p F P
0 0 0 r
s
.115 0 .563 r
.64437 .65924 m .64495 .67489 L .66203 .66984 L p F P
0 0 0 r
s
.115 0 .563 r
.61194 .71656 m .61152 .70065 L .59468 .70558 L p F P
0 0 0 r
s
.115 0 .563 r
.59468 .70558 m .59502 .72147 L .61194 .71656 L p F P
0 0 0 r
s
.134 0 .891 r
.49575 .4144 m .50491 .42519 L .52147 .41936 L p F P
0 0 0 r
s
.134 0 .891 r
.50491 .42519 m .49575 .4144 L .47923 .42026 L p F P
0 0 0 r
s
.188 0 .528 r
.35765 .72109 m .35848 .70521 L .34845 .69607 L p F P
0 0 0 r
s
.188 0 .528 r
.34932 .6803 m .34845 .69607 L .35848 .70521 L p F P
0 0 0 r
s
.188 0 .528 r
.31253 .58017 m .31358 .56497 L .30329 .55501 L p F P
0 0 0 r
s
.188 0 .528 r
.30438 .53993 m .30329 .55501 L .31358 .56497 L p F P
0 0 0 r
s
.134 0 .891 r
.25813 .41395 m .26868 .42474 L .28449 .41891 L p F P
0 0 0 r
s
.188 0 .528 r
.26741 .43925 m .26868 .42474 L .25813 .41395 L p F P
0 0 0 r
s
.115 0 .563 r
.89607 .457 m .89425 .44236 L .8765 .44812 L p F P
0 0 0 r
s
.115 0 .563 r
.8765 .44812 m .87823 .46273 L .89607 .457 L p F P
0 0 0 r
s
.134 0 .891 r
.77575 .41395 m .78326 .42474 L .80071 .41891 L p F P
0 0 0 r
s
.134 0 .891 r
.78326 .42474 m .77575 .41395 L .75833 .41981 L p F P
0 0 0 r
s
.115 0 .563 r
.56183 .76331 m .56165 .74716 L .54496 .75195 L p F P
0 0 0 r
s
.115 0 .563 r
.54496 .75195 m .54506 .76806 L .56183 .76331 L p F P
0 0 0 r
s
.188 0 .528 r
.40277 .86201 m .40337 .84544 L .39361 .83713 L p F P
0 0 0 r
s
.188 0 .528 r
.39426 .82066 m .39361 .83713 L .40337 .84544 L p F P
0 0 0 r
s
.115 0 .563 r
.84601 .50369 m .84444 .48882 L .82684 .49443 L p F P
0 0 0 r
s
.115 0 .563 r
.82684 .49443 m .82833 .50928 L .84601 .50369 L p F P
0 0 0 r
s
.134 0 .891 r
.53813 .4135 m .54704 .4243 L .56374 .41846 L p F P
0 0 0 r
s
.134 0 .891 r
.54704 .4243 m .53813 .4135 L .52147 .41936 L p F P
0 0 0 r
s
.115 0 .563 r
.51169 .81008 m .51176 .7937 L .49523 .79834 L p F P
0 0 0 r
s
.115 0 .563 r
.49523 .79834 m .49507 .81468 L .51169 .81008 L p F P
0 0 0 r
s
.134 0 .891 r
.81827 .41305 m .82554 .42385 L .84313 .41801 L p F P
0 0 0 r
s
.134 0 .891 r
.82554 .42385 m .81827 .41305 L .80071 .41891 L p F P
0 0 0 r
s
.115 0 .563 r
.79593 .55041 m .7946 .5353 L .77716 .54077 L p F P
0 0 0 r
s
.115 0 .563 r
.77716 .54077 m .7784 .55585 L .79593 .55041 L p F P
0 0 0 r
s
.115 0 .563 r
.46152 .85687 m .46184 .84026 L .44546 .84475 L p F P
0 0 0 r
s
.115 0 .563 r
.44546 .84475 m .44507 .86133 L .46152 .85687 L p F P
0 0 0 r
s
.134 0 .891 r
.3004 .41305 m .31071 .42385 L .32666 .41801 L p F P
0 0 0 r
s
.134 0 .891 r
.31071 .42385 m .3004 .41305 L .28449 .41891 L p F P
0 0 0 r
s
.115 0 .563 r
.74582 .59715 m .74474 .58181 L .72746 .58712 L p F P
0 0 0 r
s
.115 0 .563 r
.72746 .58712 m .72845 .60244 L .74582 .59715 L p F P
0 0 0 r
s
.134 0 .891 r
.58055 .41259 m .58922 .4234 L .60606 .41756 L p F P
0 0 0 r
s
.134 0 .891 r
.58922 .4234 m .58055 .41259 L .56374 .41846 L p F P
0 0 0 r
s
.134 0 .891 r
.86084 .41214 m .86786 .42295 L .8856 .41711 L p F P
0 0 0 r
s
.134 0 .891 r
.86786 .42295 m .86084 .41214 L .84313 .41801 L p F P
0 0 0 r
s
.115 0 .563 r
.69569 .64391 m .69486 .62834 L .67773 .63351 L p F P
0 0 0 r
s
.115 0 .563 r
.67773 .63351 m .67847 .64905 L .69569 .64391 L p F P
0 0 0 r
s
.134 0 .891 r
.34271 .41214 m .35278 .42295 L .36887 .41711 L p F P
0 0 0 r
s
.134 0 .891 r
.35278 .42295 m .34271 .41214 L .32666 .41801 L p F P
0 0 0 r
s
.188 0 .528 r
.39361 .83713 m .39426 .82066 L .38444 .81221 L p F P
0 0 0 r
s
.188 0 .528 r
.38514 .79584 m .38444 .81221 L .39426 .82066 L p F P
0 0 0 r
s
.188 0 .528 r
.30329 .55501 m .30438 .53993 L .29403 .52981 L p F P
0 0 0 r
s
.188 0 .528 r
.29517 .51483 m .29403 .52981 L .30438 .53993 L p F P
0 0 0 r
s
.188 0 .528 r
.34845 .69607 m .34932 .6803 L .33923 .67101 L p F P
0 0 0 r
s
.188 0 .528 r
.34015 .65534 m .33923 .67101 L .34932 .6803 L p F P
0 0 0 r
s
.134 0 .891 r
.62301 .41169 m .63143 .42251 L .64842 .41666 L p F P
0 0 0 r
s
.134 0 .891 r
.63143 .42251 m .62301 .41169 L .60606 .41756 L p F P
0 0 0 r
s
.115 0 .563 r
.64554 .6907 m .64495 .67489 L .62797 .67991 L p F P
0 0 0 r
s
.115 0 .563 r
.62797 .67991 m .62847 .69569 L .64554 .6907 L p F P
0 0 0 r
s
.134 0 .891 r
.91022 .42206 m .90345 .41123 L .8856 .41711 L p F P
0 0 0 r
s
.195 0 .31 r
.90532 .42578 m .90345 .41123 L .91022 .42206 L p F P
0 0 0 r
s
.195 0 .31 r
.91022 .42206 m .91211 .43657 L .90532 .42578 L p F P
0 0 0 r
s
.115 0 .563 r
.59536 .7375 m .59502 .72147 L .57819 .72634 L p F P
0 0 0 r
s
.115 0 .563 r
.57819 .72634 m .57845 .74235 L .59536 .7375 L p F P
0 0 0 r
s
.134 0 .891 r
.38506 .41123 m .39489 .42206 L .41112 .41621 L p F P
0 0 0 r
s
.134 0 .891 r
.39489 .42206 m .38506 .41123 L .36887 .41711 L p F P
0 0 0 r
s
.115 0 .563 r
.87997 .47749 m .87823 .46273 L .8605 .46843 L p F P
0 0 0 r
s
.115 0 .563 r
.8605 .46843 m .86215 .48318 L .87997 .47749 L p F P
0 0 0 r
s
.134 0 .891 r
.66551 .41078 m .67369 .42161 L .69082 .41576 L p F P
0 0 0 r
s
.134 0 .891 r
.67369 .42161 m .66551 .41078 L .64842 .41666 L p F P
0 0 0 r
s
.115 0 .563 r
.54515 .78434 m .54506 .76806 L .52839 .77279 L p F P
0 0 0 r
s
.115 0 .563 r
.52839 .77279 m .5284 .78903 L .54515 .78434 L p F P
0 0 0 r
s
.134 0 .891 r
.42746 .41032 m .43704 .42116 L .45342 .41531 L p F P
0 0 0 r
s
.134 0 .891 r
.43704 .42116 m .42746 .41032 L .41112 .41621 L p F P
0 0 0 r
s
.188 0 .528 r
.38444 .81221 m .38514 .79584 L .37525 .78723 L p F P
0 0 0 r
s
.188 0 .528 r
.37599 .77097 m .37525 .78723 L .38514 .79584 L p F P
0 0 0 r
s
.188 0 .528 r
.33923 .67101 m .34015 .65534 L .33 .64589 L p F P
0 0 0 r
s
.188 0 .528 r
.33096 .63033 m .33 .64589 L .34015 .65534 L p F P
0 0 0 r
s
.188 0 .528 r
.29403 .52981 m .29517 .51483 L .28475 .50455 L p F P
0 0 0 r
s
.188 0 .528 r
.28594 .48969 m .28475 .50455 L .29517 .51483 L p F P
0 0 0 r
s
.115 0 .563 r
.82982 .52427 m .82833 .50928 L .81075 .51483 L p F P
0 0 0 r
s
.115 0 .563 r
.81075 .51483 m .81216 .52981 L .82982 .52427 L p F P
0 0 0 r
s
.115 0 .563 r
.49492 .83119 m .49507 .81468 L .47856 .81926 L p F P
0 0 0 r
s
.115 0 .563 r
.47856 .81926 m .47833 .83574 L .49492 .83119 L p F P
0 0 0 r
s
.115 0 .563 r
.77965 .57108 m .7784 .55585 L .76098 .56125 L p F P
0 0 0 r
s
.115 0 .563 r
.76098 .56125 m .76214 .57646 L .77965 .57108 L p F P
0 0 0 r
s
.134 0 .891 r
.70806 .40987 m .71599 .42071 L .73326 .41486 L p F P
0 0 0 r
s
.134 0 .891 r
.71599 .42071 m .70806 .40987 L .69082 .41576 L p F P
0 0 0 r
s
.115 0 .563 r
.44466 .87807 m .44507 .86133 L .42871 .86576 L p F P
0 0 0 r
s
.115 0 .563 r
.42871 .86576 m .42823 .88247 L .44466 .87807 L p F P
0 0 0 r
s
.115 0 .563 r
.72945 .6179 m .72845 .60244 L .71119 .6077 L p F P
0 0 0 r
s
.115 0 .563 r
.71119 .6077 m .7121 .62314 L .72945 .6179 L p F P
0 0 0 r
s
.134 0 .891 r
.4699 .40942 m .47923 .42026 L .49575 .4144 L p F P
0 0 0 r
s
.134 0 .891 r
.47923 .42026 m .4699 .40942 L .45342 .41531 L p F P
0 0 0 r
s
.134 0 .891 r
.75065 .40896 m .75833 .41981 L .77575 .41395 L p F P
0 0 0 r
s
.134 0 .891 r
.75833 .41981 m .75065 .40896 L .73326 .41486 L p F P
0 0 0 r
s
.115 0 .563 r
.67923 .66475 m .67847 .64905 L .66137 .65416 L p F P
0 0 0 r
s
.115 0 .563 r
.66137 .65416 m .66203 .66984 L .67923 .66475 L p F P
0 0 0 r
s
.115 0 .563 r
.62898 .71163 m .62847 .69569 L .61152 .70065 L p F P
0 0 0 r
s
.115 0 .563 r
.61152 .70065 m .61194 .71656 L .62898 .71163 L p F P
0 0 0 r
s
.134 0 .891 r
.51238 .40851 m .52147 .41936 L .53813 .4135 L p F P
0 0 0 r
s
.134 0 .891 r
.52147 .41936 m .51238 .40851 L .49575 .4144 L p F P
0 0 0 r
s
.188 0 .528 r
.37525 .78723 m .37599 .77097 L .36604 .76221 L p F P
0 0 0 r
s
.188 0 .528 r
.36683 .74606 m .36604 .76221 L .37599 .77097 L p F P
0 0 0 r
s
.188 0 .528 r
.33 .64589 m .33096 .63033 L .32074 .62073 L p F P
0 0 0 r
s
.188 0 .528 r
.32176 .60527 m .32074 .62073 L .33096 .63033 L p F P
0 0 0 r
s
.188 0 .528 r
.28475 .50455 m .28594 .48969 L .27545 .47925 L p F P
0 0 0 r
s
.188 0 .528 r
.27668 .46449 m .27545 .47925 L .28594 .48969 L p F P
0 0 0 r
s
.134 0 .891 r
.27399 .40805 m .28449 .41891 L .3004 .41305 L p F P
0 0 0 r
s
.134 0 .891 r
.28449 .41891 m .27399 .40805 L .25813 .41395 L p F P
0 0 0 r
s
.115 0 .563 r
.91403 .45122 m .91211 .43657 L .89425 .44236 L p F P
0 0 0 r
s
.115 0 .563 r
.89425 .44236 m .89607 .457 L .91403 .45122 L p F P
0 0 0 r
s
.134 0 .891 r
.79328 .40805 m .80071 .41891 L .81827 .41305 L p F P
0 0 0 r
s
.134 0 .891 r
.80071 .41891 m .79328 .40805 L .77575 .41395 L p F P
0 0 0 r
s
.115 0 .563 r
.57871 .75852 m .57845 .74235 L .56165 .74716 L p F P
0 0 0 r
s
.115 0 .563 r
.56165 .74716 m .56183 .76331 L .57871 .75852 L p F P
0 0 0 r
s
.115 0 .563 r
.86381 .49806 m .86215 .48318 L .84444 .48882 L p F P
0 0 0 r
s
.115 0 .563 r
.84444 .48882 m .84601 .50369 L .86381 .49806 L p F P
0 0 0 r
s
.134 0 .891 r
.5549 .4076 m .56374 .41846 L .58055 .41259 L p F P
0 0 0 r
s
.134 0 .891 r
.56374 .41846 m .5549 .4076 L .53813 .4135 L p F P
0 0 0 r
s
.115 0 .563 r
.52841 .80544 m .5284 .78903 L .51176 .7937 L p F P
0 0 0 r
s
.115 0 .563 r
.51176 .7937 m .51169 .81008 L .52841 .80544 L p F P
0 0 0 r
s
.115 0 .563 r
.81357 .54493 m .81216 .52981 L .7946 .5353 L p F P
0 0 0 r
s
.115 0 .563 r
.7946 .5353 m .79593 .55041 L .81357 .54493 L p F P
0 0 0 r
s
.115 0 .563 r
.47809 .85238 m .47833 .83574 L .46184 .84026 L p F P
0 0 0 r
s
.115 0 .563 r
.46184 .84026 m .46152 .85687 L .47809 .85238 L p F P
0 0 0 r
s
.134 0 .891 r
.31641 .40714 m .32666 .41801 L .34271 .41214 L p F P
0 0 0 r
s
.134 0 .891 r
.32666 .41801 m .31641 .40714 L .3004 .41305 L p F P
0 0 0 r
s
.134 0 .891 r
.83595 .40714 m .84313 .41801 L .86084 .41214 L p F P
0 0 0 r
s
.134 0 .891 r
.84313 .41801 m .83595 .40714 L .81827 .41305 L p F P
0 0 0 r
s
.115 0 .563 r
.76331 .59182 m .76214 .57646 L .74474 .58181 L p F P
0 0 0 r
s
.115 0 .563 r
.74474 .58181 m .74582 .59715 L .76331 .59182 L p F P
0 0 0 r
s
.134 0 .891 r
.59747 .40668 m .60606 .41756 L .62301 .41169 L p F P
0 0 0 r
s
.134 0 .891 r
.60606 .41756 m .59747 .40668 L .58055 .41259 L p F P
0 0 0 r
s
.115 0 .563 r
.42774 .89935 m .42823 .88247 L .4119 .88684 L p F P
0 0 0 r
s
.115 0 .563 r
.4119 .88684 m .41134 .90369 L .42774 .89935 L p F P
0 0 0 r
s
.188 0 .528 r
.41134 .90369 m .4119 .88684 L .40215 .87875 L p F P
0 0 0 r
s
.188 0 .528 r
.40277 .86201 m .40215 .87875 L .4119 .88684 L p F P
0 0 0 r
s
.188 0 .528 r
.36604 .76221 m .36683 .74606 L .35681 .73713 L p F P
0 0 0 r
s
.188 0 .528 r
.35765 .72109 m .35681 .73713 L .36683 .74606 L p F P
0 0 0 r
s
.188 0 .528 r
.32074 .62073 m .32176 .60527 L .31147 .59551 L p F P
0 0 0 r
s
.188 0 .528 r
.31253 .58017 m .31147 .59551 L .32176 .60527 L p F P
0 0 0 r
s
.188 0 .528 r
.27545 .47925 m .27668 .46449 L .26613 .45389 L p F P
0 0 0 r
s
.188 0 .528 r
.26741 .43925 m .26613 .45389 L .27668 .46449 L p F P
0 0 0 r
s
.134 0 .891 r
.87866 .40623 m .8856 .41711 L .90345 .41123 L p F P
0 0 0 r
s
.134 0 .891 r
.8856 .41711 m .87866 .40623 L .86084 .41214 L p F P
0 0 0 r
s
.115 0 .563 r
.71302 .63873 m .7121 .62314 L .69486 .62834 L p F P
0 0 0 r
s
.115 0 .563 r
.69486 .62834 m .69569 .64391 L .71302 .63873 L p F P
0 0 0 r
s
.134 0 .891 r
.35886 .40623 m .36887 .41711 L .38506 .41123 L p F P
0 0 0 r
s
.134 0 .891 r
.36887 .41711 m .35886 .40623 L .34271 .41214 L p F P
0 0 0 r
s
.134 0 .891 r
.64007 .40577 m .64842 .41666 L .66551 .41078 L p F P
0 0 0 r
s
.134 0 .891 r
.64842 .41666 m .64007 .40577 L .62301 .41169 L p F P
0 0 0 r
s
.115 0 .563 r
.66271 .68567 m .66203 .66984 L .64495 .67489 L p F P
0 0 0 r
s
.115 0 .563 r
.64495 .67489 m .64554 .6907 L .66271 .68567 L p F P
0 0 0 r
s
.115 0 .563 r
.61237 .73263 m .61194 .71656 L .59502 .72147 L p F P
0 0 0 r
s
.115 0 .563 r
.59502 .72147 m .59536 .7375 L .61237 .73263 L p F P
0 0 0 r
s
.134 0 .891 r
.40136 .40532 m .41112 .41621 L .42746 .41032 L p F P
0 0 0 r
s
.134 0 .891 r
.41112 .41621 m .40136 .40532 L .38506 .41123 L p F P
0 0 0 r
s
.115 0 .563 r
.89791 .47178 m .89607 .457 L .87823 .46273 L p F P
0 0 0 r
s
.115 0 .563 r
.87823 .46273 m .87997 .47749 L .89791 .47178 L p F P
0 0 0 r
s
.134 0 .891 r
.68272 .40486 m .69082 .41576 L .70806 .40987 L p F P
0 0 0 r
s
.134 0 .891 r
.69082 .41576 m .68272 .40486 L .66551 .41078 L p F P
0 0 0 r
s
.115 0 .563 r
.56201 .77961 m .56183 .76331 L .54506 .76806 L p F P
0 0 0 r
s
.115 0 .563 r
.54506 .76806 m .54515 .78434 L .56201 .77961 L p F P
0 0 0 r
s
.188 0 .528 r
.40215 .87875 m .40277 .86201 L .39295 .85377 L p F P
0 0 0 r
s
.188 0 .528 r
.39361 .83713 m .39295 .85377 L .40277 .86201 L p F P
0 0 0 r
s
.188 0 .528 r
.35681 .73713 m .35765 .72109 L .34757 .71201 L p F P
0 0 0 r
s
.188 0 .528 r
.34845 .69607 m .34757 .71201 L .35765 .72109 L p F P
0 0 0 r
s
.188 0 .528 r
.26613 .45389 m .26741 .43925 L .2568 .42849 L p F P
0 0 0 r
s
.188 0 .528 r
.25813 .41395 m .2568 .42849 L .26741 .43925 L p F P
0 0 0 r
s
.188 0 .528 r
.31147 .59551 m .31253 .58017 L .30218 .57025 L p F P
0 0 0 r
s
.188 0 .528 r
.30329 .55501 m .30218 .57025 L .31253 .58017 L p F P
0 0 0 r
s
.115 0 .563 r
.8476 .51871 m .84601 .50369 L .82833 .50928 L p F P
0 0 0 r
s
.115 0 .563 r
.82833 .50928 m .82982 .52427 L .8476 .51871 L p F P
0 0 0 r
s
.134 0 .891 r
.4439 .4044 m .45342 .41531 L .4699 .40942 L p F P
0 0 0 r
s
.134 0 .891 r
.45342 .41531 m .4439 .4044 L .42746 .41032 L p F P
0 0 0 r
s
.115 0 .563 r
.51162 .82662 m .51169 .81008 L .49507 .81468 L p F P
0 0 0 r
s
.115 0 .563 r
.49507 .81468 m .49492 .83119 L .51162 .82662 L p F P
0 0 0 r
s
.115 0 .563 r
.79727 .56566 m .79593 .55041 L .7784 .55585 L p F P
0 0 0 r
s
.115 0 .563 r
.7784 .55585 m .77965 .57108 L .79727 .56566 L p F P
0 0 0 r
s
.134 0 .891 r
.72541 .40394 m .73326 .41486 L .75065 .40896 L p F P
0 0 0 r
s
.134 0 .891 r
.73326 .41486 m .72541 .40394 L .70806 .40987 L p F P
0 0 0 r
s
.115 0 .563 r
.4612 .87365 m .46152 .85687 L .44507 .86133 L p F P
0 0 0 r
s
.115 0 .563 r
.44507 .86133 m .44466 .87807 L .4612 .87365 L p F P
0 0 0 r
s
.115 0 .563 r
.74692 .61263 m .74582 .59715 L .72845 .60244 L p F P
0 0 0 r
s
.115 0 .563 r
.72845 .60244 m .72945 .6179 L .74692 .61263 L p F P
0 0 0 r
s
.134 0 .891 r
.48649 .40349 m .49575 .4144 L .51238 .40851 L p F P
0 0 0 r
s
.134 0 .891 r
.49575 .4144 m .48649 .40349 L .4699 .40942 L p F P
0 0 0 r
s
.134 0 .891 r
.76814 .40303 m .77575 .41395 L .79328 .40805 L p F P
0 0 0 r
s
.134 0 .891 r
.77575 .41395 m .76814 .40303 L .75065 .40896 L p F P
0 0 0 r
s
.115 0 .563 r
.69654 .65963 m .69569 .64391 L .67847 .64905 L p F P
0 0 0 r
s
.115 0 .563 r
.67847 .64905 m .67923 .66475 L .69654 .65963 L p F P
0 0 0 r
s
.188 0 .528 r
.39295 .85377 m .39361 .83713 L .38373 .82873 L p F P
0 0 0 r
s
.188 0 .528 r
.38444 .81221 m .38373 .82873 L .39361 .83713 L p F P
0 0 0 r
s
.188 0 .528 r
.34757 .71201 m .34845 .69607 L .3383 .68683 L p F P
0 0 0 r
s
.188 0 .528 r
.33923 .67101 m .3383 .68683 L .34845 .69607 L p F P
0 0 0 r
s
.188 0 .528 r
.30218 .57025 m .30329 .55501 L .29287 .54493 L p F P
0 0 0 r
s
.188 0 .528 r
.29403 .52981 m .29287 .54493 L .30329 .55501 L p F P
0 0 0 r
s
.134 0 .891 r
.24744 .40303 m .25813 .41395 L .27399 .40805 L p F P
0 0 0 r
s
.188 0 .528 r
.2568 .42849 m .25813 .41395 L .24744 .40303 L p F P
0 0 0 r
s
.115 0 .563 r
.64613 .70666 m .64554 .6907 L .62847 .69569 L p F P
0 0 0 r
s
.115 0 .563 r
.62847 .69569 m .62898 .71163 L .64613 .70666 L p F P
0 0 0 r
s
.134 0 .891 r
.52911 .40257 m .53813 .4135 L .5549 .4076 L p F P
0 0 0 r
s
.134 0 .891 r
.53813 .4135 m .52911 .40257 L .51238 .40851 L p F P
0 0 0 r
s
.115 0 .563 r
.5957 .7537 m .59536 .7375 L .57845 .74235 L p F P
0 0 0 r
s
.115 0 .563 r
.57845 .74235 m .57871 .75852 L .5957 .7537 L p F P
0 0 0 r
s
.134 0 .891 r
.28996 .40211 m .3004 .41305 L .31641 .40714 L p F P
0 0 0 r
s
.134 0 .891 r
.3004 .41305 m .28996 .40211 L .27399 .40805 L p F P
0 0 0 r
s
.195 0 .31 r
.90721 .44046 m .90532 .42578 L .91211 .43657 L p F P
0 0 0 r
s
.195 0 .31 r
.91211 .43657 m .91403 .45122 L .90721 .44046 L p F P
0 0 0 r
s
.134 0 .891 r
.81092 .40211 m .81827 .41305 L .83595 .40714 L p F P
0 0 0 r
s
.134 0 .891 r
.81827 .41305 m .81092 .40211 L .79328 .40805 L p F P
0 0 0 r
s
.115 0 .563 r
.88173 .4924 m .87997 .47749 L .86215 .48318 L p F P
0 0 0 r
s
.115 0 .563 r
.86215 .48318 m .86381 .49806 L .88173 .4924 L p F P
0 0 0 r
s
.134 0 .891 r
.57178 .40165 m .58055 .41259 L .59747 .40668 L p F P
0 0 0 r
s
.134 0 .891 r
.58055 .41259 m .57178 .40165 L .5549 .4076 L p F P
0 0 0 r
s
.115 0 .563 r
.54524 .80077 m .54515 .78434 L .5284 .78903 L p F P
0 0 0 r
s
.115 0 .563 r
.5284 .78903 m .52841 .80544 L .54524 .80077 L p F P
0 0 0 r
s
.134 0 .891 r
.85374 .4012 m .86084 .41214 L .87866 .40623 L p F P
0 0 0 r
s
.134 0 .891 r
.86084 .41214 m .85374 .4012 L .83595 .40714 L p F P
0 0 0 r
s
.115 0 .563 r
.83133 .53942 m .82982 .52427 L .81216 .52981 L p F P
0 0 0 r
s
.115 0 .563 r
.81216 .52981 m .81357 .54493 L .83133 .53942 L p F P
0 0 0 r
s
.115 0 .563 r
.49476 .84787 m .49492 .83119 L .47833 .83574 L p F P
0 0 0 r
s
.115 0 .563 r
.47833 .83574 m .47809 .85238 L .49476 .84787 L p F P
0 0 0 r
s
.134 0 .891 r
.33252 .4012 m .34271 .41214 L .35886 .40623 L p F P
0 0 0 r
s
.134 0 .891 r
.34271 .41214 m .33252 .4012 L .31641 .40714 L p F P
0 0 0 r
s
.188 0 .528 r
.38373 .82873 m .38444 .81221 L .3745 .80365 L p F P
0 0 0 r
s
.188 0 .528 r
.37525 .78723 m .3745 .80365 L .38444 .81221 L p F P
0 0 0 r
s
.188 0 .528 r
.3383 .68683 m .33923 .67101 L .32902 .66161 L p F P
0 0 0 r
s
.188 0 .528 r
.33 .64589 m .32902 .66161 L .33923 .67101 L p F P
0 0 0 r
s
.188 0 .528 r
.29287 .54493 m .29403 .52981 L .28355 .51956 L p F P
0 0 0 r
s
.188 0 .528 r
.28475 .50455 m .28355 .51956 L .29403 .52981 L p F P
0 0 0 r
s
.115 0 .563 r
.78091 .58646 m .77965 .57108 L .76214 .57646 L p F P
0 0 0 r
s
.115 0 .563 r
.76214 .57646 m .76331 .59182 L .78091 .58646 L p F P
0 0 0 r
s
.134 0 .891 r
.61449 .40074 m .62301 .41169 L .64007 .40577 L p F P
0 0 0 r
s
.134 0 .891 r
.62301 .41169 m .61449 .40074 L .59747 .40668 L p F P
0 0 0 r
s
.115 0 .563 r
.44426 .89498 m .44466 .87807 L .42823 .88247 L p F P
0 0 0 r
s
.115 0 .563 r
.42823 .88247 m .42774 .89935 L .44426 .89498 L p F P
0 0 0 r
s
.134 0 .891 r
.90345 .41123 m .8966 .40028 L .87866 .40623 L p F P
0 0 0 r
s
.195 0 .31 r
.89845 .41485 m .8966 .40028 L .90345 .41123 L p F P
0 0 0 r
s
.195 0 .31 r
.90345 .41123 m .90532 .42578 L .89845 .41485 L p F P
0 0 0 r
s
.115 0 .563 r
.73046 .63352 m .72945 .6179 L .7121 .62314 L p F P
0 0 0 r
s
.115 0 .563 r
.7121 .62314 m .71302 .63873 L .73046 .63352 L p F P
0 0 0 r
s
.134 0 .891 r
.37512 .40028 m .38506 .41123 L .40136 .40532 L p F P
0 0 0 r
s
.134 0 .891 r
.38506 .41123 m .37512 .40028 L .35886 .40623 L p F P
0 0 0 r
s
.134 0 .891 r
.65724 .39982 m .66551 .41078 L .68272 .40486 L p F P
0 0 0 r
s
.134 0 .891 r
.66551 .41078 m .65724 .39982 L .64007 .40577 L p F P
0 0 0 r
s
.115 0 .563 r
.67999 .68061 m .67923 .66475 L .66203 .66984 L p F P
0 0 0 r
s
.115 0 .563 r
.66203 .66984 m .66271 .68567 L .67999 .68061 L p F P
0 0 0 r
s
.134 0 .891 r
.41777 .39936 m .42746 .41032 L .4439 .4044 L p F P
0 0 0 r
s
.134 0 .891 r
.42746 .41032 m .41777 .39936 L .40136 .40532 L p F P
0 0 0 r
s
.188 0 .528 r
.28355 .51956 m .28475 .50455 L .2742 .49415 L p F P
0 0 0 r
s
.188 0 .528 r
.27545 .47925 m .2742 .49415 L .28475 .50455 L p F P
0 0 0 r
s
.188 0 .528 r
.3745 .80365 m .37525 .78723 L .36524 .77852 L p F P
0 0 0 r
s
.188 0 .528 r
.36604 .76221 m .36524 .77852 L .37525 .78723 L p F P
0 0 0 r
s
.188 0 .528 r
.32902 .66161 m .33 .64589 L .31972 .63633 L p F P
0 0 0 r
s
.188 0 .528 r
.32074 .62073 m .31972 .63633 L .33 .64589 L p F P
0 0 0 r
s
.115 0 .563 r
.62949 .72772 m .62898 .71163 L .61194 .71656 L p F P
0 0 0 r
s
.115 0 .563 r
.61194 .71656 m .61237 .73263 L .62949 .72772 L p F P
0 0 0 r
s
.134 0 .891 r
.70004 .3989 m .70806 .40987 L .72541 .40394 L p F P
0 0 0 r
s
.134 0 .891 r
.70806 .40987 m .70004 .3989 L .68272 .40486 L p F P
0 0 0 r
s
.115 0 .563 r
.91596 .46602 m .91403 .45122 L .89607 .457 L p F P
0 0 0 r
s
.115 0 .563 r
.89607 .457 m .89791 .47178 L .91596 .46602 L p F P
0 0 0 r
s
.115 0 .563 r
.57897 .77485 m .57871 .75852 L .56183 .76331 L p F P
0 0 0 r
s
.115 0 .563 r
.56183 .76331 m .56201 .77961 L .57897 .77485 L p F P
0 0 0 r
s
.134 0 .891 r
.46045 .39844 m .4699 .40942 L .48649 .40349 L p F P
0 0 0 r
s
.134 0 .891 r
.4699 .40942 m .46045 .39844 L .4439 .4044 L p F P
0 0 0 r
s
.115 0 .563 r
.52842 .82201 m .52841 .80544 L .51169 .81008 L p F P
0 0 0 r
s
.115 0 .563 r
.51169 .81008 m .51162 .82662 L .52842 .82201 L p F P
0 0 0 r
s
.115 0 .563 r
.8655 .5131 m .86381 .49806 L .84601 .50369 L p F P
0 0 0 r
s
.115 0 .563 r
.84601 .50369 m .8476 .51871 L .8655 .5131 L p F P
0 0 0 r
s
.134 0 .891 r
.74288 .39798 m .75065 .40896 L .76814 .40303 L p F P
0 0 0 r
s
.134 0 .891 r
.75065 .40896 m .74288 .39798 L .72541 .40394 L p F P
0 0 0 r
s
.115 0 .563 r
.81501 .56021 m .81357 .54493 L .79593 .55041 L p F P
0 0 0 r
s
.115 0 .563 r
.79593 .55041 m .79727 .56566 L .81501 .56021 L p F P
0 0 0 r
s
.115 0 .563 r
.47785 .86919 m .47809 .85238 L .46152 .85687 L p F P
0 0 0 r
s
.115 0 .563 r
.46152 .85687 m .4612 .87365 L .47785 .86919 L p F P
0 0 0 r
s
.115 0 .563 r
.76449 .60733 m .76331 .59182 L .74582 .59715 L p F P
0 0 0 r
s
.115 0 .563 r
.74582 .59715 m .74692 .61263 L .76449 .60733 L p F P
0 0 0 r
s
.188 0 .528 r
.36524 .77852 m .36604 .76221 L .35597 .75333 L p F P
0 0 0 r
s
.188 0 .528 r
.35681 .73713 m .35597 .75333 L .36604 .76221 L p F P
0 0 0 r
s
.188 0 .528 r
.2742 .49415 m .27545 .47925 L .26484 .46868 L p F P
0 0 0 r
s
.188 0 .528 r
.26613 .45389 m .26484 .46868 L .27545 .47925 L p F P
0 0 0 r
s
.134 0 .891 r
.50318 .39752 m .51238 .40851 L .52911 .40257 L p F P
0 0 0 r
s
.134 0 .891 r
.51238 .40851 m .50318 .39752 L .48649 .40349 L p F P
0 0 0 r
s
.115 0 .563 r
.42725 .9164 m .42774 .89935 L .41134 .90369 L p F P
0 0 0 r
s
.115 0 .563 r
.41134 .90369 m .41076 .9207 L .42725 .9164 L p F P
0 0 0 r
s
.188 0 .528 r
.41076 .9207 m .41134 .90369 L .40154 .89566 L p F P
0 0 0 r
s
.188 0 .528 r
.40215 .87875 m .40154 .89566 L .41134 .90369 L p F P
0 0 0 r
s
.188 0 .528 r
.31972 .63633 m .32074 .62073 L .3104 .61101 L p F P
0 0 0 r
s
.188 0 .528 r
.31147 .59551 m .3104 .61101 L .32074 .62073 L p F P
0 0 0 r
s
.115 0 .563 r
.71395 .65448 m .71302 .63873 L .69569 .64391 L p F P
0 0 0 r
s
.115 0 .563 r
.69569 .64391 m .69654 .65963 L .71395 .65448 L p F P
0 0 0 r
s
.134 0 .891 r
.26337 .39706 m .27399 .40805 L .28996 .40211 L p F P
0 0 0 r
s
.134 0 .891 r
.27399 .40805 m .26337 .39706 L .24744 .40303 L p F P
0 0 0 r
s
.134 0 .891 r
.78576 .39706 m .79328 .40805 L .81092 .40211 L p F P
0 0 0 r
s
.134 0 .891 r
.79328 .40805 m .78576 .39706 L .76814 .40303 L p F P
0 0 0 r
s
.115 0 .563 r
.66339 .70166 m .66271 .68567 L .64554 .6907 L p F P
0 0 0 r
s
.115 0 .563 r
.64554 .6907 m .64613 .70666 L .66339 .70166 L p F P
0 0 0 r
s
.134 0 .891 r
.54595 .3966 m .5549 .4076 L .57178 .40165 L p F P
0 0 0 r
s
.134 0 .891 r
.5549 .4076 m .54595 .3966 L .52911 .40257 L p F P
0 0 0 r
s
.134 0 .891 r
.82868 .39614 m .83595 .40714 L .85374 .4012 L p F P
0 0 0 r
s
.134 0 .891 r
.83595 .40714 m .82868 .39614 L .81092 .40211 L p F P
0 0 0 r
s
.115 0 .563 r
.6128 .74886 m .61237 .73263 L .59536 .7375 L p F P
0 0 0 r
s
.115 0 .563 r
.59536 .7375 m .5957 .7537 L .6128 .74886 L p F P
0 0 0 r
s
.134 0 .891 r
.30603 .39614 m .31641 .40714 L .33252 .4012 L p F P
0 0 0 r
s
.134 0 .891 r
.31641 .40714 m .30603 .39614 L .28996 .40211 L p F P
0 0 0 r
s
.188 0 .528 r
.35597 .75333 m .35681 .73713 L .34668 .7281 L p F P
0 0 0 r
s
.188 0 .528 r
.34757 .71201 m .34668 .7281 L .35681 .73713 L p F P
0 0 0 r
s
.188 0 .528 r
.3104 .61101 m .31147 .59551 L .30107 .58563 L p F P
0 0 0 r
s
.188 0 .528 r
.30218 .57025 m .30107 .58563 L .31147 .59551 L p F P
0 0 0 r
s
.188 0 .528 r
.26484 .46868 m .26613 .45389 L .25545 .44316 L p F P
0 0 0 r
s
.188 0 .528 r
.2568 .42849 m .25545 .44316 L .26613 .45389 L p F P
0 0 0 r
s
.115 0 .563 r
.89976 .4867 m .89791 .47178 L .87997 .47749 L p F P
0 0 0 r
s
.115 0 .563 r
.87997 .47749 m .88173 .4924 L .89976 .4867 L p F P
0 0 0 r
s
.134 0 .891 r
.58877 .39568 m .59747 .40668 L .61449 .40074 L p F P
0 0 0 r
s
.134 0 .891 r
.59747 .40668 m .58877 .39568 L .57178 .40165 L p F P
0 0 0 r
s
.115 0 .563 r
.56218 .79608 m .56201 .77961 L .54515 .78434 L p F P
0 0 0 r
s
.115 0 .563 r
.54515 .78434 m .54524 .80077 L .56218 .79608 L p F P
0 0 0 r
s
.188 0 .528 r
.40154 .89566 m .40215 .87875 L .39229 .87056 L p F P
0 0 0 r
s
.188 0 .528 r
.39295 .85377 m .39229 .87056 L .40215 .87875 L p F P
0 0 0 r
s
.115 0 .563 r
.51154 .84332 m .51162 .82662 L .49492 .83119 L p F P
0 0 0 r
s
.115 0 .563 r
.49492 .83119 m .49476 .84787 L .51154 .84332 L p F P
0 0 0 r
s
.134 0 .891 r
.34874 .39521 m .35886 .40623 L .37512 .40028 L p F P
0 0 0 r
s
.134 0 .891 r
.35886 .40623 m .34874 .39521 L .33252 .4012 L p F P
0 0 0 r
s
.134 0 .891 r
.87164 .39521 m .87866 .40623 L .8966 .40028 L p F P
0 0 0 r
s
.134 0 .891 r
.87866 .40623 m .87164 .39521 L .85374 .4012 L p F P
0 0 0 r
s
.115 0 .563 r
.84921 .53387 m .8476 .51871 L .82982 .52427 L p F P
0 0 0 r
s
.115 0 .563 r
.82982 .52427 m .83133 .53942 L .84921 .53387 L p F P
0 0 0 r
s
.115 0 .563 r
.46088 .89059 m .4612 .87365 L .44466 .87807 L p F P
0 0 0 r
s
.115 0 .563 r
.44466 .87807 m .44426 .89498 L .46088 .89059 L p F P
0 0 0 r
s
.115 0 .563 r
.79863 .58106 m .79727 .56566 L .77965 .57108 L p F P
0 0 0 r
s
.115 0 .563 r
.77965 .57108 m .78091 .58646 L .79863 .58106 L p F P
0 0 0 r
s
.134 0 .891 r
.63163 .39475 m .64007 .40577 L .65724 .39982 L p F P
0 0 0 r
s
.134 0 .891 r
.64007 .40577 m .63163 .39475 L .61449 .40074 L p F P
0 0 0 r
s
.134 0 .891 r
.39149 .39429 m .40136 .40532 L .41777 .39936 L p F P
0 0 0 r
s
.134 0 .891 r
.40136 .40532 m .39149 .39429 L .37512 .40028 L p F P
0 0 0 r
s
.115 0 .563 r
.74802 .62828 m .74692 .61263 L .72945 .6179 L p F P
0 0 0 r
s
.115 0 .563 r
.72945 .6179 m .73046 .63352 L .74802 .62828 L p F P
0 0 0 r
s
.188 0 .528 r
.25545 .44316 m .2568 .42849 L .24605 .4176 L p F P
0 0 0 r
s
.188 0 .528 r
.24744 .40303 m .24605 .4176 L .2568 .42849 L p F P
0 0 0 r
s
.134 0 .891 r
.67452 .39383 m .68272 .40486 L .70004 .3989 L p F P
0 0 0 r
s
.134 0 .891 r
.68272 .40486 m .67452 .39383 L .65724 .39982 L p F P
0 0 0 r
s
.115 0 .563 r
.69739 .67552 m .69654 .65963 L .67923 .66475 L p F P
0 0 0 r
s
.115 0 .563 r
.67923 .66475 m .67999 .68061 L .69739 .67552 L p F P
0 0 0 r
s
.188 0 .528 r
.39229 .87056 m .39295 .85377 L .38302 .84542 L p F P
0 0 0 r
s
.188 0 .528 r
.38373 .82873 m .38302 .84542 L .39295 .85377 L p F P
0 0 0 r
s
.188 0 .528 r
.34668 .7281 m .34757 .71201 L .33737 .70281 L p F P
0 0 0 r
s
.188 0 .528 r
.3383 .68683 m .33737 .70281 L .34757 .71201 L p F P
0 0 0 r
s
.188 0 .528 r
.30107 .58563 m .30218 .57025 L .29171 .56021 L p F P
0 0 0 r
s
.188 0 .528 r
.29287 .54493 m .29171 .56021 L .30218 .57025 L p F P
0 0 0 r
s
.115 0 .563 r
.64673 .72278 m .64613 .70666 L .62898 .71163 L p F P
0 0 0 r
s
.115 0 .563 r
.62898 .71163 m .62949 .72772 L .64673 .72278 L p F P
0 0 0 r
s
.134 0 .891 r
.43428 .39337 m .4439 .4044 L .46045 .39844 L p F P
0 0 0 r
s
.134 0 .891 r
.4439 .4044 m .43428 .39337 L .41777 .39936 L p F P
0 0 0 r
s
.134 0 .891 r
.71747 .3929 m .72541 .40394 L .74288 .39798 L p F P
0 0 0 r
s
.134 0 .891 r
.72541 .40394 m .71747 .3929 L .70004 .3989 L p F P
0 0 0 r
s
.195 0 .31 r
.90912 .4553 m .90721 .44046 L .91403 .45122 L p F P
0 0 0 r
s
.195 0 .31 r
.91403 .45122 m .91596 .46602 L .90912 .4553 L p F P
0 0 0 r
s
.115 0 .563 r
.59605 .77006 m .5957 .7537 L .57871 .75852 L p F P
0 0 0 r
s
.115 0 .563 r
.57871 .75852 m .57897 .77485 L .59605 .77006 L p F P
0 0 0 r
s
.115 0 .563 r
.88351 .50746 m .88173 .4924 L .86381 .49806 L p F P
0 0 0 r
s
.115 0 .563 r
.86381 .49806 m .8655 .5131 L .88351 .50746 L p F P
0 0 0 r
s
.134 0 .891 r
.47711 .39244 m .48649 .40349 L .50318 .39752 L p F P
0 0 0 r
s
.134 0 .891 r
.48649 .40349 m .47711 .39244 L .46045 .39844 L p F P
0 0 0 r
s
.115 0 .563 r
.54534 .81737 m .54524 .80077 L .52841 .80544 L p F P
0 0 0 r
s
.115 0 .563 r
.52841 .80544 m .52842 .82201 L .54534 .81737 L p F P
0 0 0 r
s
.188 0 .528 r
.38302 .84542 m .38373 .82873 L .37374 .82023 L p F P
0 0 0 r
s
.188 0 .528 r
.3745 .80365 m .37374 .82023 L .38373 .82873 L p F P
0 0 0 r
s
.188 0 .528 r
.29171 .56021 m .29287 .54493 L .28234 .53473 L p F P
0 0 0 r
s
.188 0 .528 r
.28355 .51956 m .28234 .53473 L .29287 .54493 L p F P
0 0 0 r
s
.134 0 .891 r
.23663 .39198 m .24744 .40303 L .26337 .39706 L p F P
0 0 0 r
s
.188 0 .528 r
.24605 .4176 m .24744 .40303 L .23663 .39198 L p F P
0 0 0 r
s
.115 0 .563 r
.83286 .55472 m .83133 .53942 L .81357 .54493 L p F P
0 0 0 r
s
.115 0 .563 r
.81357 .54493 m .81501 .56021 L .83286 .55472 L p F P
0 0 0 r
s
.134 0 .891 r
.76045 .39198 m .76814 .40303 L .78576 .39706 L p F P
0 0 0 r
s
.134 0 .891 r
.76814 .40303 m .76045 .39198 L .74288 .39798 L p F P
0 0 0 r
s
.115 0 .563 r
.4946 .86471 m .49476 .84787 L .47809 .85238 L p F P
0 0 0 r
s
.115 0 .563 r
.47809 .85238 m .47785 .86919 L .4946 .86471 L p F P
0 0 0 r
s
.188 0 .528 r
.33737 .70281 m .3383 .68683 L .32804 .67748 L p F P
0 0 0 r
s
.188 0 .528 r
.32902 .66161 m .32804 .67748 L .3383 .68683 L p F P
0 0 0 r
s
.115 0 .563 r
.78219 .602 m .78091 .58646 L .76331 .59182 L p F P
0 0 0 r
s
.115 0 .563 r
.76331 .59182 m .76449 .60733 L .78219 .602 L p F P
0 0 0 r
s
.115 0 .563 r
.44385 .91206 m .44426 .89498 L .42774 .89935 L p F P
0 0 0 r
s
.115 0 .563 r
.42774 .89935 m .42725 .9164 L .44385 .91206 L p F P
0 0 0 r
s
.134 0 .891 r
.51999 .39151 m .52911 .40257 L .54595 .3966 L p F P
0 0 0 r
s
.134 0 .891 r
.52911 .40257 m .51999 .39151 L .50318 .39752 L p F P
0 0 0 r
s
.195 0 .31 r
.90032 .42958 m .89845 .41485 L .90532 .42578 L p F P
0 0 0 r
s
.195 0 .31 r
.90532 .42578 m .90721 .44046 L .90032 .42958 L p F P
0 0 0 r
s
.134 0 .891 r
.80348 .39105 m .81092 .40211 L .82868 .39614 L p F P
0 0 0 r
s
.134 0 .891 r
.81092 .40211 m .80348 .39105 L .78576 .39706 L p F P
0 0 0 r
s
.115 0 .563 r
.73149 .6493 m .73046 .63352 L .71302 .63873 L p F P
0 0 0 r
s
.115 0 .563 r
.71302 .63873 m .71395 .65448 L .73149 .6493 L p F P
0 0 0 r
s
.134 0 .891 r
.2794 .39105 m .28996 .40211 L .30603 .39614 L p F P
0 0 0 r
s
.134 0 .891 r
.28996 .40211 m .2794 .39105 L .26337 .39706 L p F P
0 0 0 r
s
.115 0 .563 r
.68076 .69662 m .67999 .68061 L .66271 .68567 L p F P
0 0 0 r
s
.115 0 .563 r
.66271 .68567 m .66339 .70166 L .68076 .69662 L p F P
0 0 0 r
s
.134 0 .891 r
.56291 .39059 m .57178 .40165 L .58877 .39568 L p F P
0 0 0 r
s
.134 0 .891 r
.57178 .40165 m .56291 .39059 L .54595 .3966 L p F P
0 0 0 r
s
.134 0 .891 r
.32221 .39012 m .33252 .4012 L .34874 .39521 L p F P
0 0 0 r
s
.134 0 .891 r
.33252 .4012 m .32221 .39012 L .30603 .39614 L p F P
0 0 0 r
s
.188 0 .528 r
.37374 .82023 m .3745 .80365 L .36444 .79499 L p F P
0 0 0 r
s
.188 0 .528 r
.36524 .77852 m .36444 .79499 L .3745 .80365 L p F P
0 0 0 r
s
.188 0 .528 r
.28234 .53473 m .28355 .51956 L .27294 .5092 L p F P
0 0 0 r
s
.188 0 .528 r
.2742 .49415 m .27294 .5092 L .28355 .51956 L p F P
0 0 0 r
s
.134 0 .891 r
.84655 .39012 m .85374 .4012 L .87164 .39521 L p F P
0 0 0 r
s
.134 0 .891 r
.85374 .4012 m .84655 .39012 L .82868 .39614 L p F P
0 0 0 r
s
.115 0 .563 r
.63001 .74397 m .62949 .72772 L .61237 .73263 L p F P
0 0 0 r
s
.115 0 .563 r
.61237 .73263 m .6128 .74886 L .63001 .74397 L p F P
0 0 0 r
s
.188 0 .528 r
.32804 .67748 m .32902 .66161 L .31869 .65209 L p F P
0 0 0 r
s
.188 0 .528 r
.31972 .63633 m .31869 .65209 L .32902 .66161 L p F P
0 0 0 r
s
.115 0 .563 r
.57923 .79135 m .57897 .77485 L .56201 .77961 L p F P
0 0 0 r
s
.115 0 .563 r
.56201 .77961 m .56218 .79608 L .57923 .79135 L p F P
0 0 0 r
s
.115 0 .563 r
.91791 .48097 m .91596 .46602 L .89791 .47178 L p F P
0 0 0 r
s
.115 0 .563 r
.89791 .47178 m .89976 .4867 L .91791 .48097 L p F P
0 0 0 r
s
.134 0 .891 r
.60587 .38966 m .61449 .40074 L .63163 .39475 L p F P
0 0 0 r
s
.134 0 .891 r
.61449 .40074 m .60587 .38966 L .58877 .39568 L p F P
0 0 0 r
s
.134 0 .891 r
.8966 .40028 m .88967 .38919 L .87164 .39521 L p F P
0 0 0 r
s
.195 0 .31 r
.89149 .4038 m .88967 .38919 L .8966 .40028 L p F P
0 0 0 r
s
.195 0 .31 r
.8966 .40028 m .89845 .41485 L .89149 .4038 L p F P
0 0 0 r
s
.115 0 .563 r
.8672 .52829 m .8655 .5131 L .8476 .51871 L p F P
0 0 0 r
s
.115 0 .563 r
.8476 .51871 m .84921 .53387 L .8672 .52829 L p F P
0 0 0 r
s
.115 0 .563 r
.52843 .83875 m .52842 .82201 L .51162 .82662 L p F P
0 0 0 r
s
.115 0 .563 r
.51162 .82662 m .51154 .84332 L .52843 .83875 L p F P
0 0 0 r
s
.134 0 .891 r
.36506 .38919 m .37512 .40028 L .39149 .39429 L p F P
0 0 0 r
s
.134 0 .891 r
.37512 .40028 m .36506 .38919 L .34874 .39521 L p F P
0 0 0 r
s
.115 0 .563 r
.47761 .88617 m .47785 .86919 L .4612 .87365 L p F P
0 0 0 r
s
.115 0 .563 r
.4612 .87365 m .46088 .89059 L .47761 .88617 L p F P
0 0 0 r
s
.115 0 .563 r
.81645 .57563 m .81501 .56021 L .79727 .56566 L p F P
0 0 0 r
s
.115 0 .563 r
.79727 .56566 m .79863 .58106 L .81645 .57563 L p F P
0 0 0 r
s
.134 0 .891 r
.64887 .38873 m .65724 .39982 L .67452 .39383 L p F P
0 0 0 r
s
.134 0 .891 r
.65724 .39982 m .64887 .38873 L .63163 .39475 L p F P
0 0 0 r
s
.134 0 .891 r
.40796 .38826 m .41777 .39936 L .43428 .39337 L p F P
0 0 0 r
s
.134 0 .891 r
.41777 .39936 m .40796 .38826 L .39149 .39429 L p F P
0 0 0 r
s
.115 0 .563 r
.42675 .93361 m .42725 .9164 L .41076 .9207 L p F P
0 0 0 r
s
.115 0 .563 r
.41076 .9207 m .41019 .93788 L .42675 .93361 L p F P
0 0 0 r
s
.188 0 .528 r
.41019 .93788 m .41076 .9207 L .40091 .91273 L p F P
0 0 0 r
s
.188 0 .528 r
.40154 .89566 m .40091 .91273 L .41076 .9207 L p F P
0 0 0 r
s
.188 0 .528 r
.36444 .79499 m .36524 .77852 L .35512 .7697 L p F P
0 0 0 r
s
.188 0 .528 r
.35597 .75333 m .35512 .7697 L .36524 .77852 L p F P
0 0 0 r
s
.188 0 .528 r
.31869 .65209 m .31972 .63633 L .30932 .62666 L p F P
0 0 0 r
s
.188 0 .528 r
.3104 .61101 m .30932 .62666 L .31972 .63633 L p F P
0 0 0 r
s
.188 0 .528 r
.27294 .5092 m .2742 .49415 L .26353 .48362 L p F P
0 0 0 r
s
.188 0 .528 r
.26484 .46868 m .26353 .48362 L .2742 .49415 L p F P
0 0 0 r
s
.115 0 .563 r
.76569 .623 m .76449 .60733 L .74692 .61263 L p F P
0 0 0 r
s
.115 0 .563 r
.74692 .61263 m .74802 .62828 L .76569 .623 L p F P
0 0 0 r
s
.134 0 .891 r
.69192 .3878 m .70004 .3989 L .71747 .3929 L p F P
0 0 0 r
s
.134 0 .891 r
.70004 .3989 m .69192 .3878 L .67452 .39383 L p F P
0 0 0 r
s
.115 0 .563 r
.71489 .67039 m .71395 .65448 L .69654 .65963 L p F P
0 0 0 r
s
.115 0 .563 r
.69654 .65963 m .69739 .67552 L .71489 .67039 L p F P
0 0 0 r
s
.134 0 .891 r
.45089 .38733 m .46045 .39844 L .47711 .39244 L p F P
0 0 0 r
s
.134 0 .891 r
.46045 .39844 m .45089 .38733 L .43428 .39337 L p F P
0 0 0 r
s
.115 0 .563 r
.66408 .71781 m .66339 .70166 L .64613 .70666 L p F P
0 0 0 r
s
.115 0 .563 r
.64613 .70666 m .64673 .72278 L .66408 .71781 L p F P
0 0 0 r
s
.134 0 .891 r
.73501 .38687 m .74288 .39798 L .76045 .39198 L p F P
0 0 0 r
s
.134 0 .891 r
.74288 .39798 m .73501 .38687 L .71747 .3929 L p F P
0 0 0 r
s
.115 0 .563 r
.61323 .76525 m .6128 .74886 L .5957 .7537 L p F P
0 0 0 r
s
.115 0 .563 r
.5957 .7537 m .59605 .77006 L .61323 .76525 L p F P
0 0 0 r
s
.115 0 .563 r
.56236 .81271 m .56218 .79608 L .54524 .80077 L p F P
0 0 0 r
s
.115 0 .563 r
.54524 .80077 m .54534 .81737 L .56236 .81271 L p F P
0 0 0 r
s
.188 0 .528 r
.40091 .91273 m .40154 .89566 L .39162 .88753 L p F P
0 0 0 r
s
.188 0 .528 r
.39229 .87056 m .39162 .88753 L .40154 .89566 L p F P
0 0 0 r
s
.188 0 .528 r
.35512 .7697 m .35597 .75333 L .34578 .74435 L p F P
0 0 0 r
s
.188 0 .528 r
.34668 .7281 m .34578 .74435 L .35597 .75333 L p F P
0 0 0 r
s
.188 0 .528 r
.26353 .48362 m .26484 .46868 L .2541 .45799 L p F P
0 0 0 r
s
.188 0 .528 r
.25545 .44316 m .2541 .45799 L .26484 .46868 L p F P
0 0 0 r
s
.115 0 .563 r
.90164 .50178 m .89976 .4867 L .88173 .4924 L p F P
0 0 0 r
s
.115 0 .563 r
.88173 .4924 m .88351 .50746 L .90164 .50178 L p F P
0 0 0 r
s
.134 0 .891 r
.49388 .3864 m .50318 .39752 L .51999 .39151 L p F P
0 0 0 r
s
.134 0 .891 r
.50318 .39752 m .49388 .3864 L .47711 .39244 L p F P
0 0 0 r
s
.188 0 .528 r
.30932 .62666 m .3104 .61101 L .29994 .60117 L p F P
0 0 0 r
s
.188 0 .528 r
.30107 .58563 m .29994 .60117 L .3104 .61101 L p F P
0 0 0 r
s
.134 0 .891 r
.77814 .38593 m .78576 .39706 L .80348 .39105 L p F P
0 0 0 r
s
.134 0 .891 r
.78576 .39706 m .77814 .38593 L .76045 .39198 L p F P
0 0 0 r
s
.115 0 .563 r
.51147 .86019 m .51154 .84332 L .49476 .84787 L p F P
0 0 0 r
s
.115 0 .563 r
.49476 .84787 m .4946 .86471 L .51147 .86019 L p F P
0 0 0 r
s
.134 0 .891 r
.25262 .38593 m .26337 .39706 L .2794 .39105 L p F P
0 0 0 r
s
.134 0 .891 r
.26337 .39706 m .25262 .38593 L .23663 .39198 L p F P
0 0 0 r
s
.115 0 .563 r
.85083 .54919 m .84921 .53387 L .83133 .53942 L p F P
0 0 0 r
s
.115 0 .563 r
.83133 .53942 m .83286 .55472 L .85083 .54919 L p F P
0 0 0 r
s
.115 0 .563 r
.79999 .59662 m .79863 .58106 L .78091 .58646 L p F P
0 0 0 r
s
.115 0 .563 r
.78091 .58646 m .78219 .602 L .79999 .59662 L p F P
0 0 0 r
s
.115 0 .563 r
.46055 .9077 m .46088 .89059 L .44426 .89498 L p F P
0 0 0 r
s
.115 0 .563 r
.44426 .89498 m .44385 .91206 L .46055 .9077 L p F P
0 0 0 r
s
.134 0 .891 r
.5369 .38547 m .54595 .3966 L .56291 .39059 L p F P
0 0 0 r
s
.134 0 .891 r
.54595 .3966 m .5369 .38547 L .51999 .39151 L p F P
0 0 0 r
s
.115 0 .563 r
.74913 .64408 m .74802 .62828 L .73046 .63352 L p F P
0 0 0 r
s
.115 0 .563 r
.73046 .63352 m .73149 .6493 L .74913 .64408 L p F P
0 0 0 r
s
.134 0 .891 r
.29553 .385 m .30603 .39614 L .32221 .39012 L p F P
0 0 0 r
s
.134 0 .891 r
.30603 .39614 m .29553 .385 L .2794 .39105 L p F P
0 0 0 r
s
.134 0 .891 r
.82132 .385 m .82868 .39614 L .84655 .39012 L p F P
0 0 0 r
s
.134 0 .891 r
.82868 .39614 m .82132 .385 L .80348 .39105 L p F P
0 0 0 r
s
.188 0 .528 r
.39162 .88753 m .39229 .87056 L .38231 .86228 L p F P
0 0 0 r
s
.188 0 .528 r
.38302 .84542 m .38231 .86228 L .39229 .87056 L p F P
0 0 0 r
s
.188 0 .528 r
.29994 .60117 m .30107 .58563 L .29053 .57563 L p F P
0 0 0 r
s
.188 0 .528 r
.29171 .56021 m .29053 .57563 L .30107 .58563 L p F P
0 0 0 r
s
.188 0 .528 r
.2541 .45799 m .25545 .44316 L .24465 .43231 L p F P
0 0 0 r
s
.188 0 .528 r
.24605 .4176 m .24465 .43231 L .25545 .44316 L p F P
0 0 0 r
s
.115 0 .563 r
.69825 .69156 m .69739 .67552 L .67999 .68061 L p F P
0 0 0 r
s
.115 0 .563 r
.67999 .68061 m .68076 .69662 L .69825 .69156 L p F P
0 0 0 r
s
.134 0 .891 r
.57997 .38453 m .58877 .39568 L .60587 .38966 L p F P
0 0 0 r
s
.134 0 .891 r
.58877 .39568 m .57997 .38453 L .56291 .39059 L p F P
0 0 0 r
s
.188 0 .528 r
.34578 .74435 m .34668 .7281 L .33642 .71896 L p F P
0 0 0 r
s
.188 0 .528 r
.33737 .70281 m .33642 .71896 L .34668 .7281 L p F P
0 0 0 r
s
.134 0 .891 r
.86454 .38407 m .87164 .39521 L .88967 .38919 L p F P
0 0 0 r
s
.134 0 .891 r
.87164 .39521 m .86454 .38407 L .84655 .39012 L p F P
0 0 0 r
s
.134 0 .891 r
.33849 .38407 m .34874 .39521 L .36506 .38919 L p F P
0 0 0 r
s
.134 0 .891 r
.34874 .39521 m .33849 .38407 L .32221 .39012 L p F P
0 0 0 r
s
.115 0 .563 r
.64733 .73906 m .64673 .72278 L .62949 .72772 L p F P
0 0 0 r
s
.115 0 .563 r
.62949 .72772 m .63001 .74397 L .64733 .73906 L p F P
0 0 0 r
s
.195 0 .31 r
.91105 .47028 m .90912 .4553 L .91596 .46602 L p F P
0 0 0 r
s
.195 0 .31 r
.91596 .46602 m .91791 .48097 L .91105 .47028 L p F P
0 0 0 r
s
.115 0 .563 r
.5964 .78659 m .59605 .77006 L .57897 .77485 L p F P
0 0 0 r
s
.115 0 .563 r
.57897 .77485 m .57923 .79135 L .5964 .78659 L p F P
0 0 0 r
s
.134 0 .891 r
.62308 .3836 m .63163 .39475 L .64887 .38873 L p F P
0 0 0 r
s
.134 0 .891 r
.63163 .39475 m .62308 .3836 L .60587 .38966 L p F P
0 0 0 r
s
.115 0 .563 r
.8853 .52267 m .88351 .50746 L .8655 .5131 L p F P
0 0 0 r
s
.115 0 .563 r
.8655 .5131 m .8672 .52829 L .8853 .52267 L p F P
0 0 0 r
s
.115 0 .563 r
.54543 .83414 m .54534 .81737 L .52842 .82201 L p F P
0 0 0 r
s
.115 0 .563 r
.52842 .82201 m .52843 .83875 L .54543 .83414 L p F P
0 0 0 r
s
.134 0 .891 r
.38149 .38313 m .39149 .39429 L .40796 .38826 L p F P
0 0 0 r
s
.134 0 .891 r
.39149 .39429 m .38149 .38313 L .36506 .38919 L p F P
0 0 0 r
s
.115 0 .563 r
.49444 .88172 m .4946 .86471 L .47785 .86919 L p F P
0 0 0 r
s
.115 0 .563 r
.47785 .86919 m .47761 .88617 L .49444 .88172 L p F P
0 0 0 r
s
.188 0 .528 r
.38231 .86228 m .38302 .84542 L .37297 .83698 L p F P
0 0 0 r
s
.188 0 .528 r
.37374 .82023 m .37297 .83698 L .38302 .84542 L p F P
0 0 0 r
s
.134 0 .891 r
.66623 .38266 m .67452 .39383 L .69192 .3878 L p F P
0 0 0 r
s
.134 0 .891 r
.67452 .39383 m .66623 .38266 L .64887 .38873 L p F P
0 0 0 r
s
.188 0 .528 r
.29053 .57563 m .29171 .56021 L .28111 .55004 L p F P
0 0 0 r
s
.188 0 .528 r
.28234 .53473 m .28111 .55004 L .29171 .56021 L p F P
0 0 0 r
s
.188 0 .528 r
.24465 .43231 m .24605 .4176 L .23518 .40658 L p F P
0 0 0 r
s
.188 0 .528 r
.23663 .39198 m .23518 .40658 L .24605 .4176 L p F P
0 0 0 r
s
.115 0 .563 r
.8344 .57017 m .83286 .55472 L .81501 .56021 L p F P
0 0 0 r
s
.115 0 .563 r
.81501 .56021 m .81645 .57563 L .8344 .57017 L p F P
0 0 0 r
s
.188 0 .528 r
.33642 .71896 m .33737 .70281 L .32704 .69351 L p F P
0 0 0 r
s
.188 0 .528 r
.32804 .67748 m .32704 .69351 L .33737 .70281 L p F P
0 0 0 r
s
.115 0 .563 r
.44343 .92932 m .44385 .91206 L .42725 .9164 L p F P
0 0 0 r
s
.115 0 .563 r
.42725 .9164 m .42675 .93361 L .44343 .92932 L p F P
0 0 0 r
s
.115 0 .563 r
.78347 .61769 m .78219 .602 L .76449 .60733 L p F P
0 0 0 r
s
.115 0 .563 r
.76449 .60733 m .76569 .623 L .78347 .61769 L p F P
0 0 0 r
s
.134 0 .891 r
.42453 .3822 m .43428 .39337 L .45089 .38733 L p F P
0 0 0 r
s
.134 0 .891 r
.43428 .39337 m .42453 .3822 L .40796 .38826 L p F P
0 0 0 r
s
.195 0 .31 r
.9022 .44445 m .90032 .42958 L .90721 .44046 L p F P
0 0 0 r
s
.195 0 .31 r
.90721 .44046 m .90912 .4553 L .9022 .44445 L p F P
0 0 0 r
s
.134 0 .891 r
.70943 .38173 m .71747 .3929 L .73501 .38687 L p F P
0 0 0 r
s
.134 0 .891 r
.71747 .3929 m .70943 .38173 L .69192 .3878 L p F P
0 0 0 r
s
.115 0 .563 r
.73252 .66523 m .73149 .6493 L .71395 .65448 L p F P
0 0 0 r
s
.115 0 .563 r
.71395 .65448 m .71489 .67039 L .73252 .66523 L p F P
0 0 0 r
s
.115 0 .563 r
.68154 .7128 m .68076 .69662 L .66339 .70166 L p F P
0 0 0 r
s
.115 0 .563 r
.66339 .70166 m .66408 .71781 L .68154 .7128 L p F P
0 0 0 r
s
.134 0 .891 r
.46762 .38126 m .47711 .39244 L .49388 .3864 L p F P
0 0 0 r
s
.134 0 .891 r
.47711 .39244 m .46762 .38126 L .45089 .38733 L p F P
0 0 0 r
s
.188 0 .528 r
.37297 .83698 m .37374 .82023 L .36362 .81163 L p F P
0 0 0 r
s
.188 0 .528 r
.36444 .79499 m .36362 .81163 L .37374 .82023 L p F P
0 0 0 r
s
.188 0 .528 r
.28111 .55004 m .28234 .53473 L .27167 .5244 L p F P
0 0 0 r
s
.188 0 .528 r
.27294 .5092 m .27167 .5244 L .28234 .53473 L p F P
0 0 0 r
s
.134 0 .891 r
.22569 .38079 m .23663 .39198 L .25262 .38593 L p F P
0 0 0 r
s
.188 0 .528 r
.23518 .40658 m .23663 .39198 L .22569 .38079 L p F P
0 0 0 r
s
.134 0 .891 r
.75267 .38079 m .76045 .39198 L .77814 .38593 L p F P
0 0 0 r
s
.134 0 .891 r
.76045 .39198 m .75267 .38079 L .73501 .38687 L p F P
0 0 0 r
s
.115 0 .563 r
.63053 .76039 m .63001 .74397 L .6128 .74886 L p F P
0 0 0 r
s
.115 0 .563 r
.6128 .74886 m .61323 .76525 L .63053 .76039 L p F P
0 0 0 r
s
.188 0 .528 r
.32704 .69351 m .32804 .67748 L .31765 .66801 L p F P
0 0 0 r
s
.188 0 .528 r
.31869 .65209 m .31765 .66801 L .32804 .67748 L p F P
0 0 0 r
s
.115 0 .563 r
.91988 .49607 m .91791 .48097 L .89976 .4867 L p F P
0 0 0 r
s
.115 0 .563 r
.89976 .4867 m .90164 .50178 L .91988 .49607 L p F P
0 0 0 r
s
.134 0 .891 r
.51075 .38032 m .51999 .39151 L .5369 .38547 L p F P
0 0 0 r
s
.134 0 .891 r
.51999 .39151 m .51075 .38032 L .49388 .3864 L p F P
0 0 0 r
s
.115 0 .563 r
.5795 .80801 m .57923 .79135 L .56218 .79608 L p F P
0 0 0 r
s
.115 0 .563 r
.56218 .79608 m .56236 .81271 L .5795 .80801 L p F P
0 0 0 r
s
.134 0 .891 r
.26871 .37985 m .2794 .39105 L .29553 .385 L p F P
0 0 0 r
s
.134 0 .891 r
.2794 .39105 m .26871 .37985 L .25262 .38593 L p F P
0 0 0 r
s
.195 0 .31 r
.89334 .41856 m .89149 .4038 L .89845 .41485 L p F P
0 0 0 r
s
.195 0 .31 r
.89845 .41485 m .90032 .42958 L .89334 .41856 L p F P
0 0 0 r
s
.115 0 .563 r
.86891 .54363 m .8672 .52829 L .84921 .53387 L p F P
0 0 0 r
s
.115 0 .563 r
.84921 .53387 m .85083 .54919 L .86891 .54363 L p F P
0 0 0 r
s
.134 0 .891 r
.79595 .37985 m .80348 .39105 L .82132 .385 L p F P
0 0 0 r
s
.134 0 .891 r
.80348 .39105 m .79595 .37985 L .77814 .38593 L p F P
0 0 0 r
s
.115 0 .563 r
.52844 .85565 m .52843 .83875 L .51154 .84332 L p F P
0 0 0 r
s
.115 0 .563 r
.51154 .84332 m .51147 .86019 L .52844 .85565 L p F P
0 0 0 r
s
.115 0 .563 r
.81792 .59122 m .81645 .57563 L .79863 .58106 L p F P
0 0 0 r
s
.115 0 .563 r
.79863 .58106 m .79999 .59662 L .81792 .59122 L p F P
0 0 0 r
s
.134 0 .891 r
.55392 .37938 m .56291 .39059 L .57997 .38453 L p F P
0 0 0 r
s
.134 0 .891 r
.56291 .39059 m .55392 .37938 L .5369 .38547 L p F P
0 0 0 r
s
.115 0 .563 r
.47736 .90332 m .47761 .88617 L .46088 .89059 L p F P
0 0 0 r
s
.115 0 .563 r
.46088 .89059 m .46055 .9077 L .47736 .90332 L p F P
0 0 0 r
s
.115 0 .563 r
.76689 .63883 m .76569 .623 L .74802 .62828 L p F P
0 0 0 r
s
.115 0 .563 r
.74802 .62828 m .74913 .64408 L .76689 .63883 L p F P
0 0 0 r
s
.134 0 .891 r
.31177 .37891 m .32221 .39012 L .33849 .38407 L p F P
0 0 0 r
s
.134 0 .891 r
.32221 .39012 m .31177 .37891 L .29553 .385 L p F P
0 0 0 r
s
.115 0 .563 r
.42625 .951 m .42675 .93361 L .41019 .93788 L p F P
0 0 0 r
s
.115 0 .563 r
.41019 .93788 m .4096 .95524 L .42625 .951 L p F P
0 0 0 r
s
.188 0 .528 r
.4096 .95524 m .41019 .93788 L .40028 .92998 L p F P
0 0 0 r
s
.188 0 .528 r
.40091 .91273 m .40028 .92998 L .41019 .93788 L p F P
0 0 0 r
s
.188 0 .528 r
.36362 .81163 m .36444 .79499 L .35426 .78622 L p F P
0 0 0 r
s
.188 0 .528 r
.35512 .7697 m .35426 .78622 L .36444 .79499 L p F P
0 0 0 r
s
.188 0 .528 r
.27167 .5244 m .27294 .5092 L .26221 .49871 L p F P
0 0 0 r
s
.188 0 .528 r
.26353 .48362 m .26221 .49871 L .27294 .5092 L p F P
0 0 0 r
s
.134 0 .891 r
.83928 .37891 m .84655 .39012 L .86454 .38407 L p F P
0 0 0 r
s
.134 0 .891 r
.84655 .39012 m .83928 .37891 L .82132 .385 L p F P
0 0 0 r
s
.188 0 .528 r
.31765 .66801 m .31869 .65209 L .30823 .64247 L p F P
0 0 0 r
s
.188 0 .528 r
.30932 .62666 m .30823 .64247 L .31869 .65209 L p F P
0 0 0 r
s
.115 0 .563 r
.71585 .68646 m .71489 .67039 L .69739 .67552 L p F P
0 0 0 r
s
.115 0 .563 r
.69739 .67552 m .69825 .69156 L .71585 .68646 L p F P
0 0 0 r
s
.134 0 .891 r
.59714 .37844 m .60587 .38966 L .62308 .3836 L p F P
0 0 0 r
s
.134 0 .891 r
.60587 .38966 m .59714 .37844 L .57997 .38453 L p F P
0 0 0 r
s
.134 0 .891 r
.35488 .37797 m .36506 .38919 L .38149 .38313 L p F P
0 0 0 r
s
.134 0 .891 r
.36506 .38919 m .35488 .37797 L .33849 .38407 L p F P
0 0 0 r
s
.134 0 .891 r
.88967 .38919 m .88265 .37797 L .86454 .38407 L p F P
0 0 0 r
s
.195 0 .31 r
.88445 .39261 m .88265 .37797 L .88967 .38919 L p F P
0 0 0 r
s
.195 0 .31 r
.88967 .38919 m .89149 .4038 L .88445 .39261 L p F P
0 0 0 r
s
.115 0 .563 r
.66477 .73412 m .66408 .71781 L .64673 .72278 L p F P
0 0 0 r
s
.115 0 .563 r
.64673 .72278 m .64733 .73906 L .66477 .73412 L p F P
0 0 0 r
s
.134 0 .891 r
.6404 .3775 m .64887 .38873 L .66623 .38266 L p F P
0 0 0 r
s
.134 0 .891 r
.64887 .38873 m .6404 .3775 L .62308 .3836 L p F P
0 0 0 r
s
.115 0 .563 r
.61367 .7818 m .61323 .76525 L .59605 .77006 L p F P
0 0 0 r
s
.115 0 .563 r
.59605 .77006 m .5964 .78659 L .61367 .7818 L p F P
0 0 0 r
s
.115 0 .563 r
.56255 .82951 m .56236 .81271 L .54534 .81737 L p F P
0 0 0 r
s
.115 0 .563 r
.54534 .81737 m .54543 .83414 L .56255 .82951 L p F P
0 0 0 r
s
.134 0 .891 r
.39803 .37703 m .40796 .38826 L .42453 .3822 L p F P
0 0 0 r
s
.134 0 .891 r
.40796 .38826 m .39803 .37703 L .38149 .38313 L p F P
0 0 0 r
s
.188 0 .528 r
.40028 .92998 m .40091 .91273 L .39094 .90467 L p F P
0 0 0 r
s
.188 0 .528 r
.39162 .88753 m .39094 .90467 L .40091 .91273 L p F P
0 0 0 r
s
.188 0 .528 r
.35426 .78622 m .35512 .7697 L .34487 .76077 L p F P
0 0 0 r
s
.188 0 .528 r
.34578 .74435 m .34487 .76077 L .35512 .7697 L p F P
0 0 0 r
s
.188 0 .528 r
.30823 .64247 m .30932 .62666 L .2988 .61687 L p F P
0 0 0 r
s
.188 0 .528 r
.29994 .60117 m .2988 .61687 L .30932 .62666 L p F P
0 0 0 r
s
.188 0 .528 r
.26221 .49871 m .26353 .48362 L .25273 .47297 L p F P
0 0 0 r
s
.188 0 .528 r
.2541 .45799 m .25273 .47297 L .26353 .48362 L p F P
0 0 0 r
s
.115 0 .563 r
.90353 .51701 m .90164 .50178 L .88351 .50746 L p F P
0 0 0 r
s
.115 0 .563 r
.88351 .50746 m .8853 .52267 L .90353 .51701 L p F P
0 0 0 r
s
.115 0 .563 r
.51139 .87724 m .51147 .86019 L .4946 .86471 L p F P
0 0 0 r
s
.115 0 .563 r
.4946 .86471 m .49444 .88172 L .51139 .87724 L p F P
0 0 0 r
s
.134 0 .891 r
.6837 .37656 m .69192 .3878 L .70943 .38173 L p F P
0 0 0 r
s
.134 0 .891 r
.69192 .3878 m .6837 .37656 L .66623 .38266 L p F P
0 0 0 r
s
.115 0 .563 r
.85246 .56466 m .85083 .54919 L .83286 .55472 L p F P
0 0 0 r
s
.115 0 .563 r
.83286 .55472 m .8344 .57017 L .85246 .56466 L p F P
0 0 0 r
s
.134 0 .891 r
.44122 .37609 m .45089 .38733 L .46762 .38126 L p F P
0 0 0 r
s
.134 0 .891 r
.45089 .38733 m .44122 .37609 L .42453 .3822 L p F P
0 0 0 r
s
.115 0 .563 r
.80137 .61234 m .79999 .59662 L .78219 .602 L p F P
0 0 0 r
s
.115 0 .563 r
.78219 .602 m .78347 .61769 L .80137 .61234 L p F P
0 0 0 r
s
.115 0 .563 r
.46022 .92499 m .46055 .9077 L .44385 .91206 L p F P
0 0 0 r
s
.115 0 .563 r
.44385 .91206 m .44343 .92932 L .46022 .92499 L p F P
0 0 0 r
s
.134 0 .891 r
.72705 .37562 m .73501 .38687 L .75267 .38079 L p F P
0 0 0 r
s
.134 0 .891 r
.73501 .38687 m .72705 .37562 L .70943 .38173 L p F P
0 0 0 r
s
.115 0 .563 r
.75026 .66004 m .74913 .64408 L .73149 .6493 L p F P
0 0 0 r
s
.115 0 .563 r
.73149 .6493 m .73252 .66523 L .75026 .66004 L p F P
0 0 0 r
s
.188 0 .528 r
.39094 .90467 m .39162 .88753 L .38158 .87931 L p F P
0 0 0 r
s
.188 0 .528 r
.38231 .86228 m .38158 .87931 L .39162 .88753 L p F P
0 0 0 r
s
.188 0 .528 r
.25273 .47297 m .2541 .45799 L .24323 .44717 L p F P
0 0 0 r
s
.188 0 .528 r
.24465 .43231 m .24323 .44717 L .2541 .45799 L p F P
0 0 0 r
s
.115 0 .563 r
.69911 .70776 m .69825 .69156 L .68076 .69662 L p F P
0 0 0 r
s
.115 0 .563 r
.68076 .69662 m .68154 .7128 L .69911 .70776 L p F P
0 0 0 r
s
.134 0 .891 r
.48446 .37515 m .49388 .3864 L .51075 .38032 L p F P
0 0 0 r
s
.134 0 .891 r
.49388 .3864 m .48446 .37515 L .46762 .38126 L p F P
0 0 0 r
s
.188 0 .528 r
.34487 .76077 m .34578 .74435 L .33546 .73526 L p F P
0 0 0 r
s
.188 0 .528 r
.33642 .71896 m .33546 .73526 L .34578 .74435 L p F P
0 0 0 r
s
.188 0 .528 r
.2988 .61687 m .29994 .60117 L .28935 .59122 L p F P
0 0 0 r
s
.188 0 .528 r
.29053 .57563 m .28935 .59122 L .29994 .60117 L p F P
0 0 0 r
s
.134 0 .891 r
.24174 .37468 m .25262 .38593 L .26871 .37985 L p F P
0 0 0 r
s
.134 0 .891 r
.25262 .38593 m .24174 .37468 L .22569 .38079 L p F P
0 0 0 r
s
.134 0 .891 r
.77044 .37468 m .77814 .38593 L .79595 .37985 L p F P
0 0 0 r
s
.134 0 .891 r
.77814 .38593 m .77044 .37468 L .75267 .38079 L p F P
0 0 0 r
s
.115 0 .563 r
.64795 .75551 m .64733 .73906 L .63001 .74397 L p F P
0 0 0 r
s
.115 0 .563 r
.63001 .74397 m .63053 .76039 L .64795 .75551 L p F P
0 0 0 r
s
.195 0 .31 r
.913 .48542 m .91105 .47028 L .91791 .48097 L p F P
0 0 0 r
s
.195 0 .31 r
.91791 .48097 m .91988 .49607 L .913 .48542 L p F P
0 0 0 r
s
.134 0 .891 r
.52774 .3742 m .5369 .38547 L .55392 .37938 L p F P
0 0 0 r
s
.134 0 .891 r
.5369 .38547 m .52774 .3742 L .51075 .38032 L p F P
0 0 0 r
s
.115 0 .563 r
.59675 .80328 m .5964 .78659 L .57923 .79135 L p F P
0 0 0 r
s
.115 0 .563 r
.57923 .79135 m .5795 .80801 L .59675 .80328 L p F P
0 0 0 r
s
.134 0 .891 r
.28491 .37373 m .29553 .385 L .31177 .37891 L p F P
0 0 0 r
s
.134 0 .891 r
.29553 .385 m .28491 .37373 L .26871 .37985 L p F P
0 0 0 r
s
.115 0 .563 r
.88712 .53803 m .8853 .52267 L .8672 .52829 L p F P
0 0 0 r
s
.115 0 .563 r
.8672 .52829 m .86891 .54363 L .88712 .53803 L p F P
0 0 0 r
s
.134 0 .891 r
.81388 .37373 m .82132 .385 L .83928 .37891 L p F P
0 0 0 r
s
.134 0 .891 r
.82132 .385 m .81388 .37373 L .79595 .37985 L p F P
0 0 0 r
s
.115 0 .563 r
.54553 .85108 m .54543 .83414 L .52843 .83875 L p F P
0 0 0 r
s
.115 0 .563 r
.52843 .83875 m .52844 .85565 L .54553 .85108 L p F P
0 0 0 r
s
.115 0 .563 r
.49428 .8989 m .49444 .88172 L .47761 .88617 L p F P
0 0 0 r
s
.115 0 .563 r
.47761 .88617 m .47736 .90332 L .49428 .8989 L p F P
0 0 0 r
s
.188 0 .528 r
.38158 .87931 m .38231 .86228 L .3722 .8539 L p F P
0 0 0 r
s
.188 0 .528 r
.37297 .83698 m .3722 .8539 L .38231 .86228 L p F P
0 0 0 r
s
.188 0 .528 r
.28935 .59122 m .29053 .57563 L .27987 .56551 L p F P
0 0 0 r
s
.188 0 .528 r
.28111 .55004 m .27987 .56551 L .29053 .57563 L p F P
0 0 0 r
s
.188 0 .528 r
.24323 .44717 m .24465 .43231 L .23371 .42132 L p F P
0 0 0 r
s
.188 0 .528 r
.23518 .40658 m .23371 .42132 L .24465 .43231 L p F P
0 0 0 r
s
.115 0 .563 r
.83596 .58577 m .8344 .57017 L .81645 .57563 L p F P
0 0 0 r
s
.115 0 .563 r
.81645 .57563 m .81792 .59122 L .83596 .58577 L p F P
0 0 0 r
s
.134 0 .891 r
.57106 .37326 m .57997 .38453 L .59714 .37844 L p F P
0 0 0 r
s
.134 0 .891 r
.57997 .38453 m .57106 .37326 L .55392 .37938 L p F P
0 0 0 r
s
.188 0 .528 r
.33546 .73526 m .33642 .71896 L .32604 .7097 L p F P
0 0 0 r
s
.188 0 .528 r
.32704 .69351 m .32604 .7097 L .33642 .71896 L p F P
0 0 0 r
s
.115 0 .563 r
.78477 .63354 m .78347 .61769 L .76569 .623 L p F P
0 0 0 r
s
.115 0 .563 r
.76569 .623 m .76689 .63883 L .78477 .63354 L p F P
0 0 0 r
s
.134 0 .891 r
.32812 .37279 m .33849 .38407 L .35488 .37797 L p F P
0 0 0 r
s
.134 0 .891 r
.33849 .38407 m .32812 .37279 L .31177 .37891 L p F P
0 0 0 r
s
.134 0 .891 r
.85736 .37279 m .86454 .38407 L .88265 .37797 L p F P
0 0 0 r
s
.134 0 .891 r
.86454 .38407 m .85736 .37279 L .83928 .37891 L p F P
0 0 0 r
s
.115 0 .563 r
.44301 .94674 m .44343 .92932 L .42675 .93361 L p F P
0 0 0 r
s
.115 0 .563 r
.42675 .93361 m .42625 .951 L .44301 .94674 L p F P
0 0 0 r
s
.195 0 .31 r
.90411 .45947 m .9022 .44445 L .90912 .4553 L p F P
0 0 0 r
s
.195 0 .31 r
.90912 .4553 m .91105 .47028 L .90411 .45947 L p F P
0 0 0 r
s
.115 0 .563 r
.73356 .68133 m .73252 .66523 L .71489 .67039 L p F P
0 0 0 r
s
.115 0 .563 r
.71489 .67039 m .71585 .68646 L .73356 .68133 L p F P
0 0 0 r
s
.134 0 .891 r
.61443 .37231 m .62308 .3836 L .6404 .3775 L p F P
0 0 0 r
s
.134 0 .891 r
.62308 .3836 m .61443 .37231 L .59714 .37844 L p F P
0 0 0 r
s
.115 0 .563 r
.68232 .72914 m .68154 .7128 L .66408 .71781 L p F P
0 0 0 r
s
.115 0 .563 r
.66408 .71781 m .66477 .73412 L .68232 .72914 L p F P
0 0 0 r
s
.134 0 .891 r
.37137 .37184 m .38149 .38313 L .39803 .37703 L p F P
0 0 0 r
s
.134 0 .891 r
.38149 .38313 m .37137 .37184 L .35488 .37797 L p F P
0 0 0 r
s
.188 0 .528 r
.3722 .8539 m .37297 .83698 L .3628 .82843 L p F P
0 0 0 r
s
.188 0 .528 r
.36362 .81163 m .3628 .82843 L .37297 .83698 L p F P
0 0 0 r
s
.188 0 .528 r
.23371 .42132 m .23518 .40658 L .22417 .39542 L p F P
0 0 0 r
s
.188 0 .528 r
.22569 .38079 m .22417 .39542 L .23518 .40658 L p F P
0 0 0 r
s
.134 0 .891 r
.65784 .37137 m .66623 .38266 L .6837 .37656 L p F P
0 0 0 r
s
.134 0 .891 r
.66623 .38266 m .65784 .37137 L .6404 .3775 L p F P
0 0 0 r
s
.115 0 .563 r
.63106 .77698 m .63053 .76039 L .61323 .76525 L p F P
0 0 0 r
s
.115 0 .563 r
.61323 .76525 m .61367 .7818 L .63106 .77698 L p F P
0 0 0 r
s
.188 0 .528 r
.32604 .7097 m .32704 .69351 L .31659 .6841 L p F P
0 0 0 r
s
.188 0 .528 r
.31765 .66801 m .31659 .6841 L .32704 .69351 L p F P
0 0 0 r
s
.188 0 .528 r
.27987 .56551 m .28111 .55004 L .27038 .53976 L p F P
0 0 0 r
s
.188 0 .528 r
.27167 .5244 m .27038 .53976 L .28111 .55004 L p F P
0 0 0 r
s
.115 0 .563 r
.92188 .51132 m .91988 .49607 L .90164 .50178 L p F P
0 0 0 r
s
.115 0 .563 r
.90164 .50178 m .90353 .51701 L .92188 .51132 L p F P
0 0 0 r
s
.115 0 .563 r
.57977 .82484 m .5795 .80801 L .56236 .81271 L p F P
0 0 0 r
s
.115 0 .563 r
.56236 .81271 m .56255 .82951 L .57977 .82484 L p F P
0 0 0 r
s
.134 0 .891 r
.41467 .37089 m .42453 .3822 L .44122 .37609 L p F P
0 0 0 r
s
.134 0 .891 r
.42453 .3822 m .41467 .37089 L .39803 .37703 L p F P
0 0 0 r
s
.195 0 .31 r
.8952 .43346 m .89334 .41856 L .90032 .42958 L p F P
0 0 0 r
s
.195 0 .31 r
.90032 .42958 m .9022 .44445 L .8952 .43346 L p F P
0 0 0 r
s
.134 0 .891 r
.70129 .37042 m .70943 .38173 L .72705 .37562 L p F P
0 0 0 r
s
.134 0 .891 r
.70943 .38173 m .70129 .37042 L .6837 .37656 L p F P
0 0 0 r
s
.115 0 .563 r
.52845 .87273 m .52844 .85565 L .51147 .86019 L p F P
0 0 0 r
s
.115 0 .563 r
.51147 .86019 m .51139 .87724 L .52845 .87273 L p F P
0 0 0 r
s
.115 0 .563 r
.87065 .55913 m .86891 .54363 L .85083 .54919 L p F P
0 0 0 r
s
.115 0 .563 r
.85083 .54919 m .85246 .56466 L .87065 .55913 L p F P
0 0 0 r
s
.115 0 .563 r
.47711 .92064 m .47736 .90332 L .46055 .9077 L p F P
0 0 0 r
s
.115 0 .563 r
.46055 .9077 m .46022 .92499 L .47711 .92064 L p F P
0 0 0 r
s
.115 0 .563 r
.81939 .60696 m .81792 .59122 L .79999 .59662 L p F P
0 0 0 r
s
.115 0 .563 r
.79999 .59662 m .80137 .61234 L .81939 .60696 L p F P
0 0 0 r
s
.134 0 .891 r
.45802 .36994 m .46762 .38126 L .48446 .37515 L p F P
0 0 0 r
s
.134 0 .891 r
.46762 .38126 m .45802 .36994 L .44122 .37609 L p F P
0 0 0 r
s
.188 0 .528 r
.3628 .82843 m .36362 .81163 L .35339 .80292 L p F P
0 0 0 r
s
.188 0 .528 r
.35426 .78622 m .35339 .80292 L .36362 .81163 L p F P
0 0 0 r
s
.188 0 .528 r
.27038 .53976 m .27167 .5244 L .26087 .51395 L p F P
0 0 0 r
s
.188 0 .528 r
.26221 .49871 m .26087 .51395 L .27167 .5244 L p F P
0 0 0 r
s
.115 0 .563 r
.76811 .65481 m .76689 .63883 L .74913 .64408 L p F P
0 0 0 r
s
.115 0 .563 r
.74913 .64408 m .75026 .66004 L .76811 .65481 L p F P
0 0 0 r
s
.115 0 .563 r
.42575 .96857 m .42625 .951 L .4096 .95524 L p F P
0 0 0 r
s
.115 0 .563 r
.4096 .95524 m .40901 .97277 L .42575 .96857 L p F P
0 0 0 r
s
.188 0 .528 r
.40901 .97277 m .4096 .95524 L .39964 .9474 L p F P
0 0 0 r
s
.188 0 .528 r
.40028 .92998 m .39964 .9474 L .4096 .95524 L p F P
0 0 0 r
s
.188 0 .528 r
.31659 .6841 m .31765 .66801 L .30713 .65844 L p F P
0 0 0 r
s
.188 0 .528 r
.30823 .64247 m .30713 .65844 L .31765 .66801 L p F P
0 0 0 r
s
.134 0 .891 r
.21462 .36947 m .22569 .38079 L .24174 .37468 L p F P
0 0 0 r
s
.188 0 .528 r
.22417 .39542 m .22569 .38079 L .21462 .36947 L p F P
0 0 0 r
s
.134 0 .891 r
.74479 .36947 m .75267 .38079 L .77044 .37468 L p F P
0 0 0 r
s
.134 0 .891 r
.75267 .38079 m .74479 .36947 L .72705 .37562 L p F P
0 0 0 r
s
.134 0 .891 r
.5014 .369 m .51075 .38032 L .52774 .3742 L p F P
0 0 0 r
s
.134 0 .891 r
.51075 .38032 m .5014 .369 L .48446 .37515 L p F P
0 0 0 r
s
.115 0 .563 r
.71681 .70269 m .71585 .68646 L .69825 .69156 L p F P
0 0 0 r
s
.115 0 .563 r
.69825 .69156 m .69911 .70776 L .71681 .70269 L p F P
0 0 0 r
s
.134 0 .891 r
.25789 .36852 m .26871 .37985 L .28491 .37373 L p F P
0 0 0 r
s
.134 0 .891 r
.26871 .37985 m .25789 .36852 L .24174 .37468 L p F P
0 0 0 r
s
.195 0 .31 r
.88627 .4074 m .88445 .39261 L .89149 .4038 L p F P
0 0 0 r
s
.195 0 .31 r
.89149 .4038 m .89334 .41856 L .88627 .4074 L p F P
0 0 0 r
s
.134 0 .891 r
.78833 .36852 m .79595 .37985 L .81388 .37373 L p F P
0 0 0 r
s
.134 0 .891 r
.79595 .37985 m .78833 .36852 L .77044 .37468 L p F P
0 0 0 r
s
.115 0 .563 r
.66547 .7506 m .66477 .73412 L .64733 .73906 L p F P
0 0 0 r
s
.115 0 .563 r
.64733 .73906 m .64795 .75551 L .66547 .7506 L p F P
0 0 0 r
s
.134 0 .891 r
.54483 .36805 m .55392 .37938 L .57106 .37326 L p F P
0 0 0 r
s
.134 0 .891 r
.55392 .37938 m .54483 .36805 L .52774 .3742 L p F P
0 0 0 r
s
.115 0 .563 r
.61411 .79852 m .61367 .7818 L .5964 .78659 L p F P
0 0 0 r
s
.115 0 .563 r
.5964 .78659 m .59675 .80328 L .61411 .79852 L p F P
0 0 0 r
s
.115 0 .563 r
.90544 .5324 m .90353 .51701 L .8853 .52267 L p F P
0 0 0 r
s
.115 0 .563 r
.8853 .52267 m .88712 .53803 L .90544 .5324 L p F P
0 0 0 r
s
.134 0 .891 r
.83192 .36757 m .83928 .37891 L .85736 .37279 L p F P
0 0 0 r
s
.134 0 .891 r
.83928 .37891 m .83192 .36757 L .81388 .37373 L p F P
0 0 0 r
s
.115 0 .563 r
.56273 .84648 m .56255 .82951 L .54543 .83414 L p F P
0 0 0 r
s
.115 0 .563 r
.54543 .83414 m .54553 .85108 L .56273 .84648 L p F P
0 0 0 r
s
.134 0 .891 r
.30121 .36757 m .31177 .37891 L .32812 .37279 L p F P
0 0 0 r
s
.134 0 .891 r
.31177 .37891 m .30121 .36757 L .28491 .37373 L p F P
0 0 0 r
s
.188 0 .528 r
.39964 .9474 m .40028 .92998 L .39025 .92198 L p F P
0 0 0 r
s
.188 0 .528 r
.39094 .90467 m .39025 .92198 L .40028 .92998 L p F P
0 0 0 r
s
.188 0 .528 r
.35339 .80292 m .35426 .78622 L .34395 .77735 L p F P
0 0 0 r
s
.188 0 .528 r
.34487 .76077 m .34395 .77735 L .35426 .78622 L p F P
0 0 0 r
s
.188 0 .528 r
.26087 .51395 m .26221 .49871 L .25134 .48809 L p F P
0 0 0 r
s
.188 0 .528 r
.25273 .47297 m .25134 .48809 L .26221 .49871 L p F P
0 0 0 r
s
.188 0 .528 r
.30713 .65844 m .30823 .64247 L .29765 .63272 L p F P
0 0 0 r
s
.188 0 .528 r
.2988 .61687 m .29765 .63272 L .30823 .64247 L p F P
0 0 0 r
s
.115 0 .563 r
.85412 .5803 m .85246 .56466 L .8344 .57017 L p F P
0 0 0 r
s
.115 0 .563 r
.8344 .57017 m .83596 .58577 L .85412 .5803 L p F P
0 0 0 r
s
.134 0 .891 r
.58831 .36709 m .59714 .37844 L .61443 .37231 L p F P
0 0 0 r
s
.134 0 .891 r
.59714 .37844 m .58831 .36709 L .57106 .37326 L p F P
0 0 0 r
s
.115 0 .563 r
.51132 .89445 m .51139 .87724 L .49444 .88172 L p F P
0 0 0 r
s
.115 0 .563 r
.49444 .88172 m .49428 .8989 L .51132 .89445 L p F P
0 0 0 r
s
.115 0 .563 r
.80277 .62822 m .80137 .61234 L .78347 .61769 L p F P
0 0 0 r
s
.115 0 .563 r
.78347 .61769 m .78477 .63354 L .80277 .62822 L p F P
0 0 0 r
s
.134 0 .891 r
.34457 .36662 m .35488 .37797 L .37137 .37184 L p F P
0 0 0 r
s
.134 0 .891 r
.35488 .37797 m .34457 .36662 L .32812 .37279 L p F P
0 0 0 r
s
.115 0 .563 r
.45988 .94245 m .46022 .92499 L .44343 .92932 L p F P
0 0 0 r
s
.115 0 .563 r
.44343 .92932 m .44301 .94674 L .45988 .94245 L p F P
0 0 0 r
s
.134 0 .891 r
.88265 .37797 m .87555 .36662 L .85736 .37279 L p F P
0 0 0 r
s
.195 0 .31 r
.87733 .38129 m .87555 .36662 L .88265 .37797 L p F P
0 0 0 r
s
.195 0 .31 r
.88265 .37797 m .88445 .39261 L .87733 .38129 L p F P
0 0 0 r
s
.115 0 .563 r
.75139 .67616 m .75026 .66004 L .73252 .66523 L p F P
0 0 0 r
s
.115 0 .563 r
.73252 .66523 m .73356 .68133 L .75139 .67616 L p F P
0 0 0 r
s
.134 0 .891 r
.63183 .36614 m .6404 .3775 L .65784 .37137 L p F P
0 0 0 r
s
.134 0 .891 r
.6404 .3775 m .63183 .36614 L .61443 .37231 L p F P
0 0 0 r
s
.115 0 .563 r
.69999 .72413 m .69911 .70776 L .68154 .7128 L p F P
0 0 0 r
s
.115 0 .563 r
.68154 .7128 m .68232 .72914 L .69999 .72413 L p F P
0 0 0 r
s
.134 0 .891 r
.38798 .36567 m .39803 .37703 L .41467 .37089 L p F P
0 0 0 r
s
.134 0 .891 r
.39803 .37703 m .38798 .36567 L .37137 .37184 L p F P
0 0 0 r
s
.188 0 .528 r
.39025 .92198 m .39094 .90467 L .38085 .89651 L p F P
0 0 0 r
s
.188 0 .528 r
.38158 .87931 m .38085 .89651 L .39094 .90467 L p F P
0 0 0 r
s
.188 0 .528 r
.34395 .77735 m .34487 .76077 L .3345 .75173 L p F P
0 0 0 r
s
.188 0 .528 r
.33546 .73526 m .3345 .75173 L .34487 .76077 L p F P
0 0 0 r
s
.188 0 .528 r
.29765 .63272 m .2988 .61687 L .28815 .60696 L p F P
0 0 0 r
s
.188 0 .528 r
.28935 .59122 m .28815 .60696 L .2988 .61687 L p F P
0 0 0 r
s
.188 0 .528 r
.25134 .48809 m .25273 .47297 L .2418 .46218 L p F P
0 0 0 r
s
.188 0 .528 r
.24323 .44717 m .2418 .46218 L .25273 .47297 L p F P
0 0 0 r
s
.134 0 .891 r
.67539 .36519 m .6837 .37656 L .70129 .37042 L p F P
0 0 0 r
s
.134 0 .891 r
.6837 .37656 m .67539 .36519 L .65784 .37137 L p F P
0 0 0 r
s
.115 0 .563 r
.64856 .77213 m .64795 .75551 L .63053 .76039 L p F P
0 0 0 r
s
.115 0 .563 r
.63053 .76039 m .63106 .77698 L .64856 .77213 L p F P
0 0 0 r
s
.115 0 .563 r
.59711 .82014 m .59675 .80328 L .5795 .80801 L p F P
0 0 0 r
s
.115 0 .563 r
.5795 .80801 m .57977 .82484 L .59711 .82014 L p F P
0 0 0 r
s
.134 0 .891 r
.43143 .36471 m .44122 .37609 L .45802 .36994 L p F P
0 0 0 r
s
.134 0 .891 r
.44122 .37609 m .43143 .36471 L .41467 .37089 L p F P
0 0 0 r
s
.195 0 .31 r
.91497 .50071 m .913 .48542 L .91988 .49607 L p F P
0 0 0 r
s
.195 0 .31 r
.91988 .49607 m .92188 .51132 L .91497 .50071 L p F P
0 0 0 r
s
.134 0 .891 r
.71899 .36423 m .72705 .37562 L .74479 .36947 L p F P
0 0 0 r
s
.134 0 .891 r
.72705 .37562 m .71899 .36423 L .70129 .37042 L p F P
0 0 0 r
s
.115 0 .563 r
.54563 .86819 m .54553 .85108 L .52844 .85565 L p F P
0 0 0 r
s
.115 0 .563 r
.52844 .85565 m .52845 .87273 L .54563 .86819 L p F P
0 0 0 r
s
.115 0 .563 r
.88895 .55355 m .88712 .53803 L .86891 .54363 L p F P
0 0 0 r
s
.115 0 .563 r
.86891 .54363 m .87065 .55913 L .88895 .55355 L p F P
0 0 0 r
s
.188 0 .528 r
.2418 .46218 m .24323 .44717 L .23223 .43622 L p F P
0 0 0 r
s
.188 0 .528 r
.23371 .42132 m .23223 .43622 L .24323 .44717 L p F P
0 0 0 r
s
.134 0 .891 r
.47492 .36376 m .48446 .37515 L .5014 .369 L p F P
0 0 0 r
s
.134 0 .891 r
.48446 .37515 m .47492 .36376 L .45802 .36994 L p F P
0 0 0 r
s
.115 0 .563 r
.49412 .91625 m .49428 .8989 L .47736 .90332 L p F P
0 0 0 r
s
.115 0 .563 r
.47736 .90332 m .47711 .92064 L .49412 .91625 L p F P
0 0 0 r
s
.188 0 .528 r
.38085 .89651 m .38158 .87931 L .37142 .87098 L p F P
0 0 0 r
s
.188 0 .528 r
.3722 .8539 m .37142 .87098 L .38158 .87931 L p F P
0 0 0 r
s
.188 0 .528 r
.3345 .75173 m .33546 .73526 L .32502 .72606 L p F P
0 0 0 r
s
.188 0 .528 r
.32604 .7097 m .32502 .72606 L .33546 .73526 L p F P
0 0 0 r
s
.188 0 .528 r
.28815 .60696 m .28935 .59122 L .27863 .58114 L p F P
0 0 0 r
s
.188 0 .528 r
.27987 .56551 m .27863 .58114 L .28935 .59122 L p F P
0 0 0 r
s
.115 0 .563 r
.83753 .60154 m .83596 .58577 L .81792 .59122 L p F P
0 0 0 r
s
.115 0 .563 r
.81792 .59122 m .81939 .60696 L .83753 .60154 L p F P
0 0 0 r
s
.134 0 .891 r
.76265 .36328 m .77044 .37468 L .78833 .36852 L p F P
0 0 0 r
s
.134 0 .891 r
.77044 .37468 m .76265 .36328 L .74479 .36947 L p F P
0 0 0 r
s
.115 0 .563 r
.78609 .64955 m .78477 .63354 L .76689 .63883 L p F P
0 0 0 r
s
.115 0 .563 r
.76689 .63883 m .76811 .65481 L .78609 .64955 L p F P
0 0 0 r
s
.115 0 .563 r
.44259 .96435 m .44301 .94674 L .42625 .951 L p F P
0 0 0 r
s
.115 0 .563 r
.42625 .951 m .42575 .96857 L .44259 .96435 L p F P
0 0 0 r
s
.134 0 .891 r
.23073 .36328 m .24174 .37468 L .25789 .36852 L p F P
0 0 0 r
s
.134 0 .891 r
.24174 .37468 m .23073 .36328 L .21462 .36947 L p F P
0 0 0 r
s
.195 0 .31 r
.90604 .47464 m .90411 .45947 L .91105 .47028 L p F P
0 0 0 r
s
.195 0 .31 r
.91105 .47028 m .913 .48542 L .90604 .47464 L p F P
0 0 0 r
s
.115 0 .563 r
.73461 .69759 m .73356 .68133 L .71585 .68646 L p F P
0 0 0 r
s
.115 0 .563 r
.71585 .68646 m .71681 .70269 L .73461 .69759 L p F P
0 0 0 r
s
.134 0 .891 r
.51846 .3628 m .52774 .3742 L .54483 .36805 L p F P
0 0 0 r
s
.134 0 .891 r
.52774 .3742 m .51846 .3628 L .5014 .369 L p F P
0 0 0 r
s
.134 0 .891 r
.80634 .36232 m .81388 .37373 L .83192 .36757 L p F P
0 0 0 r
s
.134 0 .891 r
.81388 .37373 m .80634 .36232 L .78833 .36852 L p F P
0 0 0 r
s
.134 0 .891 r
.27415 .36232 m .28491 .37373 L .30121 .36757 L p F P
0 0 0 r
s
.134 0 .891 r
.28491 .37373 m .27415 .36232 L .25789 .36852 L p F P
0 0 0 r
s
.115 0 .563 r
.68312 .74565 m .68232 .72914 L .66477 .73412 L p F P
0 0 0 r
s
.115 0 .563 r
.66477 .73412 m .66547 .7506 L .68312 .74565 L p F P
0 0 0 r
s
.188 0 .528 r
.23223 .43622 m .23371 .42132 L .22264 .4102 L p F P
0 0 0 r
s
.188 0 .528 r
.22417 .39542 m .22264 .4102 L .23371 .42132 L p F P
0 0 0 r
s
.188 0 .528 r
.37142 .87098 m .3722 .8539 L .36197 .84541 L p F P
0 0 0 r
s
.188 0 .528 r
.3628 .82843 m .36197 .84541 L .3722 .8539 L p F P
0 0 0 r
s
.188 0 .528 r
.27863 .58114 m .27987 .56551 L .26908 .55527 L p F P
0 0 0 r
s
.188 0 .528 r
.27038 .53976 m .26908 .55527 L .27987 .56551 L p F P
0 0 0 r
s
.134 0 .891 r
.56204 .36185 m .57106 .37326 L .58831 .36709 L p F P
0 0 0 r
s
.134 0 .891 r
.57106 .37326 m .56204 .36185 L .54483 .36805 L p F P
0 0 0 r
s
.115 0 .563 r
.63159 .79373 m .63106 .77698 L .61367 .7818 L p F P
0 0 0 r
s
.115 0 .563 r
.61367 .7818 m .61411 .79852 L .63159 .79373 L p F P
0 0 0 r
s
.188 0 .528 r
.32502 .72606 m .32604 .7097 L .31553 .70034 L p F P
0 0 0 r
s
.188 0 .528 r
.31659 .6841 m .31553 .70034 L .32604 .7097 L p F P
0 0 0 r
s
.134 0 .891 r
.31762 .36137 m .32812 .37279 L .34457 .36662 L p F P
0 0 0 r
s
.134 0 .891 r
.32812 .37279 m .31762 .36137 L .30121 .36757 L p F P
0 0 0 r
s
.115 0 .563 r
.92389 .52673 m .92188 .51132 L .90353 .51701 L p F P
0 0 0 r
s
.115 0 .563 r
.90353 .51701 m .90544 .5324 L .92389 .52673 L p F P
0 0 0 r
s
.134 0 .891 r
.85008 .36137 m .85736 .37279 L .87555 .36662 L p F P
0 0 0 r
s
.134 0 .891 r
.85736 .37279 m .85008 .36137 L .83192 .36757 L p F P
0 0 0 r
s
.115 0 .563 r
.58004 .84184 m .57977 .82484 L .56255 .82951 L p F P
0 0 0 r
s
.115 0 .563 r
.56255 .82951 m .56273 .84648 L .58004 .84184 L p F P
0 0 0 r
s
.115 0 .563 r
.52847 .88998 m .52845 .87273 L .51139 .87724 L p F P
0 0 0 r
s
.115 0 .563 r
.51139 .87724 m .51132 .89445 L .52847 .88998 L p F P
0 0 0 r
s
.195 0 .31 r
.89708 .44852 m .8952 .43346 L .9022 .44445 L p F P
0 0 0 r
s
.195 0 .31 r
.9022 .44445 m .90411 .45947 L .89708 .44852 L p F P
0 0 0 r
s
.115 0 .563 r
.8724 .57478 m .87065 .55913 L .85246 .56466 L p F P
0 0 0 r
s
.115 0 .563 r
.85246 .56466 m .85412 .5803 L .8724 .57478 L p F P
0 0 0 r
s
.134 0 .891 r
.60567 .36089 m .61443 .37231 L .63183 .36614 L p F P
0 0 0 r
s
.134 0 .891 r
.61443 .37231 m .60567 .36089 L .58831 .36709 L p F P
0 0 0 r
s
.115 0 .563 r
.47686 .93814 m .47711 .92064 L .46022 .92499 L p F P
0 0 0 r
s
.115 0 .563 r
.46022 .92499 m .45988 .94245 L .47686 .93814 L p F P
0 0 0 r
s
.115 0 .563 r
.82088 .62286 m .81939 .60696 L .80137 .61234 L p F P
0 0 0 r
s
.115 0 .563 r
.80137 .61234 m .80277 .62822 L .82088 .62286 L p F P
0 0 0 r
s
.134 0 .891 r
.36113 .36041 m .37137 .37184 L .38798 .36567 L p F P
0 0 0 r
s
.134 0 .891 r
.37137 .37184 m .36113 .36041 L .34457 .36662 L p F P
0 0 0 r
s
.188 0 .528 r
.36197 .84541 m .3628 .82843 L .35251 .81978 L p F P
0 0 0 r
s
.188 0 .528 r
.35339 .80292 m .35251 .81978 L .3628 .82843 L p F P
0 0 0 r
s
.115 0 .563 r
.76934 .67096 m .76811 .65481 L .75026 .66004 L p F P
0 0 0 r
s
.115 0 .563 r
.75026 .66004 m .75139 .67616 L .76934 .67096 L p F P
0 0 0 r
s
.134 0 .891 r
.64934 .35993 m .65784 .37137 L .67539 .36519 L p F P
0 0 0 r
s
.134 0 .891 r
.65784 .37137 m .64934 .35993 L .63183 .36614 L p F P
0 0 0 r
s
.115 0 .563 r
.42523 .98632 m .42575 .96857 L .40901 .97277 L p F P
0 0 0 r
s
.115 0 .563 r
.40901 .97277 m .40842 .99048 L .42523 .98632 L p F P
0 0 0 r
s
.188 0 .528 r
.40842 .99048 m .40901 .97277 L .399 .965 L p F P
0 0 0 r
s
.188 0 .528 r
.39964 .9474 m .399 .965 L .40901 .97277 L p F P
0 0 0 r
s
.188 0 .528 r
.31553 .70034 m .31659 .6841 L .30602 .67457 L p F P
0 0 0 r
s
.188 0 .528 r
.30713 .65844 m .30602 .67457 L .31659 .6841 L p F P
0 0 0 r
s
.188 0 .528 r
.26908 .55527 m .27038 .53976 L .25953 .52935 L p F P
0 0 0 r
s
.188 0 .528 r
.26087 .51395 m .25953 .52935 L .27038 .53976 L p F P
0 0 0 r
s
.188 0 .528 r
.22264 .4102 m .22417 .39542 L .21303 .38413 L p F P
0 0 0 r
s
.188 0 .528 r
.21462 .36947 m .21303 .38413 L .22417 .39542 L p F P
0 0 0 r
s
.115 0 .563 r
.71778 .71909 m .71681 .70269 L .69911 .70776 L p F P
0 0 0 r
s
.115 0 .563 r
.69911 .70776 m .69999 .72413 L .71778 .71909 L p F P
0 0 0 r
s
.134 0 .891 r
.40469 .35945 m .41467 .37089 L .43143 .36471 L p F P
0 0 0 r
s
.134 0 .891 r
.41467 .37089 m .40469 .35945 L .38798 .36567 L p F P
0 0 0 r
s
.195 0 .31 r
.88811 .42234 m .88627 .4074 L .89334 .41856 L p F P
0 0 0 r
s
.195 0 .31 r
.89334 .41856 m .8952 .43346 L .88811 .42234 L p F P
0 0 0 r
s
.134 0 .891 r
.69306 .35897 m .70129 .37042 L .71899 .36423 L p F P
0 0 0 r
s
.134 0 .891 r
.70129 .37042 m .69306 .35897 L .67539 .36519 L p F P
0 0 0 r
s
.115 0 .563 r
.66618 .76724 m .66547 .7506 L .64795 .75551 L p F P
0 0 0 r
s
.115 0 .563 r
.64795 .75551 m .64856 .77213 L .66618 .76724 L p F P
0 0 0 r
s
.115 0 .563 r
.61456 .81542 m .61411 .79852 L .59675 .80328 L p F P
0 0 0 r
s
.115 0 .563 r
.59675 .80328 m .59711 .82014 L .61456 .81542 L p F P
0 0 0 r
s
.134 0 .891 r
.44829 .35849 m .45802 .36994 L .47492 .36376 L p F P
0 0 0 r
s
.134 0 .891 r
.45802 .36994 m .44829 .35849 L .43143 .36471 L p F P
0 0 0 r
s
.188 0 .528 r
.25953 .52935 m .26087 .51395 L .24995 .50337 L p F P
0 0 0 r
s
.188 0 .528 r
.25134 .48809 m .24995 .50337 L .26087 .51395 L p F P
0 0 0 r
s
.134 0 .891 r
.20341 .35801 m .21462 .36947 L .23073 .36328 L p F P
0 0 0 r
s
.188 0 .528 r
.21303 .38413 m .21462 .36947 L .20341 .35801 L p F P
0 0 0 r
s
.115 0 .563 r
.56291 .86362 m .56273 .84648 L .54553 .85108 L p F P
0 0 0 r
s
.115 0 .563 r
.54553 .85108 m .54563 .86819 L .56291 .86362 L p F P
0 0 0 r
s
.188 0 .528 r
.35251 .81978 m .35339 .80292 L .34302 .7941 L p F P
0 0 0 r
s
.188 0 .528 r
.34395 .77735 m .34302 .7941 L .35339 .80292 L p F P
0 0 0 r
s
.134 0 .891 r
.73681 .35801 m .74479 .36947 L .76265 .36328 L p F P
0 0 0 r
s
.134 0 .891 r
.74479 .36947 m .73681 .35801 L .71899 .36423 L p F P
0 0 0 r
s
.188 0 .528 r
.399 .965 m .39964 .9474 L .38956 .93947 L p F P
0 0 0 r
s
.188 0 .528 r
.39025 .92198 m .38956 .93947 L .39964 .9474 L p F P
0 0 0 r
s
.188 0 .528 r
.30602 .67457 m .30713 .65844 L .29649 .64874 L p F P
0 0 0 r
s
.188 0 .528 r
.29765 .63272 m .29649 .64874 L .30713 .65844 L p F P
0 0 0 r
s
.115 0 .563 r
.90737 .54794 m .90544 .5324 L .88712 .53803 L p F P
0 0 0 r
s
.115 0 .563 r
.88712 .53803 m .88895 .55355 L .90737 .54794 L p F P
0 0 0 r
s
.134 0 .891 r
.49194 .35753 m .5014 .369 L .51846 .3628 L p F P
0 0 0 r
s
.134 0 .891 r
.5014 .369 m .49194 .35753 L .47492 .36376 L p F P
0 0 0 r
s
.115 0 .563 r
.51124 .91184 m .51132 .89445 L .49428 .8989 L p F P
0 0 0 r
s
.115 0 .563 r
.49428 .8989 m .49412 .91625 L .51124 .91184 L p F P
0 0 0 r
s
.115 0 .563 r
.85579 .59609 m .85412 .5803 L .83596 .58577 L p F P
0 0 0 r
s
.115 0 .563 r
.83596 .58577 m .83753 .60154 L .85579 .59609 L p F P
0 0 0 r
s
.115 0 .563 r
.80418 .64425 m .80277 .62822 L .78477 .63354 L p F P
0 0 0 r
s
.115 0 .563 r
.78477 .63354 m .78609 .64955 L .80418 .64425 L p F P
0 0 0 r
s
.134 0 .891 r
.24694 .35705 m .25789 .36852 L .27415 .36232 L p F P
0 0 0 r
s
.134 0 .891 r
.25789 .36852 m .24694 .35705 L .23073 .36328 L p F P
0 0 0 r
s
.195 0 .31 r
.87912 .39611 m .87733 .38129 L .88445 .39261 L p F P
0 0 0 r
s
.195 0 .31 r
.88445 .39261 m .88627 .4074 L .87912 .39611 L p F P
0 0 0 r
s
.134 0 .891 r
.78062 .35705 m .78833 .36852 L .80634 .36232 L p F P
0 0 0 r
s
.134 0 .891 r
.78833 .36852 m .78062 .35705 L .76265 .36328 L p F P
0 0 0 r
s
.115 0 .563 r
.45954 .96009 m .45988 .94245 L .44301 .94674 L p F P
0 0 0 r
s
.115 0 .563 r
.44301 .94674 m .44259 .96435 L .45954 .96009 L p F P
0 0 0 r
s
.115 0 .563 r
.75254 .69245 m .75139 .67616 L .73356 .68133 L p F P
0 0 0 r
s
.115 0 .563 r
.73356 .68133 m .73461 .69759 L .75254 .69245 L p F P
0 0 0 r
s
.134 0 .891 r
.53563 .35657 m .54483 .36805 L .56204 .36185 L p F P
0 0 0 r
s
.134 0 .891 r
.54483 .36805 m .53563 .35657 L .51846 .3628 L p F P
0 0 0 r
s
.134 0 .891 r
.29052 .35609 m .30121 .36757 L .31762 .36137 L p F P
0 0 0 r
s
.134 0 .891 r
.30121 .36757 m .29052 .35609 L .27415 .36232 L p F P
0 0 0 r
s
.188 0 .528 r
.24995 .50337 m .25134 .48809 L .24035 .47735 L p F P
0 0 0 r
s
.188 0 .528 r
.2418 .46218 m .24035 .47735 L .25134 .48809 L p F P
0 0 0 r
s
.134 0 .891 r
.82447 .35609 m .83192 .36757 L .85008 .36137 L p F P
0 0 0 r
s
.134 0 .891 r
.83192 .36757 m .82447 .35609 L .80634 .36232 L p F P
0 0 0 r
s
.188 0 .528 r
.38956 .93947 m .39025 .92198 L .38011 .91388 L p F P
0 0 0 r
s
.188 0 .528 r
.38085 .89651 m .38011 .91388 L .39025 .92198 L p F P
0 0 0 r
s
.115 0 .563 r
.70088 .74067 m .69999 .72413 L .68232 .72914 L p F P
0 0 0 r
s
.115 0 .563 r
.68232 .72914 m .68312 .74565 L .70088 .74067 L p F P
0 0 0 r
s
.188 0 .528 r
.34302 .7941 m .34395 .77735 L .33352 .76837 L p F P
0 0 0 r
s
.188 0 .528 r
.3345 .75173 m .33352 .76837 L .34395 .77735 L p F P
0 0 0 r
s
.188 0 .528 r
.29649 .64874 m .29765 .63272 L .28693 .62286 L p F P
0 0 0 r
s
.188 0 .528 r
.28815 .60696 m .28693 .62286 L .29765 .63272 L p F P
0 0 0 r
s
.134 0 .891 r
.57937 .35561 m .58831 .36709 L .60567 .36089 L p F P
0 0 0 r
s
.134 0 .891 r
.58831 .36709 m .57937 .35561 L .56204 .36185 L p F P
0 0 0 r
s
.115 0 .563 r
.64919 .78891 m .64856 .77213 L .63106 .77698 L p F P
0 0 0 r
s
.115 0 .563 r
.63106 .77698 m .63159 .79373 L .64919 .78891 L p F P
0 0 0 r
s
.134 0 .891 r
.87555 .36662 m .86836 .35512 L .85008 .36137 L p F P
0 0 0 r
s
.195 0 .31 r
.87011 .36983 m .86836 .35512 L .87555 .36662 L p F P
0 0 0 r
s
.195 0 .31 r
.87555 .36662 m .87733 .38129 L .87011 .36983 L p F P
0 0 0 r
s
.115 0 .563 r
.59747 .83718 m .59711 .82014 L .57977 .82484 L p F P
0 0 0 r
s
.115 0 .563 r
.57977 .82484 m .58004 .84184 L .59747 .83718 L p F P
0 0 0 r
s
.195 0 .31 r
.91696 .51616 m .91497 .50071 L .92188 .51132 L p F P
0 0 0 r
s
.195 0 .31 r
.92188 .51132 m .92389 .52673 L .91696 .51616 L p F P
0 0 0 r
s
.134 0 .891 r
.33414 .35512 m .34457 .36662 L .36113 .36041 L p F P
0 0 0 r
s
.134 0 .891 r
.34457 .36662 m .33414 .35512 L .31762 .36137 L p F P
0 0 0 r
s
.115 0 .563 r
.8908 .56923 m .88895 .55355 L .87065 .55913 L p F P
0 0 0 r
s
.115 0 .563 r
.87065 .55913 m .8724 .57478 L .8908 .56923 L p F P
0 0 0 r
s
.134 0 .891 r
.62315 .35464 m .63183 .36614 L .64934 .35993 L p F P
0 0 0 r
s
.134 0 .891 r
.63183 .36614 m .62315 .35464 L .60567 .36089 L p F P
0 0 0 r
s
.115 0 .563 r
.54573 .88547 m .54563 .86819 L .52845 .87273 L p F P
0 0 0 r
s
.115 0 .563 r
.52845 .87273 m .52847 .88998 L .54573 .88547 L p F P
0 0 0 r
s
.134 0 .891 r
.37781 .35416 m .38798 .36567 L .40469 .35945 L p F P
0 0 0 r
s
.134 0 .891 r
.38798 .36567 m .37781 .35416 L .36113 .36041 L p F P
0 0 0 r
s
.188 0 .528 r
.28693 .62286 m .28815 .60696 L .27736 .59693 L p F P
0 0 0 r
s
.188 0 .528 r
.27863 .58114 m .27736 .59693 L .28815 .60696 L p F P
0 0 0 r
s
.188 0 .528 r
.24035 .47735 m .2418 .46218 L .23073 .45127 L p F P
0 0 0 r
s
.188 0 .528 r
.23223 .43622 m .23073 .45127 L .2418 .46218 L p F P
0 0 0 r
s
.115 0 .563 r
.83912 .61747 m .83753 .60154 L .81939 .60696 L p F P
0 0 0 r
s
.115 0 .563 r
.81939 .60696 m .82088 .62286 L .83912 .61747 L p F P
0 0 0 r
s
.115 0 .563 r
.49396 .93379 m .49412 .91625 L .47711 .92064 L p F P
0 0 0 r
s
.115 0 .563 r
.47711 .92064 m .47686 .93814 L .49396 .93379 L p F P
0 0 0 r
s
.188 0 .528 r
.38011 .91388 m .38085 .89651 L .37063 .88825 L p F P
0 0 0 r
s
.188 0 .528 r
.37142 .87098 m .37063 .88825 L .38085 .89651 L p F P
0 0 0 r
s
.188 0 .528 r
.33352 .76837 m .3345 .75173 L .324 .74259 L p F P
0 0 0 r
s
.188 0 .528 r
.32502 .72606 m .324 .74259 L .3345 .75173 L p F P
0 0 0 r
s
.115 0 .563 r
.78741 .66573 m .78609 .64955 L .76811 .65481 L p F P
0 0 0 r
s
.115 0 .563 r
.76811 .65481 m .76934 .67096 L .78741 .66573 L p F P
0 0 0 r
s
.134 0 .891 r
.66697 .35368 m .67539 .36519 L .69306 .35897 L p F P
0 0 0 r
s
.134 0 .891 r
.67539 .36519 m .66697 .35368 L .64934 .35993 L p F P
0 0 0 r
s
.115 0 .563 r
.44216 .98213 m .44259 .96435 L .42575 .96857 L p F P
0 0 0 r
s
.115 0 .563 r
.42575 .96857 m .42523 .98632 L .44216 .98213 L p F P
0 0 0 r
s
.134 0 .891 r
.42152 .35319 m .43143 .36471 L .44829 .35849 L p F P
0 0 0 r
s
.134 0 .891 r
.43143 .36471 m .42152 .35319 L .40469 .35945 L p F P
0 0 0 r
s
.195 0 .31 r
.90798 .48997 m .90604 .47464 L .913 .48542 L p F P
0 0 0 r
s
.195 0 .31 r
.913 .48542 m .91497 .50071 L .90798 .48997 L p F P
0 0 0 r
s
.115 0 .563 r
.73568 .71401 m .73461 .69759 L .71681 .70269 L p F P
0 0 0 r
s
.115 0 .563 r
.71681 .70269 m .71778 .71909 L .73568 .71401 L p F P
0 0 0 r
s
.134 0 .891 r
.71084 .35271 m .71899 .36423 L .73681 .35801 L p F P
0 0 0 r
s
.134 0 .891 r
.71899 .36423 m .71084 .35271 L .69306 .35897 L p F P
0 0 0 r
s
.115 0 .563 r
.68392 .76232 m .68312 .74565 L .66547 .7506 L p F P
0 0 0 r
s
.115 0 .563 r
.66547 .7506 m .66618 .76724 L .68392 .76232 L p F P
0 0 0 r
s
.188 0 .528 r
.37063 .88825 m .37142 .87098 L .36114 .86256 L p F P
0 0 0 r
s
.188 0 .528 r
.36197 .84541 m .36114 .86256 L .37142 .87098 L p F P
0 0 0 r
s
.188 0 .528 r
.23073 .45127 m .23223 .43622 L .22109 .42513 L p F P
0 0 0 r
s
.188 0 .528 r
.22264 .4102 m .22109 .42513 L .23223 .43622 L p F P
0 0 0 r
s
.134 0 .891 r
.46527 .35223 m .47492 .36376 L .49194 .35753 L p F P
0 0 0 r
s
.134 0 .891 r
.47492 .36376 m .46527 .35223 L .44829 .35849 L p F P
0 0 0 r
s
.115 0 .563 r
.63213 .81066 m .63159 .79373 L .61411 .79852 L p F P
0 0 0 r
s
.115 0 .563 r
.61411 .79852 m .61456 .81542 L .63213 .81066 L p F P
0 0 0 r
s
.188 0 .528 r
.324 .74259 m .32502 .72606 L .31445 .71675 L p F P
0 0 0 r
s
.188 0 .528 r
.31553 .70034 m .31445 .71675 L .32502 .72606 L p F P
0 0 0 r
s
.188 0 .528 r
.27736 .59693 m .27863 .58114 L .26777 .57094 L p F P
0 0 0 r
s
.188 0 .528 r
.26908 .55527 m .26777 .57094 L .27863 .58114 L p F P
0 0 0 r
s
.134 0 .891 r
.21958 .35174 m .23073 .36328 L .24694 .35705 L p F P
0 0 0 r
s
.134 0 .891 r
.23073 .36328 m .21958 .35174 L .20341 .35801 L p F P
0 0 0 r
s
.115 0 .563 r
.58032 .85902 m .58004 .84184 L .56273 .84648 L p F P
0 0 0 r
s
.115 0 .563 r
.56273 .84648 m .56291 .86362 L .58032 .85902 L p F P
0 0 0 r
s
.115 0 .563 r
.92592 .54229 m .92389 .52673 L .90544 .5324 L p F P
0 0 0 r
s
.115 0 .563 r
.90544 .5324 m .90737 .54794 L .92592 .54229 L p F P
0 0 0 r
s
.134 0 .891 r
.75475 .35174 m .76265 .36328 L .78062 .35705 L p F P
0 0 0 r
s
.134 0 .891 r
.76265 .36328 m .75475 .35174 L .73681 .35801 L p F P
0 0 0 r
s
.115 0 .563 r
.52848 .9074 m .52847 .88998 L .51132 .89445 L p F P
0 0 0 r
s
.115 0 .563 r
.51132 .89445 m .51124 .91184 L .52848 .9074 L p F P
0 0 0 r
s
.195 0 .31 r
.89898 .46373 m .89708 .44852 L .90411 .45947 L p F P
0 0 0 r
s
.195 0 .31 r
.90411 .45947 m .90604 .47464 L .89898 .46373 L p F P
0 0 0 r
s
.134 0 .891 r
.50907 .35126 m .51846 .3628 L .53563 .35657 L p F P
0 0 0 r
s
.134 0 .891 r
.51846 .3628 m .50907 .35126 L .49194 .35753 L p F P
0 0 0 r
s
.115 0 .563 r
.87417 .59059 m .8724 .57478 L .85412 .5803 L p F P
0 0 0 r
s
.115 0 .563 r
.85412 .5803 m .85579 .59609 L .87417 .59059 L p F P
0 0 0 r
s
.115 0 .563 r
.82239 .63892 m .82088 .62286 L .80277 .62822 L p F P
0 0 0 r
s
.115 0 .563 r
.80277 .62822 m .80418 .64425 L .82239 .63892 L p F P
0 0 0 r
s
.115 0 .563 r
.47661 .95581 m .47686 .93814 L .45988 .94245 L p F P
0 0 0 r
s
.115 0 .563 r
.45988 .94245 m .45954 .96009 L .47661 .95581 L p F P
0 0 0 r
s
.134 0 .891 r
.26326 .35078 m .27415 .36232 L .29052 .35609 L p F P
0 0 0 r
s
.134 0 .891 r
.27415 .36232 m .26326 .35078 L .24694 .35705 L p F P
0 0 0 r
s
.134 0 .891 r
.79871 .35078 m .80634 .36232 L .82447 .35609 L p F P
0 0 0 r
s
.134 0 .891 r
.80634 .36232 m .79871 .35078 L .78062 .35705 L p F P
0 0 0 r
s
.188 0 .528 r
.36114 .86256 m .36197 .84541 L .35162 .83682 L p F P
0 0 0 r
s
.188 0 .528 r
.35251 .81978 m .35162 .83682 L .36197 .84541 L p F P
0 0 0 r
s
.188 0 .528 r
.26777 .57094 m .26908 .55527 L .25816 .5449 L p F P
0 0 0 r
s
.188 0 .528 r
.25953 .52935 m .25816 .5449 L .26908 .55527 L p F P
0 0 0 r
s
.115 0 .563 r
.77059 .68728 m .76934 .67096 L .75139 .67616 L p F P
0 0 0 r
s
.115 0 .563 r
.75139 .67616 m .75254 .69245 L .77059 .68728 L p F P
0 0 0 r
s
.134 0 .891 r
.55292 .35029 m .56204 .36185 L .57937 .35561 L p F P
0 0 0 r
s
.134 0 .891 r
.56204 .36185 m .55292 .35029 L .53563 .35657 L p F P
0 0 0 r
s
.115 0 .563 r
.42472 1.00425 m .42523 .98632 L .40842 .99048 L p F P
0 0 0 r
s
.115 0 .563 r
.40842 .99048 m .40782 1.00837 L .42472 1.00425 L p F P
0 0 0 r
s
.188 0 .528 r
.40782 1.00837 m .40842 .99048 L .39835 .98278 L p F P
0 0 0 r
s
.188 0 .528 r
.399 .965 m .39835 .98278 L .40842 .99048 L p F P
0 0 0 r
s
.188 0 .528 r
.31445 .71675 m .31553 .70034 L .30489 .69086 L p F P
0 0 0 r
s
.188 0 .528 r
.30602 .67457 m .30489 .69086 L .31553 .70034 L p F P
0 0 0 r
s
.188 0 .528 r
.22109 .42513 m .22264 .4102 L .21143 .39895 L p F P
0 0 0 r
s
.188 0 .528 r
.21303 .38413 m .21143 .39895 L .22264 .4102 L p F P
0 0 0 r
s
.134 0 .891 r
.30699 .34981 m .31762 .36137 L .33414 .35512 L p F P
0 0 0 r
s
.134 0 .891 r
.31762 .36137 m .30699 .34981 L .29052 .35609 L p F P
0 0 0 r
s
.134 0 .891 r
.84272 .34981 m .85008 .36137 L .86836 .35512 L p F P
0 0 0 r
s
.134 0 .891 r
.85008 .36137 m .84272 .34981 L .82447 .35609 L p F P
0 0 0 r
s
.115 0 .563 r
.71876 .73565 m .71778 .71909 L .69999 .72413 L p F P
0 0 0 r
s
.115 0 .563 r
.69999 .72413 m .70088 .74067 L .71876 .73565 L p F P
0 0 0 r
s
.195 0 .31 r
.88997 .43743 m .88811 .42234 L .8952 .43346 L p F P
0 0 0 r
s
.195 0 .31 r
.8952 .43346 m .89708 .44852 L .88997 .43743 L p F P
0 0 0 r
s
.134 0 .891 r
.5968 .34932 m .60567 .36089 L .62315 .35464 L p F P
0 0 0 r
s
.134 0 .891 r
.60567 .36089 m .5968 .34932 L .57937 .35561 L p F P
0 0 0 r
s
.115 0 .563 r
.6669 .78406 m .66618 .76724 L .64856 .77213 L p F P
0 0 0 r
s
.115 0 .563 r
.64856 .77213 m .64919 .78891 L .6669 .78406 L p F P
0 0 0 r
s
.134 0 .891 r
.35077 .34884 m .36113 .36041 L .37781 .35416 L p F P
0 0 0 r
s
.134 0 .891 r
.36113 .36041 m .35077 .34884 L .33414 .35512 L p F P
0 0 0 r
s
.115 0 .563 r
.61501 .83248 m .61456 .81542 L .59711 .82014 L p F P
0 0 0 r
s
.115 0 .563 r
.59711 .82014 m .59747 .83718 L .61501 .83248 L p F P
0 0 0 r
s
.188 0 .528 r
.35162 .83682 m .35251 .81978 L .34209 .81103 L p F P
0 0 0 r
s
.188 0 .528 r
.34302 .7941 m .34209 .81103 L .35251 .81978 L p F P
0 0 0 r
s
.188 0 .528 r
.21143 .39895 m .21303 .38413 L .20176 .3727 L p F P
0 0 0 r
s
.188 0 .528 r
.20341 .35801 m .20176 .3727 L .21303 .38413 L p F P
0 0 0 r
s
.115 0 .563 r
.90933 .56364 m .90737 .54794 L .88895 .55355 L p F P
0 0 0 r
s
.115 0 .563 r
.88895 .55355 m .8908 .56923 L .90933 .56364 L p F P
0 0 0 r
s
.134 0 .891 r
.64074 .34835 m .64934 .35993 L .66697 .35368 L p F P
0 0 0 r
s
.134 0 .891 r
.64934 .35993 m .64074 .34835 L .62315 .35464 L p F P
0 0 0 r
s
.115 0 .563 r
.5631 .88094 m .56291 .86362 L .54563 .86819 L p F P
0 0 0 r
s
.115 0 .563 r
.54563 .86819 m .54573 .88547 L .5631 .88094 L p F P
0 0 0 r
s
.188 0 .528 r
.39835 .98278 m .399 .965 L .38886 .95713 L p F P
0 0 0 r
s
.188 0 .528 r
.38956 .93947 m .38886 .95713 L .399 .965 L p F P
0 0 0 r
s
.188 0 .528 r
.30489 .69086 m .30602 .67457 L .29531 .66492 L p F P
0 0 0 r
s
.188 0 .528 r
.29649 .64874 m .29531 .66492 L .30602 .67457 L p F P
0 0 0 r
s
.188 0 .528 r
.25816 .5449 m .25953 .52935 L .24853 .51881 L p F P
0 0 0 r
s
.188 0 .528 r
.24995 .50337 m .24853 .51881 L .25953 .52935 L p F P
0 0 0 r
s
.115 0 .563 r
.51116 .92941 m .51124 .91184 L .49412 .91625 L p F P
0 0 0 r
s
.115 0 .563 r
.49412 .91625 m .49396 .93379 L .51116 .92941 L p F P
0 0 0 r
s
.115 0 .563 r
.85748 .61204 m .85579 .59609 L .83753 .60154 L p F P
0 0 0 r
s
.115 0 .563 r
.83753 .60154 m .83912 .61747 L .85748 .61204 L p F P
0 0 0 r
s
.134 0 .891 r
.39459 .34787 m .40469 .35945 L .42152 .35319 L p F P
0 0 0 r
s
.134 0 .891 r
.40469 .35945 m .39459 .34787 L .37781 .35416 L p F P
0 0 0 r
s
.195 0 .31 r
.88093 .41108 m .87912 .39611 L .88627 .4074 L p F P
0 0 0 r
s
.195 0 .31 r
.88627 .4074 m .88811 .42234 L .88093 .41108 L p F P
0 0 0 r
s
.115 0 .563 r
.8056 .66046 m .80418 .64425 L .78609 .64955 L p F P
0 0 0 r
s
.115 0 .563 r
.78609 .64955 m .78741 .66573 L .8056 .66046 L p F P
0 0 0 r
s
.134 0 .891 r
.68472 .34738 m .69306 .35897 L .71084 .35271 L p F P
0 0 0 r
s
.134 0 .891 r
.69306 .35897 m .68472 .34738 L .66697 .35368 L p F P
0 0 0 r
s
.115 0 .563 r
.4592 .97791 m .45954 .96009 L .44259 .96435 L p F P
0 0 0 r
s
.115 0 .563 r
.44259 .96435 m .44216 .98213 L .4592 .97791 L p F P
0 0 0 r
s
.134 0 .891 r
.43845 .3469 m .44829 .35849 L .46527 .35223 L p F P
0 0 0 r
s
.134 0 .891 r
.44829 .35849 m .43845 .3469 L .42152 .35319 L p F P
0 0 0 r
s
.115 0 .563 r
.7537 .7089 m .75254 .69245 L .73461 .69759 L p F P
0 0 0 r
s
.115 0 .563 r
.73461 .69759 m .73568 .71401 L .7537 .7089 L p F P
0 0 0 r
s
.188 0 .528 r
.24853 .51881 m .24995 .50337 L .23888 .49267 L p F P
0 0 0 r
s
.188 0 .528 r
.24035 .47735 m .23888 .49267 L .24995 .50337 L p F P
0 0 0 r
s
.115 0 .563 r
.70177 .75737 m .70088 .74067 L .68312 .74565 L p F P
0 0 0 r
s
.115 0 .563 r
.68312 .74565 m .68392 .76232 L .70177 .75737 L p F P
0 0 0 r
s
.134 0 .891 r
.19206 .34641 m .20341 .35801 L .21958 .35174 L p F P
0 0 0 r
s
.188 0 .528 r
.20176 .3727 m .20341 .35801 L .19206 .34641 L p F P
0 0 0 r
s
.134 0 .891 r
.72874 .34641 m .73681 .35801 L .75475 .35174 L p F P
0 0 0 r
s
.134 0 .891 r
.73681 .35801 m .72874 .34641 L .71084 .35271 L p F P
0 0 0 r
s
.188 0 .528 r
.38886 .95713 m .38956 .93947 L .37936 .93144 L p F P
0 0 0 r
s
.188 0 .528 r
.38011 .91388 m .37936 .93144 L .38956 .93947 L p F P
0 0 0 r
s
.188 0 .528 r
.34209 .81103 m .34302 .7941 L .33253 .78518 L p F P
0 0 0 r
s
.188 0 .528 r
.33352 .76837 m .33253 .78518 L .34302 .7941 L p F P
0 0 0 r
s
.188 0 .528 r
.29531 .66492 m .29649 .64874 L .28571 .63892 L p F P
0 0 0 r
s
.188 0 .528 r
.28693 .62286 m .28571 .63892 L .29649 .64874 L p F P
0 0 0 r
s
.115 0 .563 r
.64982 .80587 m .64919 .78891 L .63159 .79373 L p F P
0 0 0 r
s
.115 0 .563 r
.63159 .79373 m .63213 .81066 L .64982 .80587 L p F P
0 0 0 r
s
.134 0 .891 r
.48236 .34592 m .49194 .35753 L .50907 .35126 L p F P
0 0 0 r
s
.134 0 .891 r
.49194 .35753 m .48236 .34592 L .46527 .35223 L p F P
0 0 0 r
s
.134 0 .891 r
.23585 .34544 m .24694 .35705 L .26326 .35078 L p F P
0 0 0 r
s
.134 0 .891 r
.24694 .35705 m .23585 .34544 L .21958 .35174 L p F P
0 0 0 r
s
.195 0 .31 r
.87188 .38468 m .87011 .36983 L .87733 .38129 L p F P
0 0 0 r
s
.195 0 .31 r
.87733 .38129 m .87912 .39611 L .87188 .38468 L p F P
0 0 0 r
s
.115 0 .563 r
.59783 .85439 m .59747 .83718 L .58004 .84184 L p F P
0 0 0 r
s
.115 0 .563 r
.58004 .84184 m .58032 .85902 L .59783 .85439 L p F P
0 0 0 r
s
.195 0 .31 r
.91897 .53176 m .91696 .51616 L .92389 .52673 L p F P
0 0 0 r
s
.195 0 .31 r
.92389 .52673 m .92592 .54229 L .91897 .53176 L p F P
0 0 0 r
s
.134 0 .891 r
.77281 .34544 m .78062 .35705 L .79871 .35078 L p F P
0 0 0 r
s
.134 0 .891 r
.78062 .35705 m .77281 .34544 L .75475 .35174 L p F P
0 0 0 r
s
.115 0 .563 r
.89267 .58507 m .8908 .56923 L .8724 .57478 L p F P
0 0 0 r
s
.115 0 .563 r
.8724 .57478 m .87417 .59059 L .89267 .58507 L p F P
0 0 0 r
s
.134 0 .891 r
.52632 .34495 m .53563 .35657 L .55292 .35029 L p F P
0 0 0 r
s
.134 0 .891 r
.53563 .35657 m .52632 .34495 L .50907 .35126 L p F P
0 0 0 r
s
.115 0 .563 r
.54583 .90293 m .54573 .88547 L .52847 .88998 L p F P
0 0 0 r
s
.115 0 .563 r
.52847 .88998 m .52848 .9074 L .54583 .90293 L p F P
0 0 0 r
s
.188 0 .528 r
.37936 .93144 m .38011 .91388 L .36983 .90569 L p F P
0 0 0 r
s
.188 0 .528 r
.37063 .88825 m .36983 .90569 L .38011 .91388 L p F P
0 0 0 r
s
.188 0 .528 r
.23888 .49267 m .24035 .47735 L .22922 .46647 L p F P
0 0 0 r
s
.188 0 .528 r
.23073 .45127 m .22922 .46647 L .24035 .47735 L p F P
0 0 0 r
s
.134 0 .891 r
.27969 .34446 m .29052 .35609 L .30699 .34981 L p F P
0 0 0 r
s
.134 0 .891 r
.29052 .35609 m .27969 .34446 L .26326 .35078 L p F P
0 0 0 r
s
.188 0 .528 r
.28571 .63892 m .28693 .62286 L .27609 .61287 L p F P
0 0 0 r
s
.188 0 .528 r
.27736 .59693 m .27609 .61287 L .28693 .62286 L p F P
0 0 0 r
s
.134 0 .891 r
.81693 .34446 m .82447 .35609 L .84272 .34981 L p F P
0 0 0 r
s
.134 0 .891 r
.82447 .35609 m .81693 .34446 L .79871 .35078 L p F P
0 0 0 r
s
.115 0 .563 r
.84073 .63356 m .83912 .61747 L .82088 .62286 L p F P
0 0 0 r
s
.115 0 .563 r
.82088 .62286 m .82239 .63892 L .84073 .63356 L p F P
0 0 0 r
s
.115 0 .563 r
.49379 .9515 m .49396 .93379 L .47686 .93814 L p F P
0 0 0 r
s
.115 0 .563 r
.47686 .93814 m .47661 .95581 L .49379 .9515 L p F P
0 0 0 r
s
.188 0 .528 r
.33253 .78518 m .33352 .76837 L .32296 .75928 L p F P
0 0 0 r
s
.188 0 .528 r
.324 .74259 m .32296 .75928 L .33352 .76837 L p F P
0 0 0 r
s
.115 0 .563 r
.78875 .68207 m .78741 .66573 L .76934 .67096 L p F P
0 0 0 r
s
.115 0 .563 r
.76934 .67096 m .77059 .68728 L .78875 .68207 L p F P
0 0 0 r
s
.134 0 .891 r
.57032 .34398 m .57937 .35561 L .5968 .34932 L p F P
0 0 0 r
s
.134 0 .891 r
.57937 .35561 m .57032 .34398 L .55292 .35029 L p F P
0 0 0 r
s
.115 0 .563 r
.44173 1.0001 m .44216 .98213 L .42523 .98632 L p F P
0 0 0 r
s
.115 0 .563 r
.42523 .98632 m .42472 1.00425 L .44173 1.0001 L p F P
0 0 0 r
s
.134 0 .891 r
.32358 .34349 m .33414 .35512 L .35077 .34884 L p F P
0 0 0 r
s
.134 0 .891 r
.33414 .35512 m .32358 .34349 L .30699 .34981 L p F P
0 0 0 r
s
.195 0 .31 r
.90995 .50546 m .90798 .48997 L .91497 .50071 L p F P
0 0 0 r
s
.195 0 .31 r
.91497 .50071 m .91696 .51616 L .90995 .50546 L p F P
0 0 0 r
s
.134 0 .891 r
.86836 .35512 m .86109 .34349 L .84272 .34981 L p F P
0 0 0 r
s
.195 0 .31 r
.86281 .35822 m .86109 .34349 L .86836 .35512 L p F P
0 0 0 r
s
.195 0 .31 r
.86836 .35512 m .87011 .36983 L .86281 .35822 L p F P
0 0 0 r
s
.115 0 .563 r
.73675 .73061 m .73568 .71401 L .71778 .71909 L p F P
0 0 0 r
s
.115 0 .563 r
.71778 .71909 m .71876 .73565 L .73675 .73061 L p F P
0 0 0 r
s
.134 0 .891 r
.61436 .343 m .62315 .35464 L .64074 .34835 L p F P
0 0 0 r
s
.134 0 .891 r
.62315 .35464 m .61436 .343 L .5968 .34932 L p F P
0 0 0 r
s
.115 0 .563 r
.68473 .77917 m .68392 .76232 L .66618 .76724 L p F P
0 0 0 r
s
.115 0 .563 r
.66618 .76724 m .6669 .78406 L .68473 .77917 L p F P
0 0 0 r
s
.134 0 .891 r
.36751 .34251 m .37781 .35416 L .39459 .34787 L p F P
0 0 0 r
s
.134 0 .891 r
.37781 .35416 m .36751 .34251 L .35077 .34884 L p F P
0 0 0 r
s
.188 0 .528 r
.36983 .90569 m .37063 .88825 L .36029 .87988 L p F P
0 0 0 r
s
.188 0 .528 r
.36114 .86256 m .36029 .87988 L .37063 .88825 L p F P
0 0 0 r
s
.188 0 .528 r
.27609 .61287 m .27736 .59693 L .26645 .58677 L p F P
0 0 0 r
s
.188 0 .528 r
.26777 .57094 m .26645 .58677 L .27736 .59693 L p F P
0 0 0 r
s
.188 0 .528 r
.22922 .46647 m .23073 .45127 L .21953 .44022 L p F P
0 0 0 r
s
.188 0 .528 r
.22109 .42513 m .21953 .44022 L .23073 .45127 L p F P
0 0 0 r
s
.115 0 .563 r
.63267 .82776 m .63213 .81066 L .61456 .81542 L p F P
0 0 0 r
s
.115 0 .563 r
.61456 .81542 m .61501 .83248 L .63267 .82776 L p F P
0 0 0 r
s
.188 0 .528 r
.32296 .75928 m .324 .74259 L .31337 .73333 L p F P
0 0 0 r
s
.188 0 .528 r
.31445 .71675 m .31337 .73333 L .324 .74259 L p F P
0 0 0 r
s
.115 0 .563 r
.92798 .55802 m .92592 .54229 L .90737 .54794 L p F P
0 0 0 r
s
.115 0 .563 r
.90737 .54794 m .90933 .56364 L .92798 .55802 L p F P
0 0 0 r
s
.134 0 .891 r
.65845 .34202 m .66697 .35368 L .68472 .34738 L p F P
0 0 0 r
s
.134 0 .891 r
.66697 .35368 m .65845 .34202 L .64074 .34835 L p F P
0 0 0 r
s
.115 0 .563 r
.58059 .87637 m .58032 .85902 L .56291 .86362 L p F P
0 0 0 r
s
.115 0 .563 r
.56291 .86362 m .5631 .88094 L .58059 .87637 L p F P
0 0 0 r
s
.134 0 .891 r
.41148 .34153 m .42152 .35319 L .43845 .3469 L p F P
0 0 0 r
s
.134 0 .891 r
.42152 .35319 m .41148 .34153 L .39459 .34787 L p F P
0 0 0 r
s
.195 0 .31 r
.90091 .4791 m .89898 .46373 L .90604 .47464 L p F P
0 0 0 r
s
.195 0 .31 r
.90604 .47464 m .90798 .48997 L .90091 .4791 L p F P
0 0 0 r
s
.115 0 .563 r
.87596 .60657 m .87417 .59059 L .85579 .59609 L p F P
0 0 0 r
s
.115 0 .563 r
.85579 .59609 m .85748 .61204 L .87596 .60657 L p F P
0 0 0 r
s
.115 0 .563 r
.52849 .92501 m .52848 .9074 L .51124 .91184 L p F P
0 0 0 r
s
.115 0 .563 r
.51124 .91184 m .51116 .92941 L .52849 .92501 L p F P
0 0 0 r
s
.134 0 .891 r
.70258 .34105 m .71084 .35271 L .72874 .34641 L p F P
0 0 0 r
s
.134 0 .891 r
.71084 .35271 m .70258 .34105 L .68472 .34738 L p F P
0 0 0 r
s
.115 0 .563 r
.82391 .65515 m .82239 .63892 L .80418 .64425 L p F P
0 0 0 r
s
.115 0 .563 r
.80418 .64425 m .8056 .66046 L .82391 .65515 L p F P
0 0 0 r
s
.115 0 .563 r
.47635 .97367 m .47661 .95581 L .45954 .96009 L p F P
0 0 0 r
s
.115 0 .563 r
.45954 .96009 m .4592 .97791 L .47635 .97367 L p F P
0 0 0 r
s
.188 0 .528 r
.36029 .87988 m .36114 .86256 L .35072 .85403 L p F P
0 0 0 r
s
.188 0 .528 r
.35162 .83682 m .35072 .85403 L .36114 .86256 L p F P
0 0 0 r
s
.115 0 .563 r
.77184 .70376 m .77059 .68728 L .75254 .69245 L p F P
0 0 0 r
s
.115 0 .563 r
.75254 .69245 m .7537 .7089 L .77184 .70376 L p F P
0 0 0 r
s
.134 0 .891 r
.4555 .34056 m .46527 .35223 L .48236 .34592 L p F P
0 0 0 r
s
.134 0 .891 r
.46527 .35223 m .4555 .34056 L .43845 .3469 L p F P
0 0 0 r
s
.188 0 .528 r
.26645 .58677 m .26777 .57094 L .25679 .56062 L p F P
0 0 0 r
s
.188 0 .528 r
.25816 .5449 m .25679 .56062 L .26777 .57094 L p F P
0 0 0 r
s
.188 0 .528 r
.21953 .44022 m .22109 .42513 L .20982 .41391 L p F P
0 0 0 r
s
.188 0 .528 r
.21143 .39895 m .20982 .41391 L .22109 .42513 L p F P
0 0 0 r
s
.115 0 .563 r
.42419 1.02236 m .42472 1.00425 L .40782 1.00837 L p F P
0 0 0 r
s
.115 0 .563 r
.40782 1.00837 m .40721 1.02644 L .42419 1.02236 L p F P
0 0 0 r
s
.188 0 .528 r
.40721 1.02644 m .40782 1.00837 L .39769 1.00074 L p F P
0 0 0 r
s
.188 0 .528 r
.39835 .98278 m .39769 1.00074 L .40782 1.00837 L p F P
0 0 0 r
s
.188 0 .528 r
.31337 .73333 m .31445 .71675 L .30376 .70732 L p F P
0 0 0 r
s
.188 0 .528 r
.30489 .69086 m .30376 .70732 L .31445 .71675 L p F P
0 0 0 r
s
.115 0 .563 r
.71975 .75239 m .71876 .73565 L .70088 .74067 L p F P
0 0 0 r
s
.115 0 .563 r
.70088 .74067 m .70177 .75737 L .71975 .75239 L p F P
0 0 0 r
s
.134 0 .891 r
.20829 .34007 m .21958 .35174 L .23585 .34544 L p F P
0 0 0 r
s
.134 0 .891 r
.21958 .35174 m .20829 .34007 L .19206 .34641 L p F P
0 0 0 r
s
.134 0 .891 r
.74676 .34007 m .75475 .35174 L .77281 .34544 L p F P
0 0 0 r
s
.134 0 .891 r
.75475 .35174 m .74676 .34007 L .72874 .34641 L p F P
0 0 0 r
s
.195 0 .31 r
.89185 .45268 m .88997 .43743 L .89708 .44852 L p F P
0 0 0 r
s
.195 0 .31 r
.89708 .44852 m .89898 .46373 L .89185 .45268 L p F P
0 0 0 r
s
.134 0 .891 r
.49957 .33958 m .50907 .35126 L .52632 .34495 L p F P
0 0 0 r
s
.134 0 .891 r
.50907 .35126 m .49957 .33958 L .48236 .34592 L p F P
0 0 0 r
s
.115 0 .563 r
.66762 .80105 m .6669 .78406 L .64919 .78891 L p F P
0 0 0 r
s
.115 0 .563 r
.64919 .78891 m .64982 .80587 L .66762 .80105 L p F P
0 0 0 r
s
.134 0 .891 r
.25224 .33909 m .26326 .35078 L .27969 .34446 L p F P
0 0 0 r
s
.134 0 .891 r
.26326 .35078 m .25224 .33909 L .23585 .34544 L p F P
0 0 0 r
s
.115 0 .563 r
.61547 .84973 m .61501 .83248 L .59747 .83718 L p F P
0 0 0 r
s
.115 0 .563 r
.59747 .83718 m .59783 .85439 L .61547 .84973 L p F P
0 0 0 r
s
.134 0 .891 r
.79099 .33909 m .79871 .35078 L .81693 .34446 L p F P
0 0 0 r
s
.134 0 .891 r
.79871 .35078 m .79099 .33909 L .77281 .34544 L p F P
0 0 0 r
s
.115 0 .563 r
.56329 .89843 m .5631 .88094 L .54573 .88547 L p F P
0 0 0 r
s
.115 0 .563 r
.54573 .88547 m .54583 .90293 L .56329 .89843 L p F P
0 0 0 r
s
.188 0 .528 r
.35072 .85403 m .35162 .83682 L .34114 .82812 L p F P
0 0 0 r
s
.188 0 .528 r
.34209 .81103 m .34114 .82812 L .35162 .83682 L p F P
0 0 0 r
s
.188 0 .528 r
.25679 .56062 m .25816 .5449 L .24711 .53441 L p F P
0 0 0 r
s
.188 0 .528 r
.24853 .51881 m .24711 .53441 L .25816 .5449 L p F P
0 0 0 r
s
.188 0 .528 r
.20982 .41391 m .21143 .39895 L .20009 .38755 L p F P
0 0 0 r
s
.188 0 .528 r
.20176 .3727 m .20009 .38755 L .21143 .39895 L p F P
0 0 0 r
s
.134 0 .891 r
.54368 .3386 m .55292 .35029 L .57032 .34398 L p F P
0 0 0 r
s
.134 0 .891 r
.55292 .35029 m .54368 .3386 L .52632 .34495 L p F P
0 0 0 r
s
.188 0 .528 r
.30376 .70732 m .30489 .69086 L .29412 .68126 L p F P
0 0 0 r
s
.188 0 .528 r
.29531 .66492 m .29412 .68126 L .30489 .69086 L p F P
0 0 0 r
s
.115 0 .563 r
.9113 .5795 m .90933 .56364 L .8908 .56923 L p F P
0 0 0 r
s
.115 0 .563 r
.8908 .56923 m .89267 .58507 L .9113 .5795 L p F P
0 0 0 r
s
.188 0 .528 r
.39769 1.00074 m .39835 .98278 L .38816 .97498 L p F P
0 0 0 r
s
.188 0 .528 r
.38886 .95713 m .38816 .97498 L .39835 .98278 L p F P
0 0 0 r
s
.115 0 .563 r
.51109 .94716 m .51116 .92941 L .49396 .93379 L p F P
0 0 0 r
s
.115 0 .563 r
.49396 .93379 m .49379 .9515 L .51109 .94716 L p F P
0 0 0 r
s
.134 0 .891 r
.29623 .33811 m .30699 .34981 L .32358 .34349 L p F P
0 0 0 r
s
.134 0 .891 r
.30699 .34981 m .29623 .33811 L .27969 .34446 L p F P
0 0 0 r
s
.134 0 .891 r
.83526 .33811 m .84272 .34981 L .86109 .34349 L p F P
0 0 0 r
s
.134 0 .891 r
.84272 .34981 m .83526 .33811 L .81693 .34446 L p F P
0 0 0 r
s
.115 0 .563 r
.85918 .62815 m .85748 .61204 L .83912 .61747 L p F P
0 0 0 r
s
.115 0 .563 r
.83912 .61747 m .84073 .63356 L .85918 .62815 L p F P
0 0 0 r
s
.195 0 .31 r
.88277 .42621 m .88093 .41108 L .88811 .42234 L p F P
0 0 0 r
s
.195 0 .31 r
.88811 .42234 m .88997 .43743 L .88277 .42621 L p F P
0 0 0 r
s
.134 0 .891 r
.58783 .33762 m .5968 .34932 L .61436 .343 L p F P
0 0 0 r
s
.134 0 .891 r
.5968 .34932 m .58783 .33762 L .57032 .34398 L p F P
0 0 0 r
s
.115 0 .563 r
.80704 .67683 m .8056 .66046 L .78741 .66573 L p F P
0 0 0 r
s
.115 0 .563 r
.78741 .66573 m .78875 .68207 L .80704 .67683 L p F P
0 0 0 r
s
.115 0 .563 r
.45885 .99592 m .4592 .97791 L .44216 .98213 L p F P
0 0 0 r
s
.115 0 .563 r
.44216 .98213 m .44173 1.0001 L .45885 .99592 L p F P
0 0 0 r
s
.115 0 .563 r
.75487 .72553 m .7537 .7089 L .73568 .71401 L p F P
0 0 0 r
s
.115 0 .563 r
.73568 .71401 m .73675 .73061 L .75487 .72553 L p F P
0 0 0 r
s
.134 0 .891 r
.34027 .33713 m .35077 .34884 L .36751 .34251 L p F P
0 0 0 r
s
.134 0 .891 r
.35077 .34884 m .34027 .33713 L .32358 .34349 L p F P
0 0 0 r
s
.134 0 .891 r
.63203 .33663 m .64074 .34835 L .65845 .34202 L p F P
0 0 0 r
s
.134 0 .891 r
.64074 .34835 m .63203 .33663 L .61436 .343 L p F P
0 0 0 r
s
.115 0 .563 r
.70268 .77425 m .70177 .75737 L .68392 .76232 L p F P
0 0 0 r
s
.115 0 .563 r
.68392 .76232 m .68473 .77917 L .70268 .77425 L p F P
0 0 0 r
s
.188 0 .528 r
.38816 .97498 m .38886 .95713 L .3786 .94917 L p F P
0 0 0 r
s
.188 0 .528 r
.37936 .93144 m .3786 .94917 L .38886 .95713 L p F P
0 0 0 r
s
.188 0 .528 r
.29412 .68126 m .29531 .66492 L .28447 .65515 L p F P
0 0 0 r
s
.188 0 .528 r
.28571 .63892 m .28447 .65515 L .29531 .66492 L p F P
0 0 0 r
s
.188 0 .528 r
.24711 .53441 m .24853 .51881 L .23741 .50814 L p F P
0 0 0 r
s
.188 0 .528 r
.23888 .49267 m .23741 .50814 L .24853 .51881 L p F P
0 0 0 r
s
.188 0 .528 r
.20009 .38755 m .20176 .3727 L .19034 .36114 L p F P
0 0 0 r
s
.188 0 .528 r
.19206 .34641 m .19034 .36114 L .20176 .3727 L p F P
0 0 0 r
s
.188 0 .528 r
.34114 .82812 m .34209 .81103 L .33154 .80216 L p F P
0 0 0 r
s
.188 0 .528 r
.33253 .78518 m .33154 .80216 L .34209 .81103 L p F P
0 0 0 r
s
.134 0 .891 r
.38436 .33614 m .39459 .34787 L .41148 .34153 L p F P
0 0 0 r
s
.134 0 .891 r
.39459 .34787 m .38436 .33614 L .36751 .34251 L p F P
0 0 0 r
s
.115 0 .563 r
.65045 .823 m .64982 .80587 L .63213 .81066 L p F P
0 0 0 r
s
.115 0 .563 r
.63213 .81066 m .63267 .82776 L .65045 .823 L p F P
0 0 0 r
s
.195 0 .31 r
.921 .54753 m .91897 .53176 L .92592 .54229 L p F P
0 0 0 r
s
.195 0 .31 r
.92592 .54229 m .92798 .55802 L .921 .54753 L p F P
0 0 0 r
s
.195 0 .31 r
.87367 .39969 m .87188 .38468 L .87912 .39611 L p F P
0 0 0 r
s
.195 0 .31 r
.87912 .39611 m .88093 .41108 L .87367 .39969 L p F P
0 0 0 r
s
.134 0 .891 r
.67628 .33565 m .68472 .34738 L .70258 .34105 L p F P
0 0 0 r
s
.134 0 .891 r
.68472 .34738 m .67628 .33565 L .65845 .34202 L p F P
0 0 0 r
s
.115 0 .563 r
.5982 .87177 m .59783 .85439 L .58032 .85902 L p F P
0 0 0 r
s
.115 0 .563 r
.58032 .85902 m .58059 .87637 L .5982 .87177 L p F P
0 0 0 r
s
.115 0 .563 r
.89456 .60107 m .89267 .58507 L .87417 .59059 L p F P
0 0 0 r
s
.115 0 .563 r
.87417 .59059 m .87596 .60657 L .89456 .60107 L p F P
0 0 0 r
s
.134 0 .891 r
.42849 .33516 m .43845 .3469 L .4555 .34056 L p F P
0 0 0 r
s
.134 0 .891 r
.43845 .3469 m .42849 .33516 L .41148 .34153 L p F P
0 0 0 r
s
.115 0 .563 r
.54593 .92057 m .54583 .90293 L .52848 .9074 L p F P
0 0 0 r
s
.115 0 .563 r
.52848 .9074 m .52849 .92501 L .54593 .92057 L p F P
0 0 0 r
s
.188 0 .528 r
.23741 .50814 m .23888 .49267 L .22769 .48183 L p F P
0 0 0 r
s
.188 0 .528 r
.22922 .46647 m .22769 .48183 L .23888 .49267 L p F P
0 0 0 r
s
.134 0 .891 r
.18057 .33467 m .19206 .34641 L .20829 .34007 L p F P
0 0 0 r
s
.188 0 .528 r
.19034 .36114 m .19206 .34641 L .18057 .33467 L p F P
0 0 0 r
s
.188 0 .528 r
.3786 .94917 m .37936 .93144 L .36903 .92331 L p F P
0 0 0 r
s
.188 0 .528 r
.36983 .90569 m .36903 .92331 L .37936 .93144 L p F P
0 0 0 r
s
.188 0 .528 r
.33154 .80216 m .33253 .78518 L .32191 .77615 L p F P
0 0 0 r
s
.188 0 .528 r
.32296 .75928 m .32191 .77615 L .33253 .78518 L p F P
0 0 0 r
s
.188 0 .528 r
.28447 .65515 m .28571 .63892 L .2748 .62899 L p F P
0 0 0 r
s
.188 0 .528 r
.27609 .61287 m .2748 .62899 L .28571 .63892 L p F P
0 0 0 r
s
.115 0 .563 r
.84235 .64981 m .84073 .63356 L .82239 .63892 L p F P
0 0 0 r
s
.115 0 .563 r
.82239 .63892 m .82391 .65515 L .84235 .64981 L p F P
0 0 0 r
s
.134 0 .891 r
.72057 .33467 m .72874 .34641 L .74676 .34007 L p F P
0 0 0 r
s
.134 0 .891 r
.72874 .34641 m .72057 .33467 L .70258 .34105 L p F P
0 0 0 r
s
.115 0 .563 r
.49362 .9694 m .49379 .9515 L .47661 .95581 L p F P
0 0 0 r
s
.115 0 .563 r
.47661 .95581 m .47635 .97367 L .49362 .9694 L p F P
0 0 0 r
s
.134 0 .891 r
.47266 .33417 m .48236 .34592 L .49957 .33958 L p F P
0 0 0 r
s
.134 0 .891 r
.48236 .34592 m .47266 .33417 L .4555 .34056 L p F P
0 0 0 r
s
.115 0 .563 r
.44129 1.01825 m .44173 1.0001 L .42472 1.00425 L p F P
0 0 0 r
s
.115 0 .563 r
.42472 1.00425 m .42419 1.02236 L .44129 1.01825 L p F P
0 0 0 r
s
.115 0 .563 r
.79011 .69858 m .78875 .68207 L .77059 .68728 L p F P
0 0 0 r
s
.115 0 .563 r
.77059 .68728 m .77184 .70376 L .79011 .69858 L p F P
0 0 0 r
s
.195 0 .31 r
.86455 .37311 m .86281 .35822 L .87011 .36983 L p F P
0 0 0 r
s
.195 0 .31 r
.87011 .36983 m .87188 .38468 L .86455 .37311 L p F P
0 0 0 r
s
.195 0 .31 r
.91193 .5211 m .90995 .50546 L .91696 .51616 L p F P
0 0 0 r
s
.195 0 .31 r
.91696 .51616 m .91897 .53176 L .91193 .5211 L p F P
0 0 0 r
s
.134 0 .891 r
.76491 .33368 m .77281 .34544 L .79099 .33909 L p F P
0 0 0 r
s
.134 0 .891 r
.77281 .34544 m .76491 .33368 L .74676 .34007 L p F P
0 0 0 r
s
.115 0 .563 r
.73784 .74737 m .73675 .73061 L .71876 .73565 L p F P
0 0 0 r
s
.115 0 .563 r
.71876 .73565 m .71975 .75239 L .73784 .74737 L p F P
0 0 0 r
s
.134 0 .891 r
.22463 .33368 m .23585 .34544 L .25224 .33909 L p F P
0 0 0 r
s
.134 0 .891 r
.23585 .34544 m .22463 .33368 L .20829 .34007 L p F P
0 0 0 r
s
.115 0 .563 r
.68554 .79619 m .68473 .77917 L .6669 .78406 L p F P
0 0 0 r
s
.115 0 .563 r
.6669 .78406 m .66762 .80105 L .68554 .79619 L p F P
0 0 0 r
s
.134 0 .891 r
.51689 .33319 m .52632 .34495 L .54368 .3386 L p F P
0 0 0 r
s
.134 0 .891 r
.52632 .34495 m .51689 .33319 L .49957 .33958 L p F P
0 0 0 r
s
.134 0 .891 r
.26874 .3327 m .27969 .34446 L .29623 .33811 L p F P
0 0 0 r
s
.134 0 .891 r
.27969 .34446 m .26874 .3327 L .25224 .33909 L p F P
0 0 0 r
s
.188 0 .528 r
.36903 .92331 m .36983 .90569 L .35943 .89739 L p F P
0 0 0 r
s
.188 0 .528 r
.36029 .87988 m .35943 .89739 L .36983 .90569 L p F P
0 0 0 r
s
.188 0 .528 r
.22769 .48183 m .22922 .46647 L .21795 .45546 L p F P
0 0 0 r
s
.188 0 .528 r
.21953 .44022 m .21795 .45546 L .22922 .46647 L p F P
0 0 0 r
s
.115 0 .563 r
.63322 .84503 m .63267 .82776 L .61501 .83248 L p F P
0 0 0 r
s
.115 0 .563 r
.61501 .83248 m .61547 .84973 L .63322 .84503 L p F P
0 0 0 r
s
.188 0 .528 r
.32191 .77615 m .32296 .75928 L .31227 .75008 L p F P
0 0 0 r
s
.188 0 .528 r
.31337 .73333 m .31227 .75008 L .32296 .75928 L p F P
0 0 0 r
s
.188 0 .528 r
.2748 .62899 m .27609 .61287 L .26511 .60277 L p F P
0 0 0 r
s
.188 0 .528 r
.26645 .58677 m .26511 .60277 L .27609 .61287 L p F P
0 0 0 r
s
.134 0 .891 r
.80929 .3327 m .81693 .34446 L .83526 .33811 L p F P
0 0 0 r
s
.134 0 .891 r
.81693 .34446 m .80929 .3327 L .79099 .33909 L p F P
0 0 0 r
s
.134 0 .891 r
.56115 .3322 m .57032 .34398 L .58783 .33762 L p F P
0 0 0 r
s
.134 0 .891 r
.57032 .34398 m .56115 .3322 L .54368 .3386 L p F P
0 0 0 r
s
.115 0 .563 r
.58087 .8939 m .58059 .87637 L .5631 .88094 L p F P
0 0 0 r
s
.115 0 .563 r
.5631 .88094 m .56329 .89843 L .58087 .8939 L p F P
0 0 0 r
s
.115 0 .563 r
.93005 .5739 m .92798 .55802 L .90933 .56364 L p F P
0 0 0 r
s
.115 0 .563 r
.90933 .56364 m .9113 .5795 L .93005 .5739 L p F P
0 0 0 r
s
.195 0 .31 r
.90285 .49462 m .90091 .4791 L .90798 .48997 L p F P
0 0 0 r
s
.195 0 .31 r
.90798 .48997 m .90995 .50546 L .90285 .49462 L p F P
0 0 0 r
s
.134 0 .891 r
.86109 .34349 m .85372 .33171 L .83526 .33811 L p F P
0 0 0 r
s
.195 0 .31 r
.85542 .34647 m .85372 .33171 L .86109 .34349 L p F P
0 0 0 r
s
.195 0 .31 r
.86109 .34349 m .86281 .35822 L .85542 .34647 L p F P
0 0 0 r
s
.115 0 .563 r
.87776 .62271 m .87596 .60657 L .85748 .61204 L p F P
0 0 0 r
s
.115 0 .563 r
.85748 .61204 m .85918 .62815 L .87776 .62271 L p F P
0 0 0 r
s
.115 0 .563 r
.5285 .9428 m .52849 .92501 L .51116 .92941 L p F P
0 0 0 r
s
.115 0 .563 r
.51116 .92941 m .51109 .94716 L .5285 .9428 L p F P
0 0 0 r
s
.134 0 .891 r
.31289 .33171 m .32358 .34349 L .34027 .33713 L p F P
0 0 0 r
s
.134 0 .891 r
.32358 .34349 m .31289 .33171 L .29623 .33811 L p F P
0 0 0 r
s
.115 0 .563 r
.82545 .67155 m .82391 .65515 L .8056 .66046 L p F P
0 0 0 r
s
.115 0 .563 r
.8056 .66046 m .80704 .67683 L .82545 .67155 L p F P
0 0 0 r
s
.134 0 .891 r
.60546 .33121 m .61436 .343 L .63203 .33663 L p F P
0 0 0 r
s
.134 0 .891 r
.61436 .343 m .60546 .33121 L .58783 .33762 L p F P
0 0 0 r
s
.115 0 .563 r
.4761 .99171 m .47635 .97367 L .4592 .97791 L p F P
0 0 0 r
s
.115 0 .563 r
.4592 .97791 m .45885 .99592 L .4761 .99171 L p F P
0 0 0 r
s
.134 0 .891 r
.35708 .33072 m .36751 .34251 L .38436 .33614 L p F P
0 0 0 r
s
.134 0 .891 r
.36751 .34251 m .35708 .33072 L .34027 .33713 L p F P
0 0 0 r
s
.188 0 .528 r
.35943 .89739 m .36029 .87988 L .34982 .87142 L p F P
0 0 0 r
s
.188 0 .528 r
.35072 .85403 m .34982 .87142 L .36029 .87988 L p F P
0 0 0 r
s
.188 0 .528 r
.26511 .60277 m .26645 .58677 L .2554 .57649 L p F P
0 0 0 r
s
.188 0 .528 r
.25679 .56062 m .2554 .57649 L .26645 .58677 L p F P
0 0 0 r
s
.115 0 .563 r
.77311 .72041 m .77184 .70376 L .7537 .7089 L p F P
0 0 0 r
s
.115 0 .563 r
.7537 .7089 m .75487 .72553 L .77311 .72041 L p F P
0 0 0 r
s
.115 0 .563 r
.42367 1.04066 m .42419 1.02236 L .40721 1.02644 L p F P
0 0 0 r
s
.115 0 .563 r
.40721 1.02644 m .4066 1.0447 L .42367 1.04066 L p F P
0 0 0 r
s
.188 0 .528 r
.4066 1.0447 m .40721 1.02644 L .39703 1.01888 L p F P
0 0 0 r
s
.188 0 .528 r
.39769 1.00074 m .39703 1.01888 L .40721 1.02644 L p F P
0 0 0 r
s
.188 0 .528 r
.31227 .75008 m .31337 .73333 L .30261 .72396 L p F P
0 0 0 r
s
.188 0 .528 r
.30376 .70732 m .30261 .72396 L .31337 .73333 L p F P
0 0 0 r
s
.188 0 .528 r
.21795 .45546 m .21953 .44022 L .20819 .42903 L p F P
0 0 0 r
s
.188 0 .528 r
.20982 .41391 m .20819 .42903 L .21953 .44022 L p F P
0 0 0 r
s
.134 0 .891 r
.64982 .33023 m .65845 .34202 L .67628 .33565 L p F P
0 0 0 r
s
.134 0 .891 r
.65845 .34202 m .64982 .33023 L .63203 .33663 L p F P
0 0 0 r
s
.115 0 .563 r
.72075 .7693 m .71975 .75239 L .70177 .75737 L p F P
0 0 0 r
s
.115 0 .563 r
.70177 .75737 m .70268 .77425 L .72075 .7693 L p F P
0 0 0 r
s
.134 0 .891 r
.40132 .32973 m .41148 .34153 L .42849 .33516 L p F P
0 0 0 r
s
.134 0 .891 r
.41148 .34153 m .40132 .32973 L .38436 .33614 L p F P
0 0 0 r
s
.195 0 .31 r
.89374 .46809 m .89185 .45268 L .89898 .46373 L p F P
0 0 0 r
s
.195 0 .31 r
.89898 .46373 m .90091 .4791 L .89374 .46809 L p F P
0 0 0 r
s
.115 0 .563 r
.66835 .81821 m .66762 .80105 L .64982 .80587 L p F P
0 0 0 r
s
.115 0 .563 r
.64982 .80587 m .65045 .823 L .66835 .81821 L p F P
0 0 0 r
s
.134 0 .891 r
.69423 .32924 m .70258 .34105 L .72057 .33467 L p F P
0 0 0 r
s
.134 0 .891 r
.70258 .34105 m .69423 .32924 L .67628 .33565 L p F P
0 0 0 r
s
.115 0 .563 r
.61593 .86715 m .61547 .84973 L .59783 .85439 L p F P
0 0 0 r
s
.115 0 .563 r
.59783 .85439 m .5982 .87177 L .61593 .86715 L p F P
0 0 0 r
s
.115 0 .563 r
.56348 .91611 m .56329 .89843 L .54583 .90293 L p F P
0 0 0 r
s
.115 0 .563 r
.54583 .90293 m .54593 .92057 L .56348 .91611 L p F P
0 0 0 r
s
.188 0 .528 r
.34982 .87142 m .35072 .85403 L .34018 .8454 L p F P
0 0 0 r
s
.188 0 .528 r
.34114 .82812 m .34018 .8454 L .35072 .85403 L p F P
0 0 0 r
s
.188 0 .528 r
.20819 .42903 m .20982 .41391 L .19841 .40255 L p F P
0 0 0 r
s
.188 0 .528 r
.20009 .38755 m .19841 .40255 L .20982 .41391 L p F P
0 0 0 r
s
.188 0 .528 r
.39703 1.01888 m .39769 1.00074 L .38744 .99301 L p F P
0 0 0 r
s
.188 0 .528 r
.38816 .97498 m .38744 .99301 L .39769 1.00074 L p F P
0 0 0 r
s
.188 0 .528 r
.30261 .72396 m .30376 .70732 L .29293 .69778 L p F P
0 0 0 r
s
.188 0 .528 r
.29412 .68126 m .29293 .69778 L .30376 .70732 L p F P
0 0 0 r
s
.188 0 .528 r
.2554 .57649 m .25679 .56062 L .24567 .55016 L p F P
0 0 0 r
s
.188 0 .528 r
.24711 .53441 m .24567 .55016 L .25679 .56062 L p F P
0 0 0 r
s
.115 0 .563 r
.91329 .59553 m .9113 .5795 L .89267 .58507 L p F P
0 0 0 r
s
.115 0 .563 r
.89267 .58507 m .89456 .60107 L .91329 .59553 L p F P
0 0 0 r
s
.134 0 .891 r
.44561 .32874 m .4555 .34056 L .47266 .33417 L p F P
0 0 0 r
s
.134 0 .891 r
.4555 .34056 m .44561 .32874 L .42849 .33516 L p F P
0 0 0 r
s
.134 0 .891 r
.19687 .32825 m .20829 .34007 L .22463 .33368 L p F P
0 0 0 r
s
.134 0 .891 r
.20829 .34007 m .19687 .32825 L .18057 .33467 L p F P
0 0 0 r
s
.134 0 .891 r
.73868 .32825 m .74676 .34007 L .76491 .33368 L p F P
0 0 0 r
s
.134 0 .891 r
.74676 .34007 m .73868 .32825 L .72057 .33467 L p F P
0 0 0 r
s
.115 0 .563 r
.51101 .9651 m .51109 .94716 L .49379 .9515 L p F P
0 0 0 r
s
.115 0 .563 r
.49379 .9515 m .49362 .9694 L .51101 .9651 L p F P
0 0 0 r
s
.115 0 .563 r
.86091 .64444 m .85918 .62815 L .84073 .63356 L p F P
0 0 0 r
s
.115 0 .563 r
.84073 .63356 m .84235 .64981 L .86091 .64444 L p F P
0 0 0 r
s
.195 0 .31 r
.88462 .4415 m .88277 .42621 L .88997 .43743 L p F P
0 0 0 r
s
.195 0 .31 r
.88997 .43743 m .89185 .45268 L .88462 .4415 L p F P
0 0 0 r
s
.115 0 .563 r
.80849 .69337 m .80704 .67683 L .78875 .68207 L p F P
0 0 0 r
s
.115 0 .563 r
.78875 .68207 m .79011 .69858 L .80849 .69337 L p F P
0 0 0 r
s
.134 0 .891 r
.48994 .32775 m .49957 .33958 L .51689 .33319 L p F P
0 0 0 r
s
.134 0 .891 r
.49957 .33958 m .48994 .32775 L .47266 .33417 L p F P
0 0 0 r
s
.115 0 .563 r
.45851 1.01411 m .45885 .99592 L .44173 1.0001 L p F P
0 0 0 r
s
.115 0 .563 r
.44173 1.0001 m .44129 1.01825 L .45851 1.01411 L p F P
0 0 0 r
s
.115 0 .563 r
.75606 .74232 m .75487 .72553 L .73675 .73061 L p F P
0 0 0 r
s
.115 0 .563 r
.73675 .73061 m .73784 .74737 L .75606 .74232 L p F P
0 0 0 r
s
.134 0 .891 r
.24108 .32725 m .25224 .33909 L .26874 .3327 L p F P
0 0 0 r
s
.134 0 .891 r
.25224 .33909 m .24108 .32725 L .22463 .33368 L p F P
0 0 0 r
s
.134 0 .891 r
.78317 .32725 m .79099 .33909 L .80929 .3327 L p F P
0 0 0 r
s
.134 0 .891 r
.79099 .33909 m .78317 .32725 L .76491 .33368 L p F P
0 0 0 r
s
.188 0 .528 r
.24567 .55016 m .24711 .53441 L .23591 .52378 L p F P
0 0 0 r
s
.188 0 .528 r
.23741 .50814 m .23591 .52378 L .24711 .53441 L p F P
0 0 0 r
s
.115 0 .563 r
.70359 .7913 m .70268 .77425 L .68473 .77917 L p F P
0 0 0 r
s
.115 0 .563 r
.68473 .77917 m .68554 .79619 L .70359 .7913 L p F P
0 0 0 r
s
.134 0 .891 r
.53432 .32676 m .54368 .3386 L .56115 .3322 L p F P
0 0 0 r
s
.134 0 .891 r
.54368 .3386 m .53432 .32676 L .51689 .33319 L p F P
0 0 0 r
s
.188 0 .528 r
.38744 .99301 m .38816 .97498 L .37784 .96709 L p F P
0 0 0 r
s
.188 0 .528 r
.3786 .94917 m .37784 .96709 L .38816 .97498 L p F P
0 0 0 r
s
.188 0 .528 r
.34018 .8454 m .34114 .82812 L .33053 .81932 L p F P
0 0 0 r
s
.188 0 .528 r
.33154 .80216 m .33053 .81932 L .34114 .82812 L p F P
0 0 0 r
s
.188 0 .528 r
.29293 .69778 m .29412 .68126 L .28322 .67155 L p F P
0 0 0 r
s
.188 0 .528 r
.28447 .65515 m .28322 .67155 L .29412 .68126 L p F P
0 0 0 r
s
.188 0 .528 r
.19841 .40255 m .20009 .38755 L .1886 .37601 L p F P
0 0 0 r
s
.188 0 .528 r
.19034 .36114 m .1886 .37601 L .20009 .38755 L p F P
0 0 0 r
s
.134 0 .891 r
.28534 .32626 m .29623 .33811 L .31289 .33171 L p F P
0 0 0 r
s
.134 0 .891 r
.29623 .33811 m .28534 .32626 L .26874 .3327 L p F P
0 0 0 r
s
.115 0 .563 r
.6511 .84031 m .65045 .823 L .63267 .82776 L p F P
0 0 0 r
s
.115 0 .563 r
.63267 .82776 m .63322 .84503 L .6511 .84031 L p F P
0 0 0 r
s
.134 0 .891 r
.82771 .32626 m .83526 .33811 L .85372 .33171 L p F P
0 0 0 r
s
.134 0 .891 r
.83526 .33811 m .82771 .32626 L .80929 .3327 L p F P
0 0 0 r
s
.195 0 .31 r
.87547 .41485 m .87367 .39969 L .88093 .41108 L p F P
0 0 0 r
s
.195 0 .31 r
.88093 .41108 m .88277 .42621 L .87547 .41485 L p F P
0 0 0 r
s
.134 0 .891 r
.57875 .32576 m .58783 .33762 L .60546 .33121 L p F P
0 0 0 r
s
.134 0 .891 r
.58783 .33762 m .57875 .32576 L .56115 .3322 L p F P
0 0 0 r
s
.115 0 .563 r
.59858 .88934 m .5982 .87177 L .58059 .87637 L p F P
0 0 0 r
s
.115 0 .563 r
.58059 .87637 m .58087 .8939 L .59858 .88934 L p F P
0 0 0 r
s
.195 0 .31 r
.92305 .56346 m .921 .54753 L .92798 .55802 L p F P
0 0 0 r
s
.195 0 .31 r
.92798 .55802 m .93005 .5739 L .92305 .56346 L p F P
0 0 0 r
s
.115 0 .563 r
.89647 .61724 m .89456 .60107 L .87596 .60657 L p F P
0 0 0 r
s
.115 0 .563 r
.87596 .60657 m .87776 .62271 L .89647 .61724 L p F P
0 0 0 r
s
.115 0 .563 r
.54603 .9384 m .54593 .92057 L .52849 .92501 L p F P
0 0 0 r
s
.115 0 .563 r
.52849 .92501 m .5285 .9428 L .54603 .9384 L p F P
0 0 0 r
s
.134 0 .891 r
.32965 .32527 m .34027 .33713 L .35708 .33072 L p F P
0 0 0 r
s
.134 0 .891 r
.34027 .33713 m .32965 .32527 L .31289 .33171 L p F P
0 0 0 r
s
.188 0 .528 r
.1886 .37601 m .19034 .36114 L .17878 .34942 L p F P
0 0 0 r
s
.188 0 .528 r
.18057 .33467 m .17878 .34942 L .19034 .36114 L p F P
0 0 0 r
s
.134 0 .891 r
.62322 .32477 m .63203 .33663 L .64982 .33023 L p F P
0 0 0 r
s
.134 0 .891 r
.63203 .33663 m .62322 .32477 L .60546 .33121 L p F P
0 0 0 r
s
.115 0 .563 r
.49345 .98748 m .49362 .9694 L .47635 .97367 L p F P
0 0 0 r
s
.115 0 .563 r
.47635 .97367 m .4761 .99171 L .49345 .98748 L p F P
0 0 0 r
s
.188 0 .528 r
.37784 .96709 m .3786 .94917 L .36821 .94111 L p F P
0 0 0 r
s
.188 0 .528 r
.36903 .92331 m .36821 .94111 L .3786 .94917 L p F P
0 0 0 r
s
.188 0 .528 r
.33053 .81932 m .33154 .80216 L .32086 .79319 L p F P
0 0 0 r
s
.188 0 .528 r
.32191 .77615 m .32086 .79319 L .33154 .80216 L p F P
0 0 0 r
s
.188 0 .528 r
.28322 .67155 m .28447 .65515 L .2735 .64527 L p F P
0 0 0 r
s
.188 0 .528 r
.2748 .62899 m .2735 .64527 L .28447 .65515 L p F P
0 0 0 r
s
.188 0 .528 r
.23591 .52378 m .23741 .50814 L .22614 .49734 L p F P
0 0 0 r
s
.188 0 .528 r
.22769 .48183 m .22614 .49734 L .23741 .50814 L p F P
0 0 0 r
s
.115 0 .563 r
.84399 .66624 m .84235 .64981 L .82391 .65515 L p F P
0 0 0 r
s
.115 0 .563 r
.82391 .65515 m .82545 .67155 L .84399 .66624 L p F P
0 0 0 r
s
.134 0 .891 r
.374 .32427 m .38436 .33614 L .40132 .32973 L p F P
0 0 0 r
s
.134 0 .891 r
.38436 .33614 m .374 .32427 L .35708 .33072 L p F P
0 0 0 r
s
.115 0 .563 r
.79148 .71526 m .79011 .69858 L .77184 .70376 L p F P
0 0 0 r
s
.115 0 .563 r
.77184 .70376 m .77311 .72041 L .79148 .71526 L p F P
0 0 0 r
s
.115 0 .563 r
.44085 1.03659 m .44129 1.01825 L .42419 1.02236 L p F P
0 0 0 r
s
.115 0 .563 r
.42419 1.02236 m .42367 1.04066 L .44085 1.03659 L p F P
0 0 0 r
s
.195 0 .31 r
.91394 .53691 m .91193 .5211 L .91897 .53176 L p F P
0 0 0 r
s
.195 0 .31 r
.91897 .53176 m .921 .54753 L .91394 .53691 L p F P
0 0 0 r
s
.195 0 .31 r
.86631 .38815 m .86455 .37311 L .87188 .38468 L p F P
0 0 0 r
s
.195 0 .31 r
.87188 .38468 m .87367 .39969 L .86631 .38815 L p F P
0 0 0 r
s
.134 0 .891 r
.66773 .32377 m .67628 .33565 L .69423 .32924 L p F P
0 0 0 r
s
.134 0 .891 r
.67628 .33565 m .66773 .32377 L .64982 .33023 L p F P
0 0 0 r
s
.115 0 .563 r
.73894 .76431 m .73784 .74737 L .71975 .75239 L p F P
0 0 0 r
s
.115 0 .563 r
.71975 .75239 m .72075 .7693 L .73894 .76431 L p F P
0 0 0 r
s
.115 0 .563 r
.68637 .81339 m .68554 .79619 L .66762 .80105 L p F P
0 0 0 r
s
.115 0 .563 r
.66762 .80105 m .66835 .81821 L .68637 .81339 L p F P
0 0 0 r
s
.134 0 .891 r
.4184 .32328 m .42849 .33516 L .44561 .32874 L p F P
0 0 0 r
s
.134 0 .891 r
.42849 .33516 m .4184 .32328 L .40132 .32973 L p F P
0 0 0 r
s
.188 0 .528 r
.22614 .49734 m .22769 .48183 L .21635 .47085 L p F P
0 0 0 r
s
.188 0 .528 r
.21795 .45546 m .21635 .47085 L .22769 .48183 L p F P
0 0 0 r
s
.115 0 .563 r
.63378 .86249 m .63322 .84503 L .61547 .84973 L p F P
0 0 0 r
s
.115 0 .563 r
.61547 .84973 m .61593 .86715 L .63378 .86249 L p F P
0 0 0 r
s
.188 0 .528 r
.36821 .94111 m .36903 .92331 L .35857 .91507 L p F P
0 0 0 r
s
.188 0 .528 r
.35943 .89739 m .35857 .91507 L .36903 .92331 L p F P
0 0 0 r
s
.188 0 .528 r
.32086 .79319 m .32191 .77615 L .31116 .767 L p F P
0 0 0 r
s
.188 0 .528 r
.31227 .75008 m .31116 .767 L .32191 .77615 L p F P
0 0 0 r
s
.188 0 .528 r
.2735 .64527 m .2748 .62899 L .26376 .61893 L p F P
0 0 0 r
s
.188 0 .528 r
.26511 .60277 m .26376 .61893 L .2748 .62899 L p F P
0 0 0 r
s
.134 0 .891 r
.16894 .32278 m .18057 .33467 L .19687 .32825 L p F P
0 0 0 r
s
.188 0 .528 r
.17878 .34942 m .18057 .33467 L .16894 .32278 L p F P
0 0 0 r
s
.134 0 .891 r
.7123 .32278 m .72057 .33467 L .73868 .32825 L p F P
0 0 0 r
s
.134 0 .891 r
.72057 .33467 m .7123 .32278 L .69423 .32924 L p F P
0 0 0 r
s
.115 0 .563 r
.93215 .58995 m .93005 .5739 L .9113 .5795 L p F P
0 0 0 r
s
.115 0 .563 r
.9113 .5795 m .91329 .59553 L .93215 .58995 L p F P
0 0 0 r
s
.134 0 .891 r
.46285 .32228 m .47266 .33417 L .48994 .32775 L p F P
0 0 0 r
s
.134 0 .891 r
.47266 .33417 m .46285 .32228 L .44561 .32874 L p F P
0 0 0 r
s
.115 0 .563 r
.58116 .91161 m .58087 .8939 L .56329 .89843 L p F P
0 0 0 r
s
.115 0 .563 r
.56329 .89843 m .56348 .91611 L .58116 .91161 L p F P
0 0 0 r
s
.134 0 .891 r
.21327 .32178 m .22463 .33368 L .24108 .32725 L p F P
0 0 0 r
s
.134 0 .891 r
.22463 .33368 m .21327 .32178 L .19687 .32825 L p F P
0 0 0 r
s
.195 0 .31 r
.90481 .51031 m .90285 .49462 L .90995 .50546 L p F P
0 0 0 r
s
.195 0 .31 r
.90995 .50546 m .91193 .5211 L .90481 .51031 L p F P
0 0 0 r
s
.195 0 .31 r
.85713 .36139 m .85542 .34647 L .86281 .35822 L p F P
0 0 0 r
s
.195 0 .31 r
.86281 .35822 m .86455 .37311 L .85713 .36139 L p F P
0 0 0 r
s
.115 0 .563 r
.87959 .63902 m .87776 .62271 L .85918 .62815 L p F P
0 0 0 r
s
.115 0 .563 r
.85918 .62815 m .86091 .64444 L .87959 .63902 L p F P
0 0 0 r
s
.134 0 .891 r
.7569 .32178 m .76491 .33368 L .78317 .32725 L p F P
0 0 0 r
s
.134 0 .891 r
.76491 .33368 m .7569 .32178 L .73868 .32825 L p F P
0 0 0 r
s
.115 0 .563 r
.52851 .96077 m .5285 .9428 L .51109 .94716 L p F P
0 0 0 r
s
.115 0 .563 r
.51109 .94716 m .51101 .9651 L .52851 .96077 L p F P
0 0 0 r
s
.115 0 .563 r
.82701 .68812 m .82545 .67155 L .80704 .67683 L p F P
0 0 0 r
s
.115 0 .563 r
.80704 .67683 m .80849 .69337 L .82701 .68812 L p F P
0 0 0 r
s
.134 0 .891 r
.50734 .32128 m .51689 .33319 L .53432 .32676 L p F P
0 0 0 r
s
.134 0 .891 r
.51689 .33319 m .50734 .32128 L .48994 .32775 L p F P
0 0 0 r
s
.115 0 .563 r
.47583 1.00994 m .4761 .99171 L .45885 .99592 L p F P
0 0 0 r
s
.115 0 .563 r
.45885 .99592 m .45851 1.01411 L .47583 1.00994 L p F P
0 0 0 r
s
.188 0 .528 r
.35857 .91507 m .35943 .89739 L .3489 .88899 L p F P
0 0 0 r
s
.188 0 .528 r
.34982 .87142 m .3489 .88899 L .35943 .89739 L p F P
0 0 0 r
s
.115 0 .563 r
.77439 .73724 m .77311 .72041 L .75487 .72553 L p F P
0 0 0 r
s
.115 0 .563 r
.75487 .72553 m .75606 .74232 L .77439 .73724 L p F P
0 0 0 r
s
.134 0 .891 r
.25764 .32078 m .26874 .3327 L .28534 .32626 L p F P
0 0 0 r
s
.134 0 .891 r
.26874 .3327 m .25764 .32078 L .24108 .32725 L p F P
0 0 0 r
s
.115 0 .563 r
.42313 1.05915 m .42367 1.04066 L .4066 1.0447 L p F P
0 0 0 r
s
.115 0 .563 r
.4066 1.0447 m .40598 1.06315 L .42313 1.05915 L p F P
0 0 0 r
s
.188 0 .528 r
.40598 1.06315 m .4066 1.0447 L .39636 1.03722 L p F P
0 0 0 r
s
.188 0 .528 r
.39703 1.01888 m .39636 1.03722 L .4066 1.0447 L p F P
0 0 0 r
s
.188 0 .528 r
.31116 .767 m .31227 .75008 L .30145 .74076 L p F P
0 0 0 r
s
.188 0 .528 r
.30261 .72396 m .30145 .74076 L .31227 .75008 L p F P
0 0 0 r
s
.188 0 .528 r
.26376 .61893 m .26511 .60277 L .25399 .59253 L p F P
0 0 0 r
s
.188 0 .528 r
.2554 .57649 m .25399 .59253 L .26511 .60277 L p F P
0 0 0 r
s
.188 0 .528 r
.21635 .47085 m .21795 .45546 L .20654 .4443 L p F P
0 0 0 r
s
.188 0 .528 r
.20819 .42903 m .20654 .4443 L .21795 .45546 L p F P
0 0 0 r
s
.134 0 .891 r
.80156 .32078 m .80929 .3327 L .82771 .32626 L p F P
0 0 0 r
s
.134 0 .891 r
.80929 .3327 m .80156 .32078 L .78317 .32725 L p F P
0 0 0 r
s
.134 0 .891 r
.55188 .32028 m .56115 .3322 L .57875 .32576 L p F P
0 0 0 r
s
.134 0 .891 r
.56115 .3322 m .55188 .32028 L .53432 .32676 L p F P
0 0 0 r
s
.115 0 .563 r
.72176 .78638 m .72075 .7693 L .70268 .77425 L p F P
0 0 0 r
s
.115 0 .563 r
.70268 .77425 m .70359 .7913 L .72176 .78638 L p F P
0 0 0 r
s
.134 0 .891 r
.30206 .31978 m .31289 .33171 L .32965 .32527 L p F P
0 0 0 r
s
.134 0 .891 r
.31289 .33171 m .30206 .31978 L .28534 .32626 L p F P
0 0 0 r
s
.195 0 .31 r
.89566 .48365 m .89374 .46809 L .90091 .4791 L p F P
0 0 0 r
s
.195 0 .31 r
.90091 .4791 m .90285 .49462 L .89566 .48365 L p F P
0 0 0 r
s
.115 0 .563 r
.66909 .83555 m .66835 .81821 L .65045 .823 L p F P
0 0 0 r
s
.115 0 .563 r
.65045 .823 m .6511 .84031 L .66909 .83555 L p F P
0 0 0 r
s
.134 0 .891 r
.85372 .33171 m .84626 .31978 L .82771 .32626 L p F P
0 0 0 r
s
.195 0 .31 r
.84793 .33458 m .84626 .31978 L .85372 .33171 L p F P
0 0 0 r
s
.195 0 .31 r
.85372 .33171 m .85542 .34647 L .84793 .33458 L p F P
0 0 0 r
s
.134 0 .891 r
.59646 .31928 m .60546 .33121 L .62322 .32477 L p F P
0 0 0 r
s
.134 0 .891 r
.60546 .33121 m .59646 .31928 L .57875 .32576 L p F P
0 0 0 r
s
.115 0 .563 r
.6164 .88475 m .61593 .86715 L .5982 .87177 L p F P
0 0 0 r
s
.115 0 .563 r
.5982 .87177 m .59858 .88934 L .6164 .88475 L p F P
0 0 0 r
s
.188 0 .528 r
.25399 .59253 m .2554 .57649 L .24421 .56608 L p F P
0 0 0 r
s
.188 0 .528 r
.24567 .55016 m .24421 .56608 L .2554 .57649 L p F P
0 0 0 r
s
.188 0 .528 r
.20654 .4443 m .20819 .42903 L .1967 .4177 L p F P
0 0 0 r
s
.188 0 .528 r
.19841 .40255 m .1967 .4177 L .20819 .42903 L p F P
0 0 0 r
s
.188 0 .528 r
.3489 .88899 m .34982 .87142 L .33922 .86285 L p F P
0 0 0 r
s
.188 0 .528 r
.34018 .8454 m .33922 .86285 L .34982 .87142 L p F P
0 0 0 r
s
.115 0 .563 r
.56368 .93397 m .56348 .91611 L .54593 .92057 L p F P
0 0 0 r
s
.115 0 .563 r
.54593 .92057 m .54603 .9384 L .56368 .93397 L p F P
0 0 0 r
s
.134 0 .891 r
.34653 .31878 m .35708 .33072 L .374 .32427 L p F P
0 0 0 r
s
.134 0 .891 r
.35708 .33072 m .34653 .31878 L .32965 .32527 L p F P
0 0 0 r
s
.188 0 .528 r
.39636 1.03722 m .39703 1.01888 L .38672 1.01123 L p F P
0 0 0 r
s
.188 0 .528 r
.38744 .99301 m .38672 1.01123 L .39703 1.01888 L p F P
0 0 0 r
s
.188 0 .528 r
.30145 .74076 m .30261 .72396 L .29171 .71447 L p F P
0 0 0 r
s
.188 0 .528 r
.29293 .69778 m .29171 .71447 L .30261 .72396 L p F P
0 0 0 r
s
.115 0 .563 r
.9153 .61172 m .91329 .59553 L .89456 .60107 L p F P
0 0 0 r
s
.115 0 .563 r
.89456 .60107 m .89647 .61724 L .9153 .61172 L p F P
0 0 0 r
s
.134 0 .891 r
.64109 .31828 m .64982 .33023 L .66773 .32377 L p F P
0 0 0 r
s
.134 0 .891 r
.64982 .33023 m .64109 .31828 L .62322 .32477 L p F P
0 0 0 r
s
.115 0 .563 r
.86265 .66089 m .86091 .64444 L .84235 .64981 L p F P
0 0 0 r
s
.115 0 .563 r
.84235 .64981 m .84399 .66624 L .86265 .66089 L p F P
0 0 0 r
s
.115 0 .563 r
.51093 .98322 m .51101 .9651 L .49362 .9694 L p F P
0 0 0 r
s
.115 0 .563 r
.49362 .9694 m .49345 .98748 L .51093 .98322 L p F P
0 0 0 r
s
.195 0 .31 r
.88649 .45694 m .88462 .4415 L .89185 .45268 L p F P
0 0 0 r
s
.195 0 .31 r
.89185 .45268 m .89374 .46809 L .88649 .45694 L p F P
0 0 0 r
s
.115 0 .563 r
.80996 .71008 m .80849 .69337 L .79011 .69858 L p F P
0 0 0 r
s
.115 0 .563 r
.79011 .69858 m .79148 .71526 L .80996 .71008 L p F P
0 0 0 r
s
.134 0 .891 r
.39104 .31778 m .40132 .32973 L .4184 .32328 L p F P
0 0 0 r
s
.134 0 .891 r
.40132 .32973 m .39104 .31778 L .374 .32427 L p F P
0 0 0 r
s
.115 0 .563 r
.45815 1.03249 m .45851 1.01411 L .44129 1.01825 L p F P
0 0 0 r
s
.115 0 .563 r
.44129 1.01825 m .44085 1.03659 L .45815 1.03249 L p F P
0 0 0 r
s
.134 0 .891 r
.68576 .31728 m .69423 .32924 L .7123 .32278 L p F P
0 0 0 r
s
.134 0 .891 r
.69423 .32924 m .68576 .31728 L .66773 .32377 L p F P
0 0 0 r
s
.115 0 .563 r
.75725 .75929 m .75606 .74232 L .73784 .74737 L p F P
0 0 0 r
s
.115 0 .563 r
.73784 .74737 m .73894 .76431 L .75725 .75929 L p F P
0 0 0 r
s
.134 0 .891 r
.4356 .31678 m .44561 .32874 L .46285 .32228 L p F P
0 0 0 r
s
.134 0 .891 r
.44561 .32874 m .4356 .31678 L .4184 .32328 L p F P
0 0 0 r
s
.115 0 .563 r
.70451 .80853 m .70359 .7913 L .68554 .79619 L p F P
0 0 0 r
s
.115 0 .563 r
.68554 .79619 m .68637 .81339 L .70451 .80853 L p F P
0 0 0 r
s
.188 0 .528 r
.38672 1.01123 m .38744 .99301 L .37707 .98519 L p F P
0 0 0 r
s
.188 0 .528 r
.37784 .96709 m .37707 .98519 L .38744 .99301 L p F P
0 0 0 r
s
.188 0 .528 r
.33922 .86285 m .34018 .8454 L .32951 .83665 L p F P
0 0 0 r
s
.188 0 .528 r
.33053 .81932 m .32951 .83665 L .34018 .8454 L p F P
0 0 0 r
s
.188 0 .528 r
.29171 .71447 m .29293 .69778 L .28196 .68812 L p F P
0 0 0 r
s
.188 0 .528 r
.28322 .67155 m .28196 .68812 L .29293 .69778 L p F P
0 0 0 r
s
.188 0 .528 r
.24421 .56608 m .24567 .55016 L .2344 .53958 L p F P
0 0 0 r
s
.188 0 .528 r
.23591 .52378 m .2344 .53958 L .24567 .55016 L p F P
0 0 0 r
s
.188 0 .528 r
.1967 .4177 m .19841 .40255 L .18685 .39105 L p F P
0 0 0 r
s
.188 0 .528 r
.1886 .37601 m .18685 .39105 L .19841 .40255 L p F P
0 0 0 r
s
.115 0 .563 r
.65175 .8578 m .6511 .84031 L .63322 .84503 L p F P
0 0 0 r
s
.115 0 .563 r
.63322 .84503 m .63378 .86249 L .65175 .8578 L p F P
0 0 0 r
s
.134 0 .891 r
.1853 .31628 m .19687 .32825 L .21327 .32178 L p F P
0 0 0 r
s
.134 0 .891 r
.19687 .32825 m .1853 .31628 L .16894 .32278 L p F P
0 0 0 r
s
.134 0 .891 r
.73049 .31628 m .73868 .32825 L .7569 .32178 L p F P
0 0 0 r
s
.134 0 .891 r
.73868 .32825 m .73049 .31628 L .7123 .32278 L p F P
0 0 0 r
s
.115 0 .563 r
.59895 .90709 m .59858 .88934 L .58087 .8939 L p F P
0 0 0 r
s
.115 0 .563 r
.58087 .8939 m .58116 .91161 L .59895 .90709 L p F P
0 0 0 r
s
.195 0 .31 r
.92513 .57956 m .92305 .56346 L .93005 .5739 L p F P
0 0 0 r
s
.195 0 .31 r
.93005 .5739 m .93215 .58995 L .92513 .57956 L p F P
0 0 0 r
s
.195 0 .31 r
.8773 .43017 m .87547 .41485 L .88277 .42621 L p F P
0 0 0 r
s
.195 0 .31 r
.88277 .42621 m .88462 .4415 L .8773 .43017 L p F P
0 0 0 r
s
.134 0 .891 r
.4802 .31577 m .48994 .32775 L .50734 .32128 L p F P
0 0 0 r
s
.134 0 .891 r
.48994 .32775 m .4802 .31577 L .46285 .32228 L p F P
0 0 0 r
s
.134 0 .891 r
.22978 .31527 m .24108 .32725 L .25764 .32078 L p F P
0 0 0 r
s
.134 0 .891 r
.24108 .32725 m .22978 .31527 L .21327 .32178 L p F P
0 0 0 r
s
.115 0 .563 r
.8984 .63357 m .89647 .61724 L .87776 .62271 L p F P
0 0 0 r
s
.115 0 .563 r
.87776 .62271 m .87959 .63902 L .8984 .63357 L p F P
0 0 0 r
s
.134 0 .891 r
.77526 .31527 m .78317 .32725 L .80156 .32078 L p F P
0 0 0 r
s
.134 0 .891 r
.78317 .32725 m .77526 .31527 L .7569 .32178 L p F P
0 0 0 r
s
.115 0 .563 r
.54613 .95641 m .54603 .9384 L .5285 .9428 L p F P
0 0 0 r
s
.115 0 .563 r
.5285 .9428 m .52851 .96077 L .54613 .95641 L p F P
0 0 0 r
s
.188 0 .528 r
.2344 .53958 m .23591 .52378 L .22458 .51302 L p F P
0 0 0 r
s
.188 0 .528 r
.22614 .49734 m .22458 .51302 L .23591 .52378 L p F P
0 0 0 r
s
.188 0 .528 r
.18685 .39105 m .1886 .37601 L .17698 .36433 L p F P
0 0 0 r
s
.188 0 .528 r
.17878 .34942 m .17698 .36433 L .1886 .37601 L p F P
0 0 0 r
s
.134 0 .891 r
.52485 .31477 m .53432 .32676 L .55188 .32028 L p F P
0 0 0 r
s
.134 0 .891 r
.53432 .32676 m .52485 .31477 L .50734 .32128 L p F P
0 0 0 r
s
.115 0 .563 r
.49328 1.00575 m .49345 .98748 L .4761 .99171 L p F P
0 0 0 r
s
.115 0 .563 r
.4761 .99171 m .47583 1.00994 L .49328 1.00575 L p F P
0 0 0 r
s
.188 0 .528 r
.37707 .98519 m .37784 .96709 L .36739 .95909 L p F P
0 0 0 r
s
.188 0 .528 r
.36821 .94111 m .36739 .95909 L .37784 .96709 L p F P
0 0 0 r
s
.188 0 .528 r
.32951 .83665 m .33053 .81932 L .31979 .8104 L p F P
0 0 0 r
s
.188 0 .528 r
.32086 .79319 m .31979 .8104 L .33053 .81932 L p F P
0 0 0 r
s
.188 0 .528 r
.28196 .68812 m .28322 .67155 L .27218 .66171 L p F P
0 0 0 r
s
.188 0 .528 r
.2735 .64527 m .27218 .66171 L .28322 .67155 L p F P
0 0 0 r
s
.115 0 .563 r
.84564 .68283 m .84399 .66624 L .82545 .67155 L p F P
0 0 0 r
s
.115 0 .563 r
.82545 .67155 m .82701 .68812 L .84564 .68283 L p F P
0 0 0 r
s
.115 0 .563 r
.79286 .73212 m .79148 .71526 L .77311 .72041 L p F P
0 0 0 r
s
.115 0 .563 r
.77311 .72041 m .77439 .73724 L .79286 .73212 L p F P
0 0 0 r
s
.134 0 .891 r
.27432 .31427 m .28534 .32626 L .30206 .31978 L p F P
0 0 0 r
s
.134 0 .891 r
.28534 .32626 m .27432 .31427 L .25764 .32078 L p F P
0 0 0 r
s
.134 0 .891 r
.82007 .31427 m .82771 .32626 L .84626 .31978 L p F P
0 0 0 r
s
.134 0 .891 r
.82771 .32626 m .82007 .31427 L .80156 .32078 L p F P
0 0 0 r
s
.115 0 .563 r
.44041 1.05512 m .44085 1.03659 L .42367 1.04066 L p F P
0 0 0 r
s
.115 0 .563 r
.42367 1.04066 m .42313 1.05915 L .44041 1.05512 L p F P
0 0 0 r
s
.195 0 .31 r
.86809 .40334 m .86631 .38815 L .87367 .39969 L p F P
0 0 0 r
s
.195 0 .31 r
.87367 .39969 m .87547 .41485 L .86809 .40334 L p F P
0 0 0 r
s
.115 0 .563 r
.74005 .78143 m .73894 .76431 L .72075 .7693 L p F P
0 0 0 r
s
.115 0 .563 r
.72075 .7693 m .72176 .78638 L .74005 .78143 L p F P
0 0 0 r
s
.134 0 .891 r
.56955 .31376 m .57875 .32576 L .59646 .31928 L p F P
0 0 0 r
s
.134 0 .891 r
.57875 .32576 m .56955 .31376 L .55188 .32028 L p F P
0 0 0 r
s
.195 0 .31 r
.91597 .55289 m .91394 .53691 L .921 .54753 L p F P
0 0 0 r
s
.195 0 .31 r
.921 .54753 m .92305 .56346 L .91597 .55289 L p F P
0 0 0 r
s
.134 0 .891 r
.31889 .31326 m .32965 .32527 L .34653 .31878 L p F P
0 0 0 r
s
.134 0 .891 r
.32965 .32527 m .31889 .31326 L .30206 .31978 L p F P
0 0 0 r
s
.115 0 .563 r
.68721 .83076 m .68637 .81339 L .66835 .81821 L p F P
0 0 0 r
s
.115 0 .563 r
.66835 .81821 m .66909 .83555 L .68721 .83076 L p F P
0 0 0 r
s
.134 0 .891 r
.61429 .31276 m .62322 .32477 L .64109 .31828 L p F P
0 0 0 r
s
.134 0 .891 r
.62322 .32477 m .61429 .31276 L .59646 .31928 L p F P
0 0 0 r
s
.115 0 .563 r
.63434 .88013 m .63378 .86249 L .61593 .86715 L p F P
0 0 0 r
s
.115 0 .563 r
.61593 .86715 m .6164 .88475 L .63434 .88013 L p F P
0 0 0 r
s
.188 0 .528 r
.36739 .95909 m .36821 .94111 L .3577 .93294 L p F P
0 0 0 r
s
.188 0 .528 r
.35857 .91507 m .3577 .93294 L .36821 .94111 L p F P
0 0 0 r
s
.188 0 .528 r
.31979 .8104 m .32086 .79319 L .31004 .7841 L p F P
0 0 0 r
s
.188 0 .528 r
.31116 .767 m .31004 .7841 L .32086 .79319 L p F P
0 0 0 r
s
.188 0 .528 r
.27218 .66171 m .2735 .64527 L .26239 .63525 L p F P
0 0 0 r
s
.188 0 .528 r
.26376 .61893 m .26239 .63525 L .2735 .64527 L p F P
0 0 0 r
s
.188 0 .528 r
.22458 .51302 m .22614 .49734 L .21474 .48641 L p F P
0 0 0 r
s
.188 0 .528 r
.21635 .47085 m .21474 .48641 L .22614 .49734 L p F P
0 0 0 r
s
.188 0 .528 r
.17698 .36433 m .17878 .34942 L .16708 .33756 L p F P
0 0 0 r
s
.188 0 .528 r
.16894 .32278 m .16708 .33756 L .17878 .34942 L p F P
0 0 0 r
s
.115 0 .563 r
.93426 .60617 m .93215 .58995 L .91329 .59553 L p F P
0 0 0 r
s
.115 0 .563 r
.91329 .59553 m .9153 .61172 L .93426 .60617 L p F P
0 0 0 r
s
.134 0 .891 r
.36352 .31225 m .374 .32427 L .39104 .31778 L p F P
0 0 0 r
s
.134 0 .891 r
.374 .32427 m .36352 .31225 L .34653 .31878 L p F P
0 0 0 r
s
.115 0 .563 r
.58144 .92951 m .58116 .91161 L .56348 .91611 L p F P
0 0 0 r
s
.115 0 .563 r
.56348 .91611 m .56368 .93397 L .58144 .92951 L p F P
0 0 0 r
s
.195 0 .31 r
.90679 .52617 m .90481 .51031 L .91193 .5211 L p F P
0 0 0 r
s
.195 0 .31 r
.91193 .5211 m .91394 .53691 L .90679 .52617 L p F P
0 0 0 r
s
.134 0 .891 r
.65908 .31175 m .66773 .32377 L .68576 .31728 L p F P
0 0 0 r
s
.134 0 .891 r
.66773 .32377 m .65908 .31175 L .64109 .31828 L p F P
0 0 0 r
s
.195 0 .31 r
.85886 .37646 m .85713 .36139 L .86455 .37311 L p F P
0 0 0 r
s
.195 0 .31 r
.86455 .37311 m .86631 .38815 L .85886 .37646 L p F P
0 0 0 r
s
.115 0 .563 r
.88143 .6555 m .87959 .63902 L .86091 .64444 L p F P
0 0 0 r
s
.115 0 .563 r
.86091 .64444 m .86265 .66089 L .88143 .6555 L p F P
0 0 0 r
s
.115 0 .563 r
.52852 .97893 m .52851 .96077 L .51101 .9651 L p F P
0 0 0 r
s
.115 0 .563 r
.51101 .9651 m .51093 .98322 L .52852 .97893 L p F P
0 0 0 r
s
.134 0 .891 r
.40819 .31124 m .4184 .32328 L .4356 .31678 L p F P
0 0 0 r
s
.134 0 .891 r
.4184 .32328 m .40819 .31124 L .39104 .31778 L p F P
0 0 0 r
s
.115 0 .563 r
.82858 .70486 m .82701 .68812 L .80849 .69337 L p F P
0 0 0 r
s
.115 0 .563 r
.80849 .69337 m .80996 .71008 L .82858 .70486 L p F P
0 0 0 r
s
.115 0 .563 r
.47557 1.02837 m .47583 1.00994 L .45851 1.01411 L p F P
0 0 0 r
s
.115 0 .563 r
.45851 1.01411 m .45815 1.03249 L .47557 1.02837 L p F P
0 0 0 r
s
.134 0 .891 r
.70392 .31074 m .7123 .32278 L .73049 .31628 L p F P
0 0 0 r
s
.134 0 .891 r
.7123 .32278 m .70392 .31074 L .68576 .31728 L p F P
0 0 0 r
s
.115 0 .563 r
.77569 .75424 m .77439 .73724 L .75606 .74232 L p F P
0 0 0 r
s
.115 0 .563 r
.75606 .74232 m .75725 .75929 L .77569 .75424 L p F P
0 0 0 r
s
.188 0 .528 r
.39636 1.03722 m .39568 1.05574 L .40598 1.06315 L p F P
0 0 0 r
s
.125 0 .956 r
.42313 1.05915 m .40598 1.06315 L .39568 1.05574 L p F P
0 0 0 r
s
.188 0 .528 r
.3577 .93294 m .35857 .91507 L .34798 .90674 L p F P
0 0 0 r
s
.188 0 .528 r
.3489 .88899 m .34798 .90674 L .35857 .91507 L p F P
0 0 0 r
s
.188 0 .528 r
.31004 .7841 m .31116 .767 L .30028 .75774 L p F P
0 0 0 r
s
.188 0 .528 r
.30145 .74076 m .30028 .75774 L .31116 .767 L p F P
0 0 0 r
s
.188 0 .528 r
.26239 .63525 m .26376 .61893 L .25257 .60874 L p F P
0 0 0 r
s
.188 0 .528 r
.25399 .59253 m .25257 .60874 L .26376 .61893 L p F P
0 0 0 r
s
.188 0 .528 r
.21474 .48641 m .21635 .47085 L .20487 .45974 L p F P
0 0 0 r
s
.188 0 .528 r
.20654 .4443 m .20487 .45974 L .21635 .47085 L p F P
0 0 0 r
s
.134 0 .891 r
.15717 .31074 m .16894 .32278 L .1853 .31628 L p F P
0 0 0 r
s
.188 0 .528 r
.16708 .33756 m .16894 .32278 L .15717 .31074 L p F P
0 0 0 r
s
.115 0 .563 r
.72278 .80364 m .72176 .78638 L .70359 .7913 L p F P
0 0 0 r
s
.115 0 .563 r
.70359 .7913 m .70451 .80853 L .72278 .80364 L p F P
0 0 0 r
s
.134 0 .891 r
.45291 .31023 m .46285 .32228 L .4802 .31577 L p F P
0 0 0 r
s
.134 0 .891 r
.46285 .32228 m .45291 .31023 L .4356 .31678 L p F P
0 0 0 r
s
.115 0 .563 r
.66984 .85308 m .66909 .83555 L .6511 .84031 L p F P
0 0 0 r
s
.115 0 .563 r
.6511 .84031 m .65175 .8578 L .66984 .85308 L p F P
0 0 0 r
s
.134 0 .891 r
.20177 .30973 m .21327 .32178 L .22978 .31527 L p F P
0 0 0 r
s
.134 0 .891 r
.21327 .32178 m .20177 .30973 L .1853 .31628 L p F P
0 0 0 r
s
.195 0 .31 r
.89759 .49938 m .89566 .48365 L .90285 .49462 L p F P
0 0 0 r
s
.195 0 .31 r
.90285 .49462 m .90481 .51031 L .89759 .49938 L p F P
0 0 0 r
s
.195 0 .31 r
.84961 .34952 m .84793 .33458 L .85542 .34647 L p F P
0 0 0 r
s
.195 0 .31 r
.85542 .34647 m .85713 .36139 L .84961 .34952 L p F P
0 0 0 r
s
.134 0 .891 r
.7488 .30973 m .7569 .32178 L .77526 .31527 L p F P
0 0 0 r
s
.134 0 .891 r
.7569 .32178 m .7488 .30973 L .73049 .31628 L p F P
0 0 0 r
s
.134 0 .891 r
.49767 .30922 m .50734 .32128 L .52485 .31477 L p F P
0 0 0 r
s
.134 0 .891 r
.50734 .32128 m .49767 .30922 L .4802 .31577 L p F P
0 0 0 r
s
.115 0 .563 r
.61687 .90253 m .6164 .88475 L .59858 .88934 L p F P
0 0 0 r
s
.115 0 .563 r
.59858 .88934 m .59895 .90709 L .61687 .90253 L p F P
0 0 0 r
s
.134 0 .891 r
.24641 .30872 m .25764 .32078 L .27432 .31427 L p F P
0 0 0 r
s
.134 0 .891 r
.25764 .32078 m .24641 .30872 L .22978 .31527 L p F P
0 0 0 r
s
.188 0 .528 r
.34798 .90674 m .3489 .88899 L .33824 .88048 L p F P
0 0 0 r
s
.188 0 .528 r
.33922 .86285 m .33824 .88048 L .3489 .88899 L p F P
0 0 0 r
s
.188 0 .528 r
.20487 .45974 m .20654 .4443 L .19498 .43301 L p F P
0 0 0 r
s
.188 0 .528 r
.1967 .4177 m .19498 .43301 L .20654 .4443 L p F P
0 0 0 r
s
.115 0 .563 r
.91734 .62809 m .9153 .61172 L .89647 .61724 L p F P
0 0 0 r
s
.115 0 .563 r
.89647 .61724 m .8984 .63357 L .91734 .62809 L p F P
0 0 0 r
s
.134 0 .891 r
.79373 .30872 m .80156 .32078 L .82007 .31427 L p F P
0 0 0 r
s
.134 0 .891 r
.80156 .32078 m .79373 .30872 L .77526 .31527 L p F P
0 0 0 r
s
.115 0 .563 r
.56387 .95202 m .56368 .93397 L .54603 .9384 L p F P
0 0 0 r
s
.115 0 .563 r
.54603 .9384 m .54613 .95641 L .56387 .95202 L p F P
0 0 0 r
s
.188 0 .528 r
.39568 1.05574 m .39636 1.03722 L .386 1.02964 L p F P
0 0 0 r
s
.188 0 .528 r
.38672 1.01123 m .386 1.02964 L .39636 1.03722 L p F P
0 0 0 r
s
.188 0 .528 r
.30028 .75774 m .30145 .74076 L .29049 .73133 L p F P
0 0 0 r
s
.188 0 .528 r
.29171 .71447 m .29049 .73133 L .30145 .74076 L p F P
0 0 0 r
s
.188 0 .528 r
.25257 .60874 m .25399 .59253 L .24274 .58217 L p F P
0 0 0 r
s
.188 0 .528 r
.24421 .56608 m .24274 .58217 L .25399 .59253 L p F P
0 0 0 r
s
.134 0 .891 r
.54248 .30821 m .55188 .32028 L .56955 .31376 L p F P
0 0 0 r
s
.134 0 .891 r
.55188 .32028 m .54248 .30821 L .52485 .31477 L p F P
0 0 0 r
s
.115 0 .563 r
.86441 .67751 m .86265 .66089 L .84399 .66624 L p F P
0 0 0 r
s
.115 0 .563 r
.84399 .66624 m .84564 .68283 L .86441 .67751 L p F P
0 0 0 r
s
.115 0 .563 r
.51085 1.00153 m .51093 .98322 L .49345 .98748 L p F P
0 0 0 r
s
.115 0 .563 r
.49345 .98748 m .49328 1.00575 L .51085 1.00153 L p F P
0 0 0 r
s
.195 0 .31 r
.88838 .47255 m .88649 .45694 L .89374 .46809 L p F P
0 0 0 r
s
.195 0 .31 r
.89374 .46809 m .89566 .48365 L .88838 .47255 L p F P
0 0 0 r
s
.115 0 .563 r
.81145 .72696 m .80996 .71008 L .79148 .71526 L p F P
0 0 0 r
s
.115 0 .563 r
.79148 .71526 m .79286 .73212 L .81145 .72696 L p F P
0 0 0 r
s
.134 0 .891 r
.2911 .30771 m .30206 .31978 L .31889 .31326 L p F P
0 0 0 r
s
.134 0 .891 r
.30206 .31978 m .2911 .30771 L .27432 .31427 L p F P
0 0 0 r
s
.115 0 .563 r
.4578 1.05106 m .45815 1.03249 L .44085 1.03659 L p F P
0 0 0 r
s
.115 0 .563 r
.44085 1.03659 m .44041 1.05512 L .4578 1.05106 L p F P
0 0 0 r
s
.134 0 .891 r
.84626 .31978 m .83871 .30771 L .82007 .31427 L p F P
0 0 0 r
s
.195 0 .31 r
.84035 .32253 m .83871 .30771 L .84626 .31978 L p F P
0 0 0 r
s
.195 0 .31 r
.84626 .31978 m .84793 .33458 L .84035 .32253 L p F P
0 0 0 r
s
.134 0 .891 r
.58734 .3072 m .59646 .31928 L .61429 .31276 L p F P
0 0 0 r
s
.134 0 .891 r
.59646 .31928 m .58734 .3072 L .56955 .31376 L p F P
0 0 0 r
s
.115 0 .563 r
.75846 .77644 m .75725 .75929 L .73894 .76431 L p F P
0 0 0 r
s
.115 0 .563 r
.73894 .76431 m .74005 .78143 L .75846 .77644 L p F P
0 0 0 r
s
.188 0 .528 r
.24274 .58217 m .24421 .56608 L .23288 .55555 L p F P
0 0 0 r
s
.188 0 .528 r
.2344 .53958 m .23288 .55555 L .24421 .56608 L p F P
0 0 0 r
s
.134 0 .891 r
.33584 .30669 m .34653 .31878 L .36352 .31225 L p F P
0 0 0 r
s
.134 0 .891 r
.34653 .31878 m .33584 .30669 L .31889 .31326 L p F P
0 0 0 r
s
.115 0 .563 r
.70545 .82594 m .70451 .80853 L .68637 .81339 L p F P
0 0 0 r
s
.115 0 .563 r
.68637 .81339 m .68721 .83076 L .70545 .82594 L p F P
0 0 0 r
s
.188 0 .528 r
.386 1.02964 m .38672 1.01123 L .37629 1.00348 L p F P
0 0 0 r
s
.188 0 .528 r
.37707 .98519 m .37629 1.00348 L .38672 1.01123 L p F P
0 0 0 r
s
.188 0 .528 r
.33824 .88048 m .33922 .86285 L .32849 .85417 L p F P
0 0 0 r
s
.188 0 .528 r
.32951 .83665 m .32849 .85417 L .33922 .86285 L p F P
0 0 0 r
s
.188 0 .528 r
.29049 .73133 m .29171 .71447 L .28068 .70486 L p F P
0 0 0 r
s
.188 0 .528 r
.28196 .68812 m .28068 .70486 L .29171 .71447 L p F P
0 0 0 r
s
.188 0 .528 r
.19498 .43301 m .1967 .4177 L .18508 .40623 L p F P
0 0 0 r
s
.188 0 .528 r
.18685 .39105 m .18508 .40623 L .1967 .4177 L p F P
0 0 0 r
s
.134 0 .891 r
.63224 .30619 m .64109 .31828 L .65908 .31175 L p F P
0 0 0 r
s
.134 0 .891 r
.64109 .31828 m .63224 .30619 L .61429 .31276 L p F P
0 0 0 r
s
.115 0 .563 r
.6524 .87547 m .65175 .8578 L .63378 .86249 L p F P
0 0 0 r
s
.115 0 .563 r
.63378 .86249 m .63434 .88013 L .6524 .87547 L p F P
0 0 0 r
s
.195 0 .31 r
.87914 .44565 m .8773 .43017 L .88462 .4415 L p F P
0 0 0 r
s
.195 0 .31 r
.88462 .4415 m .88649 .45694 L .87914 .44565 L p F P
0 0 0 r
s
.115 0 .563 r
.59933 .92503 m .59895 .90709 L .58116 .91161 L p F P
0 0 0 r
s
.115 0 .563 r
.58116 .91161 m .58144 .92951 L .59933 .92503 L p F P
0 0 0 r
s
.134 0 .891 r
.38063 .30568 m .39104 .31778 L .40819 .31124 L p F P
0 0 0 r
s
.134 0 .891 r
.39104 .31778 m .38063 .30568 L .36352 .31225 L p F P
0 0 0 r
s
.195 0 .31 r
.92722 .59583 m .92513 .57956 L .93215 .58995 L p F P
0 0 0 r
s
.195 0 .31 r
.93215 .58995 m .93426 .60617 L .92722 .59583 L p F P
0 0 0 r
s
.134 0 .891 r
.6772 .30517 m .68576 .31728 L .70392 .31074 L p F P
0 0 0 r
s
.134 0 .891 r
.68576 .31728 m .6772 .30517 L .65908 .31175 L p F P
0 0 0 r
s
.115 0 .563 r
.90035 .65008 m .8984 .63357 L .87959 .63902 L p F P
0 0 0 r
s
.115 0 .563 r
.87959 .63902 m .88143 .6555 L .90035 .65008 L p F P
0 0 0 r
s
.115 0 .563 r
.54623 .97461 m .54613 .95641 L .52851 .96077 L p F P
0 0 0 r
s
.115 0 .563 r
.52851 .96077 m .52852 .97893 L .54623 .97461 L p F P
0 0 0 r
s
.188 0 .528 r
.18508 .40623 m .18685 .39105 L .17515 .3794 L p F P
0 0 0 r
s
.188 0 .528 r
.17698 .36433 m .17515 .3794 L .18685 .39105 L p F P
0 0 0 r
s
.134 0 .891 r
.42546 .30466 m .4356 .31678 L .45291 .31023 L p F P
0 0 0 r
s
.134 0 .891 r
.4356 .31678 m .42546 .30466 L .40819 .31124 L p F P
0 0 0 r
s
.188 0 .528 r
.23288 .55555 m .2344 .53958 L .223 .52887 L p F P
0 0 0 r
s
.188 0 .528 r
.22458 .51302 m .223 .52887 L .2344 .53958 L p F P
0 0 0 r
s
.115 0 .563 r
.84732 .6996 m .84564 .68283 L .82701 .68812 L p F P
0 0 0 r
s
.115 0 .563 r
.82701 .68812 m .82858 .70486 L .84732 .6996 L p F P
0 0 0 r
s
.115 0 .563 r
.49311 1.02421 m .49328 1.00575 L .47583 1.00994 L p F P
0 0 0 r
s
.115 0 .563 r
.47583 1.00994 m .47557 1.02837 L .49311 1.02421 L p F P
0 0 0 r
s
.188 0 .528 r
.37629 1.00348 m .37707 .98519 L .36656 .97727 L p F P
0 0 0 r
s
.188 0 .528 r
.36739 .95909 m .36656 .97727 L .37707 .98519 L p F P
0 0 0 r
s
.188 0 .528 r
.32849 .85417 m .32951 .83665 L .31871 .8278 L p F P
0 0 0 r
s
.188 0 .528 r
.31979 .8104 m .31871 .8278 L .32951 .83665 L p F P
0 0 0 r
s
.188 0 .528 r
.28068 .70486 m .28196 .68812 L .27086 .67833 L p F P
0 0 0 r
s
.188 0 .528 r
.27218 .66171 m .27086 .67833 L .28196 .68812 L p F P
0 0 0 r
s
.115 0 .563 r
.79426 .74915 m .79286 .73212 L .77439 .73724 L p F P
0 0 0 r
s
.115 0 .563 r
.77439 .73724 m .77569 .75424 L .79426 .74915 L p F P
0 0 0 r
s
.134 0 .891 r
.17359 .30416 m .1853 .31628 L .20177 .30973 L p F P
0 0 0 r
s
.134 0 .891 r
.1853 .31628 m .17359 .30416 L .15717 .31074 L p F P
0 0 0 r
s
.134 0 .891 r
.7222 .30416 m .73049 .31628 L .7488 .30973 L p F P
0 0 0 r
s
.134 0 .891 r
.73049 .31628 m .7222 .30416 L .70392 .31074 L p F P
0 0 0 r
s
.125 0 .956 r
.44041 1.05512 m .42313 1.05915 L .41291 1.05169 L p F P
0 0 0 r
s
.125 0 .956 r
.39568 1.05574 m .41291 1.05169 L .42313 1.05915 L p F P
0 0 0 r
s
.195 0 .31 r
.91802 .56903 m .91597 .55289 L .92305 .56346 L p F P
0 0 0 r
s
.195 0 .31 r
.92305 .56346 m .92513 .57956 L .91802 .56903 L p F P
0 0 0 r
s
.195 0 .31 r
.86989 .4187 m .86809 .40334 L .87547 .41485 L p F P
0 0 0 r
s
.195 0 .31 r
.87547 .41485 m .8773 .43017 L .86989 .4187 L p F P
0 0 0 r
s
.134 0 .891 r
.47034 .30365 m .4802 .31577 L .49767 .30922 L p F P
0 0 0 r
s
.134 0 .891 r
.4802 .31577 m .47034 .30365 L .45291 .31023 L p F P
0 0 0 r
s
.115 0 .563 r
.74117 .79872 m .74005 .78143 L .72176 .78638 L p F P
0 0 0 r
s
.115 0 .563 r
.72176 .78638 m .72278 .80364 L .74117 .79872 L p F P
0 0 0 r
s
.134 0 .891 r
.76724 .30314 m .77526 .31527 L .79373 .30872 L p F P
0 0 0 r
s
.134 0 .891 r
.77526 .31527 m .76724 .30314 L .7488 .30973 L p F P
0 0 0 r
s
.115 0 .563 r
.68805 .84832 m .68721 .83076 L .66909 .83555 L p F P
0 0 0 r
s
.115 0 .563 r
.66909 .83555 m .66984 .85308 L .68805 .84832 L p F P
0 0 0 r
s
.134 0 .891 r
.21834 .30314 m .22978 .31527 L .24641 .30872 L p F P
0 0 0 r
s
.134 0 .891 r
.22978 .31527 m .21834 .30314 L .20177 .30973 L p F P
0 0 0 r
s
.188 0 .528 r
.223 .52887 m .22458 .51302 L .21311 .50213 L p F P
0 0 0 r
s
.188 0 .528 r
.21474 .48641 m .21311 .50213 L .22458 .51302 L p F P
0 0 0 r
s
.134 0 .891 r
.51526 .30263 m .52485 .31477 L .54248 .30821 L p F P
0 0 0 r
s
.134 0 .891 r
.52485 .31477 m .51526 .30263 L .49767 .30922 L p F P
0 0 0 r
s
.115 0 .563 r
.63491 .89795 m .63434 .88013 L .6164 .88475 L p F P
0 0 0 r
s
.115 0 .563 r
.6164 .88475 m .61687 .90253 L .63491 .89795 L p F P
0 0 0 r
s
.188 0 .528 r
.17515 .3794 m .17698 .36433 L .1652 .3525 L p F P
0 0 0 r
s
.188 0 .528 r
.16708 .33756 m .1652 .3525 L .17698 .36433 L p F P
0 0 0 r
s
.188 0 .528 r
.36656 .97727 m .36739 .95909 L .35681 .951 L p F P
0 0 0 r
s
.188 0 .528 r
.3577 .93294 m .35681 .951 L .36739 .95909 L p F P
0 0 0 r
s
.188 0 .528 r
.31871 .8278 m .31979 .8104 L .30891 .80138 L p F P
0 0 0 r
s
.188 0 .528 r
.31004 .7841 m .30891 .80138 L .31979 .8104 L p F P
0 0 0 r
s
.188 0 .528 r
.27086 .67833 m .27218 .66171 L .26101 .65175 L p F P
0 0 0 r
s
.188 0 .528 r
.26239 .63525 m .26101 .65175 L .27218 .66171 L p F P
0 0 0 r
s
.134 0 .891 r
.26315 .30212 m .27432 .31427 L .2911 .30771 L p F P
0 0 0 r
s
.134 0 .891 r
.27432 .31427 m .26315 .30212 L .24641 .30872 L p F P
0 0 0 r
s
.115 0 .563 r
.93641 .62256 m .93426 .60617 L .9153 .61172 L p F P
0 0 0 r
s
.115 0 .563 r
.9153 .61172 m .91734 .62809 L .93641 .62256 L p F P
0 0 0 r
s
.134 0 .891 r
.81233 .30212 m .82007 .31427 L .83871 .30771 L p F P
0 0 0 r
s
.134 0 .891 r
.82007 .31427 m .81233 .30212 L .79373 .30872 L p F P
0 0 0 r
s
.115 0 .563 r
.58173 .9476 m .58144 .92951 L .56368 .93397 L p F P
0 0 0 r
s
.115 0 .563 r
.56368 .93397 m .56387 .95202 L .58173 .9476 L p F P
0 0 0 r
s
.195 0 .31 r
.90879 .54219 m .90679 .52617 L .91394 .53691 L p F P
0 0 0 r
s
.195 0 .31 r
.91394 .53691 m .91597 .55289 L .90879 .54219 L p F P
0 0 0 r
s
.195 0 .31 r
.86061 .3917 m .85886 .37646 L .86631 .38815 L p F P
0 0 0 r
s
.195 0 .31 r
.86631 .38815 m .86809 .40334 L .86061 .3917 L p F P
0 0 0 r
s
.115 0 .563 r
.8833 .67216 m .88143 .6555 L .86265 .66089 L p F P
0 0 0 r
s
.115 0 .563 r
.86265 .66089 m .86441 .67751 L .8833 .67216 L p F P
0 0 0 r
s
.134 0 .891 r
.56023 .30161 m .56955 .31376 L .58734 .3072 L p F P
0 0 0 r
s
.134 0 .891 r
.56955 .31376 m .56023 .30161 L .54248 .30821 L p F P
0 0 0 r
s
.115 0 .563 r
.52853 .99728 m .52852 .97893 L .51093 .98322 L p F P
0 0 0 r
s
.115 0 .563 r
.51093 .98322 m .51085 1.00153 L .52853 .99728 L p F P
0 0 0 r
s
.115 0 .563 r
.83016 .72177 m .82858 .70486 L .80996 .71008 L p F P
0 0 0 r
s
.115 0 .563 r
.80996 .71008 m .81145 .72696 L .83016 .72177 L p F P
0 0 0 r
s
.115 0 .563 r
.4753 1.04698 m .47557 1.02837 L .45815 1.03249 L p F P
0 0 0 r
s
.115 0 .563 r
.45815 1.03249 m .4578 1.05106 L .4753 1.04698 L p F P
0 0 0 r
s
.134 0 .891 r
.308 .3011 m .31889 .31326 L .33584 .30669 L p F P
0 0 0 r
s
.134 0 .891 r
.31889 .31326 m .308 .3011 L .2911 .30771 L p F P
0 0 0 r
s
.115 0 .563 r
.777 .77142 m .77569 .75424 L .75725 .75929 L p F P
0 0 0 r
s
.115 0 .563 r
.75725 .75929 m .75846 .77644 L .777 .77142 L p F P
0 0 0 r
s
.134 0 .891 r
.60525 .30059 m .61429 .31276 L .63224 .30619 L p F P
0 0 0 r
s
.134 0 .891 r
.61429 .31276 m .60525 .30059 L .58734 .3072 L p F P
0 0 0 r
s
.188 0 .528 r
.26101 .65175 m .26239 .63525 L .25114 .62512 L p F P
0 0 0 r
s
.188 0 .528 r
.25257 .60874 m .25114 .62512 L .26239 .63525 L p F P
0 0 0 r
s
.188 0 .528 r
.1652 .3525 m .16708 .33756 L .15523 .32556 L p F P
0 0 0 r
s
.188 0 .528 r
.15717 .31074 m .15523 .32556 L .16708 .33756 L p F P
0 0 0 r
s
.188 0 .528 r
.35681 .951 m .3577 .93294 L .34705 .92468 L p F P
0 0 0 r
s
.188 0 .528 r
.34798 .90674 m .34705 .92468 L .3577 .93294 L p F P
0 0 0 r
s
.188 0 .528 r
.30891 .80138 m .31004 .7841 L .29909 .7749 L p F P
0 0 0 r
s
.188 0 .528 r
.30028 .75774 m .29909 .7749 L .31004 .7841 L p F P
0 0 0 r
s
.188 0 .528 r
.21311 .50213 m .21474 .48641 L .20319 .47534 L p F P
0 0 0 r
s
.188 0 .528 r
.20487 .45974 m .20319 .47534 L .21474 .48641 L p F P
0 0 0 r
s
.115 0 .563 r
.72381 .82109 m .72278 .80364 L .70451 .80853 L p F P
0 0 0 r
s
.115 0 .563 r
.70451 .80853 m .70545 .82594 L .72381 .82109 L p F P
0 0 0 r
s
.134 0 .891 r
.3529 .30008 m .36352 .31225 L .38063 .30568 L p F P
0 0 0 r
s
.134 0 .891 r
.36352 .31225 m .3529 .30008 L .33584 .30669 L p F P
0 0 0 r
s
.195 0 .31 r
.89955 .51528 m .89759 .49938 L .90481 .51031 L p F P
0 0 0 r
s
.195 0 .31 r
.90481 .51031 m .90679 .52617 L .89955 .51528 L p F P
0 0 0 r
s
.134 0 .891 r
.65032 .29957 m .65908 .31175 L .6772 .30517 L p F P
0 0 0 r
s
.134 0 .891 r
.65908 .31175 m .65032 .29957 L .63224 .30619 L p F P
0 0 0 r
s
.115 0 .563 r
.67059 .87078 m .66984 .85308 L .65175 .8578 L p F P
0 0 0 r
s
.115 0 .563 r
.65175 .8578 m .6524 .87547 L .67059 .87078 L p F P
0 0 0 r
s
.195 0 .31 r
.85132 .36463 m .84961 .34952 L .85713 .36139 L p F P
0 0 0 r
s
.195 0 .31 r
.85713 .36139 m .85886 .37646 L .85132 .36463 L p F P
0 0 0 r
s
.115 0 .563 r
.61734 .92051 m .61687 .90253 L .59895 .90709 L p F P
0 0 0 r
s
.115 0 .563 r
.59895 .90709 m .59933 .92503 L .61734 .92051 L p F P
0 0 0 r
s
.134 0 .891 r
.39785 .29906 m .40819 .31124 L .42546 .30466 L p F P
0 0 0 r
s
.134 0 .891 r
.40819 .31124 m .39785 .29906 L .38063 .30568 L p F P
0 0 0 r
s
.188 0 .528 r
.20319 .47534 m .20487 .45974 L .19325 .44849 L p F P
0 0 0 r
s
.188 0 .528 r
.19498 .43301 m .19325 .44849 L .20487 .45974 L p F P
0 0 0 r
s
.188 0 .528 r
.386 1.02964 m .38526 1.04824 L .39568 1.05574 L p F P
0 0 0 r
s
.125 0 .956 r
.41291 1.05169 m .39568 1.05574 L .38526 1.04824 L p F P
0 0 0 r
s
.188 0 .528 r
.34705 .92468 m .34798 .90674 L .33726 .8983 L p F P
0 0 0 r
s
.188 0 .528 r
.33824 .88048 m .33726 .8983 L .34798 .90674 L p F P
0 0 0 r
s
.188 0 .528 r
.29909 .7749 m .30028 .75774 L .28925 .74836 L p F P
0 0 0 r
s
.188 0 .528 r
.29049 .73133 m .28925 .74836 L .30028 .75774 L p F P
0 0 0 r
s
.188 0 .528 r
.25114 .62512 m .25257 .60874 L .24125 .59843 L p F P
0 0 0 r
s
.188 0 .528 r
.24274 .58217 m .24125 .59843 L .25257 .60874 L p F P
0 0 0 r
s
.134 0 .891 r
.14524 .29855 m .15717 .31074 L .17359 .30416 L p F P
0 0 0 r
s
.188 0 .528 r
.15523 .32556 m .15717 .31074 L .14524 .29855 L p F P
0 0 0 r
s
.115 0 .563 r
.91939 .64462 m .91734 .62809 L .8984 .63357 L p F P
0 0 0 r
s
.115 0 .563 r
.8984 .63357 m .90035 .65008 L .91939 .64462 L p F P
0 0 0 r
s
.134 0 .891 r
.69544 .29855 m .70392 .31074 L .7222 .30416 L p F P
0 0 0 r
s
.134 0 .891 r
.70392 .31074 m .69544 .29855 L .6772 .30517 L p F P
0 0 0 r
s
.115 0 .563 r
.56407 .97026 m .56387 .95202 L .54613 .95641 L p F P
0 0 0 r
s
.115 0 .563 r
.54613 .95641 m .54623 .97461 L .56407 .97026 L p F P
0 0 0 r
s
.134 0 .891 r
.44284 .29804 m .45291 .31023 L .47034 .30365 L p F P
0 0 0 r
s
.134 0 .891 r
.45291 .31023 m .44284 .29804 L .42546 .30466 L p F P
0 0 0 r
s
.115 0 .563 r
.86618 .69431 m .86441 .67751 L .84564 .68283 L p F P
0 0 0 r
s
.115 0 .563 r
.84564 .68283 m .84732 .6996 L .86618 .69431 L p F P
0 0 0 r
s
.115 0 .563 r
.51077 1.02003 m .51085 1.00153 L .49328 1.00575 L p F P
0 0 0 r
s
.115 0 .563 r
.49328 1.00575 m .49311 1.02421 L .51077 1.02003 L p F P
0 0 0 r
s
.115 0 .563 r
.81295 .74403 m .81145 .72696 L .79286 .73212 L p F P
0 0 0 r
s
.115 0 .563 r
.79286 .73212 m .79426 .74915 L .81295 .74403 L p F P
0 0 0 r
s
.125 0 .956 r
.4578 1.05106 m .44041 1.05512 L .43026 1.04761 L p F P
0 0 0 r
s
.134 0 .891 r
.19012 .29753 m .20177 .30973 L .21834 .30314 L p F P
0 0 0 r
s
.125 0 .956 r
.41291 1.05169 m .43026 1.04761 L .44041 1.05512 L p F P
0 0 0 r
s
.134 0 .891 r
.20177 .30973 m .19012 .29753 L .17359 .30416 L p F P
0 0 0 r
s
.195 0 .31 r
.89029 .48832 m .88838 .47255 L .89566 .48365 L p F P
0 0 0 r
s
.195 0 .31 r
.89566 .48365 m .89759 .49938 L .89029 .48832 L p F P
0 0 0 r
s
.195 0 .31 r
.842 .33751 m .84035 .32253 L .84793 .33458 L p F P
0 0 0 r
s
.195 0 .31 r
.84793 .33458 m .84961 .34952 L .842 .33751 L p F P
0 0 0 r
s
.134 0 .891 r
.7406 .29753 m .7488 .30973 L .76724 .30314 L p F P
0 0 0 r
s
.134 0 .891 r
.7488 .30973 m .7406 .29753 L .7222 .30416 L p F P
0 0 0 r
s
.115 0 .563 r
.75968 .79377 m .75846 .77644 L .74005 .78143 L p F P
0 0 0 r
s
.115 0 .563 r
.74005 .78143 m .74117 .79872 L .75968 .79377 L p F P
0 0 0 r
s
.134 0 .891 r
.48788 .29702 m .49767 .30922 L .51526 .30263 L p F P
0 0 0 r
s
.134 0 .891 r
.49767 .30922 m .48788 .29702 L .47034 .30365 L p F P
0 0 0 r
s
.115 0 .563 r
.70639 .84354 m .70545 .82594 L .68721 .83076 L p F P
0 0 0 r
s
.115 0 .563 r
.68721 .83076 m .68805 .84832 L .70639 .84354 L p F P
0 0 0 r
s
.134 0 .891 r
.23504 .2965 m .24641 .30872 L .26315 .30212 L p F P
0 0 0 r
s
.134 0 .891 r
.24641 .30872 m .23504 .2965 L .21834 .30314 L p F P
0 0 0 r
s
.188 0 .528 r
.38526 1.04824 m .386 1.02964 L .3755 1.02196 L p F P
0 0 0 r
s
.188 0 .528 r
.37629 1.00348 m .3755 1.02196 L .386 1.02964 L p F P
0 0 0 r
s
.188 0 .528 r
.33726 .8983 m .33824 .88048 L .32745 .87187 L p F P
0 0 0 r
s
.188 0 .528 r
.32849 .85417 m .32745 .87187 L .33824 .88048 L p F P
0 0 0 r
s
.188 0 .528 r
.28925 .74836 m .29049 .73133 L .27939 .72177 L p F P
0 0 0 r
s
.188 0 .528 r
.28068 .70486 m .27939 .72177 L .29049 .73133 L p F P
0 0 0 r
s
.188 0 .528 r
.24125 .59843 m .24274 .58217 L .23134 .57168 L p F P
0 0 0 r
s
.188 0 .528 r
.23288 .55555 m .23134 .57168 L .24274 .58217 L p F P
0 0 0 r
s
.188 0 .528 r
.19325 .44849 m .19498 .43301 L .18329 .42158 L p F P
0 0 0 r
s
.188 0 .528 r
.18508 .40623 m .18329 .42158 L .19498 .43301 L p F P
0 0 0 r
s
.134 0 .891 r
.78581 .2965 m .79373 .30872 L .81233 .30212 L p F P
0 0 0 r
s
.134 0 .891 r
.79373 .30872 m .78581 .2965 L .76724 .30314 L p F P
0 0 0 r
s
.134 0 .891 r
.53297 .29599 m .54248 .30821 L .56023 .30161 L p F P
0 0 0 r
s
.134 0 .891 r
.54248 .30821 m .53297 .29599 L .51526 .30263 L p F P
0 0 0 r
s
.115 0 .563 r
.65307 .89333 m .6524 .87547 L .63434 .88013 L p F P
0 0 0 r
s
.115 0 .563 r
.63434 .88013 m .63491 .89795 L .65307 .89333 L p F P
0 0 0 r
s
.134 0 .891 r
.28 .29548 m .2911 .30771 L .308 .3011 L p F P
0 0 0 r
s
.134 0 .891 r
.2911 .30771 m .28 .29548 L .26315 .30212 L p F P
0 0 0 r
s
.195 0 .31 r
.881 .4613 m .87914 .44565 L .88649 .45694 L p F P
0 0 0 r
s
.195 0 .31 r
.88649 .45694 m .88838 .47255 L .881 .4613 L p F P
0 0 0 r
s
.115 0 .563 r
.59972 .94315 m .59933 .92503 L .58144 .92951 L p F P
0 0 0 r
s
.115 0 .563 r
.58144 .92951 m .58173 .9476 L .59972 .94315 L p F P
0 0 0 r
s
.195 0 .31 r
.92934 .61227 m .92722 .59583 L .93426 .60617 L p F P
0 0 0 r
s
.195 0 .31 r
.93426 .60617 m .93641 .62256 L .92934 .61227 L p F P
0 0 0 r
s
.134 0 .891 r
.83871 .30771 m .83106 .29548 L .81233 .30212 L p F P
0 0 0 r
s
.195 0 .31 r
.83267 .31033 m .83106 .29548 L .83871 .30771 L p F P
0 0 0 r
s
.195 0 .31 r
.83871 .30771 m .84035 .32253 L .83267 .31033 L p F P
0 0 0 r
s
.134 0 .891 r
.57811 .29497 m .58734 .3072 L .60525 .30059 L p F P
0 0 0 r
s
.134 0 .891 r
.58734 .3072 m .57811 .29497 L .56023 .30161 L p F P
0 0 0 r
s
.115 0 .563 r
.90232 .66676 m .90035 .65008 L .88143 .6555 L p F P
0 0 0 r
s
.115 0 .563 r
.88143 .6555 m .8833 .67216 L .90232 .66676 L p F P
0 0 0 r
s
.115 0 .563 r
.54634 .993 m .54623 .97461 L .52852 .97893 L p F P
0 0 0 r
s
.115 0 .563 r
.52852 .97893 m .52853 .99728 L .54634 .993 L p F P
0 0 0 r
s
.188 0 .528 r
.23134 .57168 m .23288 .55555 L .22141 .54487 L p F P
0 0 0 r
s
.188 0 .528 r
.223 .52887 m .22141 .54487 L .23288 .55555 L p F P
0 0 0 r
s
.188 0 .528 r
.18329 .42158 m .18508 .40623 L .1733 .39462 L p F P
0 0 0 r
s
.188 0 .528 r
.17515 .3794 m .1733 .39462 L .18508 .40623 L p F P
0 0 0 r
s
.115 0 .563 r
.84901 .71655 m .84732 .6996 L .82858 .70486 L p F P
0 0 0 r
s
.115 0 .563 r
.82858 .70486 m .83016 .72177 L .84901 .71655 L p F P
0 0 0 r
s
.134 0 .891 r
.32502 .29445 m .33584 .30669 L .3529 .30008 L p F P
0 0 0 r
s
.134 0 .891 r
.33584 .30669 m .32502 .29445 L .308 .3011 L p F P
0 0 0 r
s
.115 0 .563 r
.49293 1.04287 m .49311 1.02421 L .47557 1.02837 L p F P
0 0 0 r
s
.115 0 .563 r
.47557 1.02837 m .4753 1.04698 L .49293 1.04287 L p F P
0 0 0 r
s
.188 0 .528 r
.3755 1.02196 m .37629 1.00348 L .36572 .99563 L p F P
0 0 0 r
s
.188 0 .528 r
.36656 .97727 m .36572 .99563 L .37629 1.00348 L p F P
0 0 0 r
s
.188 0 .528 r
.32745 .87187 m .32849 .85417 L .31762 .84538 L p F P
0 0 0 r
s
.188 0 .528 r
.31871 .8278 m .31762 .84538 L .32849 .85417 L p F P
0 0 0 r
s
.188 0 .528 r
.27939 .72177 m .28068 .70486 L .26951 .69513 L p F P
0 0 0 r
s
.188 0 .528 r
.27086 .67833 m .26951 .69513 L .28068 .70486 L p F P
0 0 0 r
s
.134 0 .891 r
.62329 .29394 m .63224 .30619 L .65032 .29957 L p F P
0 0 0 r
s
.134 0 .891 r
.63224 .30619 m .62329 .29394 L .60525 .30059 L p F P
0 0 0 r
s
.115 0 .563 r
.79567 .76636 m .79426 .74915 L .77569 .75424 L p F P
0 0 0 r
s
.115 0 .563 r
.77569 .75424 m .777 .77142 L .79567 .76636 L p F P
0 0 0 r
s
.134 0 .891 r
.37008 .29343 m .38063 .30568 L .39785 .29906 L p F P
0 0 0 r
s
.134 0 .891 r
.38063 .30568 m .37008 .29343 L .3529 .30008 L p F P
0 0 0 r
s
.195 0 .31 r
.8717 .43422 m .86989 .4187 L .8773 .43017 L p F P
0 0 0 r
s
.195 0 .31 r
.8773 .43017 m .87914 .44565 L .8717 .43422 L p F P
0 0 0 r
s
.115 0 .563 r
.7423 .8162 m .74117 .79872 L .72278 .80364 L p F P
0 0 0 r
s
.115 0 .563 r
.72278 .80364 m .72381 .82109 L .7423 .8162 L p F P
0 0 0 r
s
.195 0 .31 r
.92009 .58535 m .91802 .56903 L .92513 .57956 L p F P
0 0 0 r
s
.195 0 .31 r
.92513 .57956 m .92722 .59583 L .92009 .58535 L p F P
0 0 0 r
s
.134 0 .891 r
.66852 .29291 m .6772 .30517 L .69544 .29855 L p F P
0 0 0 r
s
.134 0 .891 r
.6772 .30517 m .66852 .29291 L .65032 .29957 L p F P
0 0 0 r
s
.115 0 .563 r
.6889 .86607 m .68805 .84832 L .66984 .85308 L p F P
0 0 0 r
s
.115 0 .563 r
.66984 .85308 m .67059 .87078 L .6889 .86607 L p F P
0 0 0 r
s
.188 0 .528 r
.22141 .54487 m .223 .52887 L .21146 .51801 L p F P
0 0 0 r
s
.188 0 .528 r
.21311 .50213 m .21146 .51801 L .223 .52887 L p F P
0 0 0 r
s
.188 0 .528 r
.1733 .39462 m .17515 .3794 L .1633 .3676 L p F P
0 0 0 r
s
.188 0 .528 r
.1652 .3525 m .1633 .3676 L .17515 .3794 L p F P
0 0 0 r
s
.115 0 .563 r
.63548 .91596 m .63491 .89795 L .61687 .90253 L p F P
0 0 0 r
s
.115 0 .563 r
.61687 .90253 m .61734 .92051 L .63548 .91596 L p F P
0 0 0 r
s
.188 0 .528 r
.36572 .99563 m .36656 .97727 L .35592 .96925 L p F P
0 0 0 r
s
.188 0 .528 r
.35681 .951 m .35592 .96925 L .36656 .97727 L p F P
0 0 0 r
s
.188 0 .528 r
.31762 .84538 m .31871 .8278 L .30777 .81884 L p F P
0 0 0 r
s
.188 0 .528 r
.30891 .80138 m .30777 .81884 L .31871 .8278 L p F P
0 0 0 r
s
.188 0 .528 r
.26951 .69513 m .27086 .67833 L .25961 .66843 L p F P
0 0 0 r
s
.188 0 .528 r
.26101 .65175 m .25961 .66843 L .27086 .67833 L p F P
0 0 0 r
s
.134 0 .891 r
.41519 .2924 m .42546 .30466 L .44284 .29804 L p F P
0 0 0 r
s
.134 0 .891 r
.42546 .30466 m .41519 .2924 L .39785 .29906 L p F P
0 0 0 r
s
.134 0 .891 r
.7138 .29188 m .7222 .30416 L .7406 .29753 L p F P
0 0 0 r
s
.134 0 .891 r
.7222 .30416 m .7138 .29188 L .69544 .29855 L p F P
0 0 0 r
s
.125 0 .956 r
.43026 1.04761 m .41291 1.05169 L .40256 1.04414 L p F P
0 0 0 r
s
.134 0 .891 r
.16173 .29188 m .17359 .30416 L .19012 .29753 L p F P
0 0 0 r
s
.125 0 .956 r
.38526 1.04824 m .40256 1.04414 L .41291 1.05169 L p F P
0 0 0 r
s
.134 0 .891 r
.17359 .30416 m .16173 .29188 L .14524 .29855 L p F P
0 0 0 r
s
.115 0 .563 r
.93857 .63913 m .93641 .62256 L .91734 .62809 L p F P
0 0 0 r
s
.115 0 .563 r
.91734 .62809 m .91939 .64462 L .93857 .63913 L p F P
0 0 0 r
s
.115 0 .563 r
.58203 .96588 m .58173 .9476 L .56387 .95202 L p F P
0 0 0 r
s
.115 0 .563 r
.56387 .95202 m .56407 .97026 L .58203 .96588 L p F P
0 0 0 r
s
.195 0 .31 r
.91082 .55838 m .90879 .54219 L .91597 .55289 L p F P
0 0 0 r
s
.195 0 .31 r
.91597 .55289 m .91802 .56903 L .91082 .55838 L p F P
0 0 0 r
s
.134 0 .891 r
.46035 .29137 m .47034 .30365 L .48788 .29702 L p F P
0 0 0 r
s
.134 0 .891 r
.47034 .30365 m .46035 .29137 L .44284 .29804 L p F P
0 0 0 r
s
.115 0 .563 r
.52854 1.01582 m .52853 .99728 L .51085 1.00153 L p F P
0 0 0 r
s
.115 0 .563 r
.51085 1.00153 m .51077 1.02003 L .52854 1.01582 L p F P
0 0 0 r
s
.195 0 .31 r
.86238 .40709 m .86061 .3917 L .86809 .40334 L p F P
0 0 0 r
s
.195 0 .31 r
.86809 .40334 m .86989 .4187 L .86238 .40709 L p F P
0 0 0 r
s
.115 0 .563 r
.88518 .68898 m .8833 .67216 L .86441 .67751 L p F P
0 0 0 r
s
.115 0 .563 r
.86441 .67751 m .86618 .69431 L .88518 .68898 L p F P
0 0 0 r
s
.115 0 .563 r
.83177 .73887 m .83016 .72177 L .81145 .72696 L p F P
0 0 0 r
s
.115 0 .563 r
.81145 .72696 m .81295 .74403 L .83177 .73887 L p F P
0 0 0 r
s
.134 0 .891 r
.20676 .29085 m .21834 .30314 L .23504 .2965 L p F P
0 0 0 r
s
.134 0 .891 r
.21834 .30314 m .20676 .29085 L .19012 .29753 L p F P
0 0 0 r
s
.134 0 .891 r
.75912 .29085 m .76724 .30314 L .78581 .2965 L p F P
0 0 0 r
s
.134 0 .891 r
.76724 .30314 m .75912 .29085 L .7406 .29753 L p F P
0 0 0 r
s
.125 0 .956 r
.4753 1.04698 m .4578 1.05106 L .44772 1.0435 L p F P
0 0 0 r
s
.125 0 .956 r
.43026 1.04761 m .44772 1.0435 L .4578 1.05106 L p F P
0 0 0 r
s
.134 0 .891 r
.50555 .29034 m .51526 .30263 L .53297 .29599 L p F P
0 0 0 r
s
.134 0 .891 r
.51526 .30263 m .50555 .29034 L .48788 .29702 L p F P
0 0 0 r
s
.115 0 .563 r
.77832 .78878 m .777 .77142 L .75846 .77644 L p F P
0 0 0 r
s
.115 0 .563 r
.75846 .77644 m .75968 .79377 L .77832 .78878 L p F P
0 0 0 r
s
.188 0 .528 r
.35592 .96925 m .35681 .951 L .3461 .94281 L p F P
0 0 0 r
s
.188 0 .528 r
.34705 .92468 m .3461 .94281 L .35681 .951 L p F P
0 0 0 r
s
.188 0 .528 r
.30777 .81884 m .30891 .80138 L .2979 .79224 L p F P
0 0 0 r
s
.188 0 .528 r
.29909 .7749 m .2979 .79224 L .30891 .80138 L p F P
0 0 0 r
s
.188 0 .528 r
.25961 .66843 m .26101 .65175 L .24969 .64167 L p F P
0 0 0 r
s
.188 0 .528 r
.25114 .62512 m .24969 .64167 L .26101 .65175 L p F P
0 0 0 r
s
.188 0 .528 r
.21146 .51801 m .21311 .50213 L .20148 .4911 L p F P
0 0 0 r
s
.188 0 .528 r
.20319 .47534 m .20148 .4911 L .21311 .50213 L p F P
0 0 0 r
s
.188 0 .528 r
.1633 .3676 m .1652 .3525 L .15328 .34053 L p F P
0 0 0 r
s
.188 0 .528 r
.15523 .32556 m .15328 .34053 L .1652 .3525 L p F P
0 0 0 r
s
.115 0 .563 r
.72485 .83872 m .72381 .82109 L .70545 .82594 L p F P
0 0 0 r
s
.115 0 .563 r
.70545 .82594 m .70639 .84354 L .72485 .83872 L p F P
0 0 0 r
s
.134 0 .891 r
.25184 .28982 m .26315 .30212 L .28 .29548 L p F P
0 0 0 r
s
.134 0 .891 r
.26315 .30212 m .25184 .28982 L .23504 .2965 L p F P
0 0 0 r
s
.134 0 .891 r
.8045 .28982 m .81233 .30212 L .83106 .29548 L p F P
0 0 0 r
s
.134 0 .891 r
.81233 .30212 m .8045 .28982 L .78581 .2965 L p F P
0 0 0 r
s
.134 0 .891 r
.5508 .28931 m .56023 .30161 L .57811 .29497 L p F P
0 0 0 r
s
.134 0 .891 r
.56023 .30161 m .5508 .28931 L .53297 .29599 L p F P
0 0 0 r
s
.115 0 .563 r
.67135 .88868 m .67059 .87078 L .6524 .87547 L p F P
0 0 0 r
s
.115 0 .563 r
.6524 .87547 m .65307 .89333 L .67135 .88868 L p F P
0 0 0 r
s
.195 0 .31 r
.90153 .53134 m .89955 .51528 L .90679 .52617 L p F P
0 0 0 r
s
.195 0 .31 r
.90679 .52617 m .90879 .54219 L .90153 .53134 L p F P
0 0 0 r
s
.195 0 .31 r
.85304 .3799 m .85132 .36463 L .85886 .37646 L p F P
0 0 0 r
s
.195 0 .31 r
.85886 .37646 m .86061 .3917 L .85304 .3799 L p F P
0 0 0 r
s
.134 0 .891 r
.29697 .28879 m .308 .3011 L .32502 .29445 L p F P
0 0 0 r
s
.134 0 .891 r
.308 .3011 m .29697 .28879 L .28 .29548 L p F P
0 0 0 r
s
.115 0 .563 r
.61782 .93867 m .61734 .92051 L .59933 .92503 L p F P
0 0 0 r
s
.115 0 .563 r
.59933 .92503 m .59972 .94315 L .61782 .93867 L p F P
0 0 0 r
s
.134 0 .891 r
.5961 .28827 m .60525 .30059 L .62329 .29394 L p F P
0 0 0 r
s
.134 0 .891 r
.60525 .30059 m .5961 .28827 L .57811 .29497 L p F P
0 0 0 r
s
.188 0 .528 r
.24969 .64167 m .25114 .62512 L .23975 .61485 L p F P
0 0 0 r
s
.188 0 .528 r
.24125 .59843 m .23975 .61485 L .25114 .62512 L p F P
0 0 0 r
s
.188 0 .528 r
.20148 .4911 m .20319 .47534 L .19149 .46412 L p F P
0 0 0 r
s
.188 0 .528 r
.19325 .44849 m .19149 .46412 L .20319 .47534 L p F P
0 0 0 r
s
.188 0 .528 r
.15328 .34053 m .15523 .32556 L .14323 .3134 L p F P
0 0 0 r
s
.188 0 .528 r
.14524 .29855 m .14323 .3134 L .15523 .32556 L p F P
0 0 0 r
s
.115 0 .563 r
.92147 .66133 m .91939 .64462 L .90035 .65008 L p F P
0 0 0 r
s
.115 0 .563 r
.90035 .65008 m .90232 .66676 L .92147 .66133 L p F P
0 0 0 r
s
.115 0 .563 r
.56427 .98869 m .56407 .97026 L .54623 .97461 L p F P
0 0 0 r
s
.115 0 .563 r
.54623 .97461 m .54634 .993 L .56427 .98869 L p F P
0 0 0 r
s
.188 0 .528 r
.3461 .94281 m .34705 .92468 L .33626 .91631 L p F P
0 0 0 r
s
.188 0 .528 r
.33726 .8983 m .33626 .91631 L .34705 .92468 L p F P
0 0 0 r
s
.188 0 .528 r
.2979 .79224 m .29909 .7749 L .288 .76558 L p F P
0 0 0 r
s
.188 0 .528 r
.28925 .74836 m .288 .76558 L .29909 .7749 L p F P
0 0 0 r
s
.115 0 .563 r
.86798 .71129 m .86618 .69431 L .84732 .6996 L p F P
0 0 0 r
s
.115 0 .563 r
.84732 .6996 m .84901 .71655 L .86798 .71129 L p F P
0 0 0 r
s
.134 0 .891 r
.34215 .28776 m .3529 .30008 L .37008 .29343 L p F P
0 0 0 r
s
.134 0 .891 r
.3529 .30008 m .34215 .28776 L .32502 .29445 L p F P
0 0 0 r
s
.115 0 .563 r
.51068 1.03873 m .51077 1.02003 L .49311 1.02421 L p F P
0 0 0 r
s
.115 0 .563 r
.49311 1.02421 m .49293 1.04287 L .51068 1.03873 L p F P
0 0 0 r
s
.195 0 .31 r
.89222 .50426 m .89029 .48832 L .89759 .49938 L p F P
0 0 0 r
s
.195 0 .31 r
.89759 .49938 m .89955 .51528 L .89222 .50426 L p F P
0 0 0 r
s
.115 0 .563 r
.81446 .76127 m .81295 .74403 L .79426 .74915 L p F P
0 0 0 r
s
.115 0 .563 r
.79426 .74915 m .79567 .76636 L .81446 .76127 L p F P
0 0 0 r
s
.134 0 .891 r
.64145 .28724 m .65032 .29957 L .66852 .29291 L p F P
0 0 0 r
s
.134 0 .891 r
.65032 .29957 m .64145 .28724 L .62329 .29394 L p F P
0 0 0 r
s
.195 0 .31 r
.84368 .35265 m .842 .33751 L .84961 .34952 L p F P
0 0 0 r
s
.195 0 .31 r
.84961 .34952 m .85132 .36463 L .84368 .35265 L p F P
0 0 0 r
s
.134 0 .891 r
.38738 .28672 m .39785 .29906 L .41519 .2924 L p F P
0 0 0 r
s
.134 0 .891 r
.39785 .29906 m .38738 .28672 L .37008 .29343 L p F P
0 0 0 r
s
.115 0 .563 r
.76092 .81128 m .75968 .79377 L .74117 .79872 L p F P
0 0 0 r
s
.115 0 .563 r
.74117 .79872 m .7423 .8162 L .76092 .81128 L p F P
0 0 0 r
s
.115 0 .563 r
.70734 .86132 m .70639 .84354 L .68805 .84832 L p F P
0 0 0 r
s
.115 0 .563 r
.68805 .84832 m .6889 .86607 L .70734 .86132 L p F P
0 0 0 r
s
.188 0 .528 r
.23975 .61485 m .24125 .59843 L .22978 .58798 L p F P
0 0 0 r
s
.188 0 .528 r
.23134 .57168 m .22978 .58798 L .24125 .59843 L p F P
0 0 0 r
s
.188 0 .528 r
.19149 .46412 m .19325 .44849 L .18148 .43709 L p F P
0 0 0 r
s
.188 0 .528 r
.18329 .42158 m .18148 .43709 L .19325 .44849 L p F P
0 0 0 r
s
.134 0 .891 r
.13317 .28621 m .14524 .29855 L .16173 .29188 L p F P
0 0 0 r
s
.188 0 .528 r
.14323 .3134 m .14524 .29855 L .13317 .28621 L p F P
0 0 0 r
s
.134 0 .891 r
.68684 .28621 m .69544 .29855 L .7138 .29188 L p F P
0 0 0 r
s
.134 0 .891 r
.69544 .29855 m .68684 .28621 L .66852 .29291 L p F P
0 0 0 r
s
.188 0 .528 r
.3755 1.02196 m .37471 1.04064 L .38526 1.04824 L p F P
0 0 0 r
s
.125 0 .956 r
.40256 1.04414 m .38526 1.04824 L .37471 1.04064 L p F P
0 0 0 r
s
.188 0 .528 r
.288 .76558 m .28925 .74836 L .27809 .73887 L p F P
0 0 0 r
s
.188 0 .528 r
.27939 .72177 m .27809 .73887 L .28925 .74836 L p F P
0 0 0 r
s
.188 0 .528 r
.33626 .91631 m .33726 .8983 L .3264 .88976 L p F P
0 0 0 r
s
.188 0 .528 r
.32745 .87187 m .3264 .88976 L .33726 .8983 L p F P
0 0 0 r
s
.115 0 .563 r
.65374 .91138 m .65307 .89333 L .63491 .89795 L p F P
0 0 0 r
s
.115 0 .563 r
.63491 .89795 m .63548 .91596 L .65374 .91138 L p F P
0 0 0 r
s
.134 0 .891 r
.43265 .28569 m .44284 .29804 L .46035 .29137 L p F P
0 0 0 r
s
.134 0 .891 r
.44284 .29804 m .43265 .28569 L .41519 .2924 L p F P
0 0 0 r
s
.134 0 .891 r
.17832 .28517 m .19012 .29753 L .20676 .29085 L p F P
0 0 0 r
s
.134 0 .891 r
.19012 .29753 m .17832 .28517 L .16173 .29188 L p F P
0 0 0 r
s
.195 0 .31 r
.88289 .47711 m .881 .4613 L .88838 .47255 L p F P
0 0 0 r
s
.195 0 .31 r
.88838 .47255 m .89029 .48832 L .88289 .47711 L p F P
0 0 0 r
s
.134 0 .891 r
.73229 .28517 m .7406 .29753 L .75912 .29085 L p F P
0 0 0 r
s
.134 0 .891 r
.7406 .29753 m .73229 .28517 L .7138 .29188 L p F P
0 0 0 r
s
.115 0 .563 r
.60011 .96147 m .59972 .94315 L .58173 .9476 L p F P
0 0 0 r
s
.115 0 .563 r
.58173 .9476 m .58203 .96588 L .60011 .96147 L p F P
0 0 0 r
s
.125 0 .956 r
.43026 1.04761 m .41998 1.04001 L p .4385 1.03658 L F P
0 0 0 r
s
.125 0 .956 r
.4385 1.03658 m .44772 1.0435 L .43026 1.04761 L p F P
0 0 0 r
s
.125 0 .956 r
.40256 1.04414 m .41998 1.04001 L .43026 1.04761 L p F P
0 0 0 r
s
.195 0 .31 r
.93148 .62888 m .92934 .61227 L .93641 .62256 L p F P
0 0 0 r
s
.195 0 .31 r
.93641 .62256 m .93857 .63913 L .93148 .62888 L p F P
0 0 0 r
s
.195 0 .31 r
.8343 .32534 m .83267 .31033 L .84035 .32253 L p F P
0 0 0 r
s
.195 0 .31 r
.84035 .32253 m .842 .33751 L .8343 .32534 L p F P
0 0 0 r
s
.134 0 .891 r
.47797 .28465 m .48788 .29702 L .50555 .29034 L p F P
0 0 0 r
s
.134 0 .891 r
.48788 .29702 m .47797 .28465 L .46035 .29137 L p F P
0 0 0 r
s
.115 0 .563 r
.90431 .68362 m .90232 .66676 L .8833 .67216 L p F P
0 0 0 r
s
.115 0 .563 r
.8833 .67216 m .88518 .68898 L .90431 .68362 L p F P
0 0 0 r
s
.115 0 .563 r
.54645 1.01158 m .54634 .993 L .52853 .99728 L p F P
0 0 0 r
s
.115 0 .563 r
.52853 .99728 m .52854 1.01582 L .54645 1.01158 L p F P
0 0 0 r
s
.188 0 .528 r
.18148 .43709 m .18329 .42158 L .17144 .41001 L p F P
0 0 0 r
s
.188 0 .528 r
.1733 .39462 m .17144 .41001 L .18329 .42158 L p F P
0 0 0 r
s
.134 0 .891 r
.22352 .28413 m .23504 .2965 L .25184 .28982 L p F P
0 0 0 r
s
.134 0 .891 r
.23504 .2965 m .22352 .28413 L .20676 .29085 L p F P
0 0 0 r
s
.188 0 .528 r
.27809 .73887 m .27939 .72177 L .26816 .7121 L p F P
0 0 0 r
s
.188 0 .528 r
.26951 .69513 m .26816 .7121 L .27939 .72177 L p F P
0 0 0 r
s
.188 0 .528 r
.22978 .58798 m .23134 .57168 L .2198 .56105 L p F P
0 0 0 r
s
.188 0 .528 r
.22141 .54487 m .2198 .56105 L .23134 .57168 L p F P
0 0 0 r
s
.134 0 .891 r
.77778 .28413 m .78581 .2965 L .8045 .28982 L p F P
0 0 0 r
s
.134 0 .891 r
.78581 .2965 m .77778 .28413 L .75912 .29085 L p F P
0 0 0 r
s
.125 0 .956 r
.49293 1.04287 m .4753 1.04698 L .46531 1.03937 L p F P
0 0 0 r
s
.125 0 .956 r
.44772 1.0435 m .46531 1.03937 L .4753 1.04698 L p F P
0 0 0 r
s
.188 0 .528 r
.37471 1.04064 m .3755 1.02196 L .36487 1.01419 L p F P
0 0 0 r
s
.188 0 .528 r
.36572 .99563 m .36487 1.01419 L .3755 1.02196 L p F P
0 0 0 r
s
.188 0 .528 r
.3264 .88976 m .32745 .87187 L .31652 .86315 L p F P
0 0 0 r
s
.188 0 .528 r
.31762 .84538 m .31652 .86315 L .32745 .87187 L p F P
0 0 0 r
s
.115 0 .563 r
.85072 .73367 m .84901 .71655 L .83016 .72177 L p F P
0 0 0 r
s
.115 0 .563 r
.83016 .72177 m .83177 .73887 L .85072 .73367 L p F P
0 0 0 r
s
.134 0 .891 r
.52334 .28361 m .53297 .29599 L .5508 .28931 L p F P
0 0 0 r
s
.134 0 .891 r
.53297 .29599 m .52334 .28361 L .50555 .29034 L p F P
0 0 0 r
s
.115 0 .563 r
.79709 .78376 m .79567 .76636 L .777 .77142 L p F P
0 0 0 r
s
.115 0 .563 r
.777 .77142 m .77832 .78878 L .79709 .78376 L p F P
0 0 0 r
s
.195 0 .31 r
.87354 .44991 m .8717 .43422 L .87914 .44565 L p F P
0 0 0 r
s
.195 0 .31 r
.87914 .44565 m .881 .4613 L .87354 .44991 L p F P
0 0 0 r
s
.115 0 .563 r
.74344 .83386 m .7423 .8162 L .72381 .82109 L p F P
0 0 0 r
s
.115 0 .563 r
.72381 .82109 m .72485 .83872 L .74344 .83386 L p F P
0 0 0 r
s
.134 0 .891 r
.26876 .2831 m .28 .29548 L .29697 .28879 L p F P
0 0 0 r
s
.134 0 .891 r
.28 .29548 m .26876 .2831 L .25184 .28982 L p F P
0 0 0 r
s
.134 0 .891 r
.83106 .29548 m .82332 .2831 L .8045 .28982 L p F P
0 0 0 r
s
.195 0 .31 r
.8249 .29798 m .82332 .2831 L .83106 .29548 L p F P
0 0 0 r
s
.195 0 .31 r
.83106 .29548 m .83267 .31033 L .8249 .29798 L p F P
0 0 0 r
s
.195 0 .31 r
.92218 .60184 m .92009 .58535 L .92722 .59583 L p F P
0 0 0 r
s
.195 0 .31 r
.92722 .59583 m .92934 .61227 L .92218 .60184 L p F P
0 0 0 r
s
.134 0 .891 r
.56876 .28258 m .57811 .29497 L .5961 .28827 L p F P
0 0 0 r
s
.134 0 .891 r
.57811 .29497 m .56876 .28258 L .5508 .28931 L p F P
0 0 0 r
s
.115 0 .563 r
.68976 .884 m .6889 .86607 L .67059 .87078 L p F P
0 0 0 r
s
.115 0 .563 r
.67059 .87078 m .67135 .88868 L .68976 .884 L p F P
0 0 0 r
s
.134 0 .891 r
.31406 .28206 m .32502 .29445 L .34215 .28776 L p F P
0 0 0 r
s
.134 0 .891 r
.32502 .29445 m .31406 .28206 L .29697 .28879 L p F P
0 0 0 r
s
.188 0 .528 r
.2198 .56105 m .22141 .54487 L .20979 .53407 L p F P
0 0 0 r
s
.188 0 .528 r
.21146 .51801 m .20979 .53407 L .22141 .54487 L p F P
0 0 0 r
s
.188 0 .528 r
.36487 1.01419 m .36572 .99563 L .35502 .98769 L p F P
0 0 0 r
s
.188 0 .528 r
.35592 .96925 m .35502 .98769 L .36572 .99563 L p F P
0 0 0 r
s
.188 0 .528 r
.26816 .7121 m .26951 .69513 L .2582 .68527 L p F P
0 0 0 r
s
.188 0 .528 r
.25961 .66843 m .2582 .68527 L .26951 .69513 L p F P
0 0 0 r
s
.188 0 .528 r
.17144 .41001 m .1733 .39462 L .16138 .38286 L p F P
0 0 0 r
s
.188 0 .528 r
.1633 .3676 m .16138 .38286 L .1733 .39462 L p F P
0 0 0 r
s
.188 0 .528 r
.31652 .86315 m .31762 .84538 L .30661 .83648 L p F P
0 0 0 r
s
.188 0 .528 r
.30777 .81884 m .30661 .83648 L .31762 .84538 L p F P
0 0 0 r
s
.115 0 .563 r
.63606 .93416 m .63548 .91596 L .61734 .92051 L p F P
0 0 0 r
s
.115 0 .563 r
.61734 .92051 m .61782 .93867 L .63606 .93416 L p F P
0 0 0 r
s
.134 0 .891 r
.61422 .28154 m .62329 .29394 L .64145 .28724 L p F P
0 0 0 r
s
.134 0 .891 r
.62329 .29394 m .61422 .28154 L .5961 .28827 L p F P
0 0 0 r
s
.115 0 .563 r
.94075 .65586 m .93857 .63913 L .91939 .64462 L p F P
0 0 0 r
s
.115 0 .563 r
.91939 .64462 m .92147 .66133 L .94075 .65586 L p F P
0 0 0 r
s
.115 0 .563 r
.58232 .98435 m .58203 .96588 L .56407 .97026 L p F P
0 0 0 r
s
.115 0 .563 r
.56407 .97026 m .56427 .98869 L .58232 .98435 L p F P
0 0 0 r
s
.134 0 .891 r
.3594 .28102 m .37008 .29343 L .38738 .28672 L p F P
0 0 0 r
s
.134 0 .891 r
.37008 .29343 m .3594 .28102 L .34215 .28776 L p F P
0 0 0 r
s
.195 0 .31 r
.91286 .57474 m .91082 .55838 L .91802 .56903 L p F P
0 0 0 r
s
.195 0 .31 r
.91802 .56903 m .92009 .58535 L .91286 .57474 L p F P
0 0 0 r
s
.195 0 .31 r
.86417 .42265 m .86238 .40709 L .86989 .4187 L p F P
0 0 0 r
s
.195 0 .31 r
.86989 .4187 m .8717 .43422 L .86417 .42265 L p F P
0 0 0 r
s
.115 0 .563 r
.88708 .70599 m .88518 .68898 L .86618 .69431 L p F P
0 0 0 r
s
.115 0 .563 r
.86618 .69431 m .86798 .71129 L .88708 .70599 L p F P
0 0 0 r
s
.115 0 .563 r
.52856 1.03456 m .52854 1.01582 L .51077 1.02003 L p F P
0 0 0 r
s
.115 0 .563 r
.51077 1.02003 m .51068 1.03873 L .52856 1.03456 L p F P
0 0 0 r
s
.115 0 .563 r
.83339 .75614 m .83177 .73887 L .81295 .74403 L p F P
0 0 0 r
s
.115 0 .563 r
.81295 .74403 m .81446 .76127 L .83339 .75614 L p F P
0 0 0 r
s
.134 0 .891 r
.65973 .2805 m .66852 .29291 L .68684 .28621 L p F P
0 0 0 r
s
.134 0 .891 r
.66852 .29291 m .65973 .2805 L .64145 .28724 L p F P
0 0 0 r
s
.134 0 .891 r
.40479 .27998 m .41519 .2924 L .43265 .28569 L p F P
0 0 0 r
s
.134 0 .891 r
.41519 .2924 m .40479 .27998 L .38738 .28672 L p F P
0 0 0 r
s
.115 0 .563 r
.77966 .80632 m .77832 .78878 L .75968 .79377 L p F P
0 0 0 r
s
.115 0 .563 r
.75968 .79377 m .76092 .81128 L .77966 .80632 L p F P
0 0 0 r
s
.188 0 .528 r
.35502 .98769 m .35592 .96925 L .34515 .96113 L p F P
0 0 0 r
s
.188 0 .528 r
.3461 .94281 m .34515 .96113 L .35592 .96925 L p F P
0 0 0 r
s
.188 0 .528 r
.30661 .83648 m .30777 .81884 L .29669 .80976 L p F P
0 0 0 r
s
.188 0 .528 r
.2979 .79224 m .29669 .80976 L .30777 .81884 L p F P
0 0 0 r
s
.188 0 .528 r
.2582 .68527 m .25961 .66843 L .24823 .65839 L p F P
0 0 0 r
s
.188 0 .528 r
.24969 .64167 m .24823 .65839 L .25961 .66843 L p F P
0 0 0 r
s
.188 0 .528 r
.16138 .38286 m .1633 .3676 L .1513 .35566 L p F P
0 0 0 r
s
.188 0 .528 r
.15328 .34053 m .1513 .35566 L .1633 .3676 L p F P
0 0 0 r
s
.188 0 .528 r
.20979 .53407 m .21146 .51801 L .19976 .50703 L p F P
0 0 0 r
s
.188 0 .528 r
.20148 .4911 m .19976 .50703 L .21146 .51801 L p F P
0 0 0 r
s
.115 0 .563 r
.72591 .85653 m .72485 .83872 L .70639 .84354 L p F P
0 0 0 r
s
.115 0 .563 r
.70639 .84354 m .70734 .86132 L .72591 .85653 L p F P
0 0 0 r
s
.134 0 .891 r
.14971 .27945 m .16173 .29188 L .17832 .28517 L p F P
0 0 0 r
s
.134 0 .891 r
.16173 .29188 m .14971 .27945 L .13317 .28621 L p F P
0 0 0 r
s
.125 0 .956 r
.40256 1.04414 m .39208 1.03649 L p .41129 1.03357 L F P
0 0 0 r
s
.125 0 .956 r
.41129 1.03357 m .41998 1.04001 L .40256 1.04414 L p F P
0 0 0 r
s
.125 0 .956 r
.37471 1.04064 m .39208 1.03649 L .40256 1.04414 L p F P
0 0 0 r
s
.134 0 .891 r
.7053 .27945 m .7138 .29188 L .73229 .28517 L p F P
0 0 0 r
s
.134 0 .891 r
.7138 .29188 m .7053 .27945 L .68684 .28621 L p F P
0 0 0 r
s
.195 0 .31 r
.90352 .54758 m .90153 .53134 L .90879 .54219 L p F P
0 0 0 r
s
.195 0 .31 r
.90879 .54219 m .91082 .55838 L .90352 .54758 L p F P
0 0 0 r
s
.195 0 .31 r
.85478 .39533 m .85304 .3799 L .86061 .3917 L p F P
0 0 0 r
s
.195 0 .31 r
.86061 .3917 m .86238 .40709 L .85478 .39533 L p F P
0 0 0 r
s
.115 0 .563 r
.67212 .90677 m .67135 .88868 L .65307 .89333 L p F P
0 0 0 r
s
.115 0 .563 r
.65307 .89333 m .65374 .91138 L .67212 .90677 L p F P
0 0 0 r
s
.134 0 .891 r
.45023 .27893 m .46035 .29137 L .47797 .28465 L p F P
0 0 0 r
s
.134 0 .891 r
.46035 .29137 m .45023 .27893 L .43265 .28569 L p F P
0 0 0 r
s
.134 0 .891 r
.19503 .27841 m .20676 .29085 L .22352 .28413 L p F P
0 0 0 r
s
.134 0 .891 r
.20676 .29085 m .19503 .27841 L .17832 .28517 L p F P
0 0 0 r
s
.125 0 .956 r
.44772 1.0435 m .4385 1.03658 L .45995 1.03529 L p F P
0 0 0 r
s
.125 0 .956 r
.45995 1.03529 m .46531 1.03937 L .44772 1.0435 L p F P
0 0 0 r
s
.134 0 .891 r
.7509 .27841 m .75912 .29085 L .77778 .28413 L p F P
0 0 0 r
s
.134 0 .891 r
.75912 .29085 m .7509 .27841 L .73229 .28517 L p F P
0 0 0 r
s
.115 0 .563 r
.61831 .95703 m .61782 .93867 L .59972 .94315 L p F P
0 0 0 r
s
.115 0 .563 r
.59972 .94315 m .60011 .96147 L .61831 .95703 L p F P
0 0 0 r
s
.188 0 .528 r
.19976 .50703 m .20148 .4911 L .18972 .47993 L p F P
0 0 0 r
s
.188 0 .528 r
.19149 .46412 m .18972 .47993 L .20148 .4911 L p F P
0 0 0 r
s
.134 0 .891 r
.49572 .27789 m .50555 .29034 L .52334 .28361 L p F P
0 0 0 r
s
.134 0 .891 r
.50555 .29034 m .49572 .27789 L .47797 .28465 L p F P
0 0 0 r
s
.188 0 .528 r
.34515 .96113 m .3461 .94281 L .33525 .93451 L p F P
0 0 0 r
s
.188 0 .528 r
.33626 .91631 m .33525 .93451 L .3461 .94281 L p F P
0 0 0 r
s
.188 0 .528 r
.29669 .80976 m .2979 .79224 L .28674 .78298 L p F P
0 0 0 r
s
.188 0 .528 r
.288 .76558 m .28674 .78298 L .2979 .79224 L p F P
0 0 0 r
s
.188 0 .528 r
.24823 .65839 m .24969 .64167 L .23823 .63145 L p F P
0 0 0 r
s
.188 0 .528 r
.23975 .61485 m .23823 .63145 L .24969 .64167 L p F P
0 0 0 r
s
.188 0 .528 r
.1513 .35566 m .15328 .34053 L .1412 .3284 L p F P
0 0 0 r
s
.188 0 .528 r
.14323 .3134 m .1412 .3284 L .15328 .34053 L p F P
0 0 0 r
s
.115 0 .563 r
.56447 1.00731 m .56427 .98869 L .54634 .993 L p F P
0 0 0 r
s
.115 0 .563 r
.54634 .993 m .54645 1.01158 L .56447 1.00731 L p F P
0 0 0 r
s
.115 0 .563 r
.92357 .67822 m .92147 .66133 L .90232 .66676 L p F P
0 0 0 r
s
.115 0 .563 r
.90232 .66676 m .90431 .68362 L .92357 .67822 L p F P
0 0 0 r
s
.134 0 .891 r
.24039 .27737 m .25184 .28982 L .26876 .2831 L p F P
0 0 0 r
s
.134 0 .891 r
.25184 .28982 m .24039 .27737 L .22352 .28413 L p F P
0 0 0 r
s
.125 0 .956 r
.51068 1.03873 m .49293 1.04287 L .48302 1.0352 L p F P
0 0 0 r
s
.125 0 .956 r
.46531 1.03937 m .48302 1.0352 L .49293 1.04287 L p F P
0 0 0 r
s
.134 0 .891 r
.79656 .27737 m .8045 .28982 L .82332 .2831 L p F P
0 0 0 r
s
.134 0 .891 r
.8045 .28982 m .79656 .27737 L .77778 .28413 L p F P
0 0 0 r
s
.115 0 .563 r
.8698 .72845 m .86798 .71129 L .84901 .71655 L p F P
0 0 0 r
s
.115 0 .563 r
.84901 .71655 m .85072 .73367 L .8698 .72845 L p F P
0 0 0 r
s
.134 0 .891 r
.54125 .27684 m .5508 .28931 L .56876 .28258 L p F P
0 0 0 r
s
.134 0 .891 r
.5508 .28931 m .54125 .27684 L .52334 .28361 L p F P
0 0 0 r
s
.115 0 .563 r
.81599 .7787 m .81446 .76127 L .79567 .76636 L p F P
0 0 0 r
s
.115 0 .563 r
.79567 .76636 m .79709 .78376 L .81599 .7787 L p F P
0 0 0 r
s
.195 0 .31 r
.89417 .52036 m .89222 .50426 L .89955 .51528 L p F P
0 0 0 r
s
.195 0 .31 r
.89955 .51528 m .90153 .53134 L .89417 .52036 L p F P
0 0 0 r
s
.195 0 .31 r
.84537 .36795 m .84368 .35265 L .85132 .36463 L p F P
0 0 0 r
s
.195 0 .31 r
.85132 .36463 m .85304 .3799 L .84537 .36795 L p F P
0 0 0 r
s
.115 0 .563 r
.76216 .82898 m .76092 .81128 L .7423 .8162 L p F P
0 0 0 r
s
.115 0 .563 r
.7423 .8162 m .74344 .83386 L .76216 .82898 L p F P
0 0 0 r
s
.134 0 .891 r
.2858 .27632 m .29697 .28879 L .31406 .28206 L p F P
0 0 0 r
s
.134 0 .891 r
.29697 .28879 m .2858 .27632 L .26876 .2831 L p F P
0 0 0 r
s
.134 0 .891 r
.58683 .2758 m .5961 .28827 L .61422 .28154 L p F P
0 0 0 r
s
.134 0 .891 r
.5961 .28827 m .58683 .2758 L .56876 .28258 L p F P
0 0 0 r
s
.188 0 .528 r
.1412 .3284 m .14323 .3134 L .13108 .30108 L p F P
0 0 0 r
s
.188 0 .528 r
.13317 .28621 m .13108 .30108 L .14323 .3134 L p F P
0 0 0 r
s
.115 0 .563 r
.7083 .87928 m .70734 .86132 L .6889 .86607 L p F P
0 0 0 r
s
.115 0 .563 r
.6889 .86607 m .68976 .884 L .7083 .87928 L p F P
0 0 0 r
s
.188 0 .528 r
.28674 .78298 m .288 .76558 L .27677 .75614 L p F P
0 0 0 r
s
.188 0 .528 r
.27809 .73887 m .27677 .75614 L .288 .76558 L p F P
0 0 0 r
s
.188 0 .528 r
.23823 .63145 m .23975 .61485 L .22821 .60446 L p F P
0 0 0 r
s
.188 0 .528 r
.22978 .58798 m .22821 .60446 L .23975 .61485 L p F P
0 0 0 r
s
.188 0 .528 r
.18972 .47993 m .19149 .46412 L .17965 .45277 L p F P
0 0 0 r
s
.188 0 .528 r
.18148 .43709 m .17965 .45277 L .19149 .46412 L p F P
0 0 0 r
s
.188 0 .528 r
.33525 .93451 m .33626 .91631 L .32534 .90783 L p F P
0 0 0 r
s
.188 0 .528 r
.3264 .88976 m .32534 .90783 L .33626 .91631 L p F P
0 0 0 r
s
.134 0 .891 r
.33126 .27528 m .34215 .28776 L .3594 .28102 L p F P
0 0 0 r
s
.134 0 .891 r
.34215 .28776 m .33126 .27528 L .31406 .28206 L p F P
0 0 0 r
s
.115 0 .563 r
.65442 .92962 m .65374 .91138 L .63548 .91596 L p F P
0 0 0 r
s
.115 0 .563 r
.63548 .91596 m .63606 .93416 L .65442 .92962 L p F P
0 0 0 r
s
.195 0 .31 r
.88479 .49309 m .88289 .47711 L .89029 .48832 L p F P
0 0 0 r
s
.195 0 .31 r
.89029 .48832 m .89222 .50426 L .88479 .49309 L p F P
0 0 0 r
s
.134 0 .891 r
.63246 .27475 m .64145 .28724 L .65973 .2805 L p F P
0 0 0 r
s
.134 0 .891 r
.64145 .28724 m .63246 .27475 L .61422 .28154 L p F P
0 0 0 r
s
.195 0 .31 r
.93364 .64567 m .93148 .62888 L .93857 .63913 L p F P
0 0 0 r
s
.195 0 .31 r
.93857 .63913 m .94075 .65586 L .93364 .64567 L p F P
0 0 0 r
s
.195 0 .31 r
.83594 .34051 m .8343 .32534 L .842 .33751 L p F P
0 0 0 r
s
.195 0 .31 r
.842 .33751 m .84368 .35265 L .83594 .34051 L p F P
0 0 0 r
s
.115 0 .563 r
.6005 .97998 m .60011 .96147 L .58203 .96588 L p F P
0 0 0 r
s
.115 0 .563 r
.58203 .96588 m .58232 .98435 L .6005 .97998 L p F P
0 0 0 r
s
.115 0 .563 r
.90632 .70066 m .90431 .68362 L .88518 .68898 L p F P
0 0 0 r
s
.115 0 .563 r
.88518 .68898 m .88708 .70599 L .90632 .70066 L p F P
0 0 0 r
s
.134 0 .891 r
.37677 .27423 m .38738 .28672 L .40479 .27998 L p F P
0 0 0 r
s
.134 0 .891 r
.38738 .28672 m .37677 .27423 L .3594 .28102 L p F P
0 0 0 r
s
.115 0 .563 r
.54655 1.03036 m .54645 1.01158 L .52854 1.01582 L p F P
0 0 0 r
s
.115 0 .563 r
.52854 1.01582 m .52856 1.03456 L .54655 1.03036 L p F P
0 0 0 r
s
.188 0 .528 r
.17965 .45277 m .18148 .43709 L .16956 .42555 L p F P
0 0 0 r
s
.188 0 .528 r
.17144 .41001 m .16956 .42555 L .18148 .43709 L p F P
0 0 0 r
s
.188 0 .528 r
.22821 .60446 m .22978 .58798 L .21817 .5774 L p F P
0 0 0 r
s
.188 0 .528 r
.2198 .56105 m .21817 .5774 L .22978 .58798 L p F P
0 0 0 r
s
.134 0 .891 r
.12094 .2737 m .13317 .28621 L .14971 .27945 L p F P
0 0 0 r
s
.188 0 .528 r
.13108 .30108 m .13317 .28621 L .12094 .2737 L p F P
0 0 0 r
s
.188 0 .528 r
.36487 1.01419 m .36402 1.03295 L .37471 1.04064 L p F P
0 0 0 r
s
.125 0 .956 r
.39208 1.03649 m .37471 1.04064 L .36402 1.03295 L p F P
0 0 0 r
s
.188 0 .528 r
.27677 .75614 m .27809 .73887 L .26679 .72925 L p F P
0 0 0 r
s
.188 0 .528 r
.26816 .7121 m .26679 .72925 L .27809 .73887 L p F P
0 0 0 r
s
.115 0 .563 r
.85244 .75098 m .85072 .73367 L .83177 .73887 L p F P
0 0 0 r
s
.115 0 .563 r
.83177 .73887 m .83339 .75614 L .85244 .75098 L p F P
0 0 0 r
s
.134 0 .891 r
.67814 .2737 m .68684 .28621 L .7053 .27945 L p F P
0 0 0 r
s
.134 0 .891 r
.68684 .28621 m .67814 .2737 L .65973 .2805 L p F P
0 0 0 r
s
.188 0 .528 r
.32534 .90783 m .3264 .88976 L .3154 .8811 L p F P
0 0 0 r
s
.188 0 .528 r
.31652 .86315 m .3154 .8811 L .3264 .88976 L p F P
0 0 0 r
s
.134 0 .891 r
.42233 .27318 m .43265 .28569 L .45023 .27893 L p F P
0 0 0 r
s
.134 0 .891 r
.43265 .28569 m .42233 .27318 L .40479 .27998 L p F P
0 0 0 r
s
.115 0 .563 r
.79854 .80134 m .79709 .78376 L .77832 .78878 L p F P
0 0 0 r
s
.115 0 .563 r
.77832 .78878 m .77966 .80632 L .79854 .80134 L p F P
0 0 0 r
s
.134 0 .891 r
.16637 .27266 m .17832 .28517 L .19503 .27841 L p F P
0 0 0 r
s
.134 0 .891 r
.17832 .28517 m .16637 .27266 L .14971 .27945 L p F P
0 0 0 r
s
.115 0 .563 r
.7446 .85172 m .74344 .83386 L .72485 .83872 L p F P
0 0 0 r
s
.115 0 .563 r
.72485 .83872 m .72591 .85653 L .7446 .85172 L p F P
0 0 0 r
s
.125 0 .956 r
.41998 1.04001 m .43465 1.03653 L .4385 1.03658 L p F P
0 0 0 r
s
.125 0 .956 r
.43465 1.03653 m .41998 1.04001 L .41129 1.03357 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.92429 .6185 m .92218 .60184 L .92934 .61227 L p F P
0 0 0 r
s
.195 0 .31 r
.92934 .61227 m .93148 .62888 L .92429 .6185 L p F P
0 0 0 r
s
.195 0 .31 r
.87539 .46576 m .87354 .44991 L .881 .4613 L p F P
0 0 0 r
s
.195 0 .31 r
.881 .4613 m .88289 .47711 L .87539 .46576 L p F P
0 0 0 r
s
.195 0 .31 r
.82649 .31302 m .8249 .29798 L .83267 .31033 L p F P
0 0 0 r
s
.195 0 .31 r
.83267 .31033 m .8343 .32534 L .82649 .31302 L p F P
0 0 0 r
s
.134 0 .891 r
.72387 .27266 m .73229 .28517 L .7509 .27841 L p F P
0 0 0 r
s
.134 0 .891 r
.73229 .28517 m .72387 .27266 L .7053 .27945 L p F P
0 0 0 r
s
.134 0 .891 r
.46793 .27213 m .47797 .28465 L .49572 .27789 L p F P
0 0 0 r
s
.134 0 .891 r
.47797 .28465 m .46793 .27213 L .45023 .27893 L p F P
0 0 0 r
s
.115 0 .563 r
.69064 .90212 m .68976 .884 L .67135 .88868 L p F P
0 0 0 r
s
.115 0 .563 r
.67135 .88868 m .67212 .90677 L .69064 .90212 L p F P
0 0 0 r
s
.134 0 .891 r
.21185 .27161 m .22352 .28413 L .24039 .27737 L p F P
0 0 0 r
s
.134 0 .891 r
.22352 .28413 m .21185 .27161 L .19503 .27841 L p F P
0 0 0 r
s
.188 0 .528 r
.21817 .5774 m .2198 .56105 L .20811 .55029 L p F P
0 0 0 r
s
.188 0 .528 r
.20979 .53407 m .20811 .55029 L .2198 .56105 L p F P
0 0 0 r
s
.188 0 .528 r
.16956 .42555 m .17144 .41001 L .15944 .39828 L p F P
0 0 0 r
s
.188 0 .528 r
.16138 .38286 m .15944 .39828 L .17144 .41001 L p F P
0 0 0 r
s
.125 0 .956 r
.46531 1.03937 m .45995 1.03529 L .47989 1.03279 L p F P
0 0 0 r
s
.125 0 .956 r
.47989 1.03279 m .48302 1.0352 L .46531 1.03937 L p F P
0 0 0 r
s
.188 0 .528 r
.36402 1.03295 m .36487 1.01419 L .35411 1.00632 L p F P
0 0 0 r
s
.188 0 .528 r
.35502 .98769 m .35411 1.00632 L .36487 1.01419 L p F P
0 0 0 r
s
.188 0 .528 r
.3154 .8811 m .31652 .86315 L .30544 .85431 L p F P
0 0 0 r
s
.188 0 .528 r
.30661 .83648 m .30544 .85431 L .31652 .86315 L p F P
0 0 0 r
s
.188 0 .528 r
.26679 .72925 m .26816 .7121 L .25678 .7023 L p F P
0 0 0 r
s
.188 0 .528 r
.2582 .68527 m .25678 .7023 L .26816 .7121 L p F P
0 0 0 r
s
.134 0 .891 r
.76965 .27161 m .77778 .28413 L .79656 .27737 L p F P
0 0 0 r
s
.134 0 .891 r
.77778 .28413 m .76965 .27161 L .7509 .27841 L p F P
0 0 0 r
s
.115 0 .563 r
.63664 .95255 m .63606 .93416 L .61782 .93867 L p F P
0 0 0 r
s
.115 0 .563 r
.61782 .93867 m .61831 .95703 L .63664 .95255 L p F P
0 0 0 r
s
.134 0 .891 r
.51358 .27108 m .52334 .28361 L .54125 .27684 L p F P
0 0 0 r
s
.134 0 .891 r
.52334 .28361 m .51358 .27108 L .49572 .27789 L p F P
0 0 0 r
s
.115 0 .563 r
.94296 .67278 m .94075 .65586 L .92147 .66133 L p F P
0 0 0 r
s
.115 0 .563 r
.92147 .66133 m .92357 .67822 L .94296 .67278 L p F P
0 0 0 r
s
.115 0 .563 r
.58262 1.00301 m .58232 .98435 L .56427 .98869 L p F P
0 0 0 r
s
.115 0 .563 r
.56427 .98869 m .56447 1.00731 L .58262 1.00301 L p F P
0 0 0 r
s
.134 0 .891 r
.25738 .27055 m .26876 .2831 L .2858 .27632 L p F P
0 0 0 r
s
.134 0 .891 r
.26876 .2831 m .25738 .27055 L .24039 .27737 L p F P
0 0 0 r
s
.125 0 .956 r
.52856 1.03456 m .51068 1.03873 L .50085 1.03101 L p F P
0 0 0 r
s
.125 0 .956 r
.48302 1.0352 m .50085 1.03101 L .51068 1.03873 L p F P
0 0 0 r
s
.195 0 .31 r
.91493 .59127 m .91286 .57474 L .92009 .58535 L p F P
0 0 0 r
s
.195 0 .31 r
.92009 .58535 m .92218 .60184 L .91493 .59127 L p F P
0 0 0 r
s
.195 0 .31 r
.86598 .43837 m .86417 .42265 L .8717 .43422 L p F P
0 0 0 r
s
.195 0 .31 r
.8717 .43422 m .87354 .44991 L .86598 .43837 L p F P
0 0 0 r
s
.134 0 .891 r
.82332 .2831 m .81548 .27055 L .79656 .27737 L p F P
0 0 0 r
s
.195 0 .31 r
.81702 .28546 m .81548 .27055 L .82332 .2831 L p F P
0 0 0 r
s
.195 0 .31 r
.82332 .2831 m .8249 .29798 L .81702 .28546 L p F P
0 0 0 r
s
.115 0 .563 r
.88901 .72318 m .88708 .70599 L .86798 .71129 L p F P
0 0 0 r
s
.115 0 .563 r
.86798 .71129 m .8698 .72845 L .88901 .72318 L p F P
0 0 0 r
s
.134 0 .891 r
.55929 .27003 m .56876 .28258 L .58683 .2758 L p F P
0 0 0 r
s
.134 0 .891 r
.56876 .28258 m .55929 .27003 L .54125 .27684 L p F P
0 0 0 r
s
.115 0 .563 r
.83502 .77361 m .83339 .75614 L .81446 .76127 L p F P
0 0 0 r
s
.115 0 .563 r
.81446 .76127 m .81599 .7787 L .83502 .77361 L p F P
0 0 0 r
s
.115 0 .563 r
.78101 .82406 m .77966 .80632 L .76092 .81128 L p F P
0 0 0 r
s
.115 0 .563 r
.76092 .81128 m .76216 .82898 L .78101 .82406 L p F P
0 0 0 r
s
.134 0 .891 r
.30296 .2695 m .31406 .28206 L .33126 .27528 L p F P
0 0 0 r
s
.134 0 .891 r
.31406 .28206 m .30296 .2695 L .2858 .27632 L p F P
0 0 0 r
s
.188 0 .528 r
.35411 1.00632 m .35502 .98769 L .34418 .97964 L p F P
0 0 0 r
s
.188 0 .528 r
.34515 .96113 m .34418 .97964 L .35502 .98769 L p F P
0 0 0 r
s
.188 0 .528 r
.30544 .85431 m .30661 .83648 L .29546 .82747 L p F P
0 0 0 r
s
.188 0 .528 r
.29669 .80976 m .29546 .82747 L .30661 .83648 L p F P
0 0 0 r
s
.188 0 .528 r
.25678 .7023 m .2582 .68527 L .24675 .6753 L p F P
0 0 0 r
s
.188 0 .528 r
.24823 .65839 m .24675 .6753 L .2582 .68527 L p F P
0 0 0 r
s
.188 0 .528 r
.20811 .55029 m .20979 .53407 L .19803 .52312 L p F P
0 0 0 r
s
.188 0 .528 r
.19976 .50703 m .19803 .52312 L .20979 .53407 L p F P
0 0 0 r
s
.188 0 .528 r
.15944 .39828 m .16138 .38286 L .14931 .37095 L p F P
0 0 0 r
s
.188 0 .528 r
.1513 .35566 m .14931 .37095 L .16138 .38286 L p F P
0 0 0 r
s
.134 0 .891 r
.60504 .26898 m .61422 .28154 L .63246 .27475 L p F P
0 0 0 r
s
.134 0 .891 r
.61422 .28154 m .60504 .26898 L .58683 .2758 L p F P
0 0 0 r
s
.115 0 .563 r
.72697 .87454 m .72591 .85653 L .70734 .86132 L p F P
0 0 0 r
s
.115 0 .563 r
.70734 .86132 m .7083 .87928 L .72697 .87454 L p F P
0 0 0 r
s
.134 0 .891 r
.34859 .26845 m .3594 .28102 L .37677 .27423 L p F P
0 0 0 r
s
.134 0 .891 r
.3594 .28102 m .34859 .26845 L .33126 .27528 L p F P
0 0 0 r
s
.195 0 .31 r
.90554 .56399 m .90352 .54758 L .91082 .55838 L p F P
0 0 0 r
s
.195 0 .31 r
.91082 .55838 m .91286 .57474 L .90554 .56399 L p F P
0 0 0 r
s
.195 0 .31 r
.85654 .41092 m .85478 .39533 L .86238 .40709 L p F P
0 0 0 r
s
.195 0 .31 r
.86238 .40709 m .86417 .42265 L .85654 .41092 L p F P
0 0 0 r
s
.115 0 .563 r
.6729 .92504 m .67212 .90677 L .65374 .91138 L p F P
0 0 0 r
s
.115 0 .563 r
.65374 .91138 m .65442 .92962 L .6729 .92504 L p F P
0 0 0 r
s
.134 0 .891 r
.65084 .26792 m .65973 .2805 L .67814 .2737 L p F P
0 0 0 r
s
.134 0 .891 r
.65973 .2805 m .65084 .26792 L .63246 .27475 L p F P
0 0 0 r
s
.115 0 .563 r
.6188 .97558 m .61831 .95703 L .60011 .96147 L p F P
0 0 0 r
s
.115 0 .563 r
.60011 .96147 m .6005 .97998 L .6188 .97558 L p F P
0 0 0 r
s
.188 0 .528 r
.24675 .6753 m .24823 .65839 L .23669 .64823 L p F P
0 0 0 r
s
.188 0 .528 r
.23823 .63145 m .23669 .64823 L .24823 .65839 L p F P
0 0 0 r
s
.188 0 .528 r
.19803 .52312 m .19976 .50703 L .18792 .4959 L p F P
0 0 0 r
s
.188 0 .528 r
.18972 .47993 m .18792 .4959 L .19976 .50703 L p F P
0 0 0 r
s
.188 0 .528 r
.14931 .37095 m .1513 .35566 L .13915 .34356 L p F P
0 0 0 r
s
.188 0 .528 r
.1412 .3284 m .13915 .34356 L .1513 .35566 L p F P
0 0 0 r
s
.115 0 .563 r
.56467 1.02614 m .56447 1.00731 L .54645 1.01158 L p F P
0 0 0 r
s
.115 0 .563 r
.54645 1.01158 m .54655 1.03036 L .56467 1.02614 L p F P
0 0 0 r
s
.188 0 .528 r
.34418 .97964 m .34515 .96113 L .33423 .9529 L p F P
0 0 0 r
s
.188 0 .528 r
.33525 .93451 m .33423 .9529 L .34515 .96113 L p F P
0 0 0 r
s
.188 0 .528 r
.29546 .82747 m .29669 .80976 L .28546 .80056 L p F P
0 0 0 r
s
.188 0 .528 r
.28674 .78298 m .28546 .80056 L .29669 .80976 L p F P
0 0 0 r
s
.115 0 .563 r
.92569 .69529 m .92357 .67822 L .90431 .68362 L p F P
0 0 0 r
s
.115 0 .563 r
.90431 .68362 m .90632 .70066 L .92569 .69529 L p F P
0 0 0 r
s
.134 0 .891 r
.39426 .26739 m .40479 .27998 L .42233 .27318 L p F P
0 0 0 r
s
.134 0 .891 r
.40479 .27998 m .39426 .26739 L .37677 .27423 L p F P
0 0 0 r
s
0 .647 .956 r
.45519 1.03166 m .45995 1.03529 L .4385 1.03658 L p F P
0 0 0 r
s
0 .647 .956 r
.4385 1.03658 m .43752 1.03585 L .45519 1.03166 L p F P
0 0 0 r
s
0 .647 .956 r
.43465 1.03653 m .43752 1.03585 L .4385 1.03658 L closepath p F P
0 0 0 r
s
0 .647 .956 r
.43752 1.03585 m .43465 1.03653 L .41129 1.03357 L p F P
0 0 0 r
s
.134 0 .891 r
.13755 .26687 m .14971 .27945 L .16637 .27266 L p F P
0 0 0 r
s
.134 0 .891 r
.14971 .27945 m .13755 .26687 L .12094 .2737 L p F P
0 0 0 r
s
.125 0 .956 r
.39208 1.03649 m .4079 1.03271 L .41129 1.03357 L p F P
0 0 0 r
s
.125 0 .956 r
.4079 1.03271 m .39208 1.03649 L .38147 1.02874 L p F P
0 0 0 r
s
.125 0 .956 r
.36402 1.03295 m .38147 1.02874 L .39208 1.03649 L p F P
0 0 0 r
s
.134 0 .891 r
.69668 .26687 m .7053 .27945 L .72387 .27266 L p F P
0 0 0 r
s
.134 0 .891 r
.7053 .27945 m .69668 .26687 L .67814 .2737 L p F P
0 0 0 r
s
.115 0 .563 r
.87163 .74579 m .8698 .72845 L .85072 .73367 L p F P
0 0 0 r
s
.115 0 .563 r
.85072 .73367 m .85244 .75098 L .87163 .74579 L p F P
0 0 0 r
s
.195 0 .31 r
.89614 .53665 m .89417 .52036 L .90153 .53134 L p F P
0 0 0 r
s
.195 0 .31 r
.90153 .53134 m .90352 .54758 L .89614 .53665 L p F P
0 0 0 r
s
.134 0 .891 r
.43998 .26634 m .45023 .27893 L .46793 .27213 L p F P
0 0 0 r
s
.134 0 .891 r
.45023 .27893 m .43998 .26634 L .42233 .27318 L p F P
0 0 0 r
s
.115 0 .563 r
.81754 .79631 m .81599 .7787 L .79709 .78376 L p F P
0 0 0 r
s
.115 0 .563 r
.79709 .78376 m .79854 .80134 L .81754 .79631 L p F P
0 0 0 r
s
.195 0 .31 r
.84708 .38341 m .84537 .36795 L .85304 .3799 L p F P
0 0 0 r
s
.195 0 .31 r
.85304 .3799 m .85478 .39533 L .84708 .38341 L p F P
0 0 0 r
s
.134 0 .891 r
.18315 .26581 m .19503 .27841 L .21185 .27161 L p F P
0 0 0 r
s
.134 0 .891 r
.19503 .27841 m .18315 .26581 L .16637 .27266 L p F P
0 0 0 r
s
.134 0 .891 r
.74258 .26581 m .7509 .27841 L .76965 .27161 L p F P
0 0 0 r
s
.134 0 .891 r
.7509 .27841 m .74258 .26581 L .72387 .27266 L p F P
0 0 0 r
s
.115 0 .563 r
.76342 .84686 m .76216 .82898 L .74344 .83386 L p F P
0 0 0 r
s
.115 0 .563 r
.74344 .83386 m .7446 .85172 L .76342 .84686 L p F P
0 0 0 r
s
0 .647 .956 r
.45519 1.03166 m .43752 1.03585 L .42719 1.02809 L p F P
0 0 0 r
s
0 .647 .956 r
.42719 1.02809 m .43752 1.03585 L p .41129 1.03357 L F P
0 0 0 r
s
.188 0 .528 r
.23669 .64823 m .23823 .63145 L .22662 .62111 L p F P
0 0 0 r
s
.188 0 .528 r
.22821 .60446 m .22662 .62111 L .23823 .63145 L p F P
0 0 0 r
s
.188 0 .528 r
.18792 .4959 m .18972 .47993 L .1778 .46861 L p F P
0 0 0 r
s
.188 0 .528 r
.17965 .45277 m .1778 .46861 L .18972 .47993 L p F P
0 0 0 r
s
.188 0 .528 r
.13915 .34356 m .1412 .3284 L .12897 .31611 L p F P
0 0 0 r
s
.188 0 .528 r
.13108 .30108 m .12897 .31611 L .1412 .3284 L p F P
0 0 0 r
s
.188 0 .528 r
.28546 .80056 m .28674 .78298 L .27544 .77361 L p F P
0 0 0 r
s
.188 0 .528 r
.27677 .75614 m .27544 .77361 L .28674 .78298 L p F P
0 0 0 r
s
.134 0 .891 r
.48576 .26528 m .49572 .27789 L .51358 .27108 L p F P
0 0 0 r
s
.134 0 .891 r
.49572 .27789 m .48576 .26528 L .46793 .27213 L p F P
0 0 0 r
s
.115 0 .563 r
.70928 .89744 m .7083 .87928 L .68976 .884 L p F P
0 0 0 r
s
.115 0 .563 r
.68976 .884 m .69064 .90212 L .70928 .89744 L p F P
0 0 0 r
s
.188 0 .528 r
.33423 .9529 m .33525 .93451 L .32427 .9261 L p F P
0 0 0 r
s
.188 0 .528 r
.32534 .90783 m .32427 .9261 L .33525 .93451 L p F P
0 0 0 r
s
0 .647 .956 r
.47297 1.02744 m .47989 1.03279 L .45995 1.03529 L p F P
0 0 0 r
s
0 .647 .956 r
.45995 1.03529 m .45519 1.03166 L .47297 1.02744 L p F P
0 0 0 r
s
.125 0 .956 r
.48302 1.0352 m .47989 1.03279 L .49915 1.02968 L p F P
0 0 0 r
s
.125 0 .956 r
.49915 1.02968 m .50085 1.03101 L .48302 1.0352 L p F P
0 0 0 r
s
.134 0 .891 r
.22879 .26475 m .24039 .27737 L .25738 .27055 L p F P
0 0 0 r
s
.134 0 .891 r
.24039 .27737 m .22879 .26475 L .21185 .27161 L p F P
0 0 0 r
s
.134 0 .891 r
.78853 .26475 m .79656 .27737 L .81548 .27055 L p F P
0 0 0 r
s
.134 0 .891 r
.79656 .27737 m .78853 .26475 L .76965 .27161 L p F P
0 0 0 r
s
.115 0 .563 r
.6551 .94805 m .65442 .92962 L .63606 .93416 L p F P
0 0 0 r
s
.115 0 .563 r
.63606 .93416 m .63664 .95255 L .6551 .94805 L p F P
0 0 0 r
s
.134 0 .891 r
.53158 .26422 m .54125 .27684 L .55929 .27003 L p F P
0 0 0 r
s
.134 0 .891 r
.54125 .27684 m .53158 .26422 L .51358 .27108 L p F P
0 0 0 r
s
.115 0 .563 r
.6009 .99869 m .6005 .97998 L .58232 .98435 L p F P
0 0 0 r
s
.115 0 .563 r
.58232 .98435 m .58262 1.00301 L .6009 .99869 L p F P
0 0 0 r
s
.195 0 .31 r
.93582 .66264 m .93364 .64567 L .94075 .65586 L p F P
0 0 0 r
s
.195 0 .31 r
.94075 .65586 m .94296 .67278 L .93582 .66264 L p F P
0 0 0 r
s
.195 0 .31 r
.88671 .50924 m .88479 .49309 L .89222 .50426 L p F P
0 0 0 r
s
.195 0 .31 r
.89222 .50426 m .89417 .52036 L .88671 .50924 L p F P
0 0 0 r
s
.195 0 .31 r
.8376 .35585 m .83594 .34051 L .84368 .35265 L p F P
0 0 0 r
s
.195 0 .31 r
.84368 .35265 m .84537 .36795 L .8376 .35585 L p F P
0 0 0 r
s
.115 0 .563 r
.90835 .71788 m .90632 .70066 L .88708 .70599 L p F P
0 0 0 r
s
.115 0 .563 r
.88708 .70599 m .88901 .72318 L .90835 .71788 L p F P
0 0 0 r
s
.134 0 .891 r
.27449 .26369 m .2858 .27632 L .30296 .2695 L p F P
0 0 0 r
s
.134 0 .891 r
.2858 .27632 m .27449 .26369 L .25738 .27055 L p F P
0 0 0 r
s
.125 0 .956 r
.54655 1.03036 m .52856 1.03456 L .5188 1.02679 L p F P
0 0 0 r
s
.125 0 .956 r
.50085 1.03101 m .5188 1.02679 L .52856 1.03456 L p F P
0 0 0 r
s
.134 0 .891 r
.57745 .26316 m .58683 .2758 L .60504 .26898 L p F P
0 0 0 r
s
.134 0 .891 r
.58683 .2758 m .57745 .26316 L .55929 .27003 L p F P
0 0 0 r
s
.188 0 .528 r
.27544 .77361 m .27677 .75614 L .2654 .74659 L p F P
0 0 0 r
s
.188 0 .528 r
.26679 .72925 m .2654 .74659 L .27677 .75614 L p F P
0 0 0 r
s
.188 0 .528 r
.22662 .62111 m .22821 .60446 L .21653 .59393 L p F P
0 0 0 r
s
.188 0 .528 r
.21817 .5774 m .21653 .59393 L .22821 .60446 L p F P
0 0 0 r
s
.188 0 .528 r
.1778 .46861 m .17965 .45277 L .16765 .44127 L p F P
0 0 0 r
s
.188 0 .528 r
.16956 .42555 m .16765 .44127 L .17965 .45277 L p F P
0 0 0 r
s
.188 0 .528 r
.12897 .31611 m .13108 .30108 L .11878 .28861 L p F P
0 0 0 r
s
.188 0 .528 r
.12094 .2737 m .11878 .28861 L .13108 .30108 L p F P
0 0 0 r
s
.115 0 .563 r
.85419 .76848 m .85244 .75098 L .83339 .75614 L p F P
0 0 0 r
s
.115 0 .563 r
.83339 .75614 m .83502 .77361 L .85419 .76848 L p F P
0 0 0 r
s
.188 0 .528 r
.32427 .9261 m .32534 .90783 L .31427 .89925 L p F P
0 0 0 r
s
.188 0 .528 r
.3154 .8811 m .31427 .89925 L .32534 .90783 L p F P
0 0 0 r
s
.115 0 .563 r
.79999 .8191 m .79854 .80134 L .77966 .80632 L p F P
0 0 0 r
s
.115 0 .563 r
.77966 .80632 m .78101 .82406 L .79999 .8191 L p F P
0 0 0 r
s
.134 0 .891 r
.32023 .26263 m .33126 .27528 L .34859 .26845 L p F P
0 0 0 r
s
.134 0 .891 r
.33126 .27528 m .32023 .26263 L .30296 .2695 L p F P
0 0 0 r
s
.195 0 .31 r
.87727 .48178 m .87539 .46576 L .88289 .47711 L p F P
0 0 0 r
s
.195 0 .31 r
.88289 .47711 m .88479 .49309 L .87727 .48178 L p F P
0 0 0 r
s
.134 0 .891 r
.62337 .2621 m .63246 .27475 L .65084 .26792 L p F P
0 0 0 r
s
.134 0 .891 r
.63246 .27475 m .62337 .2621 L .60504 .26898 L p F P
0 0 0 r
s
.115 0 .563 r
.74577 .86976 m .7446 .85172 L .72591 .85653 L p F P
0 0 0 r
s
.115 0 .563 r
.72591 .85653 m .72697 .87454 L .74577 .86976 L p F P
0 0 0 r
s
.195 0 .31 r
.92643 .63534 m .92429 .6185 L .93148 .62888 L p F P
0 0 0 r
s
.195 0 .31 r
.93148 .62888 m .93364 .64567 L .92643 .63534 L p F P
0 0 0 r
s
.195 0 .31 r
.8281 .32822 m .82649 .31302 L .8343 .32534 L p F P
0 0 0 r
s
.195 0 .31 r
.8343 .32534 m .83594 .34051 L .8281 .32822 L p F P
0 0 0 r
s
0 .647 .956 r
.41129 1.03357 m .40958 1.0323 L .42719 1.02809 L p F P
0 0 0 r
s
0 .647 .956 r
.4079 1.03271 m .40958 1.0323 L .41129 1.03357 L closepath p F P
0 0 0 r
s
.134 0 .891 r
.36603 .26157 m .37677 .27423 L .39426 .26739 L p F P
0 0 0 r
s
.134 0 .891 r
.37677 .27423 m .36603 .26157 L .34859 .26845 L p F P
0 0 0 r
s
.115 0 .563 r
.69152 .92044 m .69064 .90212 L .67212 .90677 L p F P
0 0 0 r
s
.115 0 .563 r
.67212 .90677 m .6729 .92504 L .69152 .92044 L p F P
0 0 0 r
s
.188 0 .528 r
.2654 .74659 m .26679 .72925 L .25534 .71951 L p F P
0 0 0 r
s
.188 0 .528 r
.25678 .7023 m .25534 .71951 L .26679 .72925 L p F P
0 0 0 r
s
.188 0 .528 r
.21653 .59393 m .21817 .5774 L .20641 .56669 L p F P
0 0 0 r
s
.188 0 .528 r
.20811 .55029 m .20641 .56669 L .21817 .5774 L p F P
0 0 0 r
s
.188 0 .528 r
.16765 .44127 m .16956 .42555 L .15748 .41387 L p F P
0 0 0 r
s
.188 0 .528 r
.15944 .39828 m .15748 .41387 L .16956 .42555 L p F P
0 0 0 r
s
.134 0 .891 r
.10855 .26104 m .12094 .2737 L .13755 .26687 L p F P
0 0 0 r
s
.188 0 .528 r
.11878 .28861 m .12094 .2737 L .10855 .26104 L p F P
0 0 0 r
s
.134 0 .891 r
.66933 .26104 m .67814 .2737 L .69668 .26687 L p F P
0 0 0 r
s
.134 0 .891 r
.67814 .2737 m .66933 .26104 L .65084 .26792 L p F P
0 0 0 r
s
.188 0 .528 r
.35411 1.00632 m .35319 1.02516 L .36402 1.03295 L p F P
0 0 0 r
s
.125 0 .956 r
.38147 1.02874 m .36402 1.03295 L .35319 1.02516 L p F P
0 0 0 r
s
.115 0 .563 r
.63723 .97115 m .63664 .95255 L .61831 .95703 L p F P
0 0 0 r
s
.115 0 .563 r
.61831 .95703 m .6188 .97558 L .63723 .97115 L p F P
0 0 0 r
s
.188 0 .528 r
.31427 .89925 m .3154 .8811 L .30426 .87234 L p F P
0 0 0 r
s
.188 0 .528 r
.30544 .85431 m .30426 .87234 L .3154 .8811 L p F P
0 0 0 r
s
0 .647 .956 r
.49088 1.02319 m .49915 1.02968 L .47989 1.03279 L p F P
0 0 0 r
s
0 .647 .956 r
.47989 1.03279 m .47297 1.02744 L .49088 1.02319 L p F P
0 0 0 r
s
0 .647 .956 r
.40958 1.0323 m .4079 1.03271 L .39078 1.0265 L p F P
0 0 0 r
s
.125 0 .956 r
.38147 1.02874 m .39078 1.0265 L .4079 1.03271 L p F P
0 0 0 r
s
.115 0 .563 r
.9452 .68988 m .94296 .67278 L .92357 .67822 L p F P
0 0 0 r
s
.115 0 .563 r
.92357 .67822 m .92569 .69529 L .9452 .68988 L p F P
0 0 0 r
s
.134 0 .891 r
.41187 .26051 m .42233 .27318 L .43998 .26634 L p F P
0 0 0 r
s
.134 0 .891 r
.42233 .27318 m .41187 .26051 L .39426 .26739 L p F P
0 0 0 r
s
.115 0 .563 r
.58292 1.02188 m .58262 1.00301 L .56447 1.00731 L p F P
0 0 0 r
s
.115 0 .563 r
.56447 1.00731 m .56467 1.02614 L .58292 1.02188 L p F P
0 0 0 r
s
.195 0 .31 r
.81859 .30054 m .81702 .28546 L .8249 .29798 L p F P
0 0 0 r
s
.195 0 .31 r
.8249 .29798 m .82649 .31302 L .81859 .30054 L p F P
0 0 0 r
s
.134 0 .891 r
.71535 .25998 m .72387 .27266 L .74258 .26581 L p F P
0 0 0 r
s
.134 0 .891 r
.72387 .27266 m .71535 .25998 L .69668 .26687 L p F P
0 0 0 r
s
0 .647 .956 r
.42719 1.02809 m .40958 1.0323 L .39904 1.0245 L p F P
0 0 0 r
s
.134 0 .891 r
.15427 .25998 m .16637 .27266 L .18315 .26581 L p F P
0 0 0 r
s
0 .647 .956 r
.39078 1.0265 m .39904 1.0245 L .40958 1.0323 L p F P
0 0 0 r
s
.134 0 .891 r
.16637 .27266 m .15427 .25998 L .13755 .26687 L p F P
0 0 0 r
s
.195 0 .31 r
.91702 .60799 m .91493 .59127 L .92218 .60184 L p F P
0 0 0 r
s
.195 0 .31 r
.92218 .60184 m .92429 .6185 L .91702 .60799 L p F P
0 0 0 r
s
.115 0 .563 r
.89095 .74055 m .88901 .72318 L .8698 .72845 L p F P
0 0 0 r
s
.115 0 .563 r
.8698 .72845 m .87163 .74579 L .89095 .74055 L p F P
0 0 0 r
s
.195 0 .31 r
.8678 .45426 m .86598 .43837 L .87354 .44991 L p F P
0 0 0 r
s
.195 0 .31 r
.87354 .44991 m .87539 .46576 L .8678 .45426 L p F P
0 0 0 r
s
.134 0 .891 r
.45776 .25945 m .46793 .27213 L .48576 .26528 L p F P
0 0 0 r
s
.134 0 .891 r
.46793 .27213 m .45776 .25945 L .43998 .26634 L p F P
0 0 0 r
s
.115 0 .563 r
.83668 .79125 m .83502 .77361 L .81599 .7787 L p F P
0 0 0 r
s
.115 0 .563 r
.81599 .7787 m .81754 .79631 L .83668 .79125 L p F P
0 0 0 r
s
.115 0 .563 r
.78238 .84198 m .78101 .82406 L .76216 .82898 L p F P
0 0 0 r
s
.115 0 .563 r
.76216 .82898 m .76342 .84686 L .78238 .84198 L p F P
0 0 0 r
s
.134 0 .891 r
.20004 .25892 m .21185 .27161 L .22879 .26475 L p F P
0 0 0 r
s
.134 0 .891 r
.21185 .27161 m .20004 .25892 L .18315 .26581 L p F P
0 0 0 r
s
.188 0 .528 r
.35319 1.02516 m .35411 1.00632 L .34321 .99835 L p F P
0 0 0 r
s
.188 0 .528 r
.34418 .97964 m .34321 .99835 L .35411 1.00632 L p F P
0 0 0 r
s
.188 0 .528 r
.25534 .71951 m .25678 .7023 L .24525 .69238 L p F P
0 0 0 r
s
.188 0 .528 r
.24675 .6753 m .24525 .69238 L .25678 .7023 L p F P
0 0 0 r
s
.188 0 .528 r
.15748 .41387 m .15944 .39828 L .14729 .38641 L p F P
0 0 0 r
s
.188 0 .528 r
.14931 .37095 m .14729 .38641 L .15944 .39828 L p F P
0 0 0 r
s
.134 0 .891 r
.76142 .25892 m .76965 .27161 L .78853 .26475 L p F P
0 0 0 r
s
.134 0 .891 r
.76965 .27161 m .76142 .25892 L .74258 .26581 L p F P
0 0 0 r
s
0 .647 .956 r
.45519 1.03166 m .44493 1.02385 L p .46371 1.02028 L F P
0 0 0 r
s
0 .647 .956 r
.46371 1.02028 m .47297 1.02744 L .45519 1.03166 L p F P
0 0 0 r
s
0 .647 .956 r
.42719 1.02809 m .44493 1.02385 L .45519 1.03166 L p F P
0 0 0 r
s
.188 0 .528 r
.30426 .87234 m .30544 .85431 L .29423 .84537 L p F P
0 0 0 r
s
.188 0 .528 r
.29546 .82747 m .29423 .84537 L .30544 .85431 L p F P
0 0 0 r
s
.188 0 .528 r
.20641 .56669 m .20811 .55029 L .19627 .53939 L p F P
0 0 0 r
s
.188 0 .528 r
.19803 .52312 m .19627 .53939 L .20811 .55029 L p F P
0 0 0 r
s
.115 0 .563 r
.72805 .89274 m .72697 .87454 L .7083 .87928 L p F P
0 0 0 r
s
.115 0 .563 r
.7083 .87928 m .70928 .89744 L .72805 .89274 L p F P
0 0 0 r
s
.134 0 .891 r
.5037 .25838 m .51358 .27108 L .53158 .26422 L p F P
0 0 0 r
s
.134 0 .891 r
.51358 .27108 m .5037 .25838 L .48576 .26528 L p F P
0 0 0 r
s
.134 0 .891 r
.24585 .25785 m .25738 .27055 L .27449 .26369 L p F P
0 0 0 r
s
.134 0 .891 r
.25738 .27055 m .24585 .25785 L .22879 .26475 L p F P
0 0 0 r
s
.195 0 .31 r
.90758 .58058 m .90554 .56399 L .91286 .57474 L p F P
0 0 0 r
s
.195 0 .31 r
.91286 .57474 m .91493 .59127 L .90758 .58058 L p F P
0 0 0 r
s
.134 0 .891 r
.81548 .27055 m .80753 .25785 L .78853 .26475 L p F P
0 0 0 r
s
.195 0 .31 r
.80905 .27279 m .80753 .25785 L .81548 .27055 L p F P
0 0 0 r
s
.195 0 .31 r
.81548 .27055 m .81702 .28546 L .80905 .27279 L p F P
0 0 0 r
s
.125 0 .956 r
.50085 1.03101 m .49915 1.02968 L .51808 1.02622 L p F P
0 0 0 r
s
.125 0 .956 r
.51808 1.02622 m .5188 1.02679 L .50085 1.03101 L p F P
0 0 0 r
s
.195 0 .31 r
.85832 .42668 m .85654 .41092 L .86417 .42265 L p F P
0 0 0 r
s
.195 0 .31 r
.86417 .42265 m .86598 .43837 L .85832 .42668 L p F P
0 0 0 r
s
.115 0 .563 r
.67369 .94352 m .6729 .92504 L .65442 .92962 L p F P
0 0 0 r
s
.115 0 .563 r
.65442 .92962 m .6551 .94805 L .67369 .94352 L p F P
0 0 0 r
s
.134 0 .891 r
.54969 .25732 m .55929 .27003 L .57745 .26316 L p F P
0 0 0 r
s
.134 0 .891 r
.55929 .27003 m .54969 .25732 L .53158 .26422 L p F P
0 0 0 r
s
.115 0 .563 r
.6193 .99433 m .6188 .97558 L .6005 .97998 L p F P
0 0 0 r
s
.115 0 .563 r
.6005 .97998 m .6009 .99869 L .6193 .99433 L p F P
0 0 0 r
s
.188 0 .528 r
.19627 .53939 m .19803 .52312 L .18611 .51204 L p F P
0 0 0 r
s
.188 0 .528 r
.18792 .4959 m .18611 .51204 L .19803 .52312 L p F P
0 0 0 r
s
.134 0 .891 r
.29172 .25679 m .30296 .2695 L .32023 .26263 L p F P
0 0 0 r
s
.134 0 .891 r
.30296 .2695 m .29172 .25679 L .27449 .26369 L p F P
0 0 0 r
s
.188 0 .528 r
.34321 .99835 m .34418 .97964 L .33321 .97149 L p F P
0 0 0 r
s
.188 0 .528 r
.33423 .9529 m .33321 .97149 L .34418 .97964 L p F P
0 0 0 r
s
.188 0 .528 r
.29423 .84537 m .29546 .82747 L .28417 .81834 L p F P
0 0 0 r
s
.188 0 .528 r
.28546 .80056 m .28417 .81834 L .29546 .82747 L p F P
0 0 0 r
s
.188 0 .528 r
.24525 .69238 m .24675 .6753 L .23514 .66519 L p F P
0 0 0 r
s
.188 0 .528 r
.23669 .64823 m .23514 .66519 L .24675 .6753 L p F P
0 0 0 r
s
.188 0 .528 r
.14729 .38641 m .14931 .37095 L .13708 .35889 L p F P
0 0 0 r
s
.188 0 .528 r
.13915 .34356 m .13708 .35889 L .14931 .37095 L p F P
0 0 0 r
s
.125 0 .956 r
.54655 1.03036 m .53688 1.02254 L p .55551 1.01861 L F P
0 0 0 r
s
.125 0 .956 r
.55551 1.01861 m .56467 1.02614 L .54655 1.03036 L p F P
0 0 0 r
s
.125 0 .956 r
.5188 1.02679 m .53688 1.02254 L .54655 1.03036 L p F P
0 0 0 r
s
.115 0 .563 r
.92784 .71254 m .92569 .69529 L .90632 .70066 L p F P
0 0 0 r
s
.115 0 .563 r
.90632 .70066 m .90835 .71788 L .92784 .71254 L p F P
0 0 0 r
s
.134 0 .891 r
.59573 .25625 m .60504 .26898 L .62337 .2621 L p F P
0 0 0 r
s
.134 0 .891 r
.60504 .26898 m .59573 .25625 L .57745 .26316 L p F P
0 0 0 r
s
.115 0 .563 r
.87349 .76331 m .87163 .74579 L .85244 .75098 L p F P
0 0 0 r
s
.115 0 .563 r
.85244 .75098 m .85419 .76848 L .87349 .76331 L p F P
0 0 0 r
s
.115 0 .563 r
.81911 .81411 m .81754 .79631 L .79854 .80134 L p F P
0 0 0 r
s
.115 0 .563 r
.79854 .80134 m .79999 .8191 L .81911 .81411 L p F P
0 0 0 r
s
.134 0 .891 r
.33763 .25572 m .34859 .26845 L .36603 .26157 L p F P
0 0 0 r
s
.134 0 .891 r
.34859 .26845 m .33763 .25572 L .32023 .26263 L p F P
0 0 0 r
s
.195 0 .31 r
.89813 .5531 m .89614 .53665 L .90352 .54758 L p F P
0 0 0 r
s
.195 0 .31 r
.90352 .54758 m .90554 .56399 L .89813 .5531 L p F P
0 0 0 r
s
.195 0 .31 r
.84881 .39904 m .84708 .38341 L .85478 .39533 L p F P
0 0 0 r
s
.195 0 .31 r
.85478 .39533 m .85654 .41092 L .84881 .39904 L p F P
0 0 0 r
s
0 .647 .956 r
.50891 1.01892 m .51808 1.02622 L .49915 1.02968 L p F P
0 0 0 r
s
0 .647 .956 r
.49915 1.02968 m .49088 1.02319 L .50891 1.01892 L p F P
0 0 0 r
s
.134 0 .891 r
.64182 .25519 m .65084 .26792 L .66933 .26104 L p F P
0 0 0 r
s
.134 0 .891 r
.65084 .26792 m .64182 .25519 L .62337 .2621 L p F P
0 0 0 r
s
.115 0 .563 r
.7647 .86494 m .76342 .84686 L .7446 .85172 L p F P
0 0 0 r
s
.115 0 .563 r
.7446 .85172 m .74577 .86976 L .7647 .86494 L p F P
0 0 0 r
s
.134 0 .891 r
.38359 .25465 m .39426 .26739 L .41187 .26051 L p F P
0 0 0 r
s
.134 0 .891 r
.39426 .26739 m .38359 .25465 L .36603 .26157 L p F P
0 0 0 r
s
.188 0 .528 r
.28417 .81834 m .28546 .80056 L .2741 .79125 L p F P
0 0 0 r
s
.188 0 .528 r
.27544 .77361 m .2741 .79125 L .28546 .80056 L p F P
0 0 0 r
s
.188 0 .528 r
.23514 .66519 m .23669 .64823 L .22501 .63794 L p F P
0 0 0 r
s
.188 0 .528 r
.22662 .62111 m .22501 .63794 L .23669 .64823 L p F P
0 0 0 r
s
.188 0 .528 r
.13708 .35889 m .13915 .34356 L .12684 .33131 L p F P
0 0 0 r
s
.188 0 .528 r
.12897 .31611 m .12684 .33131 L .13915 .34356 L p F P
0 0 0 r
s
.115 0 .563 r
.71026 .9158 m .70928 .89744 L .69064 .90212 L p F P
0 0 0 r
s
.115 0 .563 r
.69064 .90212 m .69152 .92044 L .71026 .9158 L p F P
0 0 0 r
s
.188 0 .528 r
.18611 .51204 m .18792 .4959 L .17593 .48462 L p F P
0 0 0 r
s
.188 0 .528 r
.1778 .46861 m .17593 .48462 L .18792 .4959 L p F P
0 0 0 r
s
.188 0 .528 r
.33321 .97149 m .33423 .9529 L .32318 .94457 L p F P
0 0 0 r
s
.188 0 .528 r
.32427 .9261 m .32318 .94457 L .33423 .9529 L p F P
0 0 0 r
s
.134 0 .891 r
.68796 .25412 m .69668 .26687 L .71535 .25998 L p F P
0 0 0 r
s
.134 0 .891 r
.69668 .26687 m .68796 .25412 L .66933 .26104 L p F P
0 0 0 r
s
.125 0 .956 r
.39078 1.0265 m .38147 1.02874 L .37071 1.0209 L p F P
0 0 0 r
s
.134 0 .891 r
.12523 .25412 m .13755 .26687 L .15427 .25998 L p F P
0 0 0 r
s
.125 0 .956 r
.35319 1.02516 m .37071 1.0209 L .38147 1.02874 L p F P
0 0 0 r
s
.134 0 .891 r
.13755 .26687 m .12523 .25412 L .10855 .26104 L p F P
0 0 0 r
s
.115 0 .563 r
.65579 .96669 m .6551 .94805 L .63664 .95255 L p F P
0 0 0 r
s
.115 0 .563 r
.63664 .95255 m .63723 .97115 L .65579 .96669 L p F P
0 0 0 r
s
.195 0 .31 r
.88866 .52557 m .88671 .50924 L .89417 .52036 L p F P
0 0 0 r
s
.195 0 .31 r
.89417 .52036 m .89614 .53665 L .88866 .52557 L p F P
0 0 0 r
s
.195 0 .31 r
.83928 .37135 m .8376 .35585 L .84537 .36795 L p F P
0 0 0 r
s
.195 0 .31 r
.84537 .36795 m .84708 .38341 L .83928 .37135 L p F P
0 0 0 r
s
.115 0 .563 r
.6013 1.0176 m .6009 .99869 L .58262 1.00301 L p F P
0 0 0 r
s
.115 0 .563 r
.58262 1.00301 m .58292 1.02188 L .6013 1.0176 L p F P
0 0 0 r
s
.195 0 .31 r
.93803 .67979 m .93582 .66264 L .94296 .67278 L p F P
0 0 0 r
s
.195 0 .31 r
.94296 .67278 m .9452 .68988 L .93803 .67979 L p F P
0 0 0 r
s
.134 0 .891 r
.42961 .25358 m .43998 .26634 L .45776 .25945 L p F P
0 0 0 r
s
.134 0 .891 r
.43998 .26634 m .42961 .25358 L .41187 .26051 L p F P
0 0 0 r
s
.134 0 .891 r
.17111 .25305 m .18315 .26581 L .20004 .25892 L p F P
0 0 0 r
s
.134 0 .891 r
.18315 .26581 m .17111 .25305 L .15427 .25998 L p F P
0 0 0 r
s
.134 0 .891 r
.73415 .25305 m .74258 .26581 L .76142 .25892 L p F P
0 0 0 r
s
.134 0 .891 r
.74258 .26581 m .73415 .25305 L .71535 .25998 L p F P
0 0 0 r
s
0 .647 .956 r
.42719 1.02809 m .41673 1.02024 L p .43934 1.01959 L F P
0 0 0 r
s
0 .647 .956 r
.43934 1.01959 m .44493 1.02385 L .42719 1.02809 L p F P
0 0 0 r
s
0 .647 .956 r
.39904 1.0245 m .41673 1.02024 L .42719 1.02809 L p F P
0 0 0 r
s
.115 0 .563 r
.91041 .73528 m .90835 .71788 L .88901 .72318 L p F P
0 0 0 r
s
.115 0 .563 r
.88901 .72318 m .89095 .74055 L .91041 .73528 L p F P
0 0 0 r
s
.188 0 .528 r
.17593 .48462 m .1778 .46861 L .16573 .45715 L p F P
0 0 0 r
s
.188 0 .528 r
.16765 .44127 m .16573 .45715 L .1778 .46861 L p F P
0 0 0 r
s
.134 0 .891 r
.47567 .25251 m .48576 .26528 L .5037 .25838 L p F P
0 0 0 r
s
.134 0 .891 r
.48576 .26528 m .47567 .25251 L .45776 .25945 L p F P
0 0 0 r
s
.188 0 .528 r
.12684 .33131 m .12897 .31611 L .11659 .30367 L p F P
0 0 0 r
s
.188 0 .528 r
.11878 .28861 m .11659 .30367 L .12897 .31611 L p F P
0 0 0 r
s
.188 0 .528 r
.2741 .79125 m .27544 .77361 L .264 .76411 L p F P
0 0 0 r
s
.188 0 .528 r
.2654 .74659 m .264 .76411 L .27544 .77361 L p F P
0 0 0 r
s
.188 0 .528 r
.22501 .63794 m .22662 .62111 L .21486 .61063 L p F P
0 0 0 r
s
.188 0 .528 r
.21653 .59393 m .21486 .61063 L .22662 .62111 L p F P
0 0 0 r
s
.115 0 .563 r
.85595 .78616 m .85419 .76848 L .83502 .77361 L p F P
0 0 0 r
s
.115 0 .563 r
.83502 .77361 m .83668 .79125 L .85595 .78616 L p F P
0 0 0 r
s
.188 0 .528 r
.32318 .94457 m .32427 .9261 L .31314 .91759 L p F P
0 0 0 r
s
.188 0 .528 r
.31427 .89925 m .31314 .91759 L .32427 .9261 L p F P
0 0 0 r
s
.115 0 .563 r
.80147 .83706 m .79999 .8191 L .78101 .82406 L p F P
0 0 0 r
s
.115 0 .563 r
.78101 .82406 m .78238 .84198 L .80147 .83706 L p F P
0 0 0 r
s
.134 0 .891 r
.21705 .25198 m .22879 .26475 L .24585 .25785 L p F P
0 0 0 r
s
.134 0 .891 r
.22879 .26475 m .21705 .25198 L .20004 .25892 L p F P
0 0 0 r
s
.134 0 .891 r
.78038 .25198 m .78853 .26475 L .80753 .25785 L p F P
0 0 0 r
s
.134 0 .891 r
.78853 .26475 m .78038 .25198 L .76142 .25892 L p F P
0 0 0 r
s
0 .647 .956 r
.47297 1.02744 m .46371 1.02028 L .48524 1.01877 L p F P
0 0 0 r
s
0 .647 .956 r
.48524 1.01877 m .49088 1.02319 L .47297 1.02744 L p F P
0 0 0 r
s
.195 0 .31 r
.92859 .65237 m .92643 .63534 L .93364 .64567 L p F P
0 0 0 r
s
.195 0 .31 r
.93364 .64567 m .93582 .66264 L .92859 .65237 L p F P
0 0 0 r
s
.195 0 .31 r
.87916 .49798 m .87727 .48178 L .88479 .49309 L p F P
0 0 0 r
s
.195 0 .31 r
.88479 .49309 m .88671 .50924 L .87916 .49798 L p F P
0 0 0 r
s
.195 0 .31 r
.82973 .34359 m .8281 .32822 L .83594 .34051 L p F P
0 0 0 r
s
.195 0 .31 r
.83594 .34051 m .8376 .35585 L .82973 .34359 L p F P
0 0 0 r
s
.115 0 .563 r
.74695 .88799 m .74577 .86976 L .72697 .87454 L p F P
0 0 0 r
s
.115 0 .563 r
.72697 .87454 m .72805 .89274 L .74695 .88799 L p F P
0 0 0 r
s
.134 0 .891 r
.52178 .25144 m .53158 .26422 L .54969 .25732 L p F P
0 0 0 r
s
.134 0 .891 r
.53158 .26422 m .52178 .25144 L .5037 .25838 L p F P
0 0 0 r
s
.134 0 .891 r
.26303 .2509 m .27449 .26369 L .29172 .25679 L p F P
0 0 0 r
s
.134 0 .891 r
.27449 .26369 m .26303 .2509 L .24585 .25785 L p F P
0 0 0 r
s
.115 0 .563 r
.6924 .93895 m .69152 .92044 L .6729 .92504 L p F P
0 0 0 r
s
.115 0 .563 r
.6729 .92504 m .67369 .94352 L .6924 .93895 L p F P
0 0 0 r
s
.125 0 .956 r
.5188 1.02679 m .51808 1.02622 L .53685 1.02252 L p F P
0 0 0 r
s
.125 0 .956 r
.53685 1.02252 m .53688 1.02254 L .5188 1.02679 L p F P
0 0 0 r
s
0 .647 .956 r
.39904 1.0245 m .39078 1.0265 L .37622 1.01956 L p F P
0 0 0 r
s
.125 0 .956 r
.37071 1.0209 m .37622 1.01956 L .39078 1.0265 L p F P
0 0 0 r
s
.134 0 .891 r
.56794 .25037 m .57745 .26316 L .59573 .25625 L p F P
0 0 0 r
s
.134 0 .891 r
.57745 .26316 m .56794 .25037 L .54969 .25732 L p F P
0 0 0 r
s
.188 0 .528 r
.21486 .61063 m .21653 .59393 L .20469 .58326 L p F P
0 0 0 r
s
.188 0 .528 r
.20641 .56669 m .20469 .58326 L .21653 .59393 L p F P
0 0 0 r
s
.188 0 .528 r
.11659 .30367 m .11878 .28861 L .10631 .27597 L p F P
0 0 0 r
s
.188 0 .528 r
.10855 .26104 m .10631 .27597 L .11878 .28861 L p F P
0 0 0 r
s
.188 0 .528 r
.264 .76411 m .2654 .74659 L .25388 .73691 L p F P
0 0 0 r
s
.188 0 .528 r
.25534 .71951 m .25388 .73691 L .2654 .74659 L p F P
0 0 0 r
s
.115 0 .563 r
.63783 .98994 m .63723 .97115 L .6188 .97558 L p F P
0 0 0 r
s
.115 0 .563 r
.6188 .97558 m .6193 .99433 L .63783 .98994 L p F P
0 0 0 r
s
.188 0 .528 r
.16573 .45715 m .16765 .44127 L .1555 .42962 L p F P
0 0 0 r
s
.188 0 .528 r
.15748 .41387 m .1555 .42962 L .16765 .44127 L p F P
0 0 0 r
s
.188 0 .528 r
.31314 .91759 m .31427 .89925 L .30307 .89055 L p F P
0 0 0 r
s
.188 0 .528 r
.30426 .87234 m .30307 .89055 L .31427 .89925 L p F P
0 0 0 r
s
0 .647 .956 r
.52708 1.01461 m .53685 1.02252 L .51808 1.02622 L p F P
0 0 0 r
s
0 .647 .956 r
.51808 1.02622 m .50891 1.01892 L .52708 1.01461 L p F P
0 0 0 r
s
.115 0 .563 r
.94745 .70716 m .9452 .68988 L .92569 .69529 L p F P
0 0 0 r
s
.115 0 .563 r
.92569 .69529 m .92784 .71254 L .94745 .70716 L p F P
0 0 0 r
s
.134 0 .891 r
.30907 .24983 m .32023 .26263 L .33763 .25572 L p F P
0 0 0 r
s
.134 0 .891 r
.32023 .26263 m .30907 .24983 L .29172 .25679 L p F P
0 0 0 r
s
.125 0 .956 r
.56467 1.02614 m .55551 1.01861 L .57417 1.01458 L p F P
0 0 0 r
s
.125 0 .956 r
.57417 1.01458 m .58292 1.02188 L .56467 1.02614 L p F P
0 0 0 r
s
.134 0 .891 r
.61415 .24929 m .62337 .2621 L .64182 .25519 L p F P
0 0 0 r
s
.134 0 .891 r
.62337 .2621 m .61415 .24929 L .59573 .25625 L p F P
0 0 0 r
s
.195 0 .31 r
.91913 .62488 m .91702 .60799 L .92429 .6185 L p F P
0 0 0 r
s
.195 0 .31 r
.92429 .6185 m .92643 .63534 L .91913 .62488 L p F P
0 0 0 r
s
.195 0 .31 r
.86965 .47033 m .8678 .45426 L .87539 .46576 L p F P
0 0 0 r
s
.195 0 .31 r
.87539 .46576 m .87727 .48178 L .86965 .47033 L p F P
0 0 0 r
s
.195 0 .31 r
.82017 .31577 m .81859 .30054 L .82649 .31302 L p F P
0 0 0 r
s
.195 0 .31 r
.82649 .31302 m .8281 .32822 L .82017 .31577 L p F P
0 0 0 r
s
.115 0 .563 r
.89292 .75811 m .89095 .74055 L .87163 .74579 L p F P
0 0 0 r
s
.115 0 .563 r
.87163 .74579 m .87349 .76331 L .89292 .75811 L p F P
0 0 0 r
s
.115 0 .563 r
.83835 .80909 m .83668 .79125 L .81754 .79631 L p F P
0 0 0 r
s
.115 0 .563 r
.81754 .79631 m .81911 .81411 L .83835 .80909 L p F P
0 0 0 r
s
.134 0 .891 r
.35515 .24876 m .36603 .26157 L .38359 .25465 L p F P
0 0 0 r
s
.134 0 .891 r
.36603 .26157 m .35515 .24876 L .33763 .25572 L p F P
0 0 0 r
s
.188 0 .528 r
.1555 .42962 m .15748 .41387 L .14525 .40203 L p F P
0 0 0 r
s
.188 0 .528 r
.14729 .38641 m .14525 .40203 L .15748 .41387 L p F P
0 0 0 r
s
.1 0 .485 r
.10631 .27597 m .10855 .26104 L .12523 .25412 L p F P
0 0 0 r
s
.134 0 .891 r
.66041 .24822 m .66933 .26104 L .68796 .25412 L p F P
0 0 0 r
s
.134 0 .891 r
.66933 .26104 m .66041 .24822 L .64182 .25519 L p F P
0 0 0 r
s
.115 0 .563 r
.78376 .8601 m .78238 .84198 L .76342 .84686 L p F P
0 0 0 r
s
.115 0 .563 r
.76342 .84686 m .7647 .86494 L .78376 .8601 L p F P
0 0 0 r
s
.188 0 .528 r
.34321 .99835 m .34222 1.01727 L .35319 1.02516 L p F P
0 0 0 r
s
.125 0 .956 r
.37071 1.0209 m .35319 1.02516 L .34222 1.01727 L p F P
0 0 0 r
s
.188 0 .528 r
.25388 .73691 m .25534 .71951 L .24374 .70965 L p F P
0 0 0 r
s
.188 0 .528 r
.24525 .69238 m .24374 .70965 L .25534 .71951 L p F P
0 0 0 r
s
.188 0 .528 r
.20469 .58326 m .20641 .56669 L .19449 .55584 L p F P
0 0 0 r
s
.188 0 .528 r
.19627 .53939 m .19449 .55584 L .20641 .56669 L p F P
0 0 0 r
s
.188 0 .528 r
.30307 .89055 m .30426 .87234 L .29298 .86346 L p F P
0 0 0 r
s
.188 0 .528 r
.29423 .84537 m .29298 .86346 L .30426 .87234 L p F P
0 0 0 r
s
.134 0 .891 r
.40128 .24768 m .41187 .26051 L .42961 .25358 L p F P
0 0 0 r
s
.134 0 .891 r
.41187 .26051 m .40128 .24768 L .38359 .25465 L p F P
0 0 0 r
s
.115 0 .563 r
.72914 .91113 m .72805 .89274 L .70928 .89744 L p F P
0 0 0 r
s
.115 0 .563 r
.70928 .89744 m .71026 .9158 L .72914 .91113 L p F P
0 0 0 r
s
.134 0 .891 r
.14201 .24714 m .15427 .25998 L .17111 .25305 L p F P
0 0 0 r
s
.134 0 .891 r
.15427 .25998 m .14201 .24714 L .12523 .25412 L p F P
0 0 0 r
s
0 .647 .956 r
.39904 1.0245 m .38836 1.0166 L p .4081 1.01376 L F P
0 0 0 r
s
0 .647 .956 r
.4081 1.01376 m .41673 1.02024 L .39904 1.0245 L p F P
0 0 0 r
s
0 .647 .956 r
.37622 1.01956 m .38836 1.0166 L .39904 1.0245 L p F P
0 0 0 r
s
.195 0 .31 r
.90965 .59734 m .90758 .58058 L .91493 .59127 L p F P
0 0 0 r
s
.195 0 .31 r
.91493 .59127 m .91702 .60799 L .90965 .59734 L p F P
0 0 0 r
s
.195 0 .31 r
.81058 .28789 m .80905 .27279 L .81702 .28546 L p F P
0 0 0 r
s
.195 0 .31 r
.81702 .28546 m .81859 .30054 L .81058 .28789 L p F P
0 0 0 r
s
.134 0 .891 r
.70672 .24714 m .71535 .25998 L .73415 .25305 L p F P
0 0 0 r
s
.134 0 .891 r
.71535 .25998 m .70672 .24714 L .68796 .25412 L p F P
0 0 0 r
s
.115 0 .563 r
.67448 .96219 m .67369 .94352 L .6551 .94805 L p F P
0 0 0 r
s
.115 0 .563 r
.6551 .94805 m .65579 .96669 L .67448 .96219 L p F P
0 0 0 r
s
.195 0 .31 r
.86011 .44262 m .85832 .42668 L .86598 .43837 L p F P
0 0 0 r
s
.195 0 .31 r
.86598 .43837 m .8678 .45426 L .86011 .44262 L p F P
0 0 0 r
s
.134 0 .891 r
.44746 .2466 m .45776 .25945 L .47567 .25251 L p F P
0 0 0 r
s
.134 0 .891 r
.45776 .25945 m .44746 .2466 L .42961 .25358 L p F P
0 0 0 r
s
.115 0 .563 r
.6198 1.01328 m .6193 .99433 L .6009 .99869 L p F P
0 0 0 r
s
.115 0 .563 r
.6009 .99869 m .6013 1.0176 L .6198 1.01328 L p F P
0 0 0 r
s
.134 0 .891 r
.18807 .24606 m .20004 .25892 L .21705 .25198 L p F P
0 0 0 r
s
.134 0 .891 r
.20004 .25892 m .18807 .24606 L .17111 .25305 L p F P
0 0 0 r
s
.188 0 .528 r
.19449 .55584 m .19627 .53939 L .18428 .52835 L p F P
0 0 0 r
s
.188 0 .528 r
.18611 .51204 m .18428 .52835 L .19627 .53939 L p F P
0 0 0 r
s
.188 0 .528 r
.14525 .40203 m .14729 .38641 L .13498 .37438 L p F P
0 0 0 r
s
.188 0 .528 r
.13708 .35889 m .13498 .37438 L .14729 .38641 L p F P
0 0 0 r
s
0 .647 .956 r
.44493 1.02385 m .45948 1.02037 L .46371 1.02028 L p F P
0 0 0 r
s
0 .647 .956 r
.45948 1.02037 m .44493 1.02385 L .43934 1.01959 L closepath p F P
0 0 0 r
s
.188 0 .528 r
.34222 1.01727 m .34321 .99835 L .33217 .99028 L p F P
0 0 0 r
s
.188 0 .528 r
.33321 .97149 m .33217 .99028 L .34321 .99835 L p F P
0 0 0 r
s
.188 0 .528 r
.29298 .86346 m .29423 .84537 L .28287 .8363 L p F P
0 0 0 r
s
.188 0 .528 r
.28417 .81834 m .28287 .8363 L .29423 .84537 L p F P
0 0 0 r
s
.188 0 .528 r
.24374 .70965 m .24525 .69238 L .23357 .68233 L p F P
0 0 0 r
s
.188 0 .528 r
.23514 .66519 m .23357 .68233 L .24525 .69238 L p F P
0 0 0 r
s
.115 0 .563 r
.93 .72997 m .92784 .71254 L .90835 .71788 L p F P
0 0 0 r
s
.115 0 .563 r
.90835 .71788 m .91041 .73528 L .93 .72997 L p F P
0 0 0 r
s
.134 0 .891 r
.75308 .24606 m .76142 .25892 L .78038 .25198 L p F P
0 0 0 r
s
.134 0 .891 r
.76142 .25892 m .75308 .24606 L .73415 .25305 L p F P
0 0 0 r
s
.134 0 .891 r
.4937 .24552 m .5037 .25838 L .52178 .25144 L p F P
0 0 0 r
s
.134 0 .891 r
.5037 .25838 m .4937 .24552 L .47567 .25251 L p F P
0 0 0 r
s
.115 0 .563 r
.87536 .78103 m .87349 .76331 L .85419 .76848 L p F P
0 0 0 r
s
.115 0 .563 r
.85419 .76848 m .85595 .78616 L .87536 .78103 L p F P
0 0 0 r
s
.115 0 .563 r
.82069 .83211 m .81911 .81411 L .79999 .8191 L p F P
0 0 0 r
s
.115 0 .563 r
.79999 .8191 m .80147 .83706 L .82069 .83211 L p F P
0 0 0 r
s
.134 0 .891 r
.23418 .24499 m .24585 .25785 L .26303 .2509 L p F P
0 0 0 r
s
.134 0 .891 r
.24585 .25785 m .23418 .24499 L .21705 .25198 L p F P
0 0 0 r
s
0 .647 .956 r
.49088 1.02319 m .48524 1.01877 L .50571 1.01637 L p F P
0 0 0 r
s
0 .647 .956 r
.50571 1.01637 m .50891 1.01892 L .49088 1.02319 L p F P
0 0 0 r
s
.195 0 .31 r
.90015 .56974 m .89813 .5531 L .90554 .56399 L p F P
0 0 0 r
s
.195 0 .31 r
.90554 .56399 m .90758 .58058 L .90015 .56974 L p F P
0 0 0 r
s
.195 0 .31 r
.85056 .41484 m .84881 .39904 L .85654 .41092 L p F P
0 0 0 r
s
.195 0 .31 r
.85654 .41092 m .85832 .42668 L .85056 .41484 L p F P
0 0 0 r
s
.134 0 .891 r
.80753 .25785 m .79949 .24499 L .78038 .25198 L p F P
0 0 0 r
s
.195 0 .31 r
.80097 .25995 m .79949 .24499 L .80753 .25785 L p F P
0 0 0 r
s
.195 0 .31 r
.80753 .25785 m .80905 .27279 L .80097 .25995 L p F P
0 0 0 r
s
.134 0 .891 r
.53998 .24445 m .54969 .25732 L .56794 .25037 L p F P
0 0 0 r
s
.134 0 .891 r
.54969 .25732 m .53998 .24445 L .52178 .25144 L p F P
0 0 0 r
s
.115 0 .563 r
.76599 .88322 m .7647 .86494 L .74577 .86976 L p F P
0 0 0 r
s
.115 0 .563 r
.74577 .86976 m .74695 .88799 L .76599 .88322 L p F P
0 0 0 r
s
.134 0 .891 r
.28033 .24391 m .29172 .25679 L .30907 .24983 L p F P
0 0 0 r
s
.134 0 .891 r
.29172 .25679 m .28033 .24391 L .26303 .2509 L p F P
0 0 0 r
s
.188 0 .528 r
.23357 .68233 m .23514 .66519 L .22339 .65495 L p F P
0 0 0 r
s
.188 0 .528 r
.22501 .63794 m .22339 .65495 L .23514 .66519 L p F P
0 0 0 r
s
.188 0 .528 r
.18428 .52835 m .18611 .51204 L .17404 .50081 L p F P
0 0 0 r
s
.188 0 .528 r
.17593 .48462 m .17404 .50081 L .18611 .51204 L p F P
0 0 0 r
s
.188 0 .528 r
.13498 .37438 m .13708 .35889 L .12469 .34667 L p F P
0 0 0 r
s
.188 0 .528 r
.12684 .33131 m .12469 .34667 L .13708 .35889 L p F P
0 0 0 r
s
.125 0 .956 r
.53688 1.02254 m .53767 1.02235 L .55551 1.01861 L p F P
0 0 0 r
s
.125 0 .956 r
.53767 1.02235 m .53688 1.02254 L .53685 1.02252 L closepath p F P
0 0 0 r
s
.188 0 .528 r
.28287 .8363 m .28417 .81834 L .27274 .80909 L p F P
0 0 0 r
s
.188 0 .528 r
.2741 .79125 m .27274 .80909 L .28417 .81834 L p F P
0 0 0 r
s
.115 0 .563 r
.71125 .93436 m .71026 .9158 L .69152 .92044 L p F P
0 0 0 r
s
.115 0 .563 r
.69152 .92044 m .6924 .93895 L .71125 .93436 L p F P
0 0 0 r
s
.188 0 .528 r
.33217 .99028 m .33321 .97149 L .32209 .96323 L p F P
0 0 0 r
s
.188 0 .528 r
.32318 .94457 m .32209 .96323 L .33321 .97149 L p F P
0 0 0 r
s
0 .647 .956 r
.55508 1.01826 m .53767 1.02235 L .53685 1.02252 L p F P
0 0 0 r
s
0 .647 .956 r
.54536 1.01028 m .55508 1.01826 L p .53685 1.02252 L F P
0 0 0 r
s
0 .647 .956 r
.53685 1.02252 m .52708 1.01461 L .54536 1.01028 L p F P
0 0 0 r
s
0 .647 .956 r
.53767 1.02235 m .55508 1.01826 L .55551 1.01861 L closepath p F P
0 0 0 r
s
.134 0 .891 r
.58631 .24337 m .59573 .25625 L .61415 .24929 L p F P
0 0 0 r
s
.134 0 .891 r
.59573 .25625 m .58631 .24337 L .56794 .25037 L p F P
0 0 0 r
s
.115 0 .563 r
.65649 .98552 m .65579 .96669 L .63723 .97115 L p F P
0 0 0 r
s
.115 0 .563 r
.63723 .97115 m .63783 .98994 L .65649 .98552 L p F P
0 0 0 r
s
.134 0 .891 r
.32653 .24282 m .33763 .25572 L .35515 .24876 L p F P
0 0 0 r
s
.134 0 .891 r
.33763 .25572 m .32653 .24282 L .30907 .24983 L p F P
0 0 0 r
s
.125 0 .956 r
.58292 1.02188 m .57417 1.01458 L .59287 1.01045 L p F P
0 0 0 r
s
.125 0 .956 r
.59287 1.01045 m .6013 1.0176 L .58292 1.02188 L p F P
0 0 0 r
s
.195 0 .31 r
.94027 .69713 m .93803 .67979 L .9452 .68988 L p F P
0 0 0 r
s
.195 0 .31 r
.9452 .68988 m .94745 .70716 L .94027 .69713 L p F P
0 0 0 r
s
.195 0 .31 r
.89062 .54207 m .88866 .52557 L .89614 .53665 L p F P
0 0 0 r
s
.195 0 .31 r
.89614 .53665 m .89813 .5531 L .89062 .54207 L p F P
0 0 0 r
s
.195 0 .31 r
.84098 .38701 m .83928 .37135 L .84708 .38341 L p F P
0 0 0 r
s
.195 0 .31 r
.84708 .38341 m .84881 .39904 L .84098 .38701 L p F P
0 0 0 r
s
.134 0 .891 r
.63269 .24228 m .64182 .25519 L .66041 .24822 L p F P
0 0 0 r
s
.134 0 .891 r
.64182 .25519 m .63269 .24228 L .61415 .24929 L p F P
0 0 0 r
s
.115 0 .563 r
.91249 .75287 m .91041 .73528 L .89095 .74055 L p F P
0 0 0 r
s
.115 0 .563 r
.89095 .74055 m .89292 .75811 L .91249 .75287 L p F P
0 0 0 r
s
.188 0 .528 r
.22339 .65495 m .22501 .63794 L .21318 .62751 L p F P
0 0 0 r
s
.188 0 .528 r
.21486 .61063 m .21318 .62751 L .22501 .63794 L p F P
0 0 0 r
s
.188 0 .528 r
.17404 .50081 m .17593 .48462 L .16378 .4732 L p F P
0 0 0 r
s
.188 0 .528 r
.16573 .45715 m .16378 .4732 L .17593 .48462 L p F P
0 0 0 r
s
.188 0 .528 r
.12469 .34667 m .12684 .33131 L .11438 .3189 L p F P
0 0 0 r
s
.188 0 .528 r
.11659 .30367 m .11438 .3189 L .12684 .33131 L p F P
0 0 0 r
s
.188 0 .528 r
.27274 .80909 m .2741 .79125 L .26258 .78182 L p F P
0 0 0 r
s
.188 0 .528 r
.264 .76411 m .26258 .78182 L .2741 .79125 L p F P
0 0 0 r
s
.115 0 .563 r
.85774 .80403 m .85595 .78616 L .83668 .79125 L p F P
0 0 0 r
s
.115 0 .563 r
.83668 .79125 m .83835 .80909 L .85774 .80403 L p F P
0 0 0 r
s
.134 0 .891 r
.37279 .24174 m .38359 .25465 L .40128 .24768 L p F P
0 0 0 r
s
.134 0 .891 r
.38359 .25465 m .37279 .24174 L .35515 .24876 L p F P
0 0 0 r
s
.188 0 .528 r
.32209 .96323 m .32318 .94457 L .31199 .93613 L p F P
0 0 0 r
s
.188 0 .528 r
.31314 .91759 m .31199 .93613 L .32318 .94457 L p F P
0 0 0 r
s
.1 0 .485 r
.12306 .26906 m .12523 .25412 L .14201 .24714 L p F P
0 0 0 r
s
.1 0 .485 r
.12523 .25412 m .12306 .26906 L .10631 .27597 L p F P
0 0 0 r
s
.115 0 .563 r
.80296 .85522 m .80147 .83706 L .78238 .84198 L p F P
0 0 0 r
s
.115 0 .563 r
.78238 .84198 m .78376 .8601 L .80296 .85522 L p F P
0 0 0 r
s
.125 0 .956 r
.37622 1.01956 m .37071 1.0209 L .35982 1.01295 L p F P
0 0 0 r
s
.125 0 .956 r
.34222 1.01727 m .35982 1.01295 L .37071 1.0209 L p F P
0 0 0 r
s
.134 0 .891 r
.67912 .2412 m .68796 .25412 L .70672 .24714 L p F P
0 0 0 r
s
.134 0 .891 r
.68796 .25412 m .67912 .2412 L .66041 .24822 L p F P
0 0 0 r
s
.195 0 .31 r
.88108 .51435 m .87916 .49798 L .88671 .50924 L p F P
0 0 0 r
s
.195 0 .31 r
.88671 .50924 m .88866 .52557 L .88108 .51435 L p F P
0 0 0 r
s
.134 0 .891 r
.41909 .24066 m .42961 .25358 L .44746 .2466 L p F P
0 0 0 r
s
.134 0 .891 r
.42961 .25358 m .41909 .24066 L .40128 .24768 L p F P
0 0 0 r
s
.195 0 .31 r
.93078 .66958 m .92859 .65237 L .93582 .66264 L p F P
0 0 0 r
s
.195 0 .31 r
.93582 .66264 m .93803 .67979 L .93078 .66958 L p F P
0 0 0 r
s
.195 0 .31 r
.83138 .35912 m .82973 .34359 L .8376 .35585 L p F P
0 0 0 r
s
.195 0 .31 r
.8376 .35585 m .83928 .37135 L .83138 .35912 L p F P
0 0 0 r
s
.115 0 .563 r
.74814 .90643 m .74695 .88799 L .72805 .89274 L p F P
0 0 0 r
s
.115 0 .563 r
.72805 .89274 m .72914 .91113 L .74814 .90643 L p F P
0 0 0 r
s
0 .78 .71 r
.4628 1.01958 m .45948 1.02037 L .43934 1.01959 L p F P
0 0 0 r
s
0 .78 .71 r
.45948 1.02037 m .4628 1.01958 L .46371 1.02028 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.48079 1.01528 m .48524 1.01877 L .46371 1.02028 L p F P
0 0 0 r
s
0 .78 .71 r
.46371 1.02028 m .4628 1.01958 L .48079 1.01528 L p F P
0 0 0 r
s
.134 0 .891 r
.15892 .24012 m .17111 .25305 L .18807 .24606 L p F P
0 0 0 r
s
.134 0 .891 r
.17111 .25305 m .15892 .24012 L .14201 .24714 L p F P
0 0 0 r
s
0 .647 .956 r
.41673 1.02024 m .42635 1.01792 L .43934 1.01959 L p F P
0 0 0 r
s
0 .647 .956 r
.42635 1.01792 m .41673 1.02024 L .4081 1.01376 L closepath p F P
0 0 0 r
s
.134 0 .891 r
.72561 .24012 m .73415 .25305 L .75308 .24606 L p F P
0 0 0 r
s
.134 0 .891 r
.73415 .25305 m .72561 .24012 L .70672 .24714 L p F P
0 0 0 r
s
.115 0 .563 r
.6933 .95767 m .6924 .93895 L .67369 .94352 L p F P
0 0 0 r
s
.115 0 .563 r
.67369 .94352 m .67448 .96219 L .6933 .95767 L p F P
0 0 0 r
s
.188 0 .528 r
.26258 .78182 m .264 .76411 L .25241 .75449 L p F P
0 0 0 r
s
.188 0 .528 r
.25388 .73691 m .25241 .75449 L .264 .76411 L p F P
0 0 0 r
s
.188 0 .528 r
.21318 .62751 m .21486 .61063 L .20295 .60002 L p F P
0 0 0 r
s
.188 0 .528 r
.20469 .58326 m .20295 .60002 L .21486 .61063 L p F P
0 0 0 r
s
.188 0 .528 r
.16378 .4732 m .16573 .45715 L .1535 .44554 L p F P
0 0 0 r
s
.188 0 .528 r
.1555 .42962 m .1535 .44554 L .16573 .45715 L p F P
0 0 0 r
s
.188 0 .528 r
.11438 .3189 m .11659 .30367 L .10404 .29107 L p F P
0 0 0 r
s
.188 0 .528 r
.10631 .27597 m .10404 .29107 L .11659 .30367 L p F P
0 0 0 r
s
.134 0 .891 r
.46545 .23958 m .47567 .25251 L .4937 .24552 L p F P
0 0 0 r
s
.134 0 .891 r
.47567 .25251 m .46545 .23958 L .44746 .2466 L p F P
0 0 0 r
s
.115 0 .563 r
.63843 1.00894 m .63783 .98994 L .6193 .99433 L p F P
0 0 0 r
s
.115 0 .563 r
.6193 .99433 m .6198 1.01328 L .63843 1.00894 L p F P
0 0 0 r
s
.188 0 .528 r
.31199 .93613 m .31314 .91759 L .30186 .90896 L p F P
0 0 0 r
s
.188 0 .528 r
.30307 .89055 m .30186 .90896 L .31314 .91759 L p F P
0 0 0 r
s
0 .78 .71 r
.45249 1.01161 m .4628 1.01958 L p .43934 1.01959 L F P
0 0 0 r
s
0 .78 .71 r
.43934 1.01959 m .43455 1.01594 L .45249 1.01161 L p F P
0 0 0 r
s
0 .78 .71 r
.42635 1.01792 m .43455 1.01594 L .43934 1.01959 L closepath p F P
0 0 0 r
s
.134 0 .891 r
.20515 .23903 m .21705 .25198 L .23418 .24499 L p F P
0 0 0 r
s
.134 0 .891 r
.21705 .25198 m .20515 .23903 L .18807 .24606 L p F P
0 0 0 r
s
0 .78 .71 r
.48079 1.01528 m .4628 1.01958 L .45249 1.01161 L p F P
0 0 0 r
s
.115 0 .563 r
.94974 .72463 m .94745 .70716 L .92784 .71254 L p F P
0 0 0 r
s
.115 0 .563 r
.92784 .71254 m .93 .72997 L .94974 .72463 L p F P
0 0 0 r
s
.134 0 .891 r
.77214 .23903 m .78038 .25198 L .79949 .24499 L p F P
0 0 0 r
s
.134 0 .891 r
.78038 .25198 m .77214 .23903 L .75308 .24606 L p F P
0 0 0 r
s
0 .647 .956 r
.38836 1.0166 m .37622 1.01956 L .36285 1.01221 L p F P
0 0 0 r
s
.125 0 .956 r
.35982 1.01295 m .36285 1.01221 L .37622 1.01956 L p F P
0 0 0 r
s
.134 0 .891 r
.51185 .23849 m .52178 .25144 L .53998 .24445 L p F P
0 0 0 r
s
.134 0 .891 r
.52178 .25144 m .51185 .23849 L .4937 .24552 L p F P
0 0 0 r
s
.195 0 .31 r
.92127 .64196 m .91913 .62488 L .92643 .63534 L p F P
0 0 0 r
s
.195 0 .31 r
.92643 .63534 m .92859 .65237 L .92127 .64196 L p F P
0 0 0 r
s
.195 0 .31 r
.82176 .33117 m .82017 .31577 L .8281 .32822 L p F P
0 0 0 r
s
.195 0 .31 r
.8281 .32822 m .82973 .34359 L .82176 .33117 L p F P
0 0 0 r
s
.115 0 .563 r
.8949 .77586 m .89292 .75811 L .87349 .76331 L p F P
0 0 0 r
s
.115 0 .563 r
.87349 .76331 m .87536 .78103 L .8949 .77586 L p F P
0 0 0 r
s
.195 0 .31 r
.87151 .48657 m .86965 .47033 L .87727 .48178 L p F P
0 0 0 r
s
.195 0 .31 r
.87727 .48178 m .87916 .49798 L .87151 .48657 L p F P
0 0 0 r
s
.115 0 .563 r
.84004 .82712 m .83835 .80909 L .81911 .81411 L p F P
0 0 0 r
s
.115 0 .563 r
.81911 .81411 m .82069 .83211 L .84004 .82712 L p F P
0 0 0 r
s
.134 0 .891 r
.25142 .23795 m .26303 .2509 L .28033 .24391 L p F P
0 0 0 r
s
.134 0 .891 r
.26303 .2509 m .25142 .23795 L .23418 .24499 L p F P
0 0 0 r
s
0 .647 .956 r
.50891 1.01892 m .50571 1.01637 L .52558 1.01341 L p F P
0 0 0 r
s
0 .647 .956 r
.52558 1.01341 m .52708 1.01461 L .50891 1.01892 L p F P
0 0 0 r
s
0 .78 .71 r
.4989 1.01095 m .50571 1.01637 L .48524 1.01877 L p F P
0 0 0 r
s
0 .78 .71 r
.48524 1.01877 m .48079 1.01528 L .4989 1.01095 L p F P
0 0 0 r
s
0 .647 .956 r
.57341 1.01395 m .57417 1.01458 L .55551 1.01861 L p F P
0 0 0 r
s
0 .647 .956 r
.55551 1.01861 m .55508 1.01826 L .57341 1.01395 L p F P
0 0 0 r
s
.188 0 .528 r
.25241 .75449 m .25388 .73691 L .24221 .7271 L p F P
0 0 0 r
s
.188 0 .528 r
.24374 .70965 m .24221 .7271 L .25388 .73691 L p F P
0 0 0 r
s
.1 0 .485 r
.10404 .29107 m .10631 .27597 L .12306 .26906 L p F P
0 0 0 r
s
.134 0 .891 r
.55831 .2374 m .56794 .25037 L .58631 .24337 L p F P
0 0 0 r
s
.134 0 .891 r
.56794 .25037 m .55831 .2374 L .53998 .24445 L p F P
0 0 0 r
s
.115 0 .563 r
.78516 .87841 m .78376 .8601 L .7647 .86494 L p F P
0 0 0 r
s
.115 0 .563 r
.7647 .86494 m .76599 .88322 L .78516 .87841 L p F P
0 0 0 r
s
.188 0 .528 r
.1535 .44554 m .1555 .42962 L .14319 .41782 L p F P
0 0 0 r
s
.188 0 .528 r
.14525 .40203 m .14319 .41782 L .1555 .42962 L p F P
0 0 0 r
s
.188 0 .528 r
.30186 .90896 m .30307 .89055 L .29172 .88174 L p F P
0 0 0 r
s
.188 0 .528 r
.29298 .86346 m .29172 .88174 L .30307 .89055 L p F P
0 0 0 r
s
.188 0 .528 r
.20295 .60002 m .20469 .58326 L .1927 .57246 L p F P
0 0 0 r
s
.188 0 .528 r
.19449 .55584 m .1927 .57246 L .20469 .58326 L p F P
0 0 0 r
s
.134 0 .891 r
.29775 .23686 m .30907 .24983 L .32653 .24282 L p F P
0 0 0 r
s
.134 0 .891 r
.30907 .24983 m .29775 .23686 L .28033 .24391 L p F P
0 0 0 r
s
.115 0 .563 r
.73024 .92973 m .72914 .91113 L .71026 .9158 L p F P
0 0 0 r
s
.115 0 .563 r
.71026 .9158 m .71125 .93436 L .73024 .92973 L p F P
0 0 0 r
s
0 .647 .956 r
.55508 1.01826 m .54536 1.01028 L p .56435 1.00638 L F P
0 0 0 r
s
0 .647 .956 r
.56435 1.00638 m .57341 1.01395 L .55508 1.01826 L p F P
0 0 0 r
s
.134 0 .891 r
.60481 .23631 m .61415 .24929 L .63269 .24228 L p F P
0 0 0 r
s
.134 0 .891 r
.61415 .24929 m .60481 .23631 L .58631 .24337 L p F P
0 0 0 r
s
.195 0 .31 r
.91173 .61429 m .90965 .59734 L .91702 .60799 L p F P
0 0 0 r
s
.195 0 .31 r
.91702 .60799 m .91913 .62488 L .91173 .61429 L p F P
0 0 0 r
s
.195 0 .31 r
.86193 .45872 m .86011 .44262 L .8678 .45426 L p F P
0 0 0 r
s
.195 0 .31 r
.8678 .45426 m .86965 .47033 L .86193 .45872 L p F P
0 0 0 r
s
.195 0 .31 r
.81212 .30315 m .81058 .28789 L .81859 .30054 L p F P
0 0 0 r
s
.195 0 .31 r
.81859 .30054 m .82017 .31577 L .81212 .30315 L p F P
0 0 0 r
s
.115 0 .563 r
.67529 .98107 m .67448 .96219 L .65579 .96669 L p F P
0 0 0 r
s
.115 0 .563 r
.65579 .96669 m .65649 .98552 L .67529 .98107 L p F P
0 0 0 r
s
0 .78 .71 r
.43455 1.01594 m .42635 1.01792 L .4081 1.01376 L p F P
0 0 0 r
s
.134 0 .891 r
.34413 .23577 m .35515 .24876 L .37279 .24174 L p F P
0 0 0 r
s
.134 0 .891 r
.35515 .24876 m .34413 .23577 L .32653 .24282 L p F P
0 0 0 r
s
.125 0 .956 r
.6013 1.0176 m .59287 1.01045 L .61163 1.00624 L p F P
0 0 0 r
s
.125 0 .956 r
.61163 1.00624 m .6198 1.01328 L .6013 1.0176 L p F P
0 0 0 r
s
.188 0 .528 r
.24221 .7271 m .24374 .70965 L .23199 .69965 L p F P
0 0 0 r
s
.188 0 .528 r
.23357 .68233 m .23199 .69965 L .24374 .70965 L p F P
0 0 0 r
s
.188 0 .528 r
.1927 .57246 m .19449 .55584 L .18243 .54484 L p F P
0 0 0 r
s
.188 0 .528 r
.18428 .52835 m .18243 .54484 L .19449 .55584 L p F P
0 0 0 r
s
.188 0 .528 r
.14319 .41782 m .14525 .40203 L .13286 .39003 L p F P
0 0 0 r
s
.188 0 .528 r
.13498 .37438 m .13286 .39003 L .14525 .40203 L p F P
0 0 0 r
s
.134 0 .891 r
.65137 .23523 m .66041 .24822 L .67912 .2412 L p F P
0 0 0 r
s
.134 0 .891 r
.66041 .24822 m .65137 .23523 L .63269 .24228 L p F P
0 0 0 r
s
.188 0 .528 r
.33217 .99028 m .33111 1.00927 L .34222 1.01727 L p F P
0 0 0 r
s
.125 0 .956 r
.35982 1.01295 m .34222 1.01727 L .33111 1.00927 L p F P
0 0 0 r
s
.115 0 .563 r
.93219 .7476 m .93 .72997 L .91041 .73528 L p F P
0 0 0 r
s
.115 0 .563 r
.91041 .73528 m .91249 .75287 L .93219 .7476 L p F P
0 0 0 r
s
.188 0 .528 r
.29172 .88174 m .29298 .86346 L .28155 .85446 L p F P
0 0 0 r
s
.188 0 .528 r
.28287 .8363 m .28155 .85446 L .29298 .86346 L p F P
0 0 0 r
s
.134 0 .891 r
.39055 .23468 m .40128 .24768 L .41909 .24066 L p F P
0 0 0 r
s
.134 0 .891 r
.40128 .24768 m .39055 .23468 L .37279 .24174 L p F P
0 0 0 r
s
.115 0 .563 r
.87726 .79894 m .87536 .78103 L .85595 .78616 L p F P
0 0 0 r
s
.115 0 .563 r
.85595 .78616 m .85774 .80403 L .87726 .79894 L p F P
0 0 0 r
s
.1 0 .485 r
.13994 .2621 m .14201 .24714 L .15892 .24012 L p F P
0 0 0 r
s
.1 0 .485 r
.14201 .24714 m .13994 .2621 L .12306 .26906 L p F P
0 0 0 r
s
.115 0 .563 r
.82229 .8503 m .82069 .83211 L .80147 .83706 L p F P
0 0 0 r
s
.115 0 .563 r
.80147 .83706 m .80296 .85522 L .82229 .8503 L p F P
0 0 0 r
s
0 .647 .956 r
.38836 1.0166 m .40455 1.01267 L .4081 1.01376 L p F P
0 0 0 r
s
0 .647 .956 r
.40455 1.01267 m .38836 1.0166 L .37755 1.0086 L p F P
0 0 0 r
s
0 .647 .956 r
.36285 1.01221 m .37755 1.0086 L .38836 1.0166 L p F P
0 0 0 r
s
.195 0 .31 r
.90218 .58655 m .90015 .56974 L .90758 .58058 L p F P
0 0 0 r
s
.195 0 .31 r
.90758 .58058 m .90965 .59734 L .90218 .58655 L p F P
0 0 0 r
s
.195 0 .31 r
.80246 .27508 m .80097 .25995 L .80905 .27279 L p F P
0 0 0 r
s
.195 0 .31 r
.80905 .27279 m .81058 .28789 L .80246 .27508 L p F P
0 0 0 r
s
.134 0 .891 r
.69797 .23414 m .70672 .24714 L .72561 .24012 L p F P
0 0 0 r
s
.134 0 .891 r
.70672 .24714 m .69797 .23414 L .67912 .2412 L p F P
0 0 0 r
s
.195 0 .31 r
.85232 .43082 m .85056 .41484 L .85832 .42668 L p F P
0 0 0 r
s
.195 0 .31 r
.85832 .42668 m .86011 .44262 L .85232 .43082 L p F P
0 0 0 r
s
0 .78 .71 r
.51715 1.00658 m .52558 1.01341 L .50571 1.01637 L p F P
0 0 0 r
s
0 .78 .71 r
.50571 1.01637 m .4989 1.01095 L .51715 1.00658 L p F P
0 0 0 r
s
.134 0 .891 r
.43703 .23359 m .44746 .2466 L .46545 .23958 L p F P
0 0 0 r
s
.134 0 .891 r
.44746 .2466 m .43703 .23359 L .41909 .24066 L p F P
0 0 0 r
s
.115 0 .563 r
.76729 .90169 m .76599 .88322 L .74695 .88799 L p F P
0 0 0 r
s
.115 0 .563 r
.74695 .88799 m .74814 .90643 L .76729 .90169 L p F P
0 0 0 r
s
.134 0 .891 r
.17595 .23304 m .18807 .24606 L .20515 .23903 L p F P
0 0 0 r
s
.134 0 .891 r
.18807 .24606 m .17595 .23304 L .15892 .24012 L p F P
0 0 0 r
s
.188 0 .528 r
.13286 .39003 m .13498 .37438 L .12251 .36219 L p F P
0 0 0 r
s
.188 0 .528 r
.12469 .34667 m .12251 .36219 L .13498 .37438 L p F P
0 0 0 r
s
0 .78 .71 r
.45249 1.01161 m .43455 1.01594 L .42403 1.00793 L p F P
0 0 0 r
s
0 .78 .71 r
.42403 1.00793 m .43455 1.01594 L p .4081 1.01376 L F P
0 0 0 r
s
.188 0 .528 r
.28155 .85446 m .28287 .8363 L .27136 .82712 L p F P
0 0 0 r
s
.188 0 .528 r
.27274 .80909 m .27136 .82712 L .28287 .8363 L p F P
0 0 0 r
s
.188 0 .528 r
.23199 .69965 m .23357 .68233 L .22175 .67215 L p F P
0 0 0 r
s
.188 0 .528 r
.22339 .65495 m .22175 .67215 L .23357 .68233 L p F P
0 0 0 r
s
.134 0 .891 r
.74463 .23304 m .75308 .24606 L .77214 .23903 L p F P
0 0 0 r
s
.134 0 .891 r
.75308 .24606 m .74463 .23304 L .72561 .24012 L p F P
0 0 0 r
s
.115 0 .563 r
.71226 .95311 m .71125 .93436 L .6924 .93895 L p F P
0 0 0 r
s
.115 0 .563 r
.6924 .93895 m .6933 .95767 L .71226 .95311 L p F P
0 0 0 r
s
.188 0 .528 r
.18243 .54484 m .18428 .52835 L .17213 .51717 L p F P
0 0 0 r
s
.188 0 .528 r
.17404 .50081 m .17213 .51717 L .18428 .52835 L p F P
0 0 0 r
s
.188 0 .528 r
.33111 1.00927 m .33217 .99028 L .32098 .9821 L p F P
0 0 0 r
s
.188 0 .528 r
.32209 .96323 m .32098 .9821 L .33217 .99028 L p F P
0 0 0 r
s
.134 0 .891 r
.48356 .2325 m .4937 .24552 L .51185 .23849 L p F P
0 0 0 r
s
.134 0 .891 r
.4937 .24552 m .48356 .2325 L .46545 .23958 L p F P
0 0 0 r
s
.115 0 .563 r
.6572 1.00456 m .65649 .98552 L .63783 .98994 L p F P
0 0 0 r
s
.115 0 .563 r
.63783 .98994 m .63843 1.00894 L .6572 1.00456 L p F P
0 0 0 r
s
.134 0 .891 r
.22235 .23195 m .23418 .24499 L .25142 .23795 L p F P
0 0 0 r
s
.134 0 .891 r
.23418 .24499 m .22235 .23195 L .20515 .23903 L p F P
0 0 0 r
s
0 .78 .71 r
.48079 1.01528 m .47056 1.00726 L p .4908 1.00449 L F P
0 0 0 r
s
0 .78 .71 r
.4908 1.00449 m .4989 1.01095 L .48079 1.01528 L p F P
0 0 0 r
s
0 .78 .71 r
.45249 1.01161 m .47056 1.00726 L .48079 1.01528 L p F P
0 0 0 r
s
.134 0 .891 r
.79949 .24499 m .79134 .23195 L .77214 .23903 L p F P
0 0 0 r
s
.195 0 .31 r
.79278 .24694 m .79134 .23195 L .79949 .24499 L p F P
0 0 0 r
s
.195 0 .31 r
.79949 .24499 m .80097 .25995 L .79278 .24694 L p F P
0 0 0 r
s
.195 0 .31 r
.94252 .71466 m .94027 .69713 L .94745 .70716 L p F P
0 0 0 r
s
.195 0 .31 r
.94745 .70716 m .94974 .72463 L .94252 .71466 L p F P
0 0 0 r
s
.195 0 .31 r
.89261 .55876 m .89062 .54207 L .89813 .5531 L p F P
0 0 0 r
s
.195 0 .31 r
.89813 .5531 m .90015 .56974 L .89261 .55876 L p F P
0 0 0 r
s
.195 0 .31 r
.84269 .40285 m .84098 .38701 L .84881 .39904 L p F P
0 0 0 r
s
.195 0 .31 r
.84881 .39904 m .85056 .41484 L .84269 .40285 L p F P
0 0 0 r
s
.134 0 .891 r
.53014 .2314 m .53998 .24445 L .55831 .2374 L p F P
0 0 0 r
s
.134 0 .891 r
.53998 .24445 m .53014 .2314 L .51185 .23849 L p F P
0 0 0 r
s
.115 0 .563 r
.91459 .77066 m .91249 .75287 L .89292 .75811 L p F P
0 0 0 r
s
.115 0 .563 r
.89292 .75811 m .8949 .77586 L .91459 .77066 L p F P
0 0 0 r
s
.188 0 .528 r
.17213 .51717 m .17404 .50081 L .16181 .48943 L p F P
0 0 0 r
s
.188 0 .528 r
.16378 .4732 m .16181 .48943 L .17404 .50081 L p F P
0 0 0 r
s
.134 0 .891 r
.26879 .23086 m .28033 .24391 L .29775 .23686 L p F P
0 0 0 r
s
.134 0 .891 r
.28033 .24391 m .26879 .23086 L .25142 .23795 L p F P
0 0 0 r
s
.188 0 .528 r
.27136 .82712 m .27274 .80909 L .26115 .79972 L p F P
0 0 0 r
s
.188 0 .528 r
.26258 .78182 m .26115 .79972 L .27274 .80909 L p F P
0 0 0 r
s
.188 0 .528 r
.22175 .67215 m .22339 .65495 L .21148 .64458 L p F P
0 0 0 r
s
.188 0 .528 r
.21318 .62751 m .21148 .64458 L .22339 .65495 L p F P
0 0 0 r
s
.188 0 .528 r
.12251 .36219 m .12469 .34667 L .11214 .33429 L p F P
0 0 0 r
s
.188 0 .528 r
.11438 .3189 m .11214 .33429 L .12469 .34667 L p F P
0 0 0 r
s
0 .647 .956 r
.52708 1.01461 m .52558 1.01341 L .5451 1.01006 L p F P
0 0 0 r
s
0 .647 .956 r
.5451 1.01006 m .54536 1.01028 L .52708 1.01461 L p F P
0 0 0 r
s
.115 0 .563 r
.85954 .8221 m .85774 .80403 L .83835 .80909 L p F P
0 0 0 r
s
.115 0 .563 r
.83835 .80909 m .84004 .82712 L .85954 .8221 L p F P
0 0 0 r
s
.188 0 .528 r
.32098 .9821 m .32209 .96323 L .31082 .95487 L p F P
0 0 0 r
s
.188 0 .528 r
.31199 .93613 m .31082 .95487 L .32209 .96323 L p F P
0 0 0 r
s
0 .647 .956 r
.59187 1.00961 m .59287 1.01045 L .57417 1.01458 L p F P
0 0 0 r
s
0 .647 .956 r
.57417 1.01458 m .57341 1.01395 L .59187 1.00961 L p F P
0 0 0 r
s
.1 0 .485 r
.12088 .28417 m .12306 .26906 L .13994 .2621 L p F P
0 0 0 r
s
.1 0 .485 r
.12306 .26906 m .12088 .28417 L .10404 .29107 L p F P
0 0 0 r
s
.134 0 .891 r
.57676 .23031 m .58631 .24337 L .60481 .23631 L p F P
0 0 0 r
s
.134 0 .891 r
.58631 .24337 m .57676 .23031 L .55831 .2374 L p F P
0 0 0 r
s
.115 0 .563 r
.80446 .87357 m .80296 .85522 L .78376 .8601 L p F P
0 0 0 r
s
.115 0 .563 r
.78376 .8601 m .78516 .87841 L .80446 .87357 L p F P
0 0 0 r
s
.134 0 .891 r
.31529 .22976 m .32653 .24282 L .34413 .23577 L p F P
0 0 0 r
s
.134 0 .891 r
.32653 .24282 m .31529 .22976 L .29775 .23686 L p F P
0 0 0 r
s
.195 0 .31 r
.88301 .5309 m .88108 .51435 L .88866 .52557 L p F P
0 0 0 r
s
.195 0 .31 r
.88866 .52557 m .89062 .54207 L .88301 .5309 L p F P
0 0 0 r
s
.195 0 .31 r
.83305 .37482 m .83138 .35912 L .83928 .37135 L p F P
0 0 0 r
s
.195 0 .31 r
.83928 .37135 m .84098 .38701 L .83305 .37482 L p F P
0 0 0 r
s
0 .647 .956 r
.57341 1.01395 m .56435 1.00638 L .58347 1.00248 L p F P
0 0 0 r
s
0 .647 .956 r
.58347 1.00248 m .59187 1.00961 L .57341 1.01395 L p F P
0 0 0 r
s
.195 0 .31 r
.93298 .68698 m .93078 .66958 L .93803 .67979 L p F P
0 0 0 r
s
.195 0 .31 r
.93803 .67979 m .94027 .69713 L .93298 .68698 L p F P
0 0 0 r
s
.115 0 .563 r
.74935 .92506 m .74814 .90643 L .72914 .91113 L p F P
0 0 0 r
s
.115 0 .563 r
.72914 .91113 m .73024 .92973 L .74935 .92506 L p F P
0 0 0 r
s
0 .78 .71 r
.4081 1.01376 m .40613 1.01228 L .42403 1.00793 L p F P
0 0 0 r
s
0 .78 .71 r
.40455 1.01267 m .40613 1.01228 L .4081 1.01376 L closepath p F P
0 0 0 r
s
.134 0 .891 r
.62344 .22921 m .63269 .24228 L .65137 .23523 L p F P
0 0 0 r
s
.134 0 .891 r
.63269 .24228 m .62344 .22921 L .60481 .23631 L p F P
0 0 0 r
s
.115 0 .563 r
.69421 .97659 m .6933 .95767 L .67448 .96219 L p F P
0 0 0 r
s
.115 0 .563 r
.67448 .96219 m .67529 .98107 L .69421 .97659 L p F P
0 0 0 r
s
0 .78 .71 r
.53552 1.00219 m .5451 1.01006 L .52558 1.01341 L p F P
0 0 0 r
s
0 .78 .71 r
.52558 1.01341 m .51715 1.00658 L .53552 1.00219 L p F P
0 0 0 r
s
.188 0 .528 r
.21148 .64458 m .21318 .62751 L .2012 .61695 L p F P
0 0 0 r
s
.188 0 .528 r
.20295 .60002 m .2012 .61695 L .21318 .62751 L p F P
0 0 0 r
s
.188 0 .528 r
.11214 .33429 m .11438 .3189 L .10175 .30632 L p F P
0 0 0 r
s
.188 0 .528 r
.10404 .29107 m .10175 .30632 L .11438 .3189 L p F P
0 0 0 r
s
.188 0 .528 r
.26115 .79972 m .26258 .78182 L .25092 .77226 L p F P
0 0 0 r
s
.188 0 .528 r
.25241 .75449 m .25092 .77226 L .26258 .78182 L p F P
0 0 0 r
s
.134 0 .891 r
.36184 .22867 m .37279 .24174 L .39055 .23468 L p F P
0 0 0 r
s
.134 0 .891 r
.37279 .24174 m .36184 .22867 L .34413 .23577 L p F P
0 0 0 r
s
.125 0 .956 r
.6198 1.01328 m .61163 1.00624 L .63046 1.00195 L p F P
0 0 0 r
s
.125 0 .956 r
.63046 1.00195 m .63843 1.00894 L .6198 1.01328 L p F P
0 0 0 r
s
.188 0 .528 r
.16181 .48943 m .16378 .4732 L .15147 .46164 L p F P
0 0 0 r
s
.188 0 .528 r
.1535 .44554 m .15147 .46164 L .16378 .4732 L p F P
0 0 0 r
s
.188 0 .528 r
.31082 .95487 m .31199 .93613 L .30064 .92758 L p F P
0 0 0 r
s
.188 0 .528 r
.30186 .90896 m .30064 .92758 L .31199 .93613 L p F P
0 0 0 r
s
.125 0 .956 r
.36285 1.01221 m .35982 1.01295 L .34879 1.0049 L p F P
0 0 0 r
s
.125 0 .956 r
.33111 1.00927 m .34879 1.0049 L .35982 1.01295 L p F P
0 0 0 r
s
.134 0 .891 r
.67017 .22812 m .67912 .2412 L .69797 .23414 L p F P
0 0 0 r
s
.134 0 .891 r
.67912 .2412 m .67017 .22812 L .65137 .23523 L p F P
0 0 0 r
s
.115 0 .563 r
.95204 .74229 m .94974 .72463 L .93 .72997 L p F P
0 0 0 r
s
.115 0 .563 r
.93 .72997 m .93219 .7476 L .95204 .74229 L p F P
0 0 0 r
s
0 .78 .71 r
.40613 1.01228 m .40455 1.01267 L .38754 1.00615 L p F P
0 0 0 r
s
0 .647 .956 r
.37755 1.0086 m .38754 1.00615 L .40455 1.01267 L p F P
0 0 0 r
s
.195 0 .31 r
.82338 .34674 m .82176 .33117 L .82973 .34359 L p F P
0 0 0 r
s
.195 0 .31 r
.82973 .34359 m .83138 .35912 L .82338 .34674 L p F P
0 0 0 r
s
.195 0 .31 r
.92342 .65923 m .92127 .64196 L .92859 .65237 L p F P
0 0 0 r
s
.195 0 .31 r
.92859 .65237 m .93078 .66958 L .92342 .65923 L p F P
0 0 0 r
s
.195 0 .31 r
.8734 .50298 m .87151 .48657 L .87916 .49798 L p F P
0 0 0 r
s
.195 0 .31 r
.87916 .49798 m .88108 .51435 L .8734 .50298 L p F P
0 0 0 r
s
.115 0 .563 r
.89691 .79381 m .8949 .77586 L .87536 .78103 L p F P
0 0 0 r
s
.115 0 .563 r
.87536 .78103 m .87726 .79894 L .89691 .79381 L p F P
0 0 0 r
s
.134 0 .891 r
.40844 .22757 m .41909 .24066 L .43703 .23359 L p F P
0 0 0 r
s
.134 0 .891 r
.41909 .24066 m .40844 .22757 L .39055 .23468 L p F P
0 0 0 r
s
.1 0 .485 r
.15693 .25509 m .15892 .24012 L .17595 .23304 L p F P
0 0 0 r
s
.1 0 .485 r
.15892 .24012 m .15693 .25509 L .13994 .2621 L p F P
0 0 0 r
s
.115 0 .563 r
.84175 .84535 m .84004 .82712 L .82069 .83211 L p F P
0 0 0 r
s
.115 0 .563 r
.82069 .83211 m .82229 .8503 L .84175 .84535 L p F P
0 0 0 r
s
0 .78 .71 r
.42403 1.00793 m .40613 1.01228 L .3954 1.00422 L p F P
0 0 0 r
s
0 .78 .71 r
.38754 1.00615 m .3954 1.00422 L .40613 1.01228 L p F P
0 0 0 r
s
.134 0 .891 r
.71695 .22702 m .72561 .24012 L .74463 .23304 L p F P
0 0 0 r
s
.134 0 .891 r
.72561 .24012 m .71695 .22702 L .69797 .23414 L p F P
0 0 0 r
s
0 .647 .956 r
.37755 1.0086 m .36285 1.01221 L .35009 1.00458 L p F P
0 0 0 r
s
.125 0 .956 r
.34879 1.0049 m .35009 1.00458 L .36285 1.01221 L p F P
0 0 0 r
s
.134 0 .891 r
.45509 .22647 m .46545 .23958 L .48356 .2325 L p F P
0 0 0 r
s
.134 0 .891 r
.46545 .23958 m .45509 .22647 L .43703 .23359 L p F P
0 0 0 r
s
.1 0 .485 r
.10175 .30632 m .10404 .29107 L .12088 .28417 L p F P
0 0 0 r
s
.188 0 .528 r
.15147 .46164 m .1535 .44554 L .14111 .43378 L p F P
0 0 0 r
s
.188 0 .528 r
.14319 .41782 m .14111 .43378 L .1535 .44554 L p F P
0 0 0 r
s
.188 0 .528 r
.25092 .77226 m .25241 .75449 L .24066 .74475 L p F P
0 0 0 r
s
.188 0 .528 r
.24221 .7271 m .24066 .74475 L .25241 .75449 L p F P
0 0 0 r
s
.115 0 .563 r
.78657 .89692 m .78516 .87841 L .76599 .88322 L p F P
0 0 0 r
s
.115 0 .563 r
.76599 .88322 m .76729 .90169 L .78657 .89692 L p F P
0 0 0 r
s
.188 0 .528 r
.2012 .61695 m .20295 .60002 L .19089 .58926 L p F P
0 0 0 r
s
.188 0 .528 r
.1927 .57246 m .19089 .58926 L .20295 .60002 L p F P
0 0 0 r
s
.188 0 .528 r
.30064 .92758 m .30186 .90896 L .29044 .90023 L p F P
0 0 0 r
s
.188 0 .528 r
.29172 .88174 m .29044 .90023 L .30186 .90896 L p F P
0 0 0 r
s
.134 0 .891 r
.19309 .22592 m .20515 .23903 L .22235 .23195 L p F P
0 0 0 r
s
.134 0 .891 r
.20515 .23903 m .19309 .22592 L .17595 .23304 L p F P
0 0 0 r
s
0 .78 .71 r
.45249 1.01161 m .44205 1.00354 L p .46775 1.00505 L F P
0 0 0 r
s
0 .78 .71 r
.46775 1.00505 m .47056 1.00726 L .45249 1.01161 L p F P
0 0 0 r
s
0 .78 .71 r
.42403 1.00793 m .44205 1.00354 L .45249 1.01161 L p F P
0 0 0 r
s
.134 0 .891 r
.76379 .22592 m .77214 .23903 L .79134 .23195 L p F P
0 0 0 r
s
.134 0 .891 r
.77214 .23903 m .76379 .22592 L .74463 .23304 L p F P
0 0 0 r
s
.115 0 .563 r
.73135 .94852 m .73024 .92973 L .71125 .93436 L p F P
0 0 0 r
s
.115 0 .563 r
.71125 .93436 m .71226 .95311 L .73135 .94852 L p F P
0 0 0 r
s
.195 0 .31 r
.91384 .63142 m .91173 .61429 L .91913 .62488 L p F P
0 0 0 r
s
.195 0 .31 r
.91913 .62488 m .92127 .64196 L .91384 .63142 L p F P
0 0 0 r
s
.195 0 .31 r
.81369 .31859 m .81212 .30315 L .82017 .31577 L p F P
0 0 0 r
s
.195 0 .31 r
.82017 .31577 m .82176 .33117 L .81369 .31859 L p F P
0 0 0 r
s
.134 0 .891 r
.5018 .22537 m .51185 .23849 L .53014 .2314 L p F P
0 0 0 r
s
.134 0 .891 r
.51185 .23849 m .5018 .22537 L .48356 .2325 L p F P
0 0 0 r
s
.115 0 .563 r
.6761 1.00015 m .67529 .98107 L .65649 .98552 L p F P
0 0 0 r
s
.115 0 .563 r
.65649 .98552 m .6572 1.00456 L .6761 1.00015 L p F P
0 0 0 r
s
.195 0 .31 r
.86376 .475 m .86193 .45872 L .86965 .47033 L p F P
0 0 0 r
s
.195 0 .31 r
.86965 .47033 m .87151 .48657 L .86376 .475 L p F P
0 0 0 r
s
.134 0 .891 r
.23966 .22482 m .25142 .23795 L .26879 .23086 L p F P
0 0 0 r
s
.134 0 .891 r
.25142 .23795 m .23966 .22482 L .22235 .23195 L p F P
0 0 0 r
s
0 .78 .71 r
.4989 1.01095 m .4908 1.00449 L .51221 1.00259 L p F P
0 0 0 r
s
0 .78 .71 r
.51221 1.00259 m .51715 1.00658 L .4989 1.01095 L p F P
0 0 0 r
s
.134 0 .891 r
.54855 .22427 m .55831 .2374 L .57676 .23031 L p F P
0 0 0 r
s
.134 0 .891 r
.55831 .2374 m .54855 .22427 L .53014 .2314 L p F P
0 0 0 r
s
.188 0 .528 r
.19089 .58926 m .1927 .57246 L .18055 .56152 L p F P
0 0 0 r
s
.188 0 .528 r
.18243 .54484 m .18055 .56152 L .1927 .57246 L p F P
0 0 0 r
s
.188 0 .528 r
.24066 .74475 m .24221 .7271 L .23039 .71717 L p F P
0 0 0 r
s
.188 0 .528 r
.23199 .69965 m .23039 .71717 L .24221 .7271 L p F P
0 0 0 r
s
.115 0 .563 r
.93441 .76542 m .93219 .7476 L .91249 .75287 L p F P
0 0 0 r
s
.115 0 .563 r
.91249 .75287 m .91459 .77066 L .93441 .76542 L p F P
0 0 0 r
s
.188 0 .528 r
.14111 .43378 m .14319 .41782 L .13072 .40586 L p F P
0 0 0 r
s
.188 0 .528 r
.13286 .39003 m .13072 .40586 L .14319 .41782 L p F P
0 0 0 r
s
.188 0 .528 r
.29044 .90023 m .29172 .88174 L .28022 .87282 L p F P
0 0 0 r
s
.188 0 .528 r
.28155 .85446 m .28022 .87282 L .29172 .88174 L p F P
0 0 0 r
s
0 .647 .956 r
.61046 1.00523 m .61163 1.00624 L .59287 1.01045 L p F P
0 0 0 r
s
0 .647 .956 r
.59287 1.01045 m .59187 1.00961 L .61046 1.00523 L p F P
0 0 0 r
s
.134 0 .891 r
.28629 .22372 m .29775 .23686 L .31529 .22976 L p F P
0 0 0 r
s
.134 0 .891 r
.29775 .23686 m .28629 .22372 L .26879 .23086 L p F P
0 0 0 r
s
.115 0 .563 r
.87917 .81704 m .87726 .79894 L .85774 .80403 L p F P
0 0 0 r
s
.115 0 .563 r
.85774 .80403 m .85954 .8221 L .87917 .81704 L p F P
0 0 0 r
s
0 .647 .956 r
.54536 1.01028 m .55049 1.00906 L .56435 1.00638 L p F P
0 0 0 r
s
0 .647 .956 r
.55049 1.00906 m .54536 1.01028 L .5451 1.01006 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.56378 1.00591 m .55049 1.00906 L .5451 1.01006 L p F P
0 0 0 r
s
0 .78 .71 r
.55402 .99777 m .56378 1.00591 L p .5451 1.01006 L F P
0 0 0 r
s
0 .78 .71 r
.5451 1.01006 m .53552 1.00219 L .55402 .99777 L p F P
0 0 0 r
s
.1 0 .485 r
.13783 .27723 m .13994 .2621 L .15693 .25509 L p F P
0 0 0 r
s
.1 0 .485 r
.13994 .2621 m .13783 .27723 L .12088 .28417 L p F P
0 0 0 r
s
.195 0 .31 r
.80397 .29037 m .80246 .27508 L .81058 .28789 L p F P
0 0 0 r
s
.195 0 .31 r
.81058 .28789 m .81212 .30315 L .80397 .29037 L p F P
0 0 0 r
s
.195 0 .31 r
.90424 .60355 m .90218 .58655 L .90965 .59734 L p F P
0 0 0 r
s
.195 0 .31 r
.90965 .59734 m .91173 .61429 L .90424 .60355 L p F P
0 0 0 r
s
.195 0 .31 r
.85411 .44696 m .85232 .43082 L .86011 .44262 L p F P
0 0 0 r
s
.195 0 .31 r
.86011 .44262 m .86193 .45872 L .85411 .44696 L p F P
0 0 0 r
s
.134 0 .891 r
.59535 .22317 m .60481 .23631 L .62344 .22921 L p F P
0 0 0 r
s
.134 0 .891 r
.60481 .23631 m .59535 .22317 L .57676 .23031 L p F P
0 0 0 r
s
.115 0 .563 r
.8239 .86869 m .82229 .8503 L .80296 .85522 L p F P
0 0 0 r
s
.115 0 .563 r
.80296 .85522 m .80446 .87357 L .8239 .86869 L p F P
0 0 0 r
s
.134 0 .891 r
.33296 .22262 m .34413 .23577 L .36184 .22867 L p F P
0 0 0 r
s
.134 0 .891 r
.34413 .23577 m .33296 .22262 L .31529 .22976 L p F P
0 0 0 r
s
.115 0 .563 r
.7686 .92037 m .76729 .90169 L .74814 .90643 L p F P
0 0 0 r
s
.115 0 .563 r
.74814 .90643 m .74935 .92506 L .7686 .92037 L p F P
0 0 0 r
s
0 .647 .956 r
.59187 1.00961 m .58347 1.00248 L .60255 .99841 L p F P
0 0 0 r
s
0 .647 .956 r
.60255 .99841 m .61046 1.00523 L .59187 1.00961 L p F P
0 0 0 r
s
.188 0 .528 r
.13072 .40586 m .13286 .39003 L .12031 .37789 L p F P
0 0 0 r
s
.188 0 .528 r
.12251 .36219 m .12031 .37789 L .13286 .39003 L p F P
0 0 0 r
s
.188 0 .528 r
.23039 .71717 m .23199 .69965 L .22009 .68953 L p F P
0 0 0 r
s
.188 0 .528 r
.22175 .67215 m .22009 .68953 L .23199 .69965 L p F P
0 0 0 r
s
.134 0 .891 r
.64221 .22206 m .65137 .23523 L .67017 .22812 L p F P
0 0 0 r
s
.134 0 .891 r
.65137 .23523 m .64221 .22206 L .62344 .22921 L p F P
0 0 0 r
s
.115 0 .563 r
.71327 .97207 m .71226 .95311 L .6933 .95767 L p F P
0 0 0 r
s
.115 0 .563 r
.6933 .95767 m .69421 .97659 L .71327 .97207 L p F P
0 0 0 r
s
.188 0 .528 r
.18055 .56152 m .18243 .54484 L .1702 .53371 L p F P
0 0 0 r
s
.188 0 .528 r
.17213 .51717 m .1702 .53371 L .18243 .54484 L p F P
0 0 0 r
s
.188 0 .528 r
.28022 .87282 m .28155 .85446 L .26997 .84535 L p F P
0 0 0 r
s
.188 0 .528 r
.27136 .82712 m .26997 .84535 L .28155 .85446 L p F P
0 0 0 r
s
.188 0 .528 r
.32098 .9821 m .31986 1.00117 L .33111 1.00927 L p F P
0 0 0 r
s
.125 0 .956 r
.34879 1.0049 m .33111 1.00927 L .31986 1.00117 L p F P
0 0 0 r
s
0 .78 .71 r
.55049 1.00906 m .56378 1.00591 L .56435 1.00638 L closepath p F P
0 0 0 r
s
.134 0 .891 r
.37969 .22151 m .39055 .23468 L .40844 .22757 L p F P
0 0 0 r
s
.134 0 .891 r
.39055 .23468 m .37969 .22151 L .36184 .22867 L p F P
0 0 0 r
s
.125 0 .956 r
.63843 1.00894 m .63046 1.00195 L .64937 .99758 L p F P
0 0 0 r
s
.125 0 .956 r
.64937 .99758 m .6572 1.00456 L .63843 1.00894 L p F P
0 0 0 r
s
0 .647 .956 r
.38754 1.00615 m .37755 1.0086 L .36659 1.00049 L p F P
0 0 0 r
s
0 .647 .956 r
.35009 1.00458 m .36659 1.00049 L .37755 1.0086 L p F P
0 0 0 r
s
.195 0 .31 r
.79424 .2621 m .79278 .24694 L .80097 .25995 L p F P
0 0 0 r
s
.195 0 .31 r
.80097 .25995 m .80246 .27508 L .79424 .2621 L p F P
0 0 0 r
s
.134 0 .891 r
.68911 .22096 m .69797 .23414 L .71695 .22702 L p F P
0 0 0 r
s
.134 0 .891 r
.69797 .23414 m .68911 .22096 L .67017 .22812 L p F P
0 0 0 r
s
.195 0 .31 r
.9448 .73238 m .94252 .71466 L .94974 .72463 L p F P
0 0 0 r
s
.195 0 .31 r
.94974 .72463 m .95204 .74229 L .9448 .73238 L p F P
0 0 0 r
s
.195 0 .31 r
.89462 .57562 m .89261 .55876 L .90015 .56974 L p F P
0 0 0 r
s
.195 0 .31 r
.90015 .56974 m .90218 .58655 L .89462 .57562 L p F P
0 0 0 r
s
.195 0 .31 r
.84443 .41886 m .84269 .40285 L .85056 .41484 L p F P
0 0 0 r
s
.195 0 .31 r
.85056 .41484 m .85232 .43082 L .84443 .41886 L p F P
0 0 0 r
s
.115 0 .563 r
.91671 .78864 m .91459 .77066 L .8949 .77586 L p F P
0 0 0 r
s
.115 0 .563 r
.8949 .77586 m .89691 .79381 L .91671 .78864 L p F P
0 0 0 r
s
.134 0 .891 r
.42646 .22041 m .43703 .23359 L .45509 .22647 L p F P
0 0 0 r
s
.134 0 .891 r
.43703 .23359 m .42646 .22041 L .40844 .22757 L p F P
0 0 0 r
s
.1 0 .485 r
.17404 .24803 m .17595 .23304 L .19309 .22592 L p F P
0 0 0 r
s
.1 0 .485 r
.17595 .23304 m .17404 .24803 L .15693 .25509 L p F P
0 0 0 r
s
.188 0 .528 r
.1702 .53371 m .17213 .51717 L .15982 .50584 L p F P
0 0 0 r
s
.188 0 .528 r
.16181 .48943 m .15982 .50584 L .17213 .51717 L p F P
0 0 0 r
s
.188 0 .528 r
.12031 .37789 m .12251 .36219 L .10988 .34985 L p F P
0 0 0 r
s
.188 0 .528 r
.11214 .33429 m .10988 .34985 L .12251 .36219 L p F P
0 0 0 r
s
.188 0 .528 r
.26997 .84535 m .27136 .82712 L .25971 .81782 L p F P
0 0 0 r
s
.188 0 .528 r
.26115 .79972 m .25971 .81782 L .27136 .82712 L p F P
0 0 0 r
s
.188 0 .528 r
.22009 .68953 m .22175 .67215 L .20976 .66183 L p F P
0 0 0 r
s
.188 0 .528 r
.21148 .64458 m .20976 .66183 L .22175 .67215 L p F P
0 0 0 r
s
0 .78 .71 r
.42403 1.00793 m .41337 .99981 L p .44176 1.00332 L F P
0 0 0 r
s
0 .78 .71 r
.44176 1.00332 m .44205 1.00354 L .42403 1.00793 L p F P
0 0 0 r
s
0 .78 .71 r
.3954 1.00422 m .41337 .99981 L .42403 1.00793 L p F P
0 0 0 r
s
.134 0 .891 r
.73607 .21985 m .74463 .23304 L .76379 .22592 L p F P
0 0 0 r
s
.134 0 .891 r
.74463 .23304 m .73607 .21985 L .71695 .22702 L p F P
0 0 0 r
s
.115 0 .563 r
.86136 .84036 m .85954 .8221 L .84004 .82712 L p F P
0 0 0 r
s
.115 0 .563 r
.84004 .82712 m .84175 .84535 L .86136 .84036 L p F P
0 0 0 r
s
.188 0 .528 r
.31986 1.00117 m .32098 .9821 L .30965 .97381 L p F P
0 0 0 r
s
.188 0 .528 r
.31082 .95487 m .30965 .97381 L .32098 .9821 L p F P
0 0 0 r
s
.134 0 .891 r
.47329 .2193 m .48356 .2325 L .5018 .22537 L p F P
0 0 0 r
s
.134 0 .891 r
.48356 .2325 m .47329 .2193 L .45509 .22647 L p F P
0 0 0 r
s
.1 0 .485 r
.11867 .29944 m .12088 .28417 L .13783 .27723 L p F P
0 0 0 r
s
.1 0 .485 r
.12088 .28417 m .11867 .29944 L .10175 .30632 L p F P
0 0 0 r
s
.115 0 .563 r
.80598 .89212 m .80446 .87357 L .78516 .87841 L p F P
0 0 0 r
s
.115 0 .563 r
.78516 .87841 m .78657 .89692 L .80598 .89212 L p F P
0 0 0 r
s
.134 0 .891 r
.21036 .21875 m .22235 .23195 L .23966 .22482 L p F P
0 0 0 r
s
.134 0 .891 r
.22235 .23195 m .21036 .21875 L .19309 .22592 L p F P
0 0 0 r
s
.195 0 .31 r
.88497 .54763 m .88301 .5309 L .89062 .54207 L p F P
0 0 0 r
s
.195 0 .31 r
.89062 .54207 m .89261 .55876 L .88497 .54763 L p F P
0 0 0 r
s
0 .78 .71 r
.47056 1.00726 m .47995 1.00499 L .4908 1.00449 L p F P
0 0 0 r
s
0 .78 .71 r
.47995 1.00499 m .47056 1.00726 L .46775 1.00505 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.93522 .70457 m .93298 .68698 L .94027 .69713 L p F P
0 0 0 r
s
.195 0 .31 r
.94027 .69713 m .94252 .71466 L .93522 .70457 L p F P
0 0 0 r
s
.195 0 .31 r
.83473 .3907 m .83305 .37482 L .84098 .38701 L p F P
0 0 0 r
s
.195 0 .31 r
.84098 .38701 m .84269 .40285 L .83473 .3907 L p F P
0 0 0 r
s
.134 0 .891 r
.79134 .23195 m .78308 .21875 L .76379 .22592 L p F P
0 0 0 r
s
.195 0 .31 r
.78449 .23377 m .78308 .21875 L .79134 .23195 L p F P
0 0 0 r
s
.195 0 .31 r
.79134 .23195 m .79278 .24694 L .78449 .23377 L p F P
0 0 0 r
s
.115 0 .563 r
.75057 .9439 m .74935 .92506 L .73024 .92973 L p F P
0 0 0 r
s
.115 0 .563 r
.73024 .92973 m .73135 .94852 L .75057 .9439 L p F P
0 0 0 r
s
.134 0 .891 r
.52016 .21819 m .53014 .2314 L .54855 .22427 L p F P
0 0 0 r
s
.134 0 .891 r
.53014 .2314 m .52016 .21819 L .5018 .22537 L p F P
0 0 0 r
s
.115 0 .563 r
.69513 .99571 m .69421 .97659 L .67529 .98107 L p F P
0 0 0 r
s
.115 0 .563 r
.67529 .98107 m .6761 1.00015 L .69513 .99571 L p F P
0 0 0 r
s
.134 0 .891 r
.25711 .21764 m .26879 .23086 L .28629 .22372 L p F P
0 0 0 r
s
.134 0 .891 r
.26879 .23086 m .25711 .21764 L .23966 .22482 L p F P
0 0 0 r
s
.188 0 .528 r
.20976 .66183 m .21148 .64458 L .19942 .63407 L p F P
0 0 0 r
s
.188 0 .528 r
.2012 .61695 m .19942 .63407 L .21148 .64458 L p F P
0 0 0 r
s
.188 0 .528 r
.15982 .50584 m .16181 .48943 L .14942 .47791 L p F P
0 0 0 r
s
.188 0 .528 r
.15147 .46164 m .14942 .47791 L .16181 .48943 L p F P
0 0 0 r
s
.188 0 .528 r
.10988 .34985 m .11214 .33429 L .09943 .32175 L p F P
0 0 0 r
s
.188 0 .528 r
.10175 .30632 m .09943 .32175 L .11214 .33429 L p F P
0 0 0 r
s
.188 0 .528 r
.25971 .81782 m .26115 .79972 L .24942 .79023 L p F P
0 0 0 r
s
.188 0 .528 r
.25092 .77226 m .24942 .79023 L .26115 .79972 L p F P
0 0 0 r
s
0 .78 .71 r
.51715 1.00658 m .51221 1.00259 L .53285 1 L p F P
0 0 0 r
s
0 .78 .71 r
.53285 1 m .53552 1.00219 L .51715 1.00658 L p F P
0 0 0 r
s
.188 0 .528 r
.30965 .97381 m .31082 .95487 L .29941 .94639 L p F P
0 0 0 r
s
.188 0 .528 r
.30064 .92758 m .29941 .94639 L .31082 .95487 L p F P
0 0 0 r
s
0 .78 .71 r
.58233 1.00151 m .58347 1.00248 L .56435 1.00638 L p F P
0 0 0 r
s
0 .78 .71 r
.56435 1.00638 m .56378 1.00591 L .58233 1.00151 L p F P
0 0 0 r
s
.134 0 .891 r
.56709 .21708 m .57676 .23031 L .59535 .22317 L p F P
0 0 0 r
s
.134 0 .891 r
.57676 .23031 m .56709 .21708 L .54855 .22427 L p F P
0 0 0 r
s
.115 0 .563 r
.95437 .76014 m .95204 .74229 L .93219 .7476 L p F P
0 0 0 r
s
.115 0 .563 r
.93219 .7476 m .93441 .76542 L .95437 .76014 L p F P
0 0 0 r
s
0 .647 .956 r
.62919 1.00083 m .63046 1.00195 L .61163 1.00624 L p F P
0 0 0 r
s
0 .647 .956 r
.61163 1.00624 m .61046 1.00523 L .62919 1.00083 L p F P
0 0 0 r
s
0 .78 .71 r
.3954 1.00422 m .38754 1.00615 L .37234 .99907 L p F P
0 0 0 r
s
0 .647 .956 r
.36659 1.00049 m .37234 .99907 L .38754 1.00615 L p F P
0 0 0 r
s
.134 0 .891 r
.3039 .21653 m .31529 .22976 L .33296 .22262 L p F P
0 0 0 r
s
.134 0 .891 r
.31529 .22976 m .3039 .21653 L .28629 .22372 L p F P
0 0 0 r
s
0 .78 .71 r
.56378 1.00591 m .55402 .99777 L p .57279 .99343 L F P
0 0 0 r
s
0 .78 .71 r
.57279 .99343 m .58233 1.00151 L .56378 1.00591 L p F P
0 0 0 r
s
.195 0 .31 r
.82501 .36247 m .82338 .34674 L .83138 .35912 L p F P
0 0 0 r
s
.195 0 .31 r
.83138 .35912 m .83305 .37482 L .82501 .36247 L p F P
0 0 0 r
s
.195 0 .31 r
.92561 .67669 m .92342 .65923 L .93078 .66958 L p F P
0 0 0 r
s
.195 0 .31 r
.93078 .66958 m .93298 .68698 L .92561 .67669 L p F P
0 0 0 r
s
.115 0 .563 r
.89894 .81195 m .89691 .79381 L .87726 .79894 L p F P
0 0 0 r
s
.115 0 .563 r
.87726 .79894 m .87917 .81704 L .89894 .81195 L p F P
0 0 0 r
s
.195 0 .31 r
.87531 .51958 m .8734 .50298 L .88108 .51435 L p F P
0 0 0 r
s
.195 0 .31 r
.88108 .51435 m .88301 .5309 L .87531 .51958 L p F P
0 0 0 r
s
.1 0 .485 r
.15491 .27023 m .15693 .25509 L .17404 .24803 L p F P
0 0 0 r
s
.1 0 .485 r
.15693 .25509 m .15491 .27023 L .13783 .27723 L p F P
0 0 0 r
s
.134 0 .891 r
.61407 .21597 m .62344 .22921 L .64221 .22206 L p F P
0 0 0 r
s
.134 0 .891 r
.62344 .22921 m .61407 .21597 L .59535 .22317 L p F P
0 0 0 r
s
.115 0 .563 r
.84348 .86378 m .84175 .84535 L .82229 .8503 L p F P
0 0 0 r
s
.115 0 .563 r
.82229 .8503 m .8239 .86869 L .84348 .86378 L p F P
0 0 0 r
s
.1 0 .485 r
.09943 .32175 m .10175 .30632 L .11867 .29944 L p F P
0 0 0 r
s
.188 0 .528 r
.24942 .79023 m .25092 .77226 L .2391 .76258 L p F P
0 0 0 r
s
.188 0 .528 r
.24066 .74475 m .2391 .76258 L .25092 .77226 L p F P
0 0 0 r
s
.134 0 .891 r
.35075 .21542 m .36184 .22867 L .37969 .22151 L p F P
0 0 0 r
s
.134 0 .891 r
.36184 .22867 m .35075 .21542 L .33296 .22262 L p F P
0 0 0 r
s
0 .647 .956 r
.61046 1.00523 m .60255 .99841 L .62163 .99421 L p F P
0 0 0 r
s
0 .647 .956 r
.62163 .99421 m .62919 1.00083 L .61046 1.00523 L p F P
0 0 0 r
s
.188 0 .528 r
.14942 .47791 m .15147 .46164 L .139 .44992 L p F P
0 0 0 r
s
.188 0 .528 r
.14111 .43378 m .139 .44992 L .15147 .46164 L p F P
0 0 0 r
s
.115 0 .563 r
.78799 .91564 m .78657 .89692 L .76729 .90169 L p F P
0 0 0 r
s
.115 0 .563 r
.76729 .90169 m .7686 .92037 L .78799 .91564 L p F P
0 0 0 r
s
.188 0 .528 r
.19942 .63407 m .2012 .61695 L .18905 .60625 L p F P
0 0 0 r
s
.188 0 .528 r
.19089 .58926 m .18905 .60625 L .2012 .61695 L p F P
0 0 0 r
s
.188 0 .528 r
.29941 .94639 m .30064 .92758 L .28915 .91892 L p F P
0 0 0 r
s
.188 0 .528 r
.29044 .90023 m .28915 .91892 L .30064 .92758 L p F P
0 0 0 r
s
0 .78 .12 r
.48876 1.00287 m .47995 1.00499 L .46775 1.00505 L p F P
0 0 0 r
s
0 .78 .12 r
.47848 .99468 m .48876 1.00287 L p .46775 1.00505 L F P
0 0 0 r
s
0 .78 .12 r
.46775 1.00505 m .4602 .99913 L .47848 .99468 L p F P
0 0 0 r
s
0 .78 .12 r
.44256 1.00342 m .4602 .99913 L .46775 1.00505 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.44205 1.00354 m .44256 1.00342 L .46775 1.00505 L p F P
0 0 0 r
s
0 .78 .12 r
.47995 1.00499 m .48876 1.00287 L .4908 1.00449 L closepath p F P
0 0 0 r
s
.134 0 .891 r
.6611 .21486 m .67017 .22812 L .68911 .22096 L p F P
0 0 0 r
s
.134 0 .891 r
.67017 .22812 m .6611 .21486 L .64221 .22206 L p F P
0 0 0 r
s
.115 0 .563 r
.73247 .96753 m .73135 .94852 L .71226 .95311 L p F P
0 0 0 r
s
.115 0 .563 r
.71226 .95311 m .71327 .97207 L .73247 .96753 L p F P
0 0 0 r
s
.125 0 .956 r
.35009 1.00458 m .34879 1.0049 L .33761 .99674 L p F P
0 0 0 r
s
.125 0 .956 r
.31986 1.00117 m .33761 .99674 L .34879 1.0049 L p F P
0 0 0 r
s
0 .647 .956 r
.36659 1.00049 m .35009 1.00458 L .33765 .99673 L p F P
0 0 0 r
s
.125 0 .956 r
.33761 .99674 m .33765 .99673 L .35009 1.00458 L p F P
0 0 0 r
s
.195 0 .31 r
.91597 .64874 m .91384 .63142 L .92127 .64196 L p F P
0 0 0 r
s
.195 0 .31 r
.92127 .64196 m .92342 .65923 L .91597 .64874 L p F P
0 0 0 r
s
.195 0 .31 r
.81527 .33419 m .81369 .31859 L .82176 .33117 L p F P
0 0 0 r
s
.195 0 .31 r
.82176 .33117 m .82338 .34674 L .81527 .33419 L p F P
0 0 0 r
s
.195 0 .31 r
.86562 .49146 m .86376 .475 L .87151 .48657 L p F P
0 0 0 r
s
.195 0 .31 r
.87151 .48657 m .8734 .50298 L .86562 .49146 L p F P
0 0 0 r
s
.134 0 .891 r
.39765 .21431 m .40844 .22757 L .42646 .22041 L p F P
0 0 0 r
s
.134 0 .891 r
.40844 .22757 m .39765 .21431 L .37969 .22151 L p F P
0 0 0 r
s
.125 0 .956 r
.6572 1.00456 m .64937 .99758 L .66837 .99314 L p F P
0 0 0 r
s
.125 0 .956 r
.66837 .99314 m .6761 1.00015 L .6572 1.00456 L p F P
0 0 0 r
s
0 .78 .12 r
.50709 .99845 m .51221 1.00259 L .4908 1.00449 L p F P
0 0 0 r
s
0 .78 .12 r
.4908 1.00449 m .48876 1.00287 L .50709 .99845 L p F P
0 0 0 r
s
0 .78 .71 r
.3954 1.00422 m .38452 .99606 L p .40781 .99557 L F P
0 0 0 r
s
0 .78 .71 r
.40781 .99557 m .41337 .99981 L .3954 1.00422 L p F P
0 0 0 r
s
0 .78 .71 r
.37234 .99907 m .38452 .99606 L .3954 1.00422 L p F P
0 0 0 r
s
.134 0 .891 r
.70819 .21375 m .71695 .22702 L .73607 .21985 L p F P
0 0 0 r
s
.134 0 .891 r
.71695 .22702 m .70819 .21375 L .68911 .22096 L p F P
0 0 0 r
s
.188 0 .528 r
.2391 .76258 m .24066 .74475 L .22877 .73487 L p F P
0 0 0 r
s
.188 0 .528 r
.23039 .71717 m .22877 .73487 L .24066 .74475 L p F P
0 0 0 r
s
.188 0 .528 r
.18905 .60625 m .19089 .58926 L .17866 .57837 L p F P
0 0 0 r
s
.188 0 .528 r
.18055 .56152 m .17866 .57837 L .19089 .58926 L p F P
0 0 0 r
s
.188 0 .528 r
.139 .44992 m .14111 .43378 L .12856 .42187 L p F P
0 0 0 r
s
.188 0 .528 r
.13072 .40586 m .12856 .42187 L .14111 .43378 L p F P
0 0 0 r
s
.115 0 .563 r
.93665 .78343 m .93441 .76542 L .91459 .77066 L p F P
0 0 0 r
s
.115 0 .563 r
.91459 .77066 m .91671 .78864 L .93665 .78343 L p F P
0 0 0 r
s
.134 0 .891 r
.44461 .21319 m .45509 .22647 L .47329 .2193 L p F P
0 0 0 r
s
.134 0 .891 r
.45509 .22647 m .44461 .21319 L .42646 .22041 L p F P
0 0 0 r
s
.188 0 .528 r
.28915 .91892 m .29044 .90023 L .27887 .89138 L p F P
0 0 0 r
s
.188 0 .528 r
.28022 .87282 m .27887 .89138 L .29044 .90023 L p F P
0 0 0 r
s
.1 0 .485 r
.19127 .24093 m .19309 .22592 L .21036 .21875 L p F P
0 0 0 r
s
.1 0 .485 r
.19309 .22592 m .19127 .24093 L .17404 .24803 L p F P
0 0 0 r
s
0 .78 .71 r
.44256 1.00342 m .44205 1.00354 L .44176 1.00332 L closepath p F P
0 0 0 r
s
.134 0 .891 r
.75532 .21264 m .76379 .22592 L .78308 .21875 L p F P
0 0 0 r
s
.134 0 .891 r
.76379 .22592 m .75532 .21264 L .73607 .21985 L p F P
0 0 0 r
s
.115 0 .563 r
.88111 .83534 m .87917 .81704 L .85954 .8221 L p F P
0 0 0 r
s
.115 0 .563 r
.85954 .8221 m .86136 .84036 L .88111 .83534 L p F P
0 0 0 r
s
0 .78 .12 r
.4602 .99913 m .44256 1.00342 L .44176 1.00332 L p F P
0 0 0 r
s
0 .78 .12 r
.44971 .9909 m .4602 .99913 L p .44176 1.00332 L F P
0 0 0 r
s
0 .78 .12 r
.44176 1.00332 m .43148 .99537 L .44971 .9909 L p F P
0 0 0 r
s
0 .78 .12 r
.4183 .9986 m .43148 .99537 L .44176 1.00332 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.41337 .99981 m .4183 .9986 L .44176 1.00332 L p F P
0 0 0 r
s
.134 0 .891 r
.49161 .21208 m .5018 .22537 L .52016 .21819 L p F P
0 0 0 r
s
.134 0 .891 r
.5018 .22537 m .49161 .21208 L .47329 .2193 L p F P
0 0 0 r
s
.1 0 .485 r
.13571 .29252 m .13783 .27723 L .15491 .27023 L p F P
0 0 0 r
s
.1 0 .485 r
.13783 .27723 m .13571 .29252 L .11867 .29944 L p F P
0 0 0 r
s
.195 0 .31 r
.90632 .62074 m .90424 .60355 L .91173 .61429 L p F P
0 0 0 r
s
.195 0 .31 r
.91173 .61429 m .91384 .63142 L .90632 .62074 L p F P
0 0 0 r
s
.195 0 .31 r
.8055 .30584 m .80397 .29037 L .81212 .30315 L p F P
0 0 0 r
s
.195 0 .31 r
.81212 .30315 m .81369 .31859 L .8055 .30584 L p F P
0 0 0 r
s
.115 0 .563 r
.82554 .88728 m .8239 .86869 L .80446 .87357 L p F P
0 0 0 r
s
.115 0 .563 r
.80446 .87357 m .80598 .89212 L .82554 .88728 L p F P
0 0 0 r
s
.195 0 .31 r
.85591 .46329 m .85411 .44696 L .86193 .45872 L p F P
0 0 0 r
s
.195 0 .31 r
.86193 .45872 m .86376 .475 L .85591 .46329 L p F P
0 0 0 r
s
.134 0 .891 r
.22775 .21152 m .23966 .22482 L .25711 .21764 L p F P
0 0 0 r
s
.134 0 .891 r
.23966 .22482 m .22775 .21152 L .21036 .21875 L p F P
0 0 0 r
s
.115 0 .563 r
.76993 .93925 m .7686 .92037 L .74935 .92506 L p F P
0 0 0 r
s
.115 0 .563 r
.74935 .92506 m .75057 .9439 L .76993 .93925 L p F P
0 0 0 r
s
0 .78 .12 r
.50709 .99845 m .48876 1.00287 L .47848 .99468 L p F P
0 0 0 r
s
0 .78 .12 r
.52554 .994 m .53285 1 L .51221 1.00259 L p F P
0 0 0 r
s
0 .78 .12 r
.51221 1.00259 m .50709 .99845 L .52554 .994 L p F P
0 0 0 r
s
.188 0 .528 r
.22877 .73487 m .23039 .71717 L .21841 .7071 L p F P
0 0 0 r
s
.188 0 .528 r
.22009 .68953 m .21841 .7071 L .23039 .71717 L p F P
0 0 0 r
s
.134 0 .891 r
.53866 .21096 m .54855 .22427 L .56709 .21708 L p F P
0 0 0 r
s
.134 0 .891 r
.54855 .22427 m .53866 .21096 L .52016 .21819 L p F P
0 0 0 r
s
.115 0 .563 r
.7143 .99124 m .71327 .97207 L .69421 .97659 L p F P
0 0 0 r
s
.115 0 .563 r
.69421 .97659 m .69513 .99571 L .7143 .99124 L p F P
0 0 0 r
s
.188 0 .528 r
.17866 .57837 m .18055 .56152 L .16825 .55043 L p F P
0 0 0 r
s
.188 0 .528 r
.1702 .53371 m .16825 .55043 L .18055 .56152 L p F P
0 0 0 r
s
.188 0 .528 r
.12856 .42187 m .13072 .40586 L .11809 .39375 L p F P
0 0 0 r
s
.188 0 .528 r
.12031 .37789 m .11809 .39375 L .13072 .40586 L p F P
0 0 0 r
s
.188 0 .528 r
.27887 .89138 m .28022 .87282 L .26857 .86378 L p F P
0 0 0 r
s
.188 0 .528 r
.26997 .84535 m .26857 .86378 L .28022 .87282 L p F P
0 0 0 r
s
0 .78 .71 r
.60101 .99708 m .60255 .99841 L .58347 1.00248 L p F P
0 0 0 r
s
0 .78 .71 r
.58347 1.00248 m .58233 1.00151 L .60101 .99708 L p F P
0 0 0 r
s
.134 0 .891 r
.27467 .21041 m .28629 .22372 L .3039 .21653 L p F P
0 0 0 r
s
.134 0 .891 r
.28629 .22372 m .27467 .21041 L .25711 .21764 L p F P
0 0 0 r
s
0 .78 .71 r
.53552 1.00219 m .53285 1 L .553 .99691 L p F P
0 0 0 r
s
0 .78 .71 r
.553 .99691 m .55402 .99777 L .53552 1.00219 L p F P
0 0 0 r
s
0 .647 .956 r
.64804 .9964 m .64937 .99758 L .63046 1.00195 L p F P
0 0 0 r
s
0 .647 .956 r
.63046 1.00195 m .62919 1.00083 L .64804 .9964 L p F P
0 0 0 r
s
.134 0 .891 r
.58577 .20985 m .59535 .22317 L .61407 .21597 L p F P
0 0 0 r
s
.134 0 .891 r
.59535 .22317 m .58577 .20985 L .56709 .21708 L p F P
0 0 0 r
s
.195 0 .31 r
.79572 .27742 m .79424 .2621 L .80246 .27508 L p F P
0 0 0 r
s
.195 0 .31 r
.80246 .27508 m .80397 .29037 L .79572 .27742 L p F P
0 0 0 r
s
.195 0 .31 r
.89665 .59268 m .89462 .57562 L .90218 .58655 L p F P
0 0 0 r
s
.195 0 .31 r
.90218 .58655 m .90424 .60355 L .89665 .59268 L p F P
0 0 0 r
s
.195 0 .31 r
.84618 .43505 m .84443 .41886 L .85232 .43082 L p F P
0 0 0 r
s
.195 0 .31 r
.85232 .43082 m .85411 .44696 L .84618 .43505 L p F P
0 0 0 r
s
.195 0 .31 r
.94711 .7503 m .9448 .73238 L .95204 .74229 L p F P
0 0 0 r
s
.195 0 .31 r
.95204 .74229 m .95437 .76014 L .94711 .7503 L p F P
0 0 0 r
s
.134 0 .891 r
.32165 .20929 m .33296 .22262 L .35075 .21542 L p F P
0 0 0 r
s
.134 0 .891 r
.33296 .22262 m .32165 .20929 L .3039 .21653 L p F P
0 0 0 r
s
.115 0 .563 r
.91886 .80681 m .91671 .78864 L .89691 .79381 L p F P
0 0 0 r
s
.115 0 .563 r
.89691 .79381 m .89894 .81195 L .91886 .80681 L p F P
0 0 0 r
s
0 .78 .71 r
.58233 1.00151 m .57279 .99343 L .5923 .98957 L p F P
0 0 0 r
s
0 .78 .71 r
.5923 .98957 m .60101 .99708 L .58233 1.00151 L p F P
0 0 0 r
s
.1 0 .485 r
.17211 .26319 m .17404 .24803 L .19127 .24093 L p F P
0 0 0 r
s
.1 0 .485 r
.17404 .24803 m .17211 .26319 L .15491 .27023 L p F P
0 0 0 r
s
.188 0 .528 r
.16825 .55043 m .1702 .53371 L .15781 .52242 L p F P
0 0 0 r
s
.188 0 .528 r
.15982 .50584 m .15781 .52242 L .1702 .53371 L p F P
0 0 0 r
s
.188 0 .528 r
.11809 .39375 m .12031 .37789 L .1076 .36558 L p F P
0 0 0 r
s
.188 0 .528 r
.10988 .34985 m .1076 .36558 L .12031 .37789 L p F P
0 0 0 r
s
.188 0 .528 r
.21841 .7071 m .22009 .68953 L .20803 .67927 L p F P
0 0 0 r
s
.188 0 .528 r
.20976 .66183 m .20803 .67927 L .22009 .68953 L p F P
0 0 0 r
s
.188 0 .528 r
.26857 .86378 m .26997 .84535 L .25824 .83612 L p F P
0 0 0 r
s
.188 0 .528 r
.25971 .81782 m .25824 .83612 L .26997 .84535 L p F P
0 0 0 r
s
.134 0 .891 r
.63293 .20873 m .64221 .22206 L .6611 .21486 L p F P
0 0 0 r
s
.134 0 .891 r
.64221 .22206 m .63293 .20873 L .61407 .21597 L p F P
0 0 0 r
s
.188 0 .528 r
.30965 .97381 m .30846 .99297 L .31986 1.00117 L p F P
0 0 0 r
s
.125 0 .956 r
.31986 1.00117 m .30846 .99297 L p .33712 .99638 L F P
0 0 0 r
s
.125 0 .956 r
.33712 .99638 m .33761 .99674 L .31986 1.00117 L p F P
0 0 0 r
s
.115 0 .563 r
.8632 .85883 m .86136 .84036 L .84175 .84535 L p F P
0 0 0 r
s
.115 0 .563 r
.84175 .84535 m .84348 .86378 L .8632 .85883 L p F P
0 0 0 r
s
.1 0 .485 r
.11643 .31488 m .11867 .29944 L .13571 .29252 L p F P
0 0 0 r
s
.1 0 .485 r
.11867 .29944 m .11643 .31488 L .09943 .32175 L p F P
0 0 0 r
s
.134 0 .891 r
.36867 .20817 m .37969 .22151 L .39765 .21431 L p F P
0 0 0 r
s
.134 0 .891 r
.37969 .22151 m .36867 .20817 L .35075 .21542 L p F P
0 0 0 r
s
.115 0 .563 r
.80752 .91087 m .80598 .89212 L .78657 .89692 L p F P
0 0 0 r
s
.115 0 .563 r
.78657 .89692 m .78799 .91564 L .80752 .91087 L p F P
0 0 0 r
s
0 .647 .956 r
.62919 1.00083 m .62163 .99421 L .64072 .98987 L p F P
0 0 0 r
s
0 .647 .956 r
.64072 .98987 m .64804 .9964 L .62919 1.00083 L p F P
0 0 0 r
s
.134 0 .891 r
.68014 .20761 m .68911 .22096 L .70819 .21375 L p F P
0 0 0 r
s
.134 0 .891 r
.68911 .22096 m .68014 .20761 L .6611 .21486 L p F P
0 0 0 r
s
.195 0 .31 r
.88695 .56455 m .88497 .54763 L .89261 .55876 L p F P
0 0 0 r
s
.195 0 .31 r
.89261 .55876 m .89462 .57562 L .88695 .56455 L p F P
0 0 0 r
s
.195 0 .31 r
.78591 .24895 m .78449 .23377 L .79278 .24694 L p F P
0 0 0 r
s
.195 0 .31 r
.79278 .24694 m .79424 .2621 L .78591 .24895 L p F P
0 0 0 r
s
.195 0 .31 r
.93747 .72235 m .93522 .70457 L .94252 .71466 L p F P
0 0 0 r
s
.195 0 .31 r
.94252 .71466 m .9448 .73238 L .93747 .72235 L p F P
0 0 0 r
s
.115 0 .563 r
.75181 .96295 m .75057 .9439 L .73135 .94852 L p F P
0 0 0 r
s
.115 0 .563 r
.73135 .94852 m .73247 .96753 L .75181 .96295 L p F P
0 0 0 r
s
0 .647 .956 r
.37234 .99907 m .36659 1.00049 L .35549 .99228 L p F P
0 0 0 r
s
0 .647 .956 r
.33765 .99673 m .35549 .99228 L .36659 1.00049 L p F P
0 0 0 r
s
.195 0 .31 r
.83643 .40675 m .83473 .3907 L .84269 .40285 L p F P
0 0 0 r
s
.195 0 .31 r
.84269 .40285 m .84443 .41886 L .83643 .40675 L p F P
0 0 0 r
s
.134 0 .891 r
.41575 .20705 m .42646 .22041 L .44461 .21319 L p F P
0 0 0 r
s
.134 0 .891 r
.42646 .22041 m .41575 .20705 L .39765 .21431 L p F P
0 0 0 r
s
.125 0 .956 r
.6761 1.00015 m .66837 .99314 L .68746 .98863 L p F P
0 0 0 r
s
.125 0 .956 r
.68746 .98863 m .69513 .99571 L .6761 1.00015 L p F P
0 0 0 r
s
0 .78 .12 r
.54413 .98951 m .553 .99691 L .53285 1 L p F P
0 0 0 r
s
0 .78 .12 r
.53285 1 m .52554 .994 L .54413 .98951 L p F P
0 0 0 r
s
0 .78 .71 r
.4183 .9986 m .41337 .99981 L .40781 .99557 L closepath p F P
0 0 0 r
s
.188 0 .528 r
.25824 .83612 m .25971 .81782 L .24789 .8084 L p F P
0 0 0 r
s
.188 0 .528 r
.24942 .79023 m .24789 .8084 L .25971 .81782 L p F P
0 0 0 r
s
.188 0 .528 r
.20803 .67927 m .20976 .66183 L .19762 .65138 L p F P
0 0 0 r
s
.188 0 .528 r
.19942 .63407 m .19762 .65138 L .20976 .66183 L p F P
0 0 0 r
s
.188 0 .528 r
.1076 .36558 m .10988 .34985 L .09708 .33734 L p F P
0 0 0 r
s
.188 0 .528 r
.09943 .32175 m .09708 .33734 L .10988 .34985 L p F P
0 0 0 r
s
.134 0 .891 r
.7274 .20649 m .73607 .21985 L .75532 .21264 L p F P
0 0 0 r
s
.134 0 .891 r
.73607 .21985 m .7274 .20649 L .70819 .21375 L p F P
0 0 0 r
s
.188 0 .528 r
.15781 .52242 m .15982 .50584 L .14735 .49436 L p F P
0 0 0 r
s
.188 0 .528 r
.14942 .47791 m .14735 .49436 L .15982 .50584 L p F P
0 0 0 r
s
.188 0 .528 r
.30846 .99297 m .30965 .97381 L .29817 .96542 L p F P
0 0 0 r
s
.188 0 .528 r
.29941 .94639 m .29817 .96542 L .30965 .97381 L p F P
0 0 0 r
s
.115 0 .563 r
.95673 .77819 m .95437 .76014 L .93441 .76542 L p F P
0 0 0 r
s
.115 0 .563 r
.93441 .76542 m .93665 .78343 L .95673 .77819 L p F P
0 0 0 r
s
.134 0 .891 r
.46288 .20593 m .47329 .2193 L .49161 .21208 L p F P
0 0 0 r
s
.134 0 .891 r
.47329 .2193 m .46288 .20593 L .44461 .21319 L p F P
0 0 0 r
s
.1 0 .485 r
.20863 .23377 m .21036 .21875 L .22775 .21152 L p F P
0 0 0 r
s
.1 0 .485 r
.21036 .21875 m .20863 .23377 L .19127 .24093 L p F P
0 0 0 r
s
0 .78 .12 r
.4602 .99913 m .44971 .9909 L p .47151 .98913 L F P
0 0 0 r
s
0 .78 .12 r
.47151 .98913 m .47848 .99468 L .4602 .99913 L p F P
0 0 0 r
s
.134 0 .891 r
.78308 .21875 m .77471 .20537 L .75532 .21264 L p F P
0 0 0 r
s
.195 0 .31 r
.77608 .22041 m .77471 .20537 L .78308 .21875 L p F P
0 0 0 r
s
.195 0 .31 r
.78308 .21875 m .78449 .23377 L .77608 .22041 L p F P
0 0 0 r
s
.195 0 .31 r
.82666 .37839 m .82501 .36247 L .83305 .37482 L p F P
0 0 0 r
s
.195 0 .31 r
.83305 .37482 m .83473 .3907 L .82666 .37839 L p F P
0 0 0 r
s
.195 0 .31 r
.92781 .69433 m .92561 .67669 L .93298 .68698 L p F P
0 0 0 r
s
.195 0 .31 r
.93298 .68698 m .93522 .70457 L .92781 .69433 L p F P
0 0 0 r
s
.115 0 .563 r
.901 .83029 m .89894 .81195 L .87917 .81704 L p F P
0 0 0 r
s
.115 0 .563 r
.87917 .81704 m .88111 .83534 L .901 .83029 L p F P
0 0 0 r
s
.195 0 .31 r
.87724 .53636 m .87531 .51958 L .88301 .5309 L p F P
0 0 0 r
s
.195 0 .31 r
.88301 .5309 m .88497 .54763 L .87724 .53636 L p F P
0 0 0 r
s
0 .78 .71 r
.38452 .99606 m .37234 .99907 L .3582 .9916 L p F P
0 0 0 r
s
0 .647 .956 r
.35549 .99228 m .3582 .9916 L .37234 .99907 L p F P
0 0 0 r
s
.134 0 .891 r
.51006 .20481 m .52016 .21819 L .53866 .21096 L p F P
0 0 0 r
s
.134 0 .891 r
.52016 .21819 m .51006 .20481 L .49161 .21208 L p F P
0 0 0 r
s
.1 0 .485 r
.15287 .28554 m .15491 .27023 L .17211 .26319 L p F P
0 0 0 r
s
.1 0 .485 r
.15491 .27023 m .15287 .28554 L .13571 .29252 L p F P
0 0 0 r
s
.115 0 .563 r
.84523 .88241 m .84348 .86378 L .8239 .86869 L p F P
0 0 0 r
s
.115 0 .563 r
.8239 .86869 m .82554 .88728 L .84523 .88241 L p F P
0 0 0 r
s
0 .78 .12 r
.43148 .99537 m .4183 .9986 L .40781 .99557 L p F P
0 0 0 r
s
.1 0 .485 r
.09708 .33734 m .09943 .32175 L .11643 .31488 L p F P
0 0 0 r
s
.134 0 .891 r
.24527 .20424 m .25711 .21764 L .27467 .21041 L p F P
0 0 0 r
s
.134 0 .891 r
.25711 .21764 m .24527 .20424 L .22775 .21152 L p F P
0 0 0 r
s
.188 0 .528 r
.24789 .8084 m .24942 .79023 L .23752 .78062 L p F P
0 0 0 r
s
.188 0 .528 r
.2391 .76258 m .23752 .78062 L .24942 .79023 L p F P
0 0 0 r
s
.188 0 .528 r
.14735 .49436 m .14942 .47791 L .13687 .46623 L p F P
0 0 0 r
s
.188 0 .528 r
.139 .44992 m .13687 .46623 L .14942 .47791 L p F P
0 0 0 r
s
0 .78 .12 r
.50709 .99845 m .49689 .99021 L p .51818 .98795 L F P
0 0 0 r
s
0 .78 .12 r
.51818 .98795 m .52554 .994 L .50709 .99845 L p F P
0 0 0 r
s
0 .78 .12 r
.47848 .99468 m .49689 .99021 L .50709 .99845 L p F P
0 0 0 r
s
.115 0 .563 r
.78943 .93456 m .78799 .91564 L .7686 .92037 L p F P
0 0 0 r
s
.115 0 .563 r
.7686 .92037 m .76993 .93925 L .78943 .93456 L p F P
0 0 0 r
s
.188 0 .528 r
.29817 .96542 m .29941 .94639 L .28785 .93781 L p F P
0 0 0 r
s
.188 0 .528 r
.28915 .91892 m .28785 .93781 L .29941 .94639 L p F P
0 0 0 r
s
.188 0 .528 r
.19762 .65138 m .19942 .63407 L .1872 .62342 L p F P
0 0 0 r
s
.188 0 .528 r
.18905 .60625 m .1872 .62342 L .19942 .63407 L p F P
0 0 0 r
s
0 .78 .71 r
.61982 .99262 m .62163 .99421 L .60255 .99841 L p F P
0 0 0 r
s
0 .78 .71 r
.60255 .99841 m .60101 .99708 L .61982 .99262 L p F P
0 0 0 r
s
.134 0 .891 r
.55729 .20368 m .56709 .21708 L .58577 .20985 L p F P
0 0 0 r
s
.134 0 .891 r
.56709 .21708 m .55729 .20368 L .53866 .21096 L p F P
0 0 0 r
s
.115 0 .563 r
.73361 .98674 m .73247 .96753 L .71327 .97207 L p F P
0 0 0 r
s
.115 0 .563 r
.71327 .97207 m .7143 .99124 L .73361 .98674 L p F P
0 0 0 r
s
.134 0 .891 r
.29237 .20312 m .3039 .21653 L .32165 .20929 L p F P
0 0 0 r
s
.134 0 .891 r
.3039 .21653 m .29237 .20312 L .27467 .21041 L p F P
0 0 0 r
s
0 .78 .71 r
.55402 .99777 m .57009 .99392 L .57279 .99343 L p F P
0 0 0 r
s
0 .78 .71 r
.57009 .99392 m .55402 .99777 L .553 .99691 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.91813 .66626 m .91597 .64874 L .92342 .65923 L p F P
0 0 0 r
s
.195 0 .31 r
.92342 .65923 m .92561 .67669 L .91813 .66626 L p F P
0 0 0 r
s
.195 0 .31 r
.81687 .34996 m .81527 .33419 L .82338 .34674 L p F P
0 0 0 r
s
.195 0 .31 r
.82338 .34674 m .82501 .36247 L .81687 .34996 L p F P
0 0 0 r
s
.195 0 .31 r
.8675 .50811 m .86562 .49146 L .8734 .50298 L p F P
0 0 0 r
s
.195 0 .31 r
.8734 .50298 m .87531 .51958 L .8675 .50811 L p F P
0 0 0 r
s
0 .647 .956 r
.66703 .99193 m .66837 .99314 L .64937 .99758 L p F P
0 0 0 r
s
0 .647 .956 r
.64937 .99758 m .64804 .9964 L .66703 .99193 L p F P
0 0 0 r
s
.134 0 .891 r
.60458 .20256 m .61407 .21597 L .63293 .20873 L p F P
0 0 0 r
s
.134 0 .891 r
.61407 .21597 m .60458 .20256 L .58577 .20985 L p F P
0 0 0 r
s
.188 0 .528 r
.1872 .62342 m .18905 .60625 L .17675 .59541 L p F P
0 0 0 r
s
.188 0 .528 r
.17866 .57837 m .17675 .59541 L .18905 .60625 L p F P
0 0 0 r
s
.188 0 .528 r
.23752 .78062 m .2391 .76258 L .22713 .75277 L p F P
0 0 0 r
s
.188 0 .528 r
.22877 .73487 m .22713 .75277 L .2391 .76258 L p F P
0 0 0 r
s
.115 0 .563 r
.93891 .80165 m .93665 .78343 L .91671 .78864 L p F P
0 0 0 r
s
.115 0 .563 r
.91671 .78864 m .91886 .80681 L .93891 .80165 L p F P
0 0 0 r
s
.134 0 .891 r
.33952 .202 m .35075 .21542 L .36867 .20817 L p F P
0 0 0 r
s
.134 0 .891 r
.35075 .21542 m .33952 .202 L .32165 .20929 L p F P
0 0 0 r
s
0 .78 .71 r
.60101 .99708 m .5923 .98957 L .61168 .98549 L p F P
0 0 0 r
s
0 .78 .71 r
.61168 .98549 m .61982 .99262 L .60101 .99708 L p F P
0 0 0 r
s
.188 0 .528 r
.13687 .46623 m .139 .44992 L .12637 .43804 L p F P
0 0 0 r
s
.188 0 .528 r
.12856 .42187 m .12637 .43804 L .139 .44992 L p F P
0 0 0 r
s
.188 0 .528 r
.28785 .93781 m .28915 .91892 L .27751 .91014 L p F P
0 0 0 r
s
.188 0 .528 r
.27887 .89138 m .27751 .91014 L .28915 .91892 L p F P
0 0 0 r
s
0 .78 .12 r
.57266 .99331 m .57009 .99392 L .553 .99691 L p F P
0 0 0 r
s
0 .78 .12 r
.56286 .985 m .57266 .99331 L p .553 .99691 L F P
0 0 0 r
s
0 .78 .12 r
.553 .99691 m .54413 .98951 L .56286 .985 L p F P
0 0 0 r
s
.1 0 .485 r
.18943 .25609 m .19127 .24093 L .20863 .23377 L p F P
0 0 0 r
s
.1 0 .485 r
.19127 .24093 m .18943 .25609 L .17211 .26319 L p F P
0 0 0 r
s
.125 0 .956 r
.33765 .99673 m .33761 .99674 L .33712 .99638 L closepath p F P
0 0 0 r
s
.134 0 .891 r
.65192 .20143 m .6611 .21486 L .68014 .20761 L p F P
0 0 0 r
s
.134 0 .891 r
.6611 .21486 m .65192 .20143 L .63293 .20873 L p F P
0 0 0 r
s
.115 0 .563 r
.88307 .85385 m .88111 .83534 L .86136 .84036 L p F P
0 0 0 r
s
.115 0 .563 r
.86136 .84036 m .8632 .85883 L .88307 .85385 L p F P
0 0 0 r
s
0 .647 .956 r
.35549 .99228 m .33765 .99673 L .33712 .99638 L p F P
0 0 0 r
s
.1 0 .485 r
.13356 .30797 m .13571 .29252 L .15287 .28554 L p F P
0 0 0 r
s
.1 0 .485 r
.13571 .29252 m .13356 .30797 L .11643 .31488 L p F P
0 0 0 r
s
.195 0 .31 r
.80705 .32147 m .8055 .30584 L .81369 .31859 L p F P
0 0 0 r
s
.195 0 .31 r
.81369 .31859 m .81527 .33419 L .80705 .32147 L p F P
0 0 0 r
s
.195 0 .31 r
.90843 .63812 m .90632 .62074 L .91384 .63142 L p F P
0 0 0 r
s
.195 0 .31 r
.91384 .63142 m .91597 .64874 L .90843 .63812 L p F P
0 0 0 r
s
.195 0 .31 r
.85774 .47979 m .85591 .46329 L .86376 .475 L p F P
0 0 0 r
s
.195 0 .31 r
.86376 .475 m .86562 .49146 L .85774 .47979 L p F P
0 0 0 r
s
.134 0 .891 r
.38672 .20087 m .39765 .21431 L .41575 .20705 L p F P
0 0 0 r
s
.134 0 .891 r
.39765 .21431 m .38672 .20087 L .36867 .20817 L p F P
0 0 0 r
s
.115 0 .563 r
.82719 .90608 m .82554 .88728 L .80598 .89212 L p F P
0 0 0 r
s
.115 0 .563 r
.80598 .89212 m .80752 .91087 L .82719 .90608 L p F P
0 0 0 r
s
0 .647 .956 r
.64804 .9964 m .64072 .98987 L .65983 .9854 L p F P
0 0 0 r
s
0 .647 .956 r
.65983 .9854 m .66703 .99193 L .64804 .9964 L p F P
0 0 0 r
s
0 .647 .956 r
.34424 .98395 m .35549 .99228 L p .33712 .99638 L F P
0 0 0 r
s
0 .647 .956 r
.33712 .99638 m .32629 .98848 L .34424 .98395 L p F P
0 0 0 r
s
0 .647 .956 r
.32549 .98867 m .32629 .98848 L .33712 .99638 L closepath p F P
0 0 0 r
s
.125 0 .956 r
.30846 .99297 m .32549 .98867 L .33712 .99638 L p F P
0 0 0 r
s
.134 0 .891 r
.6993 .20031 m .70819 .21375 L .7274 .20649 L p F P
0 0 0 r
s
.134 0 .891 r
.70819 .21375 m .6993 .20031 L .68014 .20761 L p F P
0 0 0 r
s
.115 0 .563 r
.77128 .95834 m .76993 .93925 L .75057 .9439 L p F P
0 0 0 r
s
.115 0 .563 r
.75057 .9439 m .75181 .96295 L .77128 .95834 L p F P
0 0 0 r
s
0 .78 .71 r
.38452 .99606 m .39896 .99248 L .40781 .99557 L p F P
0 0 0 r
s
0 .78 .71 r
.39896 .99248 m .38452 .99606 L .3735 .98778 L p F P
0 0 0 r
s
0 .78 .71 r
.3582 .9916 m .3735 .98778 L .38452 .99606 L p F P
0 0 0 r
s
.188 0 .528 r
.12637 .43804 m .12856 .42187 L .11584 .40979 L p F P
0 0 0 r
s
.188 0 .528 r
.11809 .39375 m .11584 .40979 L .12856 .42187 L p F P
0 0 0 r
s
.188 0 .528 r
.22713 .75277 m .22877 .73487 L .21671 .72487 L p F P
0 0 0 r
s
.188 0 .528 r
.21841 .7071 m .21671 .72487 L .22877 .73487 L p F P
0 0 0 r
s
.134 0 .891 r
.43398 .19974 m .44461 .21319 L .46288 .20593 L p F P
0 0 0 r
s
.134 0 .891 r
.44461 .21319 m .43398 .19974 L .41575 .20705 L p F P
0 0 0 r
s
.125 0 .956 r
.69513 .99571 m .68746 .98863 L .70665 .98405 L p F P
0 0 0 r
s
.125 0 .956 r
.70665 .98405 m .7143 .99124 L .69513 .99571 L p F P
0 0 0 r
s
.188 0 .528 r
.17675 .59541 m .17866 .57837 L .16628 .56733 L p F P
0 0 0 r
s
.188 0 .528 r
.16825 .55043 m .16628 .56733 L .17866 .57837 L p F P
0 0 0 r
s
.188 0 .528 r
.27751 .91014 m .27887 .89138 L .26715 .88241 L p F P
0 0 0 r
s
.188 0 .528 r
.26857 .86378 m .26715 .88241 L .27887 .89138 L p F P
0 0 0 r
s
0 .78 .12 r
.42076 .98709 m .43148 .99537 L p .40781 .99557 L F P
0 0 0 r
s
0 .78 .12 r
.40781 .99557 m .40257 .99159 L .42076 .98709 L p F P
0 0 0 r
s
0 .78 .12 r
.39896 .99248 m .40257 .99159 L .40781 .99557 L closepath p F P
0 0 0 r
s
0 .78 .12 r
.43148 .99537 m .42076 .98709 L p .44365 .98614 L F P
0 0 0 r
s
0 .78 .12 r
.44365 .98614 m .44971 .9909 L .43148 .99537 L p F P
0 0 0 r
s
.134 0 .891 r
.74675 .19918 m .75532 .21264 L .77471 .20537 L p F P
0 0 0 r
s
.134 0 .891 r
.75532 .21264 m .74675 .19918 L .7274 .20649 L p F P
0 0 0 r
s
.195 0 .31 r
.79721 .29292 m .79572 .27742 L .80397 .29037 L p F P
0 0 0 r
s
.195 0 .31 r
.80397 .29037 m .8055 .30584 L .79721 .29292 L p F P
0 0 0 r
s
.195 0 .31 r
.8987 .60992 m .89665 .59268 L .90424 .60355 L p F P
0 0 0 r
s
.195 0 .31 r
.90424 .60355 m .90632 .62074 L .8987 .60992 L p F P
0 0 0 r
s
.195 0 .31 r
.94944 .76842 m .94711 .7503 L .95437 .76014 L p F P
0 0 0 r
s
.195 0 .31 r
.95437 .76014 m .95673 .77819 L .94944 .76842 L p F P
0 0 0 r
s
.134 0 .891 r
.48129 .19861 m .49161 .21208 L .51006 .20481 L p F P
0 0 0 r
s
.134 0 .891 r
.49161 .21208 m .48129 .19861 L .46288 .20593 L p F P
0 0 0 r
s
.195 0 .31 r
.84796 .45142 m .84618 .43505 L .85411 .44696 L p F P
0 0 0 r
s
.195 0 .31 r
.85411 .44696 m .85591 .46329 L .84796 .45142 L p F P
0 0 0 r
s
.1 0 .485 r
.22611 .22655 m .22775 .21152 L .24527 .20424 L p F P
0 0 0 r
s
.1 0 .485 r
.22775 .21152 m .22611 .22655 L .20863 .23377 L p F P
0 0 0 r
s
.115 0 .563 r
.92103 .82519 m .91886 .80681 L .89894 .81195 L p F P
0 0 0 r
s
.115 0 .563 r
.89894 .81195 m .901 .83029 L .92103 .82519 L p F P
0 0 0 r
s
0 .78 .12 r
.47848 .99468 m .47151 .98913 L .49587 .98938 L p F P
0 0 0 r
s
0 .78 .12 r
.49587 .98938 m .49689 .99021 L .47848 .99468 L p F P
0 0 0 r
s
.134 0 .891 r
.52865 .19748 m .53866 .21096 L .55729 .20368 L p F P
0 0 0 r
s
.134 0 .891 r
.53866 .21096 m .52865 .19748 L .51006 .20481 L p F P
0 0 0 r
s
.1 0 .485 r
.17016 .27851 m .17211 .26319 L .18943 .25609 L p F P
0 0 0 r
s
.1 0 .485 r
.17211 .26319 m .17016 .27851 L .15287 .28554 L p F P
0 0 0 r
s
.188 0 .528 r
.16628 .56733 m .16825 .55043 L .15578 .53919 L p F P
0 0 0 r
s
.188 0 .528 r
.15781 .52242 m .15578 .53919 L .16825 .55043 L p F P
0 0 0 r
s
.188 0 .528 r
.21671 .72487 m .21841 .7071 L .20627 .6969 L p F P
0 0 0 r
s
.188 0 .528 r
.20803 .67927 m .20627 .6969 L .21841 .7071 L p F P
0 0 0 r
s
.188 0 .528 r
.11584 .40979 m .11809 .39375 L .10529 .38148 L p F P
0 0 0 r
s
.188 0 .528 r
.1076 .36558 m .10529 .38148 L .11809 .39375 L p F P
0 0 0 r
s
.188 0 .528 r
.26715 .88241 m .26857 .86378 L .25676 .85462 L p F P
0 0 0 r
s
.188 0 .528 r
.25824 .83612 m .25676 .85462 L .26857 .86378 L p F P
0 0 0 r
s
.115 0 .563 r
.86507 .8775 m .8632 .85883 L .84348 .86378 L p F P
0 0 0 r
s
.115 0 .563 r
.84348 .86378 m .84523 .88241 L .86507 .8775 L p F P
0 0 0 r
s
0 .78 .71 r
.63877 .98813 m .64072 .98987 L .62163 .99421 L p F P
0 0 0 r
s
0 .78 .71 r
.62163 .99421 m .61982 .99262 L .63877 .98813 L p F P
0 0 0 r
s
.1 0 .485 r
.11417 .33049 m .11643 .31488 L .13356 .30797 L p F P
0 0 0 r
s
.1 0 .485 r
.11643 .31488 m .11417 .33049 L .09708 .33734 L p F P
0 0 0 r
s
.134 0 .891 r
.26291 .19692 m .27467 .21041 L .29237 .20312 L p F P
0 0 0 r
s
.134 0 .891 r
.27467 .21041 m .26291 .19692 L .24527 .20424 L p F P
0 0 0 r
s
0 .78 .12 r
.52554 .994 m .51818 .98795 L .53946 .98561 L p F P
0 0 0 r
s
0 .78 .12 r
.53946 .98561 m .54413 .98951 L .52554 .994 L p F P
0 0 0 r
s
.115 0 .563 r
.80908 .92984 m .80752 .91087 L .78799 .91564 L p F P
0 0 0 r
s
.115 0 .563 r
.78799 .91564 m .78943 .93456 L .80908 .92984 L p F P
0 0 0 r
s
0 .78 .12 r
.57009 .99392 m .57266 .99331 L .57279 .99343 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.78735 .2643 m .78591 .24895 L .79424 .2621 L p F P
0 0 0 r
s
.195 0 .31 r
.79424 .2621 m .79572 .27742 L .78735 .2643 L p F P
0 0 0 r
s
.195 0 .31 r
.88895 .58165 m .88695 .56455 L .89462 .57562 L p F P
0 0 0 r
s
.195 0 .31 r
.89462 .57562 m .89665 .59268 L .88895 .58165 L p F P
0 0 0 r
s
.195 0 .31 r
.83815 .42298 m .83643 .40675 L .84443 .41886 L p F P
0 0 0 r
s
.195 0 .31 r
.84443 .41886 m .84618 .43505 L .83815 .42298 L p F P
0 0 0 r
s
.195 0 .31 r
.93975 .74033 m .93747 .72235 L .9448 .73238 L p F P
0 0 0 r
s
.195 0 .31 r
.9448 .73238 m .94711 .7503 L .93975 .74033 L p F P
0 0 0 r
s
.134 0 .891 r
.57606 .19635 m .58577 .20985 L .60458 .20256 L p F P
0 0 0 r
s
.134 0 .891 r
.58577 .20985 m .57606 .19635 L .55729 .20368 L p F P
0 0 0 r
s
.115 0 .563 r
.75305 .9822 m .75181 .96295 L .73247 .96753 L p F P
0 0 0 r
s
.115 0 .563 r
.73247 .96753 m .73361 .98674 L .75305 .9822 L p F P
0 0 0 r
s
0 .78 .12 r
.59142 .98882 m .5923 .98957 L .57279 .99343 L p F P
0 0 0 r
s
0 .78 .12 r
.57279 .99343 m .57266 .99331 L .59142 .98882 L p F P
0 0 0 r
s
.134 0 .891 r
.31019 .19578 m .32165 .20929 L .33952 .202 L p F P
0 0 0 r
s
.134 0 .891 r
.32165 .20929 m .31019 .19578 L .29237 .20312 L p F P
0 0 0 r
s
0 .78 .12 r
.59142 .98882 m .57266 .99331 L .56286 .985 L p F P
0 0 0 r
s
0 .647 .956 r
.68616 .98743 m .68746 .98863 L .66837 .99314 L p F P
0 0 0 r
s
0 .647 .956 r
.66837 .99314 m .66703 .99193 L .68616 .98743 L p F P
0 0 0 r
s
.188 0 .528 r
.10529 .38148 m .1076 .36558 L .09471 .3531 L p F P
0 0 0 r
s
.188 0 .528 r
.09708 .33734 m .09471 .3531 L .1076 .36558 L p F P
0 0 0 r
s
.188 0 .528 r
.20627 .6969 m .20803 .67927 L .19581 .66888 L p F P
0 0 0 r
s
.188 0 .528 r
.19762 .65138 m .19581 .66888 L .20803 .67927 L p F P
0 0 0 r
s
.134 0 .891 r
.62352 .19522 m .63293 .20873 L .65192 .20143 L p F P
0 0 0 r
s
.134 0 .891 r
.63293 .20873 m .62352 .19522 L .60458 .20256 L p F P
0 0 0 r
s
.188 0 .528 r
.15578 .53919 m .15781 .52242 L .14526 .51099 L p F P
0 0 0 r
s
.188 0 .528 r
.14735 .49436 m .14526 .51099 L .15781 .52242 L p F P
0 0 0 r
s
.188 0 .528 r
.25676 .85462 m .25824 .83612 L .24636 .82676 L p F P
0 0 0 r
s
.188 0 .528 r
.24789 .8084 m .24636 .82676 L .25824 .83612 L p F P
0 0 0 r
s
.188 0 .528 r
.29817 .96542 m .29691 .98465 L .30846 .99297 L p F P
0 0 0 r
s
.125 0 .956 r
.32549 .98867 m .30846 .99297 L .29691 .98465 L p F P
0 0 0 r
s
.134 0 .891 r
.35752 .19465 m .36867 .20817 L .38672 .20087 L p F P
0 0 0 r
s
.134 0 .891 r
.36867 .20817 m .35752 .19465 L .33952 .202 L p F P
0 0 0 r
s
.115 0 .563 r
.95911 .79644 m .95673 .77819 L .93665 .78343 L p F P
0 0 0 r
s
.115 0 .563 r
.93665 .78343 m .93891 .80165 L .95911 .79644 L p F P
0 0 0 r
s
0 .78 .71 r
.61982 .99262 m .61168 .98549 L .63099 .9812 L p F P
0 0 0 r
s
0 .78 .71 r
.63099 .9812 m .63877 .98813 L .61982 .99262 L p F P
0 0 0 r
s
0 .78 .12 r
.40257 .99159 m .39896 .99248 L .38241 .98556 L p F P
0 0 0 r
s
0 .78 .71 r
.3735 .98778 m .38241 .98556 L .39896 .99248 L p F P
0 0 0 r
s
.1 0 .485 r
.20687 .24895 m .20863 .23377 L .22611 .22655 L p F P
0 0 0 r
s
.1 0 .485 r
.20863 .23377 m .20687 .24895 L .18943 .25609 L p F P
0 0 0 r
s
.195 0 .31 r
.77747 .23562 m .77608 .22041 L .78449 .23377 L p F P
0 0 0 r
s
.195 0 .31 r
.78449 .23377 m .78591 .24895 L .77747 .23562 L p F P
0 0 0 r
s
.195 0 .31 r
.93004 .71218 m .92781 .69433 L .93522 .70457 L p F P
0 0 0 r
s
.195 0 .31 r
.93522 .70457 m .93747 .72235 L .93004 .71218 L p F P
0 0 0 r
s
0 .647 .956 r
.3582 .9916 m .35549 .99228 L .34424 .98395 L p F P
0 0 0 r
s
.195 0 .31 r
.82833 .39448 m .82666 .37839 L .83473 .3907 L p F P
0 0 0 r
s
.195 0 .31 r
.83473 .3907 m .83643 .40675 L .82833 .39448 L p F P
0 0 0 r
s
.134 0 .891 r
.67104 .19408 m .68014 .20761 L .6993 .20031 L p F P
0 0 0 r
s
.134 0 .891 r
.68014 .20761 m .67104 .19408 L .65192 .20143 L p F P
0 0 0 r
s
.195 0 .31 r
.87919 .55333 m .87724 .53636 L .88497 .54763 L p F P
0 0 0 r
s
.195 0 .31 r
.88497 .54763 m .88695 .56455 L .87919 .55333 L p F P
0 0 0 r
s
.115 0 .563 r
.90307 .84883 m .901 .83029 L .88111 .83534 L p F P
0 0 0 r
s
.115 0 .563 r
.88111 .83534 m .88307 .85385 L .90307 .84883 L p F P
0 0 0 r
s
.1 0 .485 r
.15081 .30101 m .15287 .28554 L .17016 .27851 L p F P
0 0 0 r
s
.1 0 .485 r
.15287 .28554 m .15081 .30101 L .13356 .30797 L p F P
0 0 0 r
s
.134 0 .891 r
.4049 .19352 m .41575 .20705 L .43398 .19974 L p F P
0 0 0 r
s
.134 0 .891 r
.41575 .20705 m .4049 .19352 L .38672 .20087 L p F P
0 0 0 r
s
.115 0 .563 r
.847 .90125 m .84523 .88241 L .82554 .88728 L p F P
0 0 0 r
s
.115 0 .563 r
.82554 .88728 m .82719 .90608 L .847 .90125 L p F P
0 0 0 r
s
0 .647 .956 r
.66703 .99193 m .65983 .9854 L .67898 .98081 L p F P
0 0 0 r
s
0 .647 .956 r
.67898 .98081 m .68616 .98743 L .66703 .99193 L p F P
0 0 0 r
s
0 .78 .71 r
.3735 .98778 m .3582 .9916 L .34472 .98383 L p F P
0 0 0 r
s
0 .647 .956 r
.34424 .98395 m .34472 .98383 L .3582 .9916 L p F P
0 0 0 r
s
.1 0 .485 r
.09471 .3531 m .09708 .33734 L .11417 .33049 L p F P
0 0 0 r
s
.188 0 .528 r
.24636 .82676 m .24789 .8084 L .23593 .79885 L p F P
0 0 0 r
s
.188 0 .528 r
.23752 .78062 m .23593 .79885 L .24789 .8084 L p F P
0 0 0 r
s
.134 0 .891 r
.71861 .19295 m .7274 .20649 L .74675 .19918 L p F P
0 0 0 r
s
.134 0 .891 r
.7274 .20649 m .71861 .19295 L .6993 .20031 L p F P
0 0 0 r
s
.188 0 .528 r
.14526 .51099 m .14735 .49436 L .13472 .48273 L p F P
0 0 0 r
s
.188 0 .528 r
.13687 .46623 m .13472 .48273 L .14735 .49436 L p F P
0 0 0 r
s
.115 0 .563 r
.79089 .95369 m .78943 .93456 L .76993 .93925 L p F P
0 0 0 r
s
.115 0 .563 r
.76993 .93925 m .77128 .95834 L .79089 .95369 L p F P
0 0 0 r
s
.188 0 .528 r
.19581 .66888 m .19762 .65138 L .18532 .64079 L p F P
0 0 0 r
s
.188 0 .528 r
.1872 .62342 m .18532 .64079 L .19762 .65138 L p F P
0 0 0 r
s
.188 0 .528 r
.29691 .98465 m .29817 .96542 L .28653 .95691 L p F P
0 0 0 r
s
.188 0 .528 r
.28785 .93781 m .28653 .95691 L .29817 .96542 L p F P
0 0 0 r
s
0 .78 .12 r
.42076 .98709 m .40257 .99159 L .39163 .98325 L p F P
0 0 0 r
s
0 .78 .12 r
.38241 .98556 m .39163 .98325 L .40257 .99159 L p F P
0 0 0 r
s
.134 0 .891 r
.45234 .19238 m .46288 .20593 L .48129 .19861 L p F P
0 0 0 r
s
.134 0 .891 r
.46288 .20593 m .45234 .19238 L .43398 .19974 L p F P
0 0 0 r
s
.125 0 .956 r
.7143 .99124 m .70665 .98405 L .72592 .97939 L p F P
0 0 0 r
s
.125 0 .956 r
.72592 .97939 m .73361 .98674 L .7143 .99124 L p F P
0 0 0 r
s
0 .78 .12 r
.44971 .9909 m .46019 .98833 L .47151 .98913 L p F P
0 0 0 r
s
0 .78 .12 r
.46019 .98833 m .44971 .9909 L .44365 .98614 L closepath p F P
0 0 0 r
s
.134 0 .891 r
.77471 .20537 m .76623 .19181 L .74675 .19918 L p F P
0 0 0 r
s
.195 0 .31 r
.76757 .20688 m .76623 .19181 L .77471 .20537 L p F P
0 0 0 r
s
.195 0 .31 r
.77471 .20537 m .77608 .22041 L .76757 .20688 L p F P
0 0 0 r
s
.195 0 .31 r
.81848 .36591 m .81687 .34996 L .82501 .36247 L p F P
0 0 0 r
s
.195 0 .31 r
.82501 .36247 m .82666 .37839 L .81848 .36591 L p F P
0 0 0 r
s
.195 0 .31 r
.92031 .68397 m .91813 .66626 L .92561 .67669 L p F P
0 0 0 r
s
.195 0 .31 r
.92561 .67669 m .92781 .69433 L .92031 .68397 L p F P
0 0 0 r
s
.195 0 .31 r
.8694 .52494 m .8675 .50811 L .87531 .51958 L p F P
0 0 0 r
s
.195 0 .31 r
.87531 .51958 m .87724 .53636 L .8694 .52494 L p F P
0 0 0 r
s
.134 0 .891 r
.49982 .19124 m .51006 .20481 L .52865 .19748 L p F P
0 0 0 r
s
.134 0 .891 r
.51006 .20481 m .49982 .19124 L .48129 .19861 L p F P
0 0 0 r
s
.1 0 .485 r
.24371 .21929 m .24527 .20424 L .26291 .19692 L p F P
0 0 0 r
s
.1 0 .485 r
.24527 .20424 m .24371 .21929 L .22611 .22655 L p F P
0 0 0 r
s
.188 0 .528 r
.18532 .64079 m .1872 .62342 L .17481 .61264 L p F P
0 0 0 r
s
.188 0 .528 r
.17675 .59541 m .17481 .61264 L .1872 .62342 L p F P
0 0 0 r
s
.188 0 .528 r
.13472 .48273 m .13687 .46623 L .12415 .4544 L p F P
0 0 0 r
s
.188 0 .528 r
.12637 .43804 m .12415 .4544 L .13687 .46623 L p F P
0 0 0 r
s
.188 0 .528 r
.23593 .79885 m .23752 .78062 L .22547 .77087 L p F P
0 0 0 r
s
.188 0 .528 r
.22713 .75277 m .22547 .77087 L .23752 .78062 L p F P
0 0 0 r
s
0 .78 .12 r
.49689 .99021 m .50117 .98917 L .51818 .98795 L p F P
0 0 0 r
s
0 .78 .12 r
.50117 .98917 m .49689 .99021 L .49587 .98938 L closepath p F P
0 0 0 r
s
.115 0 .563 r
.9412 .82006 m .93891 .80165 L .91886 .80681 L p F P
0 0 0 r
s
.115 0 .563 r
.91886 .80681 m .92103 .82519 L .9412 .82006 L p F P
0 0 0 r
s
.188 0 .528 r
.28653 .95691 m .28785 .93781 L .27613 .92911 L p F P
0 0 0 r
s
.188 0 .528 r
.27751 .91014 m .27613 .92911 L .28785 .93781 L p F P
0 0 0 r
s
0 .78 .71 r
.65785 .9836 m .65983 .9854 L .64072 .98987 L p F P
0 0 0 r
s
0 .78 .71 r
.64072 .98987 m .63877 .98813 L .65785 .9836 L p F P
0 0 0 r
s
.134 0 .891 r
.54736 .1901 m .55729 .20368 L .57606 .19635 L p F P
0 0 0 r
s
.134 0 .891 r
.55729 .20368 m .54736 .1901 L .52865 .19748 L p F P
0 0 0 r
s
.1 0 .485 r
.18756 .27143 m .18943 .25609 L .20687 .24895 L p F P
0 0 0 r
s
.1 0 .485 r
.18943 .25609 m .18756 .27143 L .17016 .27851 L p F P
0 0 0 r
s
.115 0 .563 r
.88505 .87256 m .88307 .85385 L .8632 .85883 L p F P
0 0 0 r
s
.115 0 .563 r
.8632 .85883 m .86507 .8775 L .88505 .87256 L p F P
0 0 0 r
s
0 .78 .12 r
.61033 .9843 m .61168 .98549 L .5923 .98957 L p F P
0 0 0 r
s
0 .78 .12 r
.5923 .98957 m .59142 .98882 L .61033 .9843 L p F P
0 0 0 r
s
.134 0 .891 r
.28067 .18953 m .29237 .20312 L .31019 .19578 L p F P
0 0 0 r
s
.134 0 .891 r
.29237 .20312 m .28067 .18953 L .26291 .19692 L p F P
0 0 0 r
s
.1 0 .485 r
.13139 .3236 m .13356 .30797 L .15081 .30101 L p F P
0 0 0 r
s
.1 0 .485 r
.13356 .30797 m .13139 .3236 L .11417 .33049 L p F P
0 0 0 r
s
0 .78 .12 r
.54413 .98951 m .53946 .98561 L .56011 .98267 L p F P
0 0 0 r
s
0 .78 .12 r
.56011 .98267 m .56286 .985 L .54413 .98951 L p F P
0 0 0 r
s
.195 0 .31 r
.80861 .33728 m .80705 .32147 L .81527 .33419 L p F P
0 0 0 r
s
.195 0 .31 r
.81527 .33419 m .81687 .34996 L .80861 .33728 L p F P
0 0 0 r
s
.195 0 .31 r
.91055 .65569 m .90843 .63812 L .91597 .64874 L p F P
0 0 0 r
s
.195 0 .31 r
.91597 .64874 m .91813 .66626 L .91055 .65569 L p F P
0 0 0 r
s
.115 0 .563 r
.82886 .92508 m .82719 .90608 L .80752 .91087 L p F P
0 0 0 r
s
.115 0 .563 r
.80752 .91087 m .80908 .92984 L .82886 .92508 L p F P
0 0 0 r
s
.195 0 .31 r
.85958 .49648 m .85774 .47979 L .86562 .49146 L p F P
0 0 0 r
s
.195 0 .31 r
.86562 .49146 m .8675 .50811 L .85958 .49648 L p F P
0 0 0 r
s
.511 .78 0 r
.51544 .9857 m .50117 .98917 L .49587 .98938 L p F P
0 0 0 r
s
.511 .78 0 r
.5052 .97728 m .51544 .9857 L p .49587 .98938 L F P
0 0 0 r
s
.511 .78 0 r
.49587 .98938 m .48657 .98185 L .5052 .97728 L p F P
0 0 0 r
s
.511 .78 0 r
.48657 .98185 m .49587 .98938 L .47151 .98913 L p F P
0 0 0 r
s
.134 0 .891 r
.59496 .18896 m .60458 .20256 L .62352 .19522 L p F P
0 0 0 r
s
.134 0 .891 r
.60458 .20256 m .59496 .18896 L .57606 .19635 L p F P
0 0 0 r
s
.115 0 .563 r
.77264 .97764 m .77128 .95834 L .75181 .96295 L p F P
0 0 0 r
s
.115 0 .563 r
.75181 .96295 m .75305 .9822 L .77264 .97764 L p F P
0 0 0 r
s
.511 .78 0 r
.50117 .98917 m .51544 .9857 L .51818 .98795 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.47151 .98913 m .46807 .98639 L .48657 .98185 L p F P
0 0 0 r
s
.511 .78 0 r
.46019 .98833 m .46807 .98639 L .47151 .98913 L closepath p F P
0 0 0 r
s
.188 0 .528 r
.22547 .77087 m .22713 .75277 L .215 .74283 L p F P
0 0 0 r
s
.188 0 .528 r
.21671 .72487 m .215 .74283 L .22713 .75277 L p F P
0 0 0 r
s
.134 0 .891 r
.32813 .18839 m .33952 .202 L .35752 .19465 L p F P
0 0 0 r
s
.134 0 .891 r
.33952 .202 m .32813 .18839 L .31019 .19578 L p F P
0 0 0 r
s
0 .78 .12 r
.61033 .9843 m .59142 .98882 L .58171 .98045 L p F P
0 0 0 r
s
0 .78 .12 r
.56286 .985 m .58171 .98045 L .59142 .98882 L p F P
0 0 0 r
s
.188 0 .528 r
.12415 .4544 m .12637 .43804 L .11356 .42601 L p F P
0 0 0 r
s
.188 0 .528 r
.11584 .40979 m .11356 .42601 L .12637 .43804 L p F P
0 0 0 r
s
.188 0 .528 r
.17481 .61264 m .17675 .59541 L .16428 .58442 L p F P
0 0 0 r
s
.188 0 .528 r
.16628 .56733 m .16428 .58442 L .17675 .59541 L p F P
0 0 0 r
s
.188 0 .528 r
.27613 .92911 m .27751 .91014 L .26571 .90125 L p F P
0 0 0 r
s
.188 0 .528 r
.26715 .88241 m .26571 .90125 L .27751 .91014 L p F P
0 0 0 r
s
0 .647 .956 r
.32629 .98848 m .32549 .98867 L .31339 .98046 L p F P
0 0 0 r
s
.125 0 .956 r
.29691 .98465 m .31339 .98046 L .32549 .98867 L p F P
0 0 0 r
s
0 .647 .956 r
.70543 .9829 m .70665 .98405 L .68746 .98863 L p F P
0 0 0 r
s
0 .647 .956 r
.68746 .98863 m .68616 .98743 L .70543 .9829 L p F P
0 0 0 r
s
.134 0 .891 r
.6426 .18782 m .65192 .20143 L .67104 .19408 L p F P
0 0 0 r
s
.134 0 .891 r
.65192 .20143 m .6426 .18782 L .62352 .19522 L p F P
0 0 0 r
s
0 .647 .956 r
.32629 .98848 m .31481 .9801 L p .34108 .98161 L F P
0 0 0 r
s
0 .647 .956 r
.34108 .98161 m .34424 .98395 L .32629 .98848 L p F P
0 0 0 r
s
0 .647 .956 r
.31339 .98046 m .31481 .9801 L .32629 .98848 L p F P
0 0 0 r
s
.511 .78 0 r
.46807 .98639 m .46019 .98833 L .44365 .98614 L p F P
0 0 0 r
s
.195 0 .31 r
.79872 .30859 m .79721 .29292 L .8055 .30584 L p F P
0 0 0 r
s
.195 0 .31 r
.8055 .30584 m .80705 .32147 L .79872 .30859 L p F P
0 0 0 r
s
.195 0 .31 r
.90078 .62735 m .8987 .60992 L .90632 .62074 L p F P
0 0 0 r
s
.195 0 .31 r
.90632 .62074 m .90843 .63812 L .90078 .62735 L p F P
0 0 0 r
s
.195 0 .31 r
.84975 .46797 m .84796 .45142 L .85591 .46329 L p F P
0 0 0 r
s
.195 0 .31 r
.85591 .46329 m .85774 .47979 L .84975 .46797 L p F P
0 0 0 r
s
.134 0 .891 r
.37564 .18725 m .38672 .20087 L .4049 .19352 L p F P
0 0 0 r
s
.134 0 .891 r
.38672 .20087 m .37564 .18725 L .35752 .19465 L p F P
0 0 0 r
s
.195 0 .31 r
.9518 .78673 m .94944 .76842 L .95673 .77819 L p F P
0 0 0 r
s
.195 0 .31 r
.95673 .77819 m .95911 .79644 L .9518 .78673 L p F P
0 0 0 r
s
0 .78 .71 r
.63877 .98813 m .63099 .9812 L .65024 .9767 L p F P
0 0 0 r
s
0 .78 .71 r
.65024 .9767 m .65785 .9836 L .63877 .98813 L p F P
0 0 0 r
s
.511 .78 0 r
.53411 .98115 m .53946 .98561 L .51818 .98795 L p F P
0 0 0 r
s
.511 .78 0 r
.51818 .98795 m .51544 .9857 L .53411 .98115 L p F P
0 0 0 r
s
.1 0 .485 r
.22444 .24175 m .22611 .22655 L .24371 .21929 L p F P
0 0 0 r
s
.1 0 .485 r
.22611 .22655 m .22444 .24175 L .20687 .24895 L p F P
0 0 0 r
s
0 .78 .71 r
.38241 .98556 m .3735 .98778 L .36233 .9794 L p F P
0 0 0 r
s
0 .78 .71 r
.34472 .98383 m .36233 .9794 L .3735 .98778 L p F P
0 0 0 r
s
.134 0 .891 r
.6903 .18668 m .6993 .20031 L .71861 .19295 L p F P
0 0 0 r
s
.134 0 .891 r
.6993 .20031 m .6903 .18668 L .67104 .19408 L p F P
0 0 0 r
s
.115 0 .563 r
.92322 .84377 m .92103 .82519 L .901 .83029 L p F P
0 0 0 r
s
.115 0 .563 r
.901 .83029 m .90307 .84883 L .92322 .84377 L p F P
0 0 0 r
s
.1 0 .485 r
.16818 .294 m .17016 .27851 L .18756 .27143 L p F P
0 0 0 r
s
.1 0 .485 r
.17016 .27851 m .16818 .294 L .15081 .30101 L p F P
0 0 0 r
s
.188 0 .528 r
.16428 .58442 m .16628 .56733 L .15372 .55615 L p F P
0 0 0 r
s
.188 0 .528 r
.15578 .53919 m .15372 .55615 L .16628 .56733 L p F P
0 0 0 r
s
.188 0 .528 r
.11356 .42601 m .11584 .40979 L .10295 .39756 L p F P
0 0 0 r
s
.188 0 .528 r
.10529 .38148 m .10295 .39756 L .11584 .40979 L p F P
0 0 0 r
s
.188 0 .528 r
.215 .74283 m .21671 .72487 L .2045 .71473 L p F P
0 0 0 r
s
.188 0 .528 r
.20627 .6969 m .2045 .71473 L .21671 .72487 L p F P
0 0 0 r
s
.134 0 .891 r
.42321 .18611 m .43398 .19974 L .45234 .19238 L p F P
0 0 0 r
s
.134 0 .891 r
.43398 .19974 m .42321 .18611 L .4049 .19352 L p F P
0 0 0 r
s
0 .647 .956 r
.68616 .98743 m .67898 .98081 L .69817 .97609 L p F P
0 0 0 r
s
0 .647 .956 r
.69817 .97609 m .70543 .9829 L .68616 .98743 L p F P
0 0 0 r
s
.188 0 .528 r
.26571 .90125 m .26715 .88241 L .25527 .87332 L p F P
0 0 0 r
s
.188 0 .528 r
.25676 .85462 m .25527 .87332 L .26715 .88241 L p F P
0 0 0 r
s
.115 0 .563 r
.86695 .89638 m .86507 .8775 L .84523 .88241 L p F P
0 0 0 r
s
.115 0 .563 r
.84523 .88241 m .847 .90125 L .86695 .89638 L p F P
0 0 0 r
s
.1 0 .485 r
.11189 .34628 m .11417 .33049 L .13139 .3236 L p F P
0 0 0 r
s
.1 0 .485 r
.11417 .33049 m .11189 .34628 L .09471 .3531 L p F P
0 0 0 r
s
.134 0 .891 r
.73806 .18554 m .74675 .19918 L .76623 .19181 L p F P
0 0 0 r
s
.134 0 .891 r
.74675 .19918 m .73806 .18554 L .71861 .19295 L p F P
0 0 0 r
s
.115 0 .563 r
.81065 .94901 m .80908 .92984 L .78943 .93456 L p F P
0 0 0 r
s
.115 0 .563 r
.78943 .93456 m .79089 .95369 L .81065 .94901 L p F P
0 0 0 r
s
0 .78 .12 r
.42076 .98709 m .43303 .98405 L .44365 .98614 L p F P
0 0 0 r
s
0 .78 .12 r
.43303 .98405 m .42076 .98709 L .4099 .97869 L p F P
0 0 0 r
s
0 .78 .12 r
.39163 .98325 m .4099 .97869 L .42076 .98709 L p F P
0 0 0 r
s
.195 0 .31 r
.78881 .27983 m .78735 .2643 L .79572 .27742 L p F P
0 0 0 r
s
.195 0 .31 r
.79572 .27742 m .79721 .29292 L .78881 .27983 L p F P
0 0 0 r
s
.195 0 .31 r
.89098 .59895 m .88895 .58165 L .89665 .59268 L p F P
0 0 0 r
s
.195 0 .31 r
.89665 .59268 m .8987 .60992 L .89098 .59895 L p F P
0 0 0 r
s
.195 0 .31 r
.94206 .75851 m .93975 .74033 L .94711 .7503 L p F P
0 0 0 r
s
.195 0 .31 r
.94711 .7503 m .94944 .76842 L .94206 .75851 L p F P
0 0 0 r
s
.134 0 .891 r
.47083 .18497 m .48129 .19861 L .49982 .19124 L p F P
0 0 0 r
s
.134 0 .891 r
.48129 .19861 m .47083 .18497 L .45234 .19238 L p F P
0 0 0 r
s
.125 0 .956 r
.73361 .98674 m .72592 .97939 L .74529 .97464 L p F P
0 0 0 r
s
.125 0 .956 r
.74529 .97464 m .75305 .9822 L .73361 .98674 L p F P
0 0 0 r
s
.195 0 .31 r
.83989 .43939 m .83815 .42298 L .84618 .43505 L p F P
0 0 0 r
s
.195 0 .31 r
.84618 .43505 m .84796 .45142 L .83989 .43939 L p F P
0 0 0 r
s
.511 .78 0 r
.48657 .98185 m .46807 .98639 L .45752 .97799 L p F P
0 0 0 r
s
.511 .78 0 r
.45752 .97799 m .46807 .98639 L p .44365 .98614 L F P
0 0 0 r
s
.511 .78 0 r
.44365 .98614 m .43907 .98255 L .45752 .97799 L p F P
0 0 0 r
s
.511 .78 0 r
.43303 .98405 m .43907 .98255 L .44365 .98614 L closepath p F P
0 0 0 r
s
.188 0 .528 r
.2045 .71473 m .20627 .6969 L .19397 .68657 L p F P
0 0 0 r
s
.188 0 .528 r
.19581 .66888 m .19397 .68657 L .20627 .6969 L p F P
0 0 0 r
s
.134 0 .891 r
.5185 .18382 m .52865 .19748 L .54736 .1901 L p F P
0 0 0 r
s
.134 0 .891 r
.52865 .19748 m .5185 .18382 L .49982 .19124 L p F P
0 0 0 r
s
.188 0 .528 r
.10295 .39756 m .10529 .38148 L .09232 .36904 L p F P
0 0 0 r
s
.188 0 .528 r
.09471 .3531 m .09232 .36904 L .10529 .38148 L p F P
0 0 0 r
s
.188 0 .528 r
.15372 .55615 m .15578 .53919 L .14315 .52781 L p F P
0 0 0 r
s
.188 0 .528 r
.14526 .51099 m .14315 .52781 L .15578 .53919 L p F P
0 0 0 r
s
.188 0 .528 r
.25527 .87332 m .25676 .85462 L .2448 .84533 L p F P
0 0 0 r
s
.188 0 .528 r
.24636 .82676 m .2448 .84533 L .25676 .85462 L p F P
0 0 0 r
s
.1 0 .485 r
.26144 .21198 m .26291 .19692 L .28067 .18953 L p F P
0 0 0 r
s
.1 0 .485 r
.26291 .19692 m .26144 .21198 L .24371 .21929 L p F P
0 0 0 r
s
.115 0 .563 r
.96152 .8149 m .95911 .79644 L .93891 .80165 L p F P
0 0 0 r
s
.115 0 .563 r
.93891 .80165 m .9412 .82006 L .96152 .8149 L p F P
0 0 0 r
s
.511 .78 0 r
.53411 .98115 m .51544 .9857 L .5052 .97728 L p F P
0 0 0 r
s
.511 .78 0 r
.55293 .97658 m .56011 .98267 L .53946 .98561 L p F P
0 0 0 r
s
.511 .78 0 r
.53946 .98561 m .53411 .98115 L .55293 .97658 L p F P
0 0 0 r
s
0 .78 .12 r
.39163 .98325 m .38241 .98556 L .36721 .97817 L p F P
0 0 0 r
s
0 .78 .71 r
.36233 .9794 m .36721 .97817 L .38241 .98556 L p F P
0 0 0 r
s
0 .78 .12 r
.62937 .97975 m .63099 .9812 L .61168 .98549 L p F P
0 0 0 r
s
0 .78 .12 r
.61168 .98549 m .61033 .9843 L .62937 .97975 L p F P
0 0 0 r
s
0 .78 .71 r
.67707 .97905 m .67898 .98081 L .65983 .9854 L p F P
0 0 0 r
s
0 .78 .71 r
.65983 .9854 m .65785 .9836 L .67707 .97905 L p F P
0 0 0 r
s
.134 0 .891 r
.56622 .18267 m .57606 .19635 L .59496 .18896 L p F P
0 0 0 r
s
.134 0 .891 r
.57606 .19635 m .56622 .18267 L .54736 .1901 L p F P
0 0 0 r
s
.1 0 .485 r
.2051 .2643 m .20687 .24895 L .22444 .24175 L p F P
0 0 0 r
s
.1 0 .485 r
.20687 .24895 m .2051 .2643 L .18756 .27143 L p F P
0 0 0 r
s
.195 0 .31 r
.77887 .25101 m .77747 .23562 L .78591 .24895 L p F P
0 0 0 r
s
.195 0 .31 r
.78591 .24895 m .78735 .2643 L .77887 .25101 L p F P
0 0 0 r
s
.195 0 .31 r
.83002 .41074 m .82833 .39448 L .83643 .40675 L p F P
0 0 0 r
s
.195 0 .31 r
.83643 .40675 m .83815 .42298 L .83002 .41074 L p F P
0 0 0 r
s
.195 0 .31 r
.9323 .73022 m .93004 .71218 L .93747 .72235 L p F P
0 0 0 r
s
.195 0 .31 r
.93747 .72235 m .93975 .74033 L .9323 .73022 L p F P
0 0 0 r
s
.195 0 .31 r
.88116 .57048 m .87919 .55333 L .88695 .56455 L p F P
0 0 0 r
s
.195 0 .31 r
.88695 .56455 m .88895 .58165 L .88116 .57048 L p F P
0 0 0 r
s
.115 0 .563 r
.90517 .86758 m .90307 .84883 L .88307 .85385 L p F P
0 0 0 r
s
.115 0 .563 r
.88307 .85385 m .88505 .87256 L .90517 .86758 L p F P
0 0 0 r
s
.1 0 .485 r
.14872 .31666 m .15081 .30101 L .16818 .294 L p F P
0 0 0 r
s
.1 0 .485 r
.15081 .30101 m .14872 .31666 L .13139 .3236 L p F P
0 0 0 r
s
.134 0 .891 r
.29857 .1821 m .31019 .19578 L .32813 .18839 L p F P
0 0 0 r
s
.134 0 .891 r
.31019 .19578 m .29857 .1821 L .28067 .18953 L p F P
0 0 0 r
s
0 .78 .12 r
.56286 .985 m .56011 .98267 L .58033 .97925 L p F P
0 0 0 r
s
0 .78 .12 r
.58033 .97925 m .58171 .98045 L .56286 .985 L p F P
0 0 0 r
s
.115 0 .563 r
.84878 .92029 m .847 .90125 L .82719 .90608 L p F P
0 0 0 r
s
.115 0 .563 r
.82719 .90608 m .82886 .92508 L .84878 .92029 L p F P
0 0 0 r
s
.1 0 .485 r
.09232 .36904 m .09471 .3531 L .11189 .34628 L p F P
0 0 0 r
s
.188 0 .528 r
.14315 .52781 m .14526 .51099 L .13254 .4994 L p F P
0 0 0 r
s
.188 0 .528 r
.13472 .48273 m .13254 .4994 L .14526 .51099 L p F P
0 0 0 r
s
.115 0 .563 r
.79237 .97304 m .79089 .95369 L .77128 .95834 L p F P
0 0 0 r
s
.115 0 .563 r
.77128 .95834 m .77264 .97764 L .79237 .97304 L p F P
0 0 0 r
s
.188 0 .528 r
.2448 .84533 m .24636 .82676 L .23431 .81728 L p F P
0 0 0 r
s
.188 0 .528 r
.23593 .79885 m .23431 .81728 L .24636 .82676 L p F P
0 0 0 r
s
.188 0 .528 r
.19397 .68657 m .19581 .66888 L .18343 .65834 L p F P
0 0 0 r
s
.188 0 .528 r
.18532 .64079 m .18343 .65834 L .19581 .66888 L p F P
0 0 0 r
s
.188 0 .528 r
.28653 .95691 m .2852 .97622 L .29691 .98465 L p F P
0 0 0 r
s
.125 0 .956 r
.31339 .98046 m .29691 .98465 L .2852 .97622 L p F P
0 0 0 r
s
.134 0 .891 r
.614 .18153 m .62352 .19522 L .6426 .18782 L p F P
0 0 0 r
s
.134 0 .891 r
.62352 .19522 m .614 .18153 L .59496 .18896 L p F P
0 0 0 r
s
.134 0 .891 r
.34621 .18095 m .35752 .19465 L .37564 .18725 L p F P
0 0 0 r
s
.134 0 .891 r
.35752 .19465 m .34621 .18095 L .32813 .18839 L p F P
0 0 0 r
s
0 .78 .12 r
.61033 .9843 m .60071 .97587 L p .61985 .97127 L F P
0 0 0 r
s
0 .78 .12 r
.61985 .97127 m .62937 .97975 L .61033 .9843 L p F P
0 0 0 r
s
0 .78 .12 r
.58171 .98045 m .60071 .97587 L .61033 .9843 L p F P
0 0 0 r
s
0 .647 .956 r
.72483 .97834 m .72592 .97939 L .70665 .98405 L p F P
0 0 0 r
s
0 .647 .956 r
.70665 .98405 m .70543 .9829 L .72483 .97834 L p F P
0 0 0 r
s
.511 .78 0 r
.43907 .98255 m .43303 .98405 L .41173 .97824 L p F P
0 0 0 r
s
0 .78 .12 r
.4099 .97869 m .41173 .97824 L .43303 .98405 L p F P
0 0 0 r
s
.134 0 .891 r
.66182 .18038 m .67104 .19408 L .6903 .18668 L p F P
0 0 0 r
s
.134 0 .891 r
.67104 .19408 m .66182 .18038 L .6426 .18782 L p F P
0 0 0 r
s
.195 0 .31 r
.76892 .22212 m .76757 .20688 L .77608 .22041 L p F P
0 0 0 r
s
.195 0 .31 r
.77608 .22041 m .77747 .23562 L .76892 .22212 L p F P
0 0 0 r
s
.195 0 .31 r
.92251 .70187 m .92031 .68397 L .92781 .69433 L p F P
0 0 0 r
s
.195 0 .31 r
.92781 .69433 m .93004 .71218 L .92251 .70187 L p F P
0 0 0 r
s
0 .647 .956 r
.34472 .98383 m .34424 .98395 L .34108 .98161 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.82012 .38204 m .81848 .36591 L .82666 .37839 L p F P
0 0 0 r
s
.195 0 .31 r
.82666 .37839 m .82833 .39448 L .82012 .38204 L p F P
0 0 0 r
s
.195 0 .31 r
.87131 .54195 m .8694 .52494 L .87724 .53636 L p F P
0 0 0 r
s
.195 0 .31 r
.87724 .53636 m .87919 .55333 L .87131 .54195 L p F P
0 0 0 r
s
0 .78 .71 r
.36233 .9794 m .34472 .98383 L .34108 .98161 L p F P
0 0 0 r
s
.134 0 .891 r
.3939 .1798 m .4049 .19352 L .42321 .18611 L p F P
0 0 0 r
s
.134 0 .891 r
.4049 .19352 m .3939 .1798 L .37564 .18725 L p F P
0 0 0 r
s
0 .78 .71 r
.65785 .9836 m .65024 .9767 L .66945 .97201 L p F P
0 0 0 r
s
0 .78 .71 r
.66945 .97201 m .67707 .97905 L .65785 .9836 L p F P
0 0 0 r
s
.1 0 .485 r
.24214 .23451 m .24371 .21929 L .26144 .21198 L p F P
0 0 0 r
s
.1 0 .485 r
.24371 .21929 m .24214 .23451 L .22444 .24175 L p F P
0 0 0 r
s
.188 0 .528 r
.18343 .65834 m .18532 .64079 L .17286 .63006 L p F P
0 0 0 r
s
.188 0 .528 r
.17481 .61264 m .17286 .63006 L .18532 .64079 L p F P
0 0 0 r
s
.188 0 .528 r
.23431 .81728 m .23593 .79885 L .2238 .78917 L p F P
0 0 0 r
s
.188 0 .528 r
.22547 .77087 m .2238 .78917 L .23593 .79885 L p F P
0 0 0 r
s
.188 0 .528 r
.13254 .4994 m .13472 .48273 L .12192 .47094 L p F P
0 0 0 r
s
.188 0 .528 r
.12415 .4544 m .12192 .47094 L .13472 .48273 L p F P
0 0 0 r
s
.188 0 .528 r
.2852 .97622 m .28653 .95691 L .27474 .94829 L p F P
0 0 0 r
s
.188 0 .528 r
.27613 .92911 m .27474 .94829 L .28653 .95691 L p F P
0 0 0 r
s
0 .78 .12 r
.39163 .98325 m .38054 .97481 L p .40737 .97674 L F P
0 0 0 r
s
0 .78 .12 r
.40737 .97674 m .4099 .97869 L .39163 .98325 L p F P
0 0 0 r
s
0 .78 .12 r
.36721 .97817 m .38054 .97481 L .39163 .98325 L p F P
0 0 0 r
s
.134 0 .891 r
.70971 .17923 m .71861 .19295 L .73806 .18554 L p F P
0 0 0 r
s
.134 0 .891 r
.71861 .19295 m .70971 .17923 L .6903 .18668 L p F P
0 0 0 r
s
.115 0 .563 r
.94352 .83868 m .9412 .82006 L .92103 .82519 L p F P
0 0 0 r
s
.115 0 .563 r
.92103 .82519 m .92322 .84377 L .94352 .83868 L p F P
0 0 0 r
s
.1 0 .485 r
.18568 .28694 m .18756 .27143 L .2051 .2643 L p F P
0 0 0 r
s
.1 0 .485 r
.18756 .27143 m .18568 .28694 L .16818 .294 L p F P
0 0 0 r
s
.134 0 .891 r
.44165 .17865 m .45234 .19238 L .47083 .18497 L p F P
0 0 0 r
s
.134 0 .891 r
.45234 .19238 m .44165 .17865 L .42321 .18611 L p F P
0 0 0 r
s
0 .647 .956 r
.70543 .9829 m .69817 .97609 L .71739 .97122 L p F P
0 0 0 r
s
0 .647 .956 r
.71739 .97122 m .72483 .97834 L .70543 .9829 L p F P
0 0 0 r
s
.115 0 .563 r
.88705 .89148 m .88505 .87256 L .86507 .8775 L p F P
0 0 0 r
s
.115 0 .563 r
.86507 .8775 m .86695 .89638 L .88705 .89148 L p F P
0 0 0 r
s
.511 .78 0 r
.57187 .97197 m .58033 .97925 L .56011 .98267 L p F P
0 0 0 r
s
.511 .78 0 r
.56011 .98267 m .55293 .97658 L .57187 .97197 L p F P
0 0 0 r
s
.1 0 .485 r
.12919 .3394 m .13139 .3236 L .14872 .31666 L p F P
0 0 0 r
s
.1 0 .485 r
.13139 .3236 m .12919 .3394 L .11189 .34628 L p F P
0 0 0 r
s
.134 0 .891 r
.76623 .19181 m .75764 .17807 L .73806 .18554 L p F P
0 0 0 r
s
.195 0 .31 r
.75894 .19317 m .75764 .17807 L .76623 .19181 L p F P
0 0 0 r
s
.195 0 .31 r
.76623 .19181 m .76757 .20688 L .75894 .19317 L p F P
0 0 0 r
s
.195 0 .31 r
.81019 .35326 m .80861 .33728 L .81687 .34996 L p F P
0 0 0 r
s
.195 0 .31 r
.81687 .34996 m .81848 .36591 L .81019 .35326 L p F P
0 0 0 r
s
.195 0 .31 r
.9127 .67346 m .91055 .65569 L .91813 .66626 L p F P
0 0 0 r
s
.195 0 .31 r
.91813 .66626 m .92031 .68397 L .9127 .67346 L p F P
0 0 0 r
s
.115 0 .563 r
.83055 .9443 m .82886 .92508 L .80908 .92984 L p F P
0 0 0 r
s
.115 0 .563 r
.80908 .92984 m .81065 .94901 L .83055 .9443 L p F P
0 0 0 r
s
.511 .78 0 r
.45752 .97799 m .43907 .98255 L .4283 .9741 L p F P
0 0 0 r
s
.511 .78 0 r
.41173 .97824 m .4283 .9741 L .43907 .98255 L p F P
0 0 0 r
s
.195 0 .31 r
.86145 .51336 m .85958 .49648 L .8675 .50811 L p F P
0 0 0 r
s
.195 0 .31 r
.8675 .50811 m .8694 .52494 L .86145 .51336 L p F P
0 0 0 r
s
.134 0 .891 r
.48945 .1775 m .49982 .19124 L .5185 .18382 L p F P
0 0 0 r
s
.134 0 .891 r
.49982 .19124 m .48945 .1775 L .47083 .18497 L p F P
0 0 0 r
s
.125 0 .956 r
.75305 .9822 m .74529 .97464 L .76474 .9698 L p F P
0 0 0 r
s
.125 0 .956 r
.76474 .9698 m .77264 .97764 L .75305 .9822 L p F P
0 0 0 r
s
.188 0 .528 r
.12192 .47094 m .12415 .4544 L .11126 .44241 L p F P
0 0 0 r
s
.188 0 .528 r
.11356 .42601 m .11126 .44241 L .12415 .4544 L p F P
0 0 0 r
s
.188 0 .528 r
.2238 .78917 m .22547 .77087 L .21326 .761 L p F P
0 0 0 r
s
.188 0 .528 r
.215 .74283 m .21326 .761 L .22547 .77087 L p F P
0 0 0 r
s
.511 .78 0 r
.48657 .98185 m .4761 .97339 L p .49943 .97255 L F P
0 0 0 r
s
.511 .78 0 r
.49943 .97255 m .5052 .97728 L .48657 .98185 L p F P
0 0 0 r
s
.511 .78 0 r
.45752 .97799 m .4761 .97339 L .48657 .98185 L p F P
0 0 0 r
s
.188 0 .528 r
.17286 .63006 m .17481 .61264 L .16226 .6017 L p F P
0 0 0 r
s
.188 0 .528 r
.16428 .58442 m .16226 .6017 L .17481 .61264 L p F P
0 0 0 r
s
.188 0 .528 r
.27474 .94829 m .27613 .92911 L .26426 .92029 L p F P
0 0 0 r
s
.188 0 .528 r
.26571 .90125 m .26426 .92029 L .27613 .92911 L p F P
0 0 0 r
s
0 .78 .71 r
.35101 .9709 m .36233 .9794 L p .34108 .98161 L F P
0 0 0 r
s
0 .78 .71 r
.34108 .98161 m .33284 .97552 L .35101 .9709 L p F P
0 0 0 r
s
0 .78 .71 r
.33179 .97579 m .33284 .97552 L .34108 .98161 L closepath p F P
0 0 0 r
s
0 .647 .956 r
.31481 .9801 m .33179 .97579 L .34108 .98161 L p F P
0 0 0 r
s
.134 0 .891 r
.5373 .17634 m .54736 .1901 L .56622 .18267 L p F P
0 0 0 r
s
.134 0 .891 r
.54736 .1901 m .5373 .17634 L .5185 .18382 L p F P
0 0 0 r
s
0 .78 .12 r
.64854 .97516 m .65024 .9767 L .63099 .9812 L p F P
0 0 0 r
s
0 .78 .12 r
.63099 .9812 m .62937 .97975 L .64854 .97516 L p F P
0 0 0 r
s
.1 0 .485 r
.27931 .20461 m .28067 .18953 L .29857 .1821 L p F P
0 0 0 r
s
.1 0 .485 r
.28067 .18953 m .27931 .20461 L .26144 .21198 L p F P
0 0 0 r
s
.511 .78 0 r
.53411 .98115 m .52396 .97268 L p .54481 .9697 L F P
0 0 0 r
s
.511 .78 0 r
.54481 .9697 m .55293 .97658 L .53411 .98115 L p F P
0 0 0 r
s
.511 .78 0 r
.5052 .97728 m .52396 .97268 L .53411 .98115 L p F P
0 0 0 r
s
.195 0 .31 r
.80025 .32443 m .79872 .30859 L .80705 .32147 L p F P
0 0 0 r
s
.195 0 .31 r
.80705 .32147 m .80861 .33728 L .80025 .32443 L p F P
0 0 0 r
s
.195 0 .31 r
.90288 .64498 m .90078 .62735 L .90843 .63812 L p F P
0 0 0 r
s
.195 0 .31 r
.90843 .63812 m .91055 .65569 L .90288 .64498 L p F P
0 0 0 r
s
.195 0 .31 r
.95419 .80526 m .9518 .78673 L .95911 .79644 L p F P
0 0 0 r
s
.195 0 .31 r
.95911 .79644 m .96152 .8149 L .95419 .80526 L p F P
0 0 0 r
s
.195 0 .31 r
.85156 .4847 m .84975 .46797 L .85774 .47979 L p F P
0 0 0 r
s
.195 0 .31 r
.85774 .47979 m .85958 .49648 L .85156 .4847 L p F P
0 0 0 r
s
0 .78 .71 r
.69643 .97445 m .69817 .97609 L .67898 .98081 L p F P
0 0 0 r
s
0 .78 .71 r
.67898 .98081 m .67707 .97905 L .69643 .97445 L p F P
0 0 0 r
s
.134 0 .891 r
.58521 .17519 m .59496 .18896 L .614 .18153 L p F P
0 0 0 r
s
.134 0 .891 r
.59496 .18896 m .58521 .17519 L .56622 .18267 L p F P
0 0 0 r
s
.1 0 .485 r
.22276 .25712 m .22444 .24175 L .24214 .23451 L p F P
0 0 0 r
s
.1 0 .485 r
.22444 .24175 m .22276 .25712 L .2051 .2643 L p F P
0 0 0 r
s
.115 0 .563 r
.92544 .86256 m .92322 .84377 L .90307 .84883 L p F P
0 0 0 r
s
.115 0 .563 r
.90307 .84883 m .90517 .86758 L .92544 .86256 L p F P
0 0 0 r
s
0 .647 .956 r
.31481 .9801 m .31339 .98046 L .30128 .9721 L p F P
0 0 0 r
s
.125 0 .956 r
.2852 .97622 m .30128 .9721 L .31339 .98046 L p F P
0 0 0 r
s
.1 0 .485 r
.16619 .30967 m .16818 .294 L .18568 .28694 L p F P
0 0 0 r
s
.1 0 .485 r
.16818 .294 m .16619 .30967 L .14872 .31666 L p F P
0 0 0 r
s
.188 0 .528 r
.16226 .6017 m .16428 .58442 L .15165 .57329 L p F P
0 0 0 r
s
.188 0 .528 r
.15372 .55615 m .15165 .57329 L .16428 .58442 L p F P
0 0 0 r
s
.188 0 .528 r
.21326 .761 m .215 .74283 L .2027 .73276 L p F P
0 0 0 r
s
.188 0 .528 r
.2045 .71473 m .2027 .73276 L .215 .74283 L p F P
0 0 0 r
s
.134 0 .891 r
.3166 .17461 m .32813 .18839 L .34621 .18095 L p F P
0 0 0 r
s
.134 0 .891 r
.32813 .18839 m .3166 .17461 L .29857 .1821 L p F P
0 0 0 r
s
.188 0 .528 r
.11126 .44241 m .11356 .42601 L .10059 .41382 L p F P
0 0 0 r
s
.188 0 .528 r
.10295 .39756 m .10059 .41382 L .11356 .42601 L p F P
0 0 0 r
s
0 .78 .12 r
.58171 .98045 m .58033 .97925 L .60021 .97544 L p F P
0 0 0 r
s
0 .78 .12 r
.60021 .97544 m .60071 .97587 L .58171 .98045 L p F P
0 0 0 r
s
.188 0 .528 r
.26426 .92029 m .26571 .90125 L .25376 .89223 L p F P
0 0 0 r
s
.188 0 .528 r
.25527 .87332 m .25376 .89223 L .26571 .90125 L p F P
0 0 0 r
s
.115 0 .563 r
.86886 .91547 m .86695 .89638 L .847 .90125 L p F P
0 0 0 r
s
.115 0 .563 r
.847 .90125 m .84878 .92029 L .86886 .91547 L p F P
0 0 0 r
s
.1 0 .485 r
.10958 .36224 m .11189 .34628 L .12919 .3394 L p F P
0 0 0 r
s
.1 0 .485 r
.11189 .34628 m .10958 .36224 L .09232 .36904 L p F P
0 0 0 r
s
.115 0 .563 r
.81224 .9684 m .81065 .94901 L .79089 .95369 L p F P
0 0 0 r
s
.115 0 .563 r
.79089 .95369 m .79237 .97304 L .81224 .9684 L p F P
0 0 0 r
s
0 .647 .956 r
.33179 .97579 m .31481 .9801 L .30318 .97161 L p F P
0 0 0 r
s
0 .647 .956 r
.30128 .9721 m .30318 .97161 L .31481 .9801 L p F P
0 0 0 r
s
.134 0 .891 r
.63317 .17403 m .6426 .18782 L .66182 .18038 L p F P
0 0 0 r
s
.134 0 .891 r
.6426 .18782 m .63317 .17403 L .614 .18153 L p F P
0 0 0 r
s
.195 0 .31 r
.79028 .29553 m .78881 .27983 L .79721 .29292 L p F P
0 0 0 r
s
.195 0 .31 r
.79721 .29292 m .79872 .30859 L .79028 .29553 L p F P
0 0 0 r
s
.195 0 .31 r
.89302 .61644 m .89098 .59895 L .8987 .60992 L p F P
0 0 0 r
s
.195 0 .31 r
.8987 .60992 m .90078 .62735 L .89302 .61644 L p F P
0 0 0 r
s
.134 0 .891 r
.36442 .17345 m .37564 .18725 L .3939 .1798 L p F P
0 0 0 r
s
.134 0 .891 r
.37564 .18725 m .36442 .17345 L .34621 .18095 L p F P
0 0 0 r
s
.195 0 .31 r
.84165 .45598 m .83989 .43939 L .84796 .45142 L p F P
0 0 0 r
s
.195 0 .31 r
.84796 .45142 m .84975 .46797 L .84165 .45598 L p F P
0 0 0 r
s
.195 0 .31 r
.94439 .77689 m .94206 .75851 L .94944 .76842 L p F P
0 0 0 r
s
.195 0 .31 r
.94944 .76842 m .9518 .78673 L .94439 .77689 L p F P
0 0 0 r
s
0 .78 .12 r
.62937 .97975 m .61985 .97127 L .63927 .96675 L p F P
0 0 0 r
s
0 .78 .12 r
.63927 .96675 m .64854 .97516 L .62937 .97975 L p F P
0 0 0 r
s
.134 0 .891 r
.68118 .17287 m .6903 .18668 L .70971 .17923 L p F P
0 0 0 r
s
.134 0 .891 r
.6903 .18668 m .68118 .17287 L .66182 .18038 L p F P
0 0 0 r
s
0 .78 .71 r
.36721 .97817 m .36233 .9794 L .35101 .9709 L p F P
0 0 0 r
s
0 .647 .956 r
.74437 .97375 m .74529 .97464 L .72592 .97939 L p F P
0 0 0 r
s
0 .647 .956 r
.72592 .97939 m .72483 .97834 L .74437 .97375 L p F P
0 0 0 r
s
.511 .78 0 r
.59096 .96733 m .60021 .97544 L .58033 .97925 L p F P
0 0 0 r
s
.511 .78 0 r
.58033 .97925 m .57187 .97197 L .59096 .96733 L p F P
0 0 0 r
s
.188 0 .528 r
.10059 .41382 m .10295 .39756 L .08989 .38516 L p F P
0 0 0 r
s
.188 0 .528 r
.09232 .36904 m .08989 .38516 L .10295 .39756 L p F P
0 0 0 r
s
.188 0 .528 r
.2027 .73276 m .2045 .71473 L .19212 .70446 L p F P
0 0 0 r
s
.188 0 .528 r
.19397 .68657 m .19212 .70446 L .2045 .71473 L p F P
0 0 0 r
s
.134 0 .891 r
.4123 .1723 m .42321 .18611 L .44165 .17865 L p F P
0 0 0 r
s
.134 0 .891 r
.42321 .18611 m .4123 .1723 L .3939 .1798 L p F P
0 0 0 r
s
0 .78 .71 r
.67707 .97905 m .66945 .97201 L .68862 .96712 L p F P
0 0 0 r
s
0 .78 .71 r
.68862 .96712 m .69643 .97445 L .67707 .97905 L p F P
0 0 0 r
s
.188 0 .528 r
.15165 .57329 m .15372 .55615 L .14101 .54481 L p F P
0 0 0 r
s
.188 0 .528 r
.14315 .52781 m .14101 .54481 L .15372 .55615 L p F P
0 0 0 r
s
.188 0 .528 r
.25376 .89223 m .25527 .87332 L .24323 .86411 L p F P
0 0 0 r
s
.188 0 .528 r
.2448 .84533 m .24323 .86411 L .25527 .87332 L p F P
0 0 0 r
s
.1 0 .485 r
.25997 .2272 m .26144 .21198 L .27931 .20461 L p F P
0 0 0 r
s
.1 0 .485 r
.26144 .21198 m .25997 .2272 L .24214 .23451 L p F P
0 0 0 r
s
0 .78 .12 r
.41173 .97824 m .4099 .97869 L .40737 .97674 L closepath p F P
0 0 0 r
s
.134 0 .891 r
.72925 .17172 m .73806 .18554 L .75764 .17807 L p F P
0 0 0 r
s
.134 0 .891 r
.73806 .18554 m .72925 .17172 L .70971 .17923 L p F P
0 0 0 r
s
.115 0 .563 r
.96396 .83355 m .96152 .8149 L .9412 .82006 L p F P
0 0 0 r
s
.115 0 .563 r
.9412 .82006 m .94352 .83868 L .96396 .83355 L p F P
0 0 0 r
s
.1 0 .485 r
.20331 .27983 m .2051 .2643 L .22276 .25712 L p F P
0 0 0 r
s
.1 0 .485 r
.2051 .2643 m .20331 .27983 L .18568 .28694 L p F P
0 0 0 r
s
.195 0 .31 r
.78029 .26656 m .77887 .25101 L .78735 .2643 L p F P
0 0 0 r
s
.195 0 .31 r
.78735 .2643 m .78881 .27983 L .78029 .26656 L p F P
0 0 0 r
s
.134 0 .891 r
.46023 .17114 m .47083 .18497 L .48945 .1775 L p F P
0 0 0 r
s
.134 0 .891 r
.47083 .18497 m .46023 .17114 L .44165 .17865 L p F P
0 0 0 r
s
.195 0 .31 r
.93458 .74847 m .9323 .73022 L .93975 .74033 L p F P
0 0 0 r
s
.195 0 .31 r
.93975 .74033 m .94206 .75851 L .93458 .74847 L p F P
0 0 0 r
s
0 .647 .956 r
.72483 .97834 m .71739 .97122 L .73663 .9662 L p F P
0 0 0 r
s
0 .647 .956 r
.73663 .9662 m .74437 .97375 L .72483 .97834 L p F P
0 0 0 r
s
.195 0 .31 r
.83172 .4272 m .83002 .41074 L .83815 .42298 L p F P
0 0 0 r
s
.195 0 .31 r
.83815 .42298 m .83989 .43939 L .83172 .4272 L p F P
0 0 0 r
s
.195 0 .31 r
.88315 .58783 m .88116 .57048 L .88895 .58165 L p F P
0 0 0 r
s
.195 0 .31 r
.88895 .58165 m .89098 .59895 L .88315 .58783 L p F P
0 0 0 r
s
.115 0 .563 r
.90729 .88654 m .90517 .86758 L .88505 .87256 L p F P
0 0 0 r
s
.115 0 .563 r
.88505 .87256 m .88705 .89148 L .90729 .88654 L p F P
0 0 0 r
s
.511 .78 0 r
.4283 .9741 m .41173 .97824 L .40737 .97674 L p F P
0 0 0 r
s
0 .78 .12 r
.38054 .97481 m .36721 .97817 L .35291 .97042 L p F P
0 0 0 r
s
0 .78 .71 r
.35101 .9709 m .35291 .97042 L .36721 .97817 L p F P
0 0 0 r
s
.1 0 .485 r
.14662 .33248 m .14872 .31666 L .16619 .30967 L p F P
0 0 0 r
s
.1 0 .485 r
.14872 .31666 m .14662 .33248 L .12919 .3394 L p F P
0 0 0 r
s
.115 0 .563 r
.85059 .93955 m .84878 .92029 L .82886 .92508 L p F P
0 0 0 r
s
.115 0 .563 r
.82886 .92508 m .83055 .9443 L .85059 .93955 L p F P
0 0 0 r
s
.511 .78 0 r
.45752 .97799 m .44683 .96947 L p .47388 .97159 L F P
0 0 0 r
s
.511 .78 0 r
.47388 .97159 m .4761 .97339 L .45752 .97799 L p F P
0 0 0 r
s
.511 .78 0 r
.4283 .9741 m .44683 .96947 L .45752 .97799 L p F P
0 0 0 r
s
.134 0 .891 r
.50821 .16997 m .5185 .18382 L .5373 .17634 L p F P
0 0 0 r
s
.134 0 .891 r
.5185 .18382 m .50821 .16997 L .48945 .1775 L p F P
0 0 0 r
s
.1 0 .485 r
.08989 .38516 m .09232 .36904 L .10958 .36224 L p F P
0 0 0 r
s
.188 0 .528 r
.14101 .54481 m .14315 .52781 L .13034 .51627 L p F P
0 0 0 r
s
.188 0 .528 r
.13254 .4994 m .13034 .51627 L .14315 .52781 L p F P
0 0 0 r
s
.125 0 .956 r
.77264 .97764 m .76474 .9698 L .78427 .96484 L p F P
0 0 0 r
s
.125 0 .956 r
.78427 .96484 m .79237 .97304 L .77264 .97764 L p F P
0 0 0 r
s
.188 0 .528 r
.24323 .86411 m .2448 .84533 L .23268 .83593 L p F P
0 0 0 r
s
.188 0 .528 r
.23431 .81728 m .23268 .83593 L .2448 .84533 L p F P
0 0 0 r
s
.188 0 .528 r
.19212 .70446 m .19397 .68657 L .18151 .6761 L p F P
0 0 0 r
s
.188 0 .528 r
.18343 .65834 m .18151 .6761 L .19397 .68657 L p F P
0 0 0 r
s
.511 .78 0 r
.5052 .97728 m .49943 .97255 L .52288 .97178 L p F P
0 0 0 r
s
.511 .78 0 r
.52288 .97178 m .52396 .97268 L .5052 .97728 L p F P
0 0 0 r
s
.195 0 .31 r
.77028 .23753 m .76892 .22212 L .77747 .23562 L p F P
0 0 0 r
s
.195 0 .31 r
.77747 .23562 m .77887 .25101 L .77028 .23753 L p F P
0 0 0 r
s
.195 0 .31 r
.82177 .39835 m .82012 .38204 L .82833 .39448 L p F P
0 0 0 r
s
.195 0 .31 r
.82833 .39448 m .83002 .41074 L .82177 .39835 L p F P
0 0 0 r
s
.195 0 .31 r
.92474 .71998 m .92251 .70187 L .93004 .71218 L p F P
0 0 0 r
s
.195 0 .31 r
.93004 .71218 m .9323 .73022 L .92474 .71998 L p F P
0 0 0 r
s
.134 0 .891 r
.55625 .16881 m .56622 .18267 L .58521 .17519 L p F P
0 0 0 r
s
.134 0 .891 r
.56622 .18267 m .55625 .16881 L .5373 .17634 L p F P
0 0 0 r
s
.195 0 .31 r
.87325 .55916 m .87131 .54195 L .87919 .55333 L p F P
0 0 0 r
s
.195 0 .31 r
.87919 .55333 m .88116 .57048 L .87325 .55916 L p F P
0 0 0 r
s
.511 .78 0 r
.41737 .96553 m .4283 .9741 L p .40737 .97674 L F P
0 0 0 r
s
.511 .78 0 r
.40737 .97674 m .39889 .97019 L .41737 .96553 L p F P
0 0 0 r
s
.511 .78 0 r
.39392 .97144 m .39889 .97019 L .40737 .97674 L closepath p F P
0 0 0 r
s
0 .78 .12 r
.38054 .97481 m .39392 .97144 L .40737 .97674 L p F P
0 0 0 r
s
0 .78 .12 r
.66786 .97054 m .66945 .97201 L .65024 .9767 L p F P
0 0 0 r
s
0 .78 .12 r
.65024 .9767 m .64854 .97516 L .66786 .97054 L p F P
0 0 0 r
s
.1 0 .485 r
.2973 .19719 m .29857 .1821 L .3166 .17461 L p F P
0 0 0 r
s
.1 0 .485 r
.29857 .1821 m .2973 .19719 L .27931 .20461 L p F P
0 0 0 r
s
.511 .78 0 r
.55293 .97658 m .54481 .9697 L .56586 .96678 L p F P
0 0 0 r
s
.511 .78 0 r
.56586 .96678 m .57187 .97197 L .55293 .97658 L p F P
0 0 0 r
s
.1 0 .485 r
.24055 .24989 m .24214 .23451 L .25997 .2272 L p F P
0 0 0 r
s
.1 0 .485 r
.24214 .23451 m .24055 .24989 L .22276 .25712 L p F P
0 0 0 r
s
.188 0 .528 r
.18151 .6761 m .18343 .65834 L .17088 .64767 L p F P
0 0 0 r
s
.188 0 .528 r
.17286 .63006 m .17088 .64767 L .18343 .65834 L p F P
0 0 0 r
s
.134 0 .891 r
.60434 .16765 m .614 .18153 L .63317 .17403 L p F P
0 0 0 r
s
.134 0 .891 r
.614 .18153 m .60434 .16765 L .58521 .17519 L p F P
0 0 0 r
s
.188 0 .528 r
.13034 .51627 m .13254 .4994 L .11965 .48766 L p F P
0 0 0 r
s
.188 0 .528 r
.12192 .47094 m .11965 .48766 L .13254 .4994 L p F P
0 0 0 r
s
.188 0 .528 r
.23268 .83593 m .23431 .81728 L .22211 .80768 L p F P
0 0 0 r
s
.188 0 .528 r
.2238 .78917 m .22211 .80768 L .23431 .81728 L p F P
0 0 0 r
s
.188 0 .528 r
.27474 .94829 m .27333 .96769 L .2852 .97622 L p F P
0 0 0 r
s
.125 0 .956 r
.30128 .9721 m .2852 .97622 L .27333 .96769 L p F P
0 0 0 r
s
.115 0 .563 r
.94586 .85751 m .94352 .83868 L .92322 .84377 L p F P
0 0 0 r
s
.115 0 .563 r
.92322 .84377 m .92544 .86256 L .94586 .85751 L p F P
0 0 0 r
s
0 .78 .71 r
.71593 .96983 m .71739 .97122 L .69817 .97609 L p F P
0 0 0 r
s
0 .78 .71 r
.69817 .97609 m .69643 .97445 L .71593 .96983 L p F P
0 0 0 r
s
.1 0 .485 r
.18378 .30262 m .18568 .28694 L .20331 .27983 L p F P
0 0 0 r
s
.1 0 .485 r
.18568 .28694 m .18378 .30262 L .16619 .30967 L p F P
0 0 0 r
s
.134 0 .891 r
.33475 .16707 m .34621 .18095 L .36442 .17345 L p F P
0 0 0 r
s
.134 0 .891 r
.34621 .18095 m .33475 .16707 L .3166 .17461 L p F P
0 0 0 r
s
0 .78 .12 r
.60071 .97587 m .61926 .9714 L .61985 .97127 L p F P
0 0 0 r
s
0 .78 .12 r
.61926 .9714 m .60071 .97587 L .60021 .97544 L closepath p F P
0 0 0 r
s
.115 0 .563 r
.88907 .91061 m .88705 .89148 L .86695 .89638 L p F P
0 0 0 r
s
.115 0 .563 r
.86695 .89638 m .86886 .91547 L .88907 .91061 L p F P
0 0 0 r
s
0 .78 .71 r
.33284 .97552 m .33179 .97579 L .31913 .96752 L p F P
0 0 0 r
s
0 .647 .956 r
.30318 .97161 m .31913 .96752 L .33179 .97579 L p F P
0 0 0 r
s
.1 0 .485 r
.12697 .35538 m .12919 .3394 L .14662 .33248 L p F P
0 0 0 r
s
.1 0 .485 r
.12919 .3394 m .12697 .35538 L .10958 .36224 L p F P
0 0 0 r
s
.195 0 .31 r
.76025 .20843 m .75894 .19317 L .76757 .20688 L p F P
0 0 0 r
s
.195 0 .31 r
.76757 .20688 m .76892 .22212 L .76025 .20843 L p F P
0 0 0 r
s
.195 0 .31 r
.91488 .69143 m .9127 .67346 L .92031 .68397 L p F P
0 0 0 r
s
.195 0 .31 r
.92031 .68397 m .92251 .70187 L .91488 .69143 L p F P
0 0 0 r
s
.115 0 .563 r
.83226 .96373 m .83055 .9443 L .81065 .94901 L p F P
0 0 0 r
s
.115 0 .563 r
.81065 .94901 m .81224 .9684 L .83226 .96373 L p F P
0 0 0 r
s
0 .78 .71 r
.33284 .97552 m .32129 .96697 L p .34112 .96348 L F P
0 0 0 r
s
0 .78 .71 r
.34112 .96348 m .35101 .9709 L .33284 .97552 L p F P
0 0 0 r
s
0 .78 .71 r
.31913 .96752 m .32129 .96697 L .33284 .97552 L p F P
0 0 0 r
s
.134 0 .891 r
.65248 .16648 m .66182 .18038 L .68118 .17287 L p F P
0 0 0 r
s
.134 0 .891 r
.66182 .18038 m .65248 .16648 L .63317 .17403 L p F P
0 0 0 r
s
.195 0 .31 r
.81179 .36943 m .81019 .35326 L .81848 .36591 L p F P
0 0 0 r
s
.195 0 .31 r
.81848 .36591 m .82012 .38204 L .81179 .36943 L p F P
0 0 0 r
s
.195 0 .31 r
.86334 .53043 m .86145 .51336 L .8694 .52494 L p F P
0 0 0 r
s
.195 0 .31 r
.8694 .52494 m .87131 .54195 L .86334 .53043 L p F P
0 0 0 r
s
.511 .78 0 r
.61984 .97126 m .61926 .9714 L .60021 .97544 L p F P
0 0 0 r
s
.511 .78 0 r
.61018 .96265 m .61984 .97126 L p .60021 .97544 L F P
0 0 0 r
s
.511 .78 0 r
.60021 .97544 m .59096 .96733 L .61018 .96265 L p F P
0 0 0 r
s
.134 0 .891 r
.38276 .1659 m .3939 .1798 L .4123 .1723 L p F P
0 0 0 r
s
.134 0 .891 r
.3939 .1798 m .38276 .1659 L .36442 .17345 L p F P
0 0 0 r
s
0 .78 .12 r
.64854 .97516 m .63927 .96675 L .65853 .96194 L p F P
0 0 0 r
s
0 .78 .12 r
.65853 .96194 m .66786 .97054 L .64854 .97516 L p F P
0 0 0 r
s
.188 0 .528 r
.22211 .80768 m .2238 .78917 L .21151 .77937 L p F P
0 0 0 r
s
.188 0 .528 r
.21326 .761 m .21151 .77937 L .2238 .78917 L p F P
0 0 0 r
s
.134 0 .891 r
.70068 .16532 m .70971 .17923 L .72925 .17172 L p F P
0 0 0 r
s
.134 0 .891 r
.70971 .17923 m .70068 .16532 L .68118 .17287 L p F P
0 0 0 r
s
.188 0 .528 r
.11965 .48766 m .12192 .47094 L .10894 .45899 L p F P
0 0 0 r
s
.188 0 .528 r
.11126 .44241 m .10894 .45899 L .12192 .47094 L p F P
0 0 0 r
s
.188 0 .528 r
.17088 .64767 m .17286 .63006 L .16022 .61918 L p F P
0 0 0 r
s
.188 0 .528 r
.16226 .6017 m .16022 .61918 L .17286 .63006 L p F P
0 0 0 r
s
.188 0 .528 r
.27333 .96769 m .27474 .94829 L .26279 .93955 L p F P
0 0 0 r
s
.188 0 .528 r
.26426 .92029 m .26279 .93955 L .27474 .94829 L p F P
0 0 0 r
s
0 .78 .12 r
.39392 .97144 m .38054 .97481 L .36931 .96625 L p F P
0 0 0 r
s
0 .78 .12 r
.35291 .97042 m .36931 .96625 L .38054 .97481 L p F P
0 0 0 r
s
0 .647 .956 r
.76406 .96912 m .76474 .9698 L .74529 .97464 L p F P
0 0 0 r
s
0 .647 .956 r
.74529 .97464 m .74437 .97375 L .76406 .96912 L p F P
0 0 0 r
s
.134 0 .891 r
.43082 .16473 m .44165 .17865 L .46023 .17114 L p F P
0 0 0 r
s
.134 0 .891 r
.44165 .17865 m .43082 .16473 L .4123 .1723 L p F P
0 0 0 r
s
0 .78 .71 r
.69643 .97445 m .68862 .96712 L .70774 .96199 L p F P
0 0 0 r
s
0 .78 .71 r
.70774 .96199 m .71593 .96983 L .69643 .97445 L p F P
0 0 0 r
s
.1 0 .485 r
.27792 .21985 m .27931 .20461 L .2973 .19719 L p F P
0 0 0 r
s
.1 0 .485 r
.27931 .20461 m .27792 .21985 L .25997 .2272 L p F P
0 0 0 r
s
.195 0 .31 r
.80179 .34045 m .80025 .32443 L .80861 .33728 L p F P
0 0 0 r
s
.195 0 .31 r
.80861 .33728 m .81019 .35326 L .80179 .34045 L p F P
0 0 0 r
s
.195 0 .31 r
.905 .66281 m .90288 .64498 L .91055 .65569 L p F P
0 0 0 r
s
.195 0 .31 r
.91055 .65569 m .9127 .67346 L .905 .66281 L p F P
0 0 0 r
s
.511 .78 0 r
.4283 .9741 m .41737 .96553 L p .44387 .96712 L F P
0 0 0 r
s
.511 .78 0 r
.44387 .96712 m .44683 .96947 L .4283 .9741 L p F P
0 0 0 r
s
.134 0 .891 r
.75764 .17807 m .74894 .16415 L .72925 .17172 L p F P
0 0 0 r
s
.195 0 .31 r
.75019 .17927 m .74894 .16415 L .75764 .17807 L p F P
0 0 0 r
s
.195 0 .31 r
.75764 .17807 m .75894 .19317 L .75019 .17927 L p F P
0 0 0 r
s
.195 0 .31 r
.8534 .50163 m .85156 .4847 L .85958 .49648 L p F P
0 0 0 r
s
.195 0 .31 r
.85958 .49648 m .86145 .51336 L .8534 .50163 L p F P
0 0 0 r
s
.195 0 .31 r
.9566 .82399 m .95419 .80526 L .96152 .8149 L p F P
0 0 0 r
s
.195 0 .31 r
.96152 .8149 m .96396 .83355 L .9566 .82399 L p F P
0 0 0 r
s
.1 0 .485 r
.22106 .27266 m .22276 .25712 L .24055 .24989 L p F P
0 0 0 r
s
.1 0 .485 r
.22276 .25712 m .22106 .27266 L .20331 .27983 L p F P
0 0 0 r
s
.134 0 .891 r
.47894 .16357 m .48945 .1775 L .50821 .16997 L p F P
0 0 0 r
s
.134 0 .891 r
.48945 .1775 m .47894 .16357 L .46023 .17114 L p F P
0 0 0 r
s
0 .647 .956 r
.74437 .97375 m .73663 .9662 L .75587 .96099 L p F P
0 0 0 r
s
0 .647 .956 r
.75587 .96099 m .76406 .96912 L .74437 .97375 L p F P
0 0 0 r
s
.115 0 .563 r
.92768 .88157 m .92544 .86256 L .90517 .86758 L p F P
0 0 0 r
s
.115 0 .563 r
.90517 .86758 m .90729 .88654 L .92768 .88157 L p F P
0 0 0 r
s
.1 0 .485 r
.16417 .3255 m .16619 .30967 L .18378 .30262 L p F P
0 0 0 r
s
.1 0 .485 r
.16619 .30967 m .16417 .3255 L .14662 .33248 L p F P
0 0 0 r
s
.188 0 .528 r
.16022 .61918 m .16226 .6017 L .14954 .59063 L p F P
0 0 0 r
s
.188 0 .528 r
.15165 .57329 m .14954 .59063 L .16226 .6017 L p F P
0 0 0 r
s
.188 0 .528 r
.10894 .45899 m .11126 .44241 L .0982 .43026 L p F P
0 0 0 r
s
.188 0 .528 r
.10059 .41382 m .0982 .43026 L .11126 .44241 L p F P
0 0 0 r
s
.188 0 .528 r
.21151 .77937 m .21326 .761 L .20089 .75099 L p F P
0 0 0 r
s
.188 0 .528 r
.2027 .73276 m .20089 .75099 L .21326 .761 L p F P
0 0 0 r
s
.188 0 .528 r
.26279 .93955 m .26426 .92029 L .25223 .91136 L p F P
0 0 0 r
s
.188 0 .528 r
.25376 .89223 m .25223 .91136 L .26426 .92029 L p F P
0 0 0 r
s
.511 .78 0 r
.4761 .97339 m .48123 .97212 L .49943 .97255 L p F P
0 0 0 r
s
.511 .78 0 r
.48123 .97212 m .4761 .97339 L .47388 .97159 L closepath p F P
0 0 0 r
s
.115 0 .563 r
.87078 .93477 m .86886 .91547 L .84878 .92029 L p F P
0 0 0 r
s
.115 0 .563 r
.84878 .92029 m .85059 .93955 L .87078 .93477 L p F P
0 0 0 r
s
.134 0 .891 r
.52711 .1624 m .5373 .17634 L .55625 .16881 L p F P
0 0 0 r
s
.134 0 .891 r
.5373 .17634 m .52711 .1624 L .50821 .16997 L p F P
0 0 0 r
s
.1 0 .485 r
.10724 .37838 m .10958 .36224 L .12697 .35538 L p F P
0 0 0 r
s
.1 0 .485 r
.10958 .36224 m .10724 .37838 L .08989 .38516 L p F P
0 0 0 r
s
.125 0 .956 r
.79237 .97304 m .78427 .96484 L .80298 .95996 L p F P
0 0 0 r
s
.125 0 .956 r
.81224 .9684 m .79237 .97304 L p .80298 .95996 L F P
0 0 0 r
s
.511 .78 0 r
.52396 .97268 m .52986 .97123 L .54481 .9697 L p F P
0 0 0 r
s
.511 .78 0 r
.52986 .97123 m .52396 .97268 L .52288 .97178 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.79177 .3114 m .79028 .29553 L .79872 .30859 L p F P
0 0 0 r
s
.195 0 .31 r
.79872 .30859 m .80025 .32443 L .79177 .3114 L p F P
0 0 0 r
s
.195 0 .31 r
.89509 .63413 m .89302 .61644 L .90078 .62735 L p F P
0 0 0 r
s
.195 0 .31 r
.90078 .62735 m .90288 .64498 L .89509 .63413 L p F P
0 0 0 r
s
.195 0 .31 r
.94675 .79549 m .94439 .77689 L .9518 .78673 L p F P
0 0 0 r
s
.195 0 .31 r
.9518 .78673 m .95419 .80526 L .94675 .79549 L p F P
0 0 0 r
s
.195 0 .31 r
.84343 .47276 m .84165 .45598 L .84975 .46797 L p F P
0 0 0 r
s
.195 0 .31 r
.84975 .46797 m .85156 .4847 L .84343 .47276 L p F P
0 0 0 r
s
.625 .656 0 r
.51367 .96409 m .52288 .97178 L .49943 .97255 L p F P
0 0 0 r
s
.625 .656 0 r
.49943 .97255 m .49482 .96876 L .51367 .96409 L p F P
0 0 0 r
s
.625 .656 0 r
.48123 .97212 m .49482 .96876 L .49943 .97255 L closepath p F P
0 0 0 r
s
.134 0 .891 r
.57533 .16123 m .58521 .17519 L .60434 .16765 L p F P
0 0 0 r
s
.134 0 .891 r
.58521 .17519 m .57533 .16123 L .55625 .16881 L p F P
0 0 0 r
s
.625 .656 0 r
.49482 .96876 m .48123 .97212 L .47388 .97159 L p F P
0 0 0 r
s
0 .647 .956 r
.30318 .97161 m .30128 .9721 L .28915 .96359 L p F P
0 0 0 r
s
.125 0 .956 r
.27333 .96769 m .28915 .96359 L .30128 .9721 L p F P
0 0 0 r
s
0 .78 .12 r
.68732 .96589 m .68862 .96712 L .66945 .97201 L p F P
0 0 0 r
s
0 .78 .12 r
.66945 .97201 m .66786 .97054 L .68732 .96589 L p F P
0 0 0 r
s
.188 0 .528 r
.20089 .75099 m .2027 .73276 L .19024 .72255 L p F P
0 0 0 r
s
.188 0 .528 r
.19212 .70446 m .19024 .72255 L .2027 .73276 L p F P
0 0 0 r
s
.1 0 .485 r
.31542 .18971 m .3166 .17461 L .33475 .16707 L p F P
0 0 0 r
s
.1 0 .485 r
.3166 .17461 m .31542 .18971 L .2973 .19719 L p F P
0 0 0 r
s
.511 .78 0 r
.57187 .97197 m .56586 .96678 L .58633 .96327 L p F P
0 0 0 r
s
.511 .78 0 r
.58633 .96327 m .59096 .96733 L .57187 .97197 L p F P
0 0 0 r
s
.188 0 .528 r
.0982 .43026 m .10059 .41382 L .08744 .40146 L p F P
0 0 0 r
s
.188 0 .528 r
.08989 .38516 m .08744 .40146 L .10059 .41382 L p F P
0 0 0 r
s
.188 0 .528 r
.14954 .59063 m .15165 .57329 L .13884 .56201 L p F P
0 0 0 r
s
.188 0 .528 r
.14101 .54481 m .13884 .56201 L .15165 .57329 L p F P
0 0 0 r
s
.188 0 .528 r
.25223 .91136 m .25376 .89223 L .24164 .8831 L p F P
0 0 0 r
s
.188 0 .528 r
.24323 .86411 m .24164 .8831 L .25376 .89223 L p F P
0 0 0 r
s
.625 .656 0 r
.54286 .96804 m .52986 .97123 L .52288 .97178 L p F P
0 0 0 r
s
.625 .656 0 r
.53266 .95939 m .54286 .96804 L p .52288 .97178 L F P
0 0 0 r
s
.625 .656 0 r
.52288 .97178 m .51367 .96409 L .53266 .95939 L p F P
0 0 0 r
s
.134 0 .891 r
.62361 .16005 m .63317 .17403 L .65248 .16648 L p F P
0 0 0 r
s
.134 0 .891 r
.63317 .17403 m .62361 .16005 L .60434 .16765 L p F P
0 0 0 r
s
.1 0 .485 r
.25847 .2426 m .25997 .2272 L .27792 .21985 L p F P
0 0 0 r
s
.1 0 .485 r
.25997 .2272 m .25847 .2426 L .24055 .24989 L p F P
0 0 0 r
s
0 .647 .956 r
.31913 .96752 m .30318 .97161 L .29139 .96301 L p F P
0 0 0 r
s
0 .647 .956 r
.28915 .96359 m .29139 .96301 L .30318 .97161 L p F P
0 0 0 r
s
.115 0 .563 r
.96643 .85242 m .96396 .83355 L .94352 .83868 L p F P
0 0 0 r
s
.115 0 .563 r
.94352 .83868 m .94586 .85751 L .96643 .85242 L p F P
0 0 0 r
s
.625 .656 0 r
.4843 .96012 m .49482 .96876 L p .47388 .97159 L F P
0 0 0 r
s
.625 .656 0 r
.47388 .97159 m .4655 .96481 L .4843 .96012 L p F P
0 0 0 r
s
.625 .656 0 r
.45075 .9685 m .4655 .96481 L .47388 .97159 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.44683 .96947 m .45075 .9685 L .47388 .97159 L p F P
0 0 0 r
s
.511 .78 0 r
.39889 .97019 m .39392 .97144 L .37792 .96406 L p F P
0 0 0 r
s
0 .78 .12 r
.36931 .96625 m .37792 .96406 L .39392 .97144 L p F P
0 0 0 r
s
.511 .78 0 r
.61926 .9714 m .61984 .97126 L .61985 .97127 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.63911 .96661 m .63927 .96675 L .61985 .97127 L p F P
0 0 0 r
s
.511 .78 0 r
.61985 .97127 m .61984 .97126 L .63911 .96661 L p F P
0 0 0 r
s
.1 0 .485 r
.20149 .29553 m .20331 .27983 L .22106 .27266 L p F P
0 0 0 r
s
.1 0 .485 r
.20331 .27983 m .20149 .29553 L .18378 .30262 L p F P
0 0 0 r
s
.195 0 .31 r
.78173 .28229 m .78029 .26656 L .78881 .27983 L p F P
0 0 0 r
s
.195 0 .31 r
.78881 .27983 m .79028 .29553 L .78173 .28229 L p F P
0 0 0 r
s
.195 0 .31 r
.83345 .44383 m .83172 .4272 L .83989 .43939 L p F P
0 0 0 r
s
.195 0 .31 r
.83989 .43939 m .84165 .45598 L .83345 .44383 L p F P
0 0 0 r
s
.134 0 .891 r
.35304 .15947 m .36442 .17345 L .38276 .1659 L p F P
0 0 0 r
s
.134 0 .891 r
.36442 .17345 m .35304 .15947 L .33475 .16707 L p F P
0 0 0 r
s
.195 0 .31 r
.93689 .76692 m .93458 .74847 L .94206 .75851 L p F P
0 0 0 r
s
.195 0 .31 r
.94206 .75851 m .94439 .77689 L .93689 .76692 L p F P
0 0 0 r
s
.511 .78 0 r
.63911 .96661 m .61984 .97126 L .61018 .96265 L p F P
0 0 0 r
s
.195 0 .31 r
.88517 .60538 m .88315 .58783 L .89098 .59895 L p F P
0 0 0 r
s
.195 0 .31 r
.89098 .59895 m .89302 .61644 L .88517 .60538 L p F P
0 0 0 r
s
.115 0 .563 r
.90944 .90571 m .90729 .88654 L .88705 .89148 L p F P
0 0 0 r
s
.115 0 .563 r
.88705 .89148 m .88907 .91061 L .90944 .90571 L p F P
0 0 0 r
s
.625 .656 0 r
.52986 .97123 m .54286 .96804 L .54481 .9697 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.73557 .96517 m .73663 .9662 L .71739 .97122 L p F P
0 0 0 r
s
0 .78 .71 r
.71739 .97122 m .71593 .96983 L .73557 .96517 L p F P
0 0 0 r
s
.1 0 .485 r
.14448 .34848 m .14662 .33248 L .16417 .3255 L p F P
0 0 0 r
s
.1 0 .485 r
.14662 .33248 m .14448 .34848 L .12697 .35538 L p F P
0 0 0 r
s
.115 0 .563 r
.85242 .95903 m .85059 .93955 L .83055 .9443 L p F P
0 0 0 r
s
.115 0 .563 r
.83055 .9443 m .83226 .96373 L .85242 .95903 L p F P
0 0 0 r
s
0 .78 .71 r
.35291 .97042 m .35101 .9709 L .34112 .96348 L closepath p F P
0 0 0 r
s
.134 0 .891 r
.67194 .15888 m .68118 .17287 L .70068 .16532 L p F P
0 0 0 r
s
.134 0 .891 r
.68118 .17287 m .67194 .15888 L .65248 .16648 L p F P
0 0 0 r
s
.1 0 .485 r
.08744 .40146 m .08989 .38516 L .10724 .37838 L p F P
0 0 0 r
s
.134 0 .891 r
.40123 .15829 m .4123 .1723 L .43082 .16473 L p F P
0 0 0 r
s
.134 0 .891 r
.4123 .1723 m .40123 .15829 L .38276 .1659 L p F P
0 0 0 r
s
0 .78 .12 r
.66786 .97054 m .65853 .96194 L .6591 .96179 L p F P
0 0 0 r
s
0 .78 .12 r
.68732 .96589 m .66786 .97054 L p .6591 .96179 L F P
0 0 0 r
s
.188 0 .528 r
.13884 .56201 m .14101 .54481 L .12811 .53332 L p F P
0 0 0 r
s
.188 0 .528 r
.13034 .51627 m .12811 .53332 L .14101 .54481 L p F P
0 0 0 r
s
.188 0 .528 r
.24164 .8831 m .24323 .86411 L .23103 .85478 L p F P
0 0 0 r
s
.188 0 .528 r
.23268 .83593 m .23103 .85478 L .24323 .86411 L p F P
0 0 0 r
s
.188 0 .528 r
.19024 .72255 m .19212 .70446 L .17957 .69405 L p F P
0 0 0 r
s
.188 0 .528 r
.18151 .6761 m .17957 .69405 L .19212 .70446 L p F P
0 0 0 r
s
0 .78 .12 r
.36931 .96625 m .35291 .97042 L .34112 .96348 L p F P
0 0 0 r
s
.134 0 .891 r
.72033 .15771 m .72925 .17172 L .74894 .16415 L p F P
0 0 0 r
s
.134 0 .891 r
.72925 .17172 m .72033 .15771 L .70068 .16532 L p F P
0 0 0 r
s
.511 .78 0 r
.41737 .96553 m .39889 .97019 L .38774 .96157 L p F P
0 0 0 r
s
.511 .78 0 r
.37792 .96406 m .38774 .96157 L .39889 .97019 L p F P
0 0 0 r
s
.195 0 .31 r
.77166 .25311 m .77028 .23753 L .77887 .25101 L p F P
0 0 0 r
s
.195 0 .31 r
.77887 .25101 m .78029 .26656 L .77166 .25311 L p F P
0 0 0 r
s
.195 0 .31 r
.92699 .73829 m .92474 .71998 L .9323 .73022 L p F P
0 0 0 r
s
.195 0 .31 r
.9323 .73022 m .93458 .74847 L .92699 .73829 L p F P
0 0 0 r
s
.134 0 .891 r
.44948 .15712 m .46023 .17114 L .47894 .16357 L p F P
0 0 0 r
s
.134 0 .891 r
.46023 .17114 m .44948 .15712 L .43082 .16473 L p F P
0 0 0 r
s
0 .78 .71 r
.71593 .96983 m .70774 .96199 L .72678 .95661 L p F P
0 0 0 r
s
0 .78 .71 r
.72678 .95661 m .73557 .96517 L .71593 .96983 L p F P
0 0 0 r
s
.195 0 .31 r
.82344 .41484 m .82177 .39835 L .83002 .41074 L p F P
0 0 0 r
s
.195 0 .31 r
.83002 .41074 m .83172 .4272 L .82344 .41484 L p F P
0 0 0 r
s
.195 0 .31 r
.87522 .57657 m .87325 .55916 L .88116 .57048 L p F P
0 0 0 r
s
.195 0 .31 r
.88116 .57048 m .88315 .58783 L .87522 .57657 L p F P
0 0 0 r
s
0 .647 .956 r
.78389 .96445 m .78427 .96484 L .76474 .9698 L p F P
0 0 0 r
s
0 .647 .956 r
.76474 .9698 m .76406 .96912 L .78389 .96445 L p F P
0 0 0 r
s
.625 .656 0 r
.5619 .96337 m .56586 .96678 L .54481 .9697 L p F P
0 0 0 r
s
.625 .656 0 r
.54481 .9697 m .54286 .96804 L .5619 .96337 L p F P
0 0 0 r
s
.1 0 .485 r
.29601 .21244 m .2973 .19719 L .31542 .18971 L p F P
0 0 0 r
s
.1 0 .485 r
.2973 .19719 m .29601 .21244 L .27792 .21985 L p F P
0 0 0 r
s
.511 .78 0 r
.45075 .9685 m .44683 .96947 L .44387 .96712 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.23895 .26545 m .24055 .24989 L .25847 .2426 L p F P
0 0 0 r
s
.1 0 .485 r
.24055 .24989 m .23895 .26545 L .22106 .27266 L p F P
0 0 0 r
s
.188 0 .528 r
.17957 .69405 m .18151 .6761 L .16888 .66548 L p F P
0 0 0 r
s
.188 0 .528 r
.17088 .64767 m .16888 .66548 L .18151 .6761 L p F P
0 0 0 r
s
.134 0 .891 r
.49778 .15594 m .50821 .16997 L .52711 .1624 L p F P
0 0 0 r
s
.134 0 .891 r
.50821 .16997 m .49778 .15594 L .47894 .16357 L p F P
0 0 0 r
s
.188 0 .528 r
.12811 .53332 m .13034 .51627 L .11736 .50458 L p F P
0 0 0 r
s
.188 0 .528 r
.11965 .48766 m .11736 .50458 L .13034 .51627 L p F P
0 0 0 r
s
0 .647 .956 r
.76406 .96912 m .75587 .96099 L .76972 .95708 L p F P
0 0 0 r
s
0 .647 .956 r
.78389 .96445 m .76406 .96912 L p .76972 .95708 L F P
0 0 0 r
s
.188 0 .528 r
.23103 .85478 m .23268 .83593 L .22039 .82639 L p F P
0 0 0 r
s
.188 0 .528 r
.22211 .80768 m .22039 .82639 L .23268 .83593 L p F P
0 0 0 r
s
.115 0 .563 r
.94822 .87655 m .94586 .85751 L .92544 .86256 L p F P
0 0 0 r
s
.115 0 .563 r
.92544 .86256 m .92768 .88157 L .94822 .87655 L p F P
0 0 0 r
s
.1 0 .485 r
.18185 .31848 m .18378 .30262 L .20149 .29553 L p F P
0 0 0 r
s
.1 0 .485 r
.18378 .30262 m .18185 .31848 L .16417 .3255 L p F P
0 0 0 r
s
.115 0 .563 r
.89112 .92996 m .88907 .91061 L .86886 .91547 L p F P
0 0 0 r
s
.115 0 .563 r
.86886 .91547 m .87078 .93477 L .89112 .92996 L p F P
0 0 0 r
s
.625 .656 0 r
.51367 .96409 m .49482 .96876 L .4843 .96012 L p F P
0 0 0 r
s
.625 .656 0 r
.4655 .96481 m .45075 .9685 L .44387 .96712 L p F P
0 0 0 r
s
.195 0 .31 r
.76157 .22387 m .76025 .20843 L .76892 .22212 L p F P
0 0 0 r
s
.195 0 .31 r
.76892 .22212 m .77028 .23753 L .76157 .22387 L p F P
0 0 0 r
s
.195 0 .31 r
.81341 .38578 m .81179 .36943 L .82012 .38204 L p F P
0 0 0 r
s
.195 0 .31 r
.82012 .38204 m .82177 .39835 L .81341 .38578 L p F P
0 0 0 r
s
.195 0 .31 r
.91708 .7096 m .91488 .69143 L .92251 .70187 L p F P
0 0 0 r
s
.195 0 .31 r
.92251 .70187 m .92474 .71998 L .91708 .7096 L p F P
0 0 0 r
s
.134 0 .891 r
.54614 .15476 m .55625 .16881 L .57533 .16123 L p F P
0 0 0 r
s
.134 0 .891 r
.55625 .16881 m .54614 .15476 L .52711 .1624 L p F P
0 0 0 r
s
.1 0 .485 r
.12472 .37154 m .12697 .35538 L .14448 .34848 L p F P
0 0 0 r
s
.1 0 .485 r
.12697 .35538 m .12472 .37154 L .10724 .37838 L p F P
0 0 0 r
s
.125 0 .956 r
.83226 .96373 m .81224 .9684 L .80386 .95976 L p F P
0 0 0 r
s
.125 0 .956 r
.80298 .95996 m .80386 .95976 L .81224 .9684 L p F P
0 0 0 r
s
.195 0 .31 r
.86524 .54769 m .86334 .53043 L .87131 .54195 L p F P
0 0 0 r
s
.195 0 .31 r
.87131 .54195 m .87325 .55916 L .86524 .54769 L p F P
0 0 0 r
s
.625 .656 0 r
.5619 .96337 m .54286 .96804 L .53266 .95939 L p F P
0 0 0 r
s
.188 0 .528 r
.11736 .50458 m .11965 .48766 L .10659 .47576 L p F P
0 0 0 r
s
.188 0 .528 r
.10894 .45899 m .10659 .47576 L .11965 .48766 L p F P
0 0 0 r
s
.188 0 .528 r
.22039 .82639 m .22211 .80768 L .20973 .79794 L p F P
0 0 0 r
s
.188 0 .528 r
.21151 .77937 m .20973 .79794 L .22211 .80768 L p F P
0 0 0 r
s
.188 0 .528 r
.16888 .66548 m .17088 .64767 L .15816 .63685 L p F P
0 0 0 r
s
.188 0 .528 r
.16022 .61918 m .15816 .63685 L .17088 .64767 L p F P
0 0 0 r
s
.188 0 .528 r
.26279 .93955 m .26131 .95903 L .27333 .96769 L p F P
0 0 0 r
s
.125 0 .956 r
.28915 .96359 m .27333 .96769 L .26131 .95903 L p F P
0 0 0 r
s
.134 0 .891 r
.59455 .15359 m .60434 .16765 L .62361 .16005 L p F P
0 0 0 r
s
.134 0 .891 r
.60434 .16765 m .59455 .15359 L .57533 .16123 L p F P
0 0 0 r
s
0 .78 .71 r
.32129 .96697 m .31913 .96752 L .30662 .95907 L p F P
0 0 0 r
s
0 .647 .956 r
.29139 .96301 m .30662 .95907 L .31913 .96752 L p F P
0 0 0 r
s
.1 0 .485 r
.33367 .18218 m .33475 .16707 L .35304 .15947 L p F P
0 0 0 r
s
.1 0 .485 r
.33475 .16707 m .33367 .18218 L .31542 .18971 L p F P
0 0 0 r
s
.511 .78 0 r
.59096 .96733 m .58633 .96327 L .60636 .95925 L p F P
0 0 0 r
s
.511 .78 0 r
.60636 .95925 m .61018 .96265 L .59096 .96733 L p F P
0 0 0 r
s
0 .78 .12 r
.70691 .96121 m .70774 .96199 L .68862 .96712 L p F P
0 0 0 r
s
0 .78 .12 r
.68862 .96712 m .68732 .96589 L .70691 .96121 L p F P
0 0 0 r
s
.625 .656 0 r
.45475 .95612 m .4655 .96481 L p .44387 .96712 L F P
0 0 0 r
s
.625 .656 0 r
.44387 .96712 m .43599 .96084 L .45475 .95612 L p F P
0 0 0 r
s
.625 .656 0 r
.42774 .96292 m .43599 .96084 L .44387 .96712 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.41737 .96553 m .42774 .96292 L .44387 .96712 L p F P
0 0 0 r
s
.1 0 .485 r
.27652 .23526 m .27792 .21985 L .29601 .21244 L p F P
0 0 0 r
s
.1 0 .485 r
.27792 .21985 m .27652 .23526 L .25847 .2426 L p F P
0 0 0 r
s
.134 0 .891 r
.64302 .1524 m .65248 .16648 L .67194 .15888 L p F P
0 0 0 r
s
.134 0 .891 r
.65248 .16648 m .64302 .1524 L .62361 .16005 L p F P
0 0 0 r
s
.195 0 .31 r
.90715 .68084 m .905 .66281 L .9127 .67346 L p F P
0 0 0 r
s
.195 0 .31 r
.9127 .67346 m .91488 .69143 L .90715 .68084 L p F P
0 0 0 r
s
0 .78 .71 r
.32129 .96697 m .33928 .96236 L .34112 .96348 L p F P
0 0 0 r
s
0 .78 .71 r
.33928 .96236 m .32129 .96697 L .30959 .9583 L p F P
0 0 0 r
s
0 .78 .71 r
.30662 .95907 m .30959 .9583 L .32129 .96697 L p F P
0 0 0 r
s
.195 0 .31 r
.80336 .35665 m .80179 .34045 L .81019 .35326 L p F P
0 0 0 r
s
.195 0 .31 r
.81019 .35326 m .81179 .36943 L .80336 .35665 L p F P
0 0 0 r
s
.195 0 .31 r
.75146 .19456 m .75019 .17927 L .75894 .19317 L p F P
0 0 0 r
s
.195 0 .31 r
.75894 .19317 m .76025 .20843 L .75146 .19456 L p F P
0 0 0 r
s
.195 0 .31 r
.85525 .51874 m .8534 .50163 L .86145 .51336 L p F P
0 0 0 r
s
.195 0 .31 r
.86145 .51336 m .86334 .53043 L .85525 .51874 L p F P
0 0 0 r
s
.195 0 .31 r
.95904 .84293 m .9566 .82399 L .96396 .83355 L p F P
0 0 0 r
s
.195 0 .31 r
.96396 .83355 m .96643 .85242 L .95904 .84293 L p F P
0 0 0 r
s
.625 .656 0 r
.58108 .95867 m .58633 .96327 L .56586 .96678 L p F P
0 0 0 r
s
.625 .656 0 r
.56586 .96678 m .5619 .96337 L .58108 .95867 L p F P
0 0 0 r
s
.511 .78 0 r
.65852 .96193 m .65853 .96194 L .63927 .96675 L p F P
0 0 0 r
s
.511 .78 0 r
.63927 .96675 m .63911 .96661 L .65852 .96193 L p F P
0 0 0 r
s
.134 0 .891 r
.37146 .15181 m .38276 .1659 L .40123 .15829 L p F P
0 0 0 r
s
.134 0 .891 r
.38276 .1659 m .37146 .15181 L .35304 .15947 L p F P
0 0 0 r
s
.1 0 .485 r
.21934 .28838 m .22106 .27266 L .23895 .26545 L p F P
0 0 0 r
s
.1 0 .485 r
.22106 .27266 m .21934 .28838 L .20149 .29553 L p F P
0 0 0 r
s
.511 .78 0 r
.65852 .96193 m .63911 .96661 L .62955 .95794 L p F P
0 0 0 r
s
.511 .78 0 r
.61018 .96265 m .62955 .95794 L .63911 .96661 L p F P
0 0 0 r
s
.115 0 .563 r
.92995 .90078 m .92768 .88157 L .90729 .88654 L p F P
0 0 0 r
s
.115 0 .563 r
.90729 .88654 m .90944 .90571 L .92995 .90078 L p F P
0 0 0 r
s
.1 0 .485 r
.16213 .34152 m .16417 .3255 L .18185 .31848 L p F P
0 0 0 r
s
.1 0 .485 r
.16417 .3255 m .16213 .34152 L .14448 .34848 L p F P
0 0 0 r
s
.188 0 .528 r
.15816 .63685 m .16022 .61918 L .14742 .60816 L p F P
0 0 0 r
s
.188 0 .528 r
.14954 .59063 m .14742 .60816 L .16022 .61918 L p F P
0 0 0 r
s
.188 0 .528 r
.20973 .79794 m .21151 .77937 L .19905 .76943 L p F P
0 0 0 r
s
.188 0 .528 r
.20089 .75099 m .19905 .76943 L .21151 .77937 L p F P
0 0 0 r
s
.188 0 .528 r
.10659 .47576 m .10894 .45899 L .09579 .44689 L p F P
0 0 0 r
s
.188 0 .528 r
.0982 .43026 m .09579 .44689 L .10894 .45899 L p F P
0 0 0 r
s
.188 0 .528 r
.26131 .95903 m .26279 .93955 L .25068 .9307 L p F P
0 0 0 r
s
.188 0 .528 r
.25223 .91136 m .25068 .9307 L .26279 .93955 L p F P
0 0 0 r
s
0 .78 .12 r
.37792 .96406 m .36931 .96625 L .35792 .95758 L p F P
0 0 0 r
s
0 .78 .12 r
.35792 .95758 m .36931 .96625 L p .34112 .96348 L F P
0 0 0 r
s
.134 0 .891 r
.69154 .15122 m .70068 .16532 L .72033 .15771 L p F P
0 0 0 r
s
.134 0 .891 r
.70068 .16532 m .69154 .15122 L .67194 .15888 L p F P
0 0 0 r
s
.115 0 .563 r
.87273 .95429 m .87078 .93477 L .85059 .93955 L p F P
0 0 0 r
s
.115 0 .563 r
.85059 .93955 m .85242 .95903 L .87273 .95429 L p F P
0 0 0 r
s
0 .78 .71 r
.75536 .96048 m .75587 .96099 L .73663 .9662 L p F P
0 0 0 r
s
0 .78 .71 r
.73663 .9662 m .73557 .96517 L .75536 .96048 L p F P
0 0 0 r
s
.1 0 .485 r
.10488 .3947 m .10724 .37838 L .12472 .37154 L p F P
0 0 0 r
s
.1 0 .485 r
.10724 .37838 m .10488 .3947 L .08744 .40146 L p F P
0 0 0 r
s
.134 0 .891 r
.41985 .15063 m .43082 .16473 L .44948 .15712 L p F P
0 0 0 r
s
.134 0 .891 r
.43082 .16473 m .41985 .15063 L .40123 .15829 L p F P
0 0 0 r
s
0 .78 .12 r
.70691 .96121 m .68732 .96589 L .67808 .95721 L p F P
0 0 0 r
s
0 .78 .12 r
.6591 .96179 m .67808 .95721 L .68732 .96589 L p F P
0 0 0 r
s
.134 0 .891 r
.74894 .16415 m .74011 .15004 L .72033 .15771 L p F P
0 0 0 r
s
.195 0 .31 r
.74132 .16518 m .74011 .15004 L .74894 .16415 L p F P
0 0 0 r
s
.195 0 .31 r
.74894 .16415 m .75019 .17927 L .74132 .16518 L p F P
0 0 0 r
s
.195 0 .31 r
.79328 .32746 m .79177 .3114 L .80025 .32443 L p F P
0 0 0 r
s
.195 0 .31 r
.80025 .32443 m .80179 .34045 L .79328 .32746 L p F P
0 0 0 r
s
.195 0 .31 r
.89719 .65201 m .89509 .63413 L .90288 .64498 L p F P
0 0 0 r
s
.195 0 .31 r
.90288 .64498 m .905 .66281 L .89719 .65201 L p F P
0 0 0 r
s
.511 .78 0 r
.42774 .96292 m .41737 .96553 L .4063 .95685 L p F P
0 0 0 r
s
.511 .78 0 r
.38774 .96157 m .4063 .95685 L .41737 .96553 L p F P
0 0 0 r
s
.195 0 .31 r
.84523 .48974 m .84343 .47276 L .85156 .4847 L p F P
0 0 0 r
s
.195 0 .31 r
.85156 .4847 m .8534 .50163 L .84523 .48974 L p F P
0 0 0 r
s
.195 0 .31 r
.94914 .81429 m .94675 .79549 L .95419 .80526 L p F P
0 0 0 r
s
.195 0 .31 r
.95419 .80526 m .9566 .82399 L .94914 .81429 L p F P
0 0 0 r
s
.134 0 .891 r
.46828 .14945 m .47894 .16357 L .49778 .15594 L p F P
0 0 0 r
s
.134 0 .891 r
.47894 .16357 m .46828 .14945 L .44948 .15712 L p F P
0 0 0 r
s
0 .78 .71 r
.73557 .96517 m .72678 .95661 L .72937 .95583 L p F P
0 0 0 r
s
0 .78 .71 r
.75536 .96048 m .73557 .96517 L p .72937 .95583 L F P
0 0 0 r
s
0 .647 .956 r
.78427 .96484 m .78389 .96445 L .80298 .95996 L closepath p F P
0 0 0 r
s
.188 0 .528 r
.09579 .44689 m .0982 .43026 L .08496 .41794 L p F P
0 0 0 r
s
.188 0 .528 r
.08744 .40146 m .08496 .41794 L .0982 .43026 L p F P
0 0 0 r
s
.188 0 .528 r
.19905 .76943 m .20089 .75099 L .18834 .74085 L p F P
0 0 0 r
s
.188 0 .528 r
.19024 .72255 m .18834 .74085 L .20089 .75099 L p F P
0 0 0 r
s
.1 0 .485 r
.31423 .20498 m .31542 .18971 L .33367 .18218 L p F P
0 0 0 r
s
.1 0 .485 r
.31542 .18971 m .31423 .20498 L .29601 .21244 L p F P
0 0 0 r
s
.188 0 .528 r
.14742 .60816 m .14954 .59063 L .13665 .5794 L p F P
0 0 0 r
s
.188 0 .528 r
.13884 .56201 m .13665 .5794 L .14954 .59063 L p F P
0 0 0 r
s
.188 0 .528 r
.25068 .9307 m .25223 .91136 L .24003 .9023 L p F P
0 0 0 r
s
.188 0 .528 r
.24164 .8831 m .24003 .9023 L .25223 .91136 L p F P
0 0 0 r
s
.625 .656 0 r
.4843 .96012 m .4655 .96481 L .45475 .95612 L p F P
0 0 0 r
s
.1 0 .485 r
.25696 .25818 m .25847 .2426 L .27652 .23526 L p F P
0 0 0 r
s
.1 0 .485 r
.25847 .2426 m .25696 .25818 L .23895 .26545 L p F P
0 0 0 r
s
.134 0 .891 r
.51677 .14826 m .52711 .1624 L .54614 .15476 L p F P
0 0 0 r
s
.134 0 .891 r
.52711 .1624 m .51677 .14826 L .49778 .15594 L p F P
0 0 0 r
s
0 .647 .956 r
.80298 .95996 m .78389 .96445 L .77529 .95576 L p F P
0 0 0 r
s
0 .647 .956 r
.76972 .95708 m .77529 .95576 L .78389 .96445 L p F P
0 0 0 r
s
.115 0 .563 r
.96892 .87151 m .96643 .85242 L .94586 .85751 L p F P
0 0 0 r
s
.115 0 .563 r
.94586 .85751 m .94822 .87655 L .96892 .87151 L p F P
0 0 0 r
s
.1 0 .485 r
.19966 .3114 m .20149 .29553 L .21934 .28838 L p F P
0 0 0 r
s
.1 0 .485 r
.20149 .29553 m .19966 .3114 L .18185 .31848 L p F P
0 0 0 r
s
.195 0 .31 r
.78318 .2982 m .78173 .28229 L .79028 .29553 L p F P
0 0 0 r
s
.195 0 .31 r
.79028 .29553 m .79177 .3114 L .78318 .2982 L p F P
0 0 0 r
s
.195 0 .31 r
.93922 .78558 m .93689 .76692 L .94439 .77689 L p F P
0 0 0 r
s
.195 0 .31 r
.94439 .77689 m .94675 .79549 L .93922 .78558 L p F P
0 0 0 r
s
.625 .656 0 r
.51367 .96409 m .50324 .95539 L p .52476 .95269 L F P
0 0 0 r
s
.625 .656 0 r
.52476 .95269 m .53266 .95939 L .51367 .96409 L p F P
0 0 0 r
s
.625 .656 0 r
.4843 .96012 m .50324 .95539 L .51367 .96409 L p F P
0 0 0 r
s
.195 0 .31 r
.83519 .46066 m .83345 .44383 L .84165 .45598 L p F P
0 0 0 r
s
.195 0 .31 r
.84165 .45598 m .84343 .47276 L .83519 .46066 L p F P
0 0 0 r
s
.195 0 .31 r
.88721 .62312 m .88517 .60538 L .89302 .61644 L p F P
0 0 0 r
s
.195 0 .31 r
.89302 .61644 m .89509 .63413 L .88721 .62312 L p F P
0 0 0 r
s
.115 0 .563 r
.91161 .9251 m .90944 .90571 L .88907 .91061 L p F P
0 0 0 r
s
.115 0 .563 r
.88907 .91061 m .89112 .92996 L .91161 .9251 L p F P
0 0 0 r
s
.511 .78 0 r
.38774 .96157 m .37792 .96406 L .36305 .95626 L p F P
0 0 0 r
s
0 .78 .12 r
.35792 .95758 m .36305 .95626 L .37792 .96406 L p F P
0 0 0 r
s
.134 0 .891 r
.56532 .14708 m .57533 .16123 L .59455 .15359 L p F P
0 0 0 r
s
.134 0 .891 r
.57533 .16123 m .56532 .14708 L .54614 .15476 L p F P
0 0 0 r
s
.1 0 .485 r
.14233 .36466 m .14448 .34848 L .16213 .34152 L p F P
0 0 0 r
s
.1 0 .485 r
.14448 .34848 m .14233 .36466 L .12472 .37154 L p F P
0 0 0 r
s
.125 0 .956 r
.85242 .95903 m .83226 .96373 L .82398 .95503 L p F P
0 0 0 r
s
.125 0 .956 r
.80386 .95976 m .82398 .95503 L .83226 .96373 L p F P
0 0 0 r
s
0 .647 .956 r
.29139 .96301 m .28915 .96359 L .27696 .95494 L p F P
0 0 0 r
s
.125 0 .956 r
.26131 .95903 m .27696 .95494 L .28915 .96359 L p F P
0 0 0 r
s
0 .78 .12 r
.34112 .96348 m .33954 .96229 L .35792 .95758 L p F P
0 0 0 r
s
0 .78 .12 r
.33928 .96236 m .33954 .96229 L .34112 .96348 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.58108 .95867 m .5619 .96337 L .55179 .95466 L p F P
0 0 0 r
s
.625 .656 0 r
.53266 .95939 m .55179 .95466 L .5619 .96337 L p F P
0 0 0 r
s
.1 0 .485 r
.08496 .41794 m .08744 .40146 L .10488 .3947 L p F P
0 0 0 r
s
.188 0 .528 r
.13665 .5794 m .13884 .56201 L .12586 .55057 L p F P
0 0 0 r
s
.188 0 .528 r
.12811 .53332 m .12586 .55057 L .13884 .56201 L p F P
0 0 0 r
s
.188 0 .528 r
.24003 .9023 m .24164 .8831 L .22936 .87384 L p F P
0 0 0 r
s
.188 0 .528 r
.23103 .85478 m .22936 .87384 L .24164 .8831 L p F P
0 0 0 r
s
.188 0 .528 r
.18834 .74085 m .19024 .72255 L .17761 .71221 L p F P
0 0 0 r
s
.188 0 .528 r
.17957 .69405 m .17761 .71221 L .19024 .72255 L p F P
0 0 0 r
s
.625 .656 0 r
.6004 .95393 m .60636 .95925 L .58633 .96327 L p F P
0 0 0 r
s
.625 .656 0 r
.58633 .96327 m .58108 .95867 L .6004 .95393 L p F P
0 0 0 r
s
0 .647 .956 r
.30662 .95907 m .29139 .96301 L .27945 .95429 L p F P
0 0 0 r
s
0 .647 .956 r
.27696 .95494 m .27945 .95429 L .29139 .96301 L p F P
0 0 0 r
s
.134 0 .891 r
.61391 .14589 m .62361 .16005 L .64302 .1524 L p F P
0 0 0 r
s
.134 0 .891 r
.62361 .16005 m .61391 .14589 L .59455 .15359 L p F P
0 0 0 r
s
.625 .656 0 r
.43599 .96084 m .42774 .96292 L .40827 .95635 L p F P
0 0 0 r
s
.511 .78 0 r
.4063 .95685 m .40827 .95635 L .42774 .96292 L p F P
0 0 0 r
s
.195 0 .31 r
.77306 .26887 m .77166 .25311 L .78029 .26656 L p F P
0 0 0 r
s
.195 0 .31 r
.78029 .26656 m .78173 .28229 L .77306 .26887 L p F P
0 0 0 r
s
.195 0 .31 r
.82513 .43152 m .82344 .41484 L .83172 .4272 L p F P
0 0 0 r
s
.195 0 .31 r
.83172 .4272 m .83345 .44383 L .82513 .43152 L p F P
0 0 0 r
s
.1 0 .485 r
.35206 .17459 m .35304 .15947 L .37146 .15181 L p F P
0 0 0 r
s
.1 0 .485 r
.35304 .15947 m .35206 .17459 L .33367 .18218 L p F P
0 0 0 r
s
.195 0 .31 r
.92927 .75681 m .92699 .73829 L .93458 .74847 L p F P
0 0 0 r
s
.195 0 .31 r
.93458 .74847 m .93689 .76692 L .92927 .75681 L p F P
0 0 0 r
s
.511 .78 0 r
.61018 .96265 m .60636 .95925 L .62601 .95473 L p F P
0 0 0 r
s
.511 .78 0 r
.62601 .95473 m .62955 .95794 L .61018 .96265 L p F P
0 0 0 r
s
.195 0 .31 r
.8772 .59417 m .87522 .57657 L .88315 .58783 L p F P
0 0 0 r
s
.195 0 .31 r
.88315 .58783 m .88517 .60538 L .8772 .59417 L p F P
0 0 0 r
s
0 .78 .12 r
.33954 .96229 m .33928 .96236 L .32625 .95399 L p F P
0 0 0 r
s
0 .78 .71 r
.30959 .9583 m .32625 .95399 L .33928 .96236 L p F P
0 0 0 r
s
.134 0 .891 r
.66257 .1447 m .67194 .15888 L .69154 .15122 L p F P
0 0 0 r
s
.134 0 .891 r
.67194 .15888 m .66257 .1447 L .64302 .1524 L p F P
0 0 0 r
s
.1 0 .485 r
.29471 .22787 m .29601 .21244 L .31423 .20498 L p F P
0 0 0 r
s
.1 0 .485 r
.29601 .21244 m .29471 .22787 L .27652 .23526 L p F P
0 0 0 r
s
0 .78 .12 r
.35792 .95758 m .33954 .96229 L .32791 .95356 L p F P
0 0 0 r
s
0 .78 .12 r
.32625 .95399 m .32791 .95356 L .33954 .96229 L p F P
0 0 0 r
s
0 .78 .12 r
.72666 .95648 m .72678 .95661 L .70774 .96199 L p F P
0 0 0 r
s
0 .78 .12 r
.70774 .96199 m .70691 .96121 L .72666 .95648 L p F P
0 0 0 r
s
.511 .78 0 r
.65853 .96194 m .65852 .96193 L .6591 .96179 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.23732 .28118 m .23895 .26545 L .25696 .25818 L p F P
0 0 0 r
s
.1 0 .485 r
.23895 .26545 m .23732 .28118 L .21934 .28838 L p F P
0 0 0 r
s
.188 0 .528 r
.17761 .71221 m .17957 .69405 L .16686 .6835 L p F P
0 0 0 r
s
.188 0 .528 r
.16888 .66548 m .16686 .6835 L .17957 .69405 L p F P
0 0 0 r
s
.134 0 .891 r
.39002 .1441 m .40123 .15829 L .41985 .15063 L p F P
0 0 0 r
s
.134 0 .891 r
.40123 .15829 m .39002 .1441 L .37146 .15181 L p F P
0 0 0 r
s
.511 .78 0 r
.6591 .96179 m .65852 .96193 L .64906 .9532 L p F P
0 0 0 r
s
.511 .78 0 r
.62955 .95794 m .64906 .9532 L .65852 .96193 L p F P
0 0 0 r
s
.188 0 .528 r
.12586 .55057 m .12811 .53332 L .11505 .52168 L p F P
0 0 0 r
s
.188 0 .528 r
.11736 .50458 m .11505 .52168 L .12811 .53332 L p F P
0 0 0 r
s
.188 0 .528 r
.22936 .87384 m .23103 .85478 L .21866 .84532 L p F P
0 0 0 r
s
.188 0 .528 r
.22039 .82639 m .21866 .84532 L .23103 .85478 L p F P
0 0 0 r
s
.115 0 .563 r
.95062 .89581 m .94822 .87655 L .92768 .88157 L p F P
0 0 0 r
s
.115 0 .563 r
.92768 .88157 m .92995 .90078 L .95062 .89581 L p F P
0 0 0 r
s
.511 .78 0 r
.66871 .94842 m .6776 .95677 L .6591 .96179 L p F P
0 0 0 r
s
.511 .78 0 r
.64906 .9532 m .66871 .94842 L p .6591 .96179 L F P
0 0 0 r
s
0 .78 .12 r
.6776 .95677 m .67808 .95721 L .6591 .96179 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.1799 .33452 m .18185 .31848 L .19966 .3114 L p F P
0 0 0 r
s
.1 0 .485 r
.18185 .31848 m .1799 .33452 L .16213 .34152 L p F P
0 0 0 r
s
.511 .78 0 r
.38774 .96157 m .37643 .95283 L p .40281 .95411 L F P
0 0 0 r
s
.511 .78 0 r
.40281 .95411 m .4063 .95685 L .38774 .96157 L p F P
0 0 0 r
s
.511 .78 0 r
.36305 .95626 m .37643 .95283 L .38774 .96157 L p F P
0 0 0 r
s
.134 0 .891 r
.71128 .14351 m .72033 .15771 L .74011 .15004 L p F P
0 0 0 r
s
.134 0 .891 r
.72033 .15771 m .71128 .14351 L .69154 .15122 L p F P
0 0 0 r
s
.115 0 .563 r
.89319 .94952 m .89112 .92996 L .87078 .93477 L p F P
0 0 0 r
s
.115 0 .563 r
.87078 .93477 m .87273 .95429 L .89319 .94952 L p F P
0 0 0 r
s
.1 0 .485 r
.12245 .38788 m .12472 .37154 L .14233 .36466 L p F P
0 0 0 r
s
.1 0 .485 r
.12472 .37154 m .12245 .38788 L .10488 .3947 L p F P
0 0 0 r
s
.195 0 .31 r
.76291 .23948 m .76157 .22387 L .77028 .23753 L p F P
0 0 0 r
s
.195 0 .31 r
.77028 .23753 m .77166 .25311 L .76291 .23948 L p F P
0 0 0 r
s
.195 0 .31 r
.91931 .72798 m .91708 .7096 L .92474 .71998 L p F P
0 0 0 r
s
.195 0 .31 r
.92474 .71998 m .92699 .73829 L .91931 .72798 L p F P
0 0 0 r
s
.134 0 .891 r
.43859 .14291 m .44948 .15712 L .46828 .14945 L p F P
0 0 0 r
s
.134 0 .891 r
.44948 .15712 m .43859 .14291 L .41985 .15063 L p F P
0 0 0 r
s
0 .78 .12 r
.72666 .95648 m .70691 .96121 L .69777 .95246 L p F P
0 0 0 r
s
0 .78 .12 r
.67808 .95721 m .69777 .95246 L .70691 .96121 L p F P
0 0 0 r
s
.195 0 .31 r
.81504 .40231 m .81341 .38578 L .82177 .39835 L p F P
0 0 0 r
s
.195 0 .31 r
.82177 .39835 m .82344 .41484 L .81504 .40231 L p F P
0 0 0 r
s
.195 0 .31 r
.86718 .56514 m .86524 .54769 L .87325 .55916 L p F P
0 0 0 r
s
.195 0 .31 r
.87325 .55916 m .87522 .57657 L .86718 .56514 L p F P
0 0 0 r
s
0 .78 .71 r
.75587 .96099 m .75536 .96048 L .76972 .95708 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.45475 .95612 m .43599 .96084 L .42501 .9521 L p F P
0 0 0 r
s
.625 .656 0 r
.40827 .95635 m .42501 .9521 L .43599 .96084 L p F P
0 0 0 r
s
.134 0 .891 r
.48722 .14172 m .49778 .15594 L .51677 .14826 L p F P
0 0 0 r
s
.134 0 .891 r
.49778 .15594 m .48722 .14172 L .46828 .14945 L p F P
0 0 0 r
s
.188 0 .528 r
.11505 .52168 m .11736 .50458 L .10421 .49272 L p F P
0 0 0 r
s
.188 0 .528 r
.10659 .47576 m .10421 .49272 L .11736 .50458 L p F P
0 0 0 r
s
0 .78 .71 r
.76972 .95708 m .75536 .96048 L .74655 .95173 L p F P
0 0 0 r
s
0 .78 .71 r
.72937 .95583 m .74655 .95173 L .75536 .96048 L p F P
0 0 0 r
s
.188 0 .528 r
.21866 .84532 m .22039 .82639 L .20794 .81673 L p F P
0 0 0 r
s
.188 0 .528 r
.20973 .79794 m .20794 .81673 L .22039 .82639 L p F P
0 0 0 r
s
.188 0 .528 r
.16686 .6835 m .16888 .66548 L .15608 .65473 L p F P
0 0 0 r
s
.188 0 .528 r
.15816 .63685 m .15608 .65473 L .16888 .66548 L p F P
0 0 0 r
s
.1 0 .485 r
.33258 .19746 m .33367 .18218 L .35206 .17459 L p F P
0 0 0 r
s
.1 0 .485 r
.33367 .18218 m .33258 .19746 L .31423 .20498 L p F P
0 0 0 r
s
.625 .656 0 r
.4843 .96012 m .47364 .95136 L p .5002 .95285 L F P
0 0 0 r
s
.625 .656 0 r
.5002 .95285 m .50324 .95539 L .4843 .96012 L p F P
0 0 0 r
s
.625 .656 0 r
.45475 .95612 m .47364 .95136 L .4843 .96012 L p F P
0 0 0 r
s
0 .647 .956 r
.79537 .95099 m .80384 .95974 L .80298 .95996 L p F P
0 0 0 r
s
0 .647 .956 r
.77529 .95576 m .79537 .95099 L p .80298 .95996 L F P
0 0 0 r
s
.125 0 .956 r
.80384 .95974 m .80386 .95976 L .80298 .95996 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.27511 .25085 m .27652 .23526 L .29471 .22787 L p F P
0 0 0 r
s
.1 0 .485 r
.27652 .23526 m .27511 .25085 L .25696 .25818 L p F P
0 0 0 r
s
.195 0 .31 r
.80493 .37304 m .80336 .35665 L .81179 .36943 L p F P
0 0 0 r
s
.195 0 .31 r
.81179 .36943 m .81341 .38578 L .80493 .37304 L p F P
0 0 0 r
s
.195 0 .31 r
.90932 .69907 m .90715 .68084 L .91488 .69143 L p F P
0 0 0 r
s
.195 0 .31 r
.91488 .69143 m .91708 .7096 L .90932 .69907 L p F P
0 0 0 r
s
.134 0 .891 r
.5359 .14053 m .54614 .15476 L .56532 .14708 L p F P
0 0 0 r
s
.134 0 .891 r
.54614 .15476 m .5359 .14053 L .51677 .14826 L p F P
0 0 0 r
s
.125 0 .956 r
.80386 .95976 m .80384 .95974 L .82337 .95438 L p F P
0 0 0 r
s
.125 0 .956 r
.82337 .95438 m .82398 .95503 L .80386 .95976 L p F P
0 0 0 r
s
.195 0 .31 r
.85713 .53606 m .85525 .51874 L .86334 .53043 L p F P
0 0 0 r
s
.195 0 .31 r
.86334 .53043 m .86524 .54769 L .85713 .53606 L p F P
0 0 0 r
s
.195 0 .31 r
.75274 .21002 m .75146 .19456 L .76025 .20843 L p F P
0 0 0 r
s
.195 0 .31 r
.76025 .20843 m .76157 .22387 L .75274 .21002 L p F P
0 0 0 r
s
.195 0 .31 r
.96151 .86209 m .95904 .84293 L .96643 .85242 L p F P
0 0 0 r
s
.195 0 .31 r
.96643 .85242 m .96892 .87151 L .96151 .86209 L p F P
0 0 0 r
s
0 .647 .956 r
.8156 .9462 m .82337 .95438 L .80384 .95974 L p F P
0 0 0 r
s
0 .647 .956 r
.80384 .95974 m .79537 .95099 L .8156 .9462 L p F P
0 0 0 r
s
.1 0 .485 r
.2176 .30427 m .21934 .28838 L .23732 .28118 L p F P
0 0 0 r
s
.1 0 .485 r
.21934 .28838 m .2176 .30427 L .19966 .3114 L p F P
0 0 0 r
s
.115 0 .563 r
.93225 .92022 m .92995 .90078 L .90944 .90571 L p F P
0 0 0 r
s
.115 0 .563 r
.90944 .90571 m .91161 .9251 L .93225 .92022 L p F P
0 0 0 r
s
.625 .656 0 r
.53266 .95939 m .52476 .95269 L .54744 .9509 L p F P
0 0 0 r
s
.625 .656 0 r
.54744 .9509 m .55179 .95466 L .53266 .95939 L p F P
0 0 0 r
s
.625 .656 0 r
.61986 .94915 m .62601 .95473 L .60636 .95925 L p F P
0 0 0 r
s
.625 .656 0 r
.60636 .95925 m .6004 .95393 L .61986 .94915 L p F P
0 0 0 r
s
0 .78 .71 r
.30959 .9583 m .30662 .95907 L .2942 .95044 L p F P
0 0 0 r
s
0 .647 .956 r
.27945 .95429 m .2942 .95044 L .30662 .95907 L p F P
0 0 0 r
s
.188 0 .528 r
.15608 .65473 m .15816 .63685 L .14527 .62589 L p F P
0 0 0 r
s
.188 0 .528 r
.14742 .60816 m .14527 .62589 L .15816 .63685 L p F P
0 0 0 r
s
.1 0 .485 r
.16006 .35772 m .16213 .34152 L .1799 .33452 L p F P
0 0 0 r
s
.1 0 .485 r
.16213 .34152 m .16006 .35772 L .14233 .36466 L p F P
0 0 0 r
s
.188 0 .528 r
.10421 .49272 m .10659 .47576 L .09335 .4637 L p F P
0 0 0 r
s
.188 0 .528 r
.09579 .44689 m .09335 .4637 L .10659 .47576 L p F P
0 0 0 r
s
.188 0 .528 r
.20794 .81673 m .20973 .79794 L .19719 .78807 L p F P
0 0 0 r
s
.188 0 .528 r
.19905 .76943 m .19719 .78807 L .20973 .79794 L p F P
0 0 0 r
s
.188 0 .528 r
.25068 .9307 m .24912 .95026 L .26131 .95903 L p F P
0 0 0 r
s
.125 0 .956 r
.27696 .95494 m .26131 .95903 L .24912 .95026 L p F P
0 0 0 r
s
.134 0 .891 r
.58463 .13933 m .59455 .15359 L .61391 .14589 L p F P
0 0 0 r
s
.134 0 .891 r
.59455 .15359 m .58463 .13933 L .56532 .14708 L p F P
0 0 0 r
s
.125 0 .956 r
.87273 .95429 m .85242 .95903 L .84425 .95026 L p F P
0 0 0 r
s
.125 0 .956 r
.82398 .95503 m .84425 .95026 L .85242 .95903 L p F P
0 0 0 r
s
.625 .656 0 r
.6004 .95393 m .58108 .95867 L .57106 .94989 L p F P
0 0 0 r
s
.625 .656 0 r
.55179 .95466 m .57106 .94989 L .58108 .95867 L p F P
0 0 0 r
s
.1 0 .485 r
.10249 .4112 m .10488 .3947 L .12245 .38788 L p F P
0 0 0 r
s
.1 0 .485 r
.10488 .3947 m .10249 .4112 L .08496 .41794 L p F P
0 0 0 r
s
.195 0 .31 r
.74255 .18049 m .74132 .16518 L .75019 .17927 L p F P
0 0 0 r
s
.195 0 .31 r
.75019 .17927 m .75146 .19456 L .74255 .18049 L p F P
0 0 0 r
s
.195 0 .31 r
.8993 .67011 m .89719 .65201 L .905 .66281 L p F P
0 0 0 r
s
.195 0 .31 r
.905 .66281 m .90715 .68084 L .8993 .67011 L p F P
0 0 0 r
s
0 .78 .71 r
.32625 .95399 m .30959 .9583 L .29772 .94952 L p F P
0 0 0 r
s
0 .78 .71 r
.2942 .95044 m .29772 .94952 L .30959 .9583 L p F P
0 0 0 r
s
.195 0 .31 r
.7948 .3437 m .79328 .32746 L .80179 .34045 L p F P
0 0 0 r
s
.195 0 .31 r
.80179 .34045 m .80336 .35665 L .7948 .3437 L p F P
0 0 0 r
s
.134 0 .891 r
.63342 .13813 m .64302 .1524 L .66257 .1447 L p F P
0 0 0 r
s
.134 0 .891 r
.64302 .1524 m .63342 .13813 L .61391 .14589 L p F P
0 0 0 r
s
.195 0 .31 r
.95155 .83331 m .94914 .81429 L .9566 .82399 L p F P
0 0 0 r
s
.195 0 .31 r
.9566 .82399 m .95904 .84293 L .95155 .83331 L p F P
0 0 0 r
s
.195 0 .31 r
.84705 .5069 m .84523 .48974 L .8534 .50163 L p F P
0 0 0 r
s
.195 0 .31 r
.8534 .50163 m .85525 .51874 L .84705 .5069 L p F P
0 0 0 r
s
.1 0 .485 r
.37059 .16695 m .37146 .15181 L .39002 .1441 L p F P
0 0 0 r
s
.1 0 .485 r
.37146 .15181 m .37059 .16695 L .35206 .17459 L p F P
0 0 0 r
s
.511 .78 0 r
.62955 .95794 m .62601 .95473 L .64531 .94974 L p F P
0 0 0 r
s
.511 .78 0 r
.64531 .94974 m .64906 .9532 L .62955 .95794 L p F P
0 0 0 r
s
.188 0 .528 r
.19719 .78807 m .19905 .76943 L .18642 .75935 L p F P
0 0 0 r
s
.188 0 .528 r
.18834 .74085 m .18642 .75935 L .19905 .76943 L p F P
0 0 0 r
s
.134 0 .891 r
.68227 .13694 m .69154 .15122 L .71128 .14351 L p F P
0 0 0 r
s
.134 0 .891 r
.69154 .15122 m .68227 .13694 L .66257 .1447 L p F P
0 0 0 r
s
.1 0 .485 r
.31303 .22042 m .31423 .20498 L .33258 .19746 L p F P
0 0 0 r
s
.1 0 .485 r
.31423 .20498 m .31303 .22042 L .29471 .22787 L p F P
0 0 0 r
s
.188 0 .528 r
.09335 .4637 m .09579 .44689 L .08246 .43461 L p F P
0 0 0 r
s
.188 0 .528 r
.08496 .41794 m .08246 .43461 L .09579 .44689 L p F P
0 0 0 r
s
.188 0 .528 r
.24912 .95026 m .25068 .9307 L .23841 .92172 L p F P
0 0 0 r
s
.188 0 .528 r
.24003 .9023 m .23841 .92172 L .25068 .9307 L p F P
0 0 0 r
s
.188 0 .528 r
.14527 .62589 m .14742 .60816 L .13444 .59698 L p F P
0 0 0 r
s
.188 0 .528 r
.13665 .5794 m .13444 .59698 L .14742 .60816 L p F P
0 0 0 r
s
0 .78 .12 r
.36305 .95626 m .35792 .95758 L .34637 .94878 L p F P
0 0 0 r
s
0 .78 .12 r
.32791 .95356 m .34637 .94878 L .35792 .95758 L p F P
0 0 0 r
s
.134 0 .891 r
.40872 .13634 m .41985 .15063 L .43859 .14291 L p F P
0 0 0 r
s
.134 0 .891 r
.41985 .15063 m .40872 .13634 L .39002 .1441 L p F P
0 0 0 r
s
.1 0 .485 r
.25543 .27393 m .25696 .25818 L .27511 .25085 L p F P
0 0 0 r
s
.1 0 .485 r
.25696 .25818 m .25543 .27393 L .23732 .28118 L p F P
0 0 0 r
s
0 .78 .12 r
.67808 .95721 m .6776 .95677 L .69647 .95121 L p F P
0 0 0 r
s
0 .78 .12 r
.69647 .95121 m .69777 .95246 L .67808 .95721 L p F P
0 0 0 r
s
.115 0 .563 r
.97144 .89081 m .96892 .87151 L .94822 .87655 L p F P
0 0 0 r
s
.115 0 .563 r
.94822 .87655 m .95062 .89581 L .97144 .89081 L p F P
0 0 0 r
s
0 .78 .71 r
.76658 .94694 m .77506 .95552 L .76972 .95708 L p F P
0 0 0 r
s
0 .78 .71 r
.74655 .95173 m .76658 .94694 L p .76972 .95708 L F P
0 0 0 r
s
0 .647 .956 r
.77506 .95552 m .77529 .95576 L .76972 .95708 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.19781 .32746 m .19966 .3114 L .2176 .30427 L p F P
0 0 0 r
s
.1 0 .485 r
.19966 .3114 m .19781 .32746 L .1799 .33452 L p F P
0 0 0 r
s
.195 0 .31 r
.78465 .31429 m .78318 .2982 L .79177 .3114 L p F P
0 0 0 r
s
.195 0 .31 r
.79177 .3114 m .79328 .32746 L .78465 .31429 L p F P
0 0 0 r
s
.511 .78 0 r
.40827 .95635 m .4063 .95685 L .40281 .95411 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.83696 .47768 m .83519 .46066 L .84343 .47276 L p F P
0 0 0 r
s
.195 0 .31 r
.84343 .47276 m .84523 .48974 L .83696 .47768 L p F P
0 0 0 r
s
.134 0 .891 r
.74011 .15004 m .73117 .13574 L .71128 .14351 L p F P
0 0 0 r
s
.195 0 .31 r
.73234 .1509 m .73117 .13574 L .74011 .15004 L p F P
0 0 0 r
s
.195 0 .31 r
.74011 .15004 m .74132 .16518 L .73234 .1509 L p F P
0 0 0 r
s
.195 0 .31 r
.94158 .80446 m .93922 .78558 L .94675 .79549 L p F P
0 0 0 r
s
.195 0 .31 r
.94675 .79549 m .94914 .81429 L .94158 .80446 L p F P
0 0 0 r
s
.195 0 .31 r
.88927 .64107 m .88721 .62312 L .89509 .63413 L p F P
0 0 0 r
s
.195 0 .31 r
.89509 .63413 m .89719 .65201 L .88927 .64107 L p F P
0 0 0 r
s
.115 0 .563 r
.9138 .94471 m .91161 .9251 L .89112 .92996 L p F P
0 0 0 r
s
.115 0 .563 r
.89112 .92996 m .89319 .94952 L .9138 .94471 L p F P
0 0 0 r
s
.511 .78 0 r
.68851 .9436 m .69647 .95121 L .6776 .95677 L p F P
0 0 0 r
s
.511 .78 0 r
.6776 .95677 m .66871 .94842 L .68851 .9436 L p F P
0 0 0 r
s
0 .78 .12 r
.72678 .95661 m .72666 .95648 L .72937 .95583 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.14015 .38102 m .14233 .36466 L .16006 .35772 L p F P
0 0 0 r
s
.1 0 .485 r
.14233 .36466 m .14015 .38102 L .12245 .38788 L p F P
0 0 0 r
s
.134 0 .891 r
.45748 .13514 m .46828 .14945 L .48722 .14172 L p F P
0 0 0 r
s
.134 0 .891 r
.46828 .14945 m .45748 .13514 L .43859 .14291 L p F P
0 0 0 r
s
0 .78 .12 r
.72937 .95583 m .72666 .95648 L .71762 .94768 L p F P
0 0 0 r
s
0 .78 .12 r
.69777 .95246 m .71762 .94768 L .72666 .95648 L p F P
0 0 0 r
s
.625 .656 0 r
.42501 .9521 m .40827 .95635 L .40281 .95411 L p F P
0 0 0 r
s
.511 .78 0 r
.37643 .95283 m .36305 .95626 L .349 .9481 L p F P
0 0 0 r
s
0 .78 .12 r
.34637 .94878 m .349 .9481 L .36305 .95626 L p F P
0 0 0 r
s
.1 0 .485 r
.08246 .43461 m .08496 .41794 L .10249 .4112 L p F P
0 0 0 r
s
.188 0 .528 r
.13444 .59698 m .13665 .5794 L .12359 .56801 L p F P
0 0 0 r
s
.188 0 .528 r
.12586 .55057 m .12359 .56801 L .13665 .5794 L p F P
0 0 0 r
s
.188 0 .528 r
.23841 .92172 m .24003 .9023 L .22767 .89312 L p F P
0 0 0 r
s
.188 0 .528 r
.22936 .87384 m .22767 .89312 L .24003 .9023 L p F P
0 0 0 r
s
.188 0 .528 r
.18642 .75935 m .18834 .74085 L .17563 .73057 L p F P
0 0 0 r
s
.188 0 .528 r
.17761 .71221 m .17563 .73057 L .18834 .74085 L p F P
0 0 0 r
s
.625 .656 0 r
.45475 .95612 m .44385 .94731 L p .47269 .95059 L F P
0 0 0 r
s
.625 .656 0 r
.47269 .95059 m .47364 .95136 L .45475 .95612 L p F P
0 0 0 r
s
.625 .656 0 r
.42501 .9521 m .44385 .94731 L .45475 .95612 L p F P
0 0 0 r
s
0 .78 .12 r
.73761 .94286 m .74562 .95081 L .72937 .95583 L p F P
0 0 0 r
s
0 .78 .12 r
.71762 .94768 m .73761 .94286 L p .72937 .95583 L F P
0 0 0 r
s
0 .78 .71 r
.74562 .95081 m .74655 .95173 L .72937 .95583 L closepath p F P
0 0 0 r
s
.134 0 .891 r
.50629 .13393 m .51677 .14826 L .5359 .14053 L p F P
0 0 0 r
s
.134 0 .891 r
.51677 .14826 m .50629 .13393 L .48722 .14172 L p F P
0 0 0 r
s
0 .647 .956 r
.77529 .95576 m .77506 .95552 L .79408 .94966 L p F P
0 0 0 r
s
0 .647 .956 r
.79408 .94966 m .79537 .95099 L .77529 .95576 L p F P
0 0 0 r
s
0 .78 .71 r
.78676 .94211 m .79408 .94966 L .77506 .95552 L p F P
0 0 0 r
s
0 .78 .71 r
.77506 .95552 m .76658 .94694 L .78676 .94211 L p F P
0 0 0 r
s
.195 0 .31 r
.77447 .28481 m .77306 .26887 L .78173 .28229 L p F P
0 0 0 r
s
.195 0 .31 r
.78173 .28229 m .78318 .2982 L .77447 .28481 L p F P
0 0 0 r
s
.195 0 .31 r
.93158 .77555 m .92927 .75681 L .93689 .76692 L p F P
0 0 0 r
s
.195 0 .31 r
.93689 .76692 m .93922 .78558 L .93158 .77555 L p F P
0 0 0 r
s
.1 0 .485 r
.35107 .18989 m .35206 .17459 L .37059 .16695 L p F P
0 0 0 r
s
.1 0 .485 r
.35206 .17459 m .35107 .18989 L .33258 .19746 L p F P
0 0 0 r
s
.625 .656 0 r
.50324 .95539 m .51275 .95302 L .52476 .95269 L p F P
0 0 0 r
s
.625 .656 0 r
.51275 .95302 m .50324 .95539 L .5002 .95285 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.82684 .44839 m .82513 .43152 L .83345 .44383 L p F P
0 0 0 r
s
.195 0 .31 r
.83345 .44383 m .83519 .46066 L .82684 .44839 L p F P
0 0 0 r
s
.195 0 .31 r
.87921 .61197 m .8772 .59417 L .88517 .60538 L p F P
0 0 0 r
s
.195 0 .31 r
.88517 .60538 m .88721 .62312 L .87921 .61197 L p F P
0 0 0 r
s
.134 0 .891 r
.55516 .13273 m .56532 .14708 L .58463 .13933 L p F P
0 0 0 r
s
.134 0 .891 r
.56532 .14708 m .55516 .13273 L .5359 .14053 L p F P
0 0 0 r
s
.1 0 .485 r
.29339 .24347 m .29471 .22787 L .31303 .22042 L p F P
0 0 0 r
s
.1 0 .485 r
.29471 .22787 m .29339 .24347 L .27511 .25085 L p F P
0 0 0 r
s
.125 0 .956 r
.82398 .95503 m .82337 .95438 L .84284 .94875 L p F P
0 0 0 r
s
.125 0 .956 r
.84284 .94875 m .84425 .95026 L .82398 .95503 L p F P
0 0 0 r
s
0 .647 .956 r
.27945 .95429 m .27696 .95494 L .2647 .94615 L p F P
0 0 0 r
s
.125 0 .956 r
.24912 .95026 m .2647 .94615 L .27696 .95494 L p F P
0 0 0 r
s
.625 .656 0 r
.63947 .94434 m .64531 .94974 L .62601 .95473 L p F P
0 0 0 r
s
.625 .656 0 r
.62601 .95473 m .61986 .94915 L .63947 .94434 L p F P
0 0 0 r
s
.1 0 .485 r
.23568 .29709 m .23732 .28118 L .25543 .27393 L p F P
0 0 0 r
s
.1 0 .485 r
.23732 .28118 m .23568 .29709 L .2176 .30427 L p F P
0 0 0 r
s
.188 0 .528 r
.17563 .73057 m .17761 .71221 L .16481 .70172 L p F P
0 0 0 r
s
.188 0 .528 r
.16686 .6835 m .16481 .70172 L .17761 .71221 L p F P
0 0 0 r
s
.188 0 .528 r
.22767 .89312 m .22936 .87384 L .21691 .86446 L p F P
0 0 0 r
s
.188 0 .528 r
.21866 .84532 m .21691 .86446 L .22936 .87384 L p F P
0 0 0 r
s
.188 0 .528 r
.12359 .56801 m .12586 .55057 L .11271 .53898 L p F P
0 0 0 r
s
.188 0 .528 r
.11505 .52168 m .11271 .53898 L .12586 .55057 L p F P
0 0 0 r
s
.115 0 .563 r
.95304 .91529 m .95062 .89581 L .92995 .90078 L p F P
0 0 0 r
s
.115 0 .563 r
.92995 .90078 m .93225 .92022 L .95304 .91529 L p F P
0 0 0 r
s
.625 .656 0 r
.55179 .95466 m .54744 .9509 L .56904 .94811 L p F P
0 0 0 r
s
.625 .656 0 r
.56904 .94811 m .57106 .94989 L .55179 .95466 L p F P
0 0 0 r
s
0 .647 .956 r
.83598 .94137 m .84284 .94875 L .82337 .95438 L p F P
0 0 0 r
s
0 .647 .956 r
.82337 .95438 m .8156 .9462 L .83598 .94137 L p F P
0 0 0 r
s
.1 0 .485 r
.17793 .35074 m .1799 .33452 L .19781 .32746 L p F P
0 0 0 r
s
.1 0 .485 r
.1799 .33452 m .17793 .35074 L .16006 .35772 L p F P
0 0 0 r
s
0 .647 .956 r
.2942 .95044 m .27945 .95429 L .26734 .94546 L p F P
0 0 0 r
s
0 .647 .956 r
.2647 .94615 m .26734 .94546 L .27945 .95429 L p F P
0 0 0 r
s
.134 0 .891 r
.60409 .13153 m .61391 .14589 L .63342 .13813 L p F P
0 0 0 r
s
.134 0 .891 r
.61391 .14589 m .60409 .13153 L .58463 .13933 L p F P
0 0 0 r
s
.125 0 .956 r
.89319 .94952 m .87273 .95429 L .86467 .94546 L p F P
0 0 0 r
s
.125 0 .956 r
.84425 .95026 m .86467 .94546 L .87273 .95429 L p F P
0 0 0 r
s
.625 .656 0 r
.41387 .94323 m .42501 .9521 L p .40281 .95411 L F P
0 0 0 r
s
.625 .656 0 r
.40281 .95411 m .39508 .94805 L .41387 .94323 L p F P
0 0 0 r
s
.625 .656 0 r
.39148 .94897 m .39508 .94805 L .40281 .95411 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.37643 .95283 m .39148 .94897 L .40281 .95411 L p F P
0 0 0 r
s
0 .78 .12 r
.32791 .95356 m .32625 .95399 L .3135 .9454 L p F P
0 0 0 r
s
0 .78 .71 r
.29772 .94952 m .3135 .9454 L .32625 .95399 L p F P
0 0 0 r
s
.195 0 .31 r
.8167 .41904 m .81504 .40231 L .82344 .41484 L p F P
0 0 0 r
s
.195 0 .31 r
.82344 .41484 m .82513 .43152 L .8167 .41904 L p F P
0 0 0 r
s
.195 0 .31 r
.76427 .25527 m .76291 .23948 L .77166 .25311 L p F P
0 0 0 r
s
.195 0 .31 r
.77166 .25311 m .77306 .26887 L .76427 .25527 L p F P
0 0 0 r
s
.195 0 .31 r
.92156 .74657 m .91931 .72798 L .92699 .73829 L p F P
0 0 0 r
s
.195 0 .31 r
.92699 .73829 m .92927 .75681 L .92156 .74657 L p F P
0 0 0 r
s
.625 .656 0 r
.61986 .94915 m .6004 .95393 L .59048 .94509 L p F P
0 0 0 r
s
.625 .656 0 r
.57106 .94989 m .59048 .94509 L .6004 .95393 L p F P
0 0 0 r
s
.1 0 .485 r
.12015 .40441 m .12245 .38788 L .14015 .38102 L p F P
0 0 0 r
s
.1 0 .485 r
.12245 .38788 m .12015 .40441 L .10249 .4112 L p F P
0 0 0 r
s
.195 0 .31 r
.86913 .5828 m .86718 .56514 L .87522 .57657 L p F P
0 0 0 r
s
.195 0 .31 r
.87522 .57657 m .8772 .59417 L .86913 .5828 L p F P
0 0 0 r
s
0 .78 .12 r
.34637 .94878 m .32791 .95356 L .31613 .94471 L p F P
0 0 0 r
s
0 .78 .12 r
.3135 .9454 m .31613 .94471 L .32791 .95356 L p F P
0 0 0 r
s
.134 0 .891 r
.65307 .13032 m .66257 .1447 L .68227 .13694 L p F P
0 0 0 r
s
.134 0 .891 r
.66257 .1447 m .65307 .13032 L .63342 .13813 L p F P
0 0 0 r
s
.1 0 .485 r
.38925 .15925 m .39002 .1441 L .40872 .13634 L p F P
0 0 0 r
s
.1 0 .485 r
.39002 .1441 m .38925 .15925 L .37059 .16695 L p F P
0 0 0 r
s
.511 .78 0 r
.64906 .9532 m .64531 .94974 L .66427 .94424 L p F P
0 0 0 r
s
.511 .78 0 r
.66427 .94424 m .66871 .94842 L .64906 .9532 L p F P
0 0 0 r
s
.188 0 .528 r
.21691 .86446 m .21866 .84532 L .20613 .83573 L p F P
0 0 0 r
s
.188 0 .528 r
.20794 .81673 m .20613 .83573 L .21866 .84532 L p F P
0 0 0 r
s
.188 0 .528 r
.16481 .70172 m .16686 .6835 L .15397 .6728 L p F P
0 0 0 r
s
.188 0 .528 r
.15608 .65473 m .15397 .6728 L .16686 .6835 L p F P
0 0 0 r
s
.188 0 .528 r
.11271 .53898 m .11505 .52168 L .1018 .50988 L p F P
0 0 0 r
s
.188 0 .528 r
.10421 .49272 m .1018 .50988 L .11505 .52168 L p F P
0 0 0 r
s
.625 .201 0 r
.51275 .95302 m .52232 .95063 L .52476 .95269 L closepath p F P
0 0 0 r
s
.625 .201 0 r
.52232 .95063 m .51275 .95302 L .5002 .95285 L p F P
0 0 0 r
s
.625 .201 0 r
.51184 .94174 m .52232 .95063 L p .5002 .95285 L F P
0 0 0 r
s
.625 .201 0 r
.5002 .95285 m .49267 .94657 L .51184 .94174 L p F P
0 0 0 r
s
.625 .201 0 r
.47531 .95094 m .49267 .94657 L .5002 .95285 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.47364 .95136 m .47531 .95094 L .5002 .95285 L p F P
0 0 0 r
s
.134 0 .891 r
.70211 .12912 m .71128 .14351 L .73117 .13574 L p F P
0 0 0 r
s
.134 0 .891 r
.71128 .14351 m .70211 .12912 L .68227 .13694 L p F P
0 0 0 r
s
.1 0 .485 r
.33148 .21292 m .33258 .19746 L .35107 .18989 L p F P
0 0 0 r
s
.1 0 .485 r
.33258 .19746 m .33148 .21292 L .31303 .22042 L p F P
0 0 0 r
s
.511 .78 0 r
.39148 .94897 m .37643 .95283 L .36497 .94397 L p F P
0 0 0 r
s
.511 .78 0 r
.349 .9481 m .36497 .94397 L .37643 .95283 L p F P
0 0 0 r
s
.625 .201 0 r
.54155 .94583 m .54744 .9509 L .52476 .95269 L p F P
0 0 0 r
s
.625 .201 0 r
.52476 .95269 m .52232 .95063 L .54155 .94583 L p F P
0 0 0 r
s
.1 0 .485 r
.27368 .26662 m .27511 .25085 L .29339 .24347 L p F P
0 0 0 r
s
.1 0 .485 r
.27511 .25085 m .27368 .26662 L .25543 .27393 L p F P
0 0 0 r
s
.195 0 .31 r
.91151 .71752 m .90932 .69907 L .91708 .7096 L p F P
0 0 0 r
s
.195 0 .31 r
.91708 .7096 m .91931 .72798 L .91151 .71752 L p F P
0 0 0 r
s
.134 0 .891 r
.42755 .12851 m .43859 .14291 L .45748 .13514 L p F P
0 0 0 r
s
.134 0 .891 r
.43859 .14291 m .42755 .12851 L .40872 .13634 L p F P
0 0 0 r
s
0 .78 .12 r
.69777 .95246 m .69647 .95121 L .71509 .94521 L p F P
0 0 0 r
s
0 .78 .12 r
.71509 .94521 m .71762 .94768 L .69777 .95246 L p F P
0 0 0 r
s
.195 0 .31 r
.80653 .38961 m .80493 .37304 L .81341 .38578 L p F P
0 0 0 r
s
.195 0 .31 r
.81341 .38578 m .81504 .40231 L .80653 .38961 L p F P
0 0 0 r
s
.195 0 .31 r
.85902 .55357 m .85713 .53606 L .86524 .54769 L p F P
0 0 0 r
s
.195 0 .31 r
.86524 .54769 m .86718 .56514 L .85902 .55357 L p F P
0 0 0 r
s
.195 0 .31 r
.75404 .22566 m .75274 .21002 L .76157 .22387 L p F P
0 0 0 r
s
.195 0 .31 r
.76157 .22387 m .76291 .23948 L .75404 .22566 L p F P
0 0 0 r
s
.195 0 .31 r
.964 .88147 m .96151 .86209 L .96892 .87151 L p F P
0 0 0 r
s
.195 0 .31 r
.96892 .87151 m .97144 .89081 L .964 .88147 L p F P
0 0 0 r
s
.1 0 .485 r
.21584 .32035 m .2176 .30427 L .23568 .29709 L p F P
0 0 0 r
s
.1 0 .485 r
.2176 .30427 m .21584 .32035 L .19781 .32746 L p F P
0 0 0 r
s
.115 0 .563 r
.93457 .93987 m .93225 .92022 L .91161 .9251 L p F P
0 0 0 r
s
.115 0 .563 r
.91161 .9251 m .9138 .94471 L .93457 .93987 L p F P
0 0 0 r
s
.625 .656 0 r
.42501 .9521 m .41387 .94323 L p .43835 .94286 L F P
0 0 0 r
s
.625 .656 0 r
.43835 .94286 m .44385 .94731 L .42501 .9521 L p F P
0 0 0 r
s
.1 0 .485 r
.15798 .37411 m .16006 .35772 L .17793 .35074 L p F P
0 0 0 r
s
.1 0 .485 r
.16006 .35772 m .15798 .37411 L .14015 .38102 L p F P
0 0 0 r
s
.188 0 .528 r
.15397 .6728 m .15608 .65473 L .1431 .64382 L p F P
0 0 0 r
s
.188 0 .528 r
.14527 .62589 m .1431 .64382 L .15608 .65473 L p F P
0 0 0 r
s
.134 0 .891 r
.47651 .1273 m .48722 .14172 L .50629 .13393 L p F P
0 0 0 r
s
.134 0 .891 r
.48722 .14172 m .47651 .1273 L .45748 .13514 L p F P
0 0 0 r
s
.188 0 .528 r
.1018 .50988 m .10421 .49272 L .09088 .48071 L p F P
0 0 0 r
s
.188 0 .528 r
.09335 .4637 m .09088 .48071 L .10421 .49272 L p F P
0 0 0 r
s
0 .78 .71 r
.74655 .95173 m .74562 .95081 L .76422 .94455 L p F P
0 0 0 r
s
0 .78 .71 r
.76422 .94455 m .76658 .94694 L .74655 .95173 L p F P
0 0 0 r
s
.188 0 .528 r
.20613 .83573 m .20794 .81673 L .19532 .80693 L p F P
0 0 0 r
s
.188 0 .528 r
.19719 .78807 m .19532 .80693 L .20794 .81673 L p F P
0 0 0 r
s
.1 0 .485 r
.10008 .4279 m .10249 .4112 L .12015 .40441 L p F P
0 0 0 r
s
.1 0 .485 r
.10249 .4112 m .10008 .4279 L .08246 .43461 L p F P
0 0 0 r
s
.625 .656 0 r
.47531 .95094 m .47364 .95136 L .47269 .95059 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.70845 .93875 m .71509 .94521 L .69647 .95121 L p F P
0 0 0 r
s
.511 .78 0 r
.69647 .95121 m .68851 .9436 L .70845 .93875 L p F P
0 0 0 r
s
.195 0 .31 r
.74379 .19598 m .74255 .18049 L .75146 .19456 L p F P
0 0 0 r
s
.195 0 .31 r
.75146 .19456 m .75274 .21002 L .74379 .19598 L p F P
0 0 0 r
s
.195 0 .31 r
.90144 .6884 m .8993 .67011 L .90715 .68084 L p F P
0 0 0 r
s
.195 0 .31 r
.90715 .68084 m .90932 .69907 L .90144 .6884 L p F P
0 0 0 r
s
.195 0 .31 r
.79634 .36012 m .7948 .3437 L .80336 .35665 L p F P
0 0 0 r
s
.195 0 .31 r
.80336 .35665 m .80493 .37304 L .79634 .36012 L p F P
0 0 0 r
s
.134 0 .891 r
.52551 .12609 m .5359 .14053 L .55516 .13273 L p F P
0 0 0 r
s
.134 0 .891 r
.5359 .14053 m .52551 .12609 L .50629 .13393 L p F P
0 0 0 r
s
0 .647 .956 r
.79537 .95099 m .79408 .94966 L .81288 .94333 L p F P
0 0 0 r
s
0 .647 .956 r
.81288 .94333 m .8156 .9462 L .79537 .95099 L p F P
0 0 0 r
s
.195 0 .31 r
.954 .85255 m .95155 .83331 L .95904 .84293 L p F P
0 0 0 r
s
.195 0 .31 r
.95904 .84293 m .96151 .86209 L .954 .85255 L p F P
0 0 0 r
s
.195 0 .31 r
.84889 .52426 m .84705 .5069 L .85525 .51874 L p F P
0 0 0 r
s
.195 0 .31 r
.85525 .51874 m .85713 .53606 L .84889 .52426 L p F P
0 0 0 r
s
.625 .201 0 r
.49267 .94657 m .47531 .95094 L .47269 .95059 L p F P
0 0 0 r
s
.625 .201 0 r
.56091 .94099 m .56904 .94811 L .54744 .9509 L p F P
0 0 0 r
s
.625 .201 0 r
.54744 .9509 m .54155 .94583 L .56091 .94099 L p F P
0 0 0 r
s
0 .78 .12 r
.75775 .938 m .76422 .94455 L .74562 .95081 L p F P
0 0 0 r
s
0 .78 .12 r
.74562 .95081 m .73761 .94286 L .75775 .938 L p F P
0 0 0 r
s
.1 0 .485 r
.3697 .18226 m .37059 .16695 L .38925 .15925 L p F P
0 0 0 r
s
.1 0 .485 r
.37059 .16695 m .3697 .18226 L .35107 .18989 L p F P
0 0 0 r
s
.625 .201 0 r
.54155 .94583 m .52232 .95063 L .51184 .94174 L p F P
0 0 0 r
s
.625 .201 0 r
.48195 .93762 m .49267 .94657 L p .47269 .95059 L F P
0 0 0 r
s
.625 .201 0 r
.47269 .95059 m .46283 .94248 L .48195 .93762 L p F P
0 0 0 r
s
.625 .201 0 r
.44932 .94592 m .46283 .94248 L .47269 .95059 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.44385 .94731 m .44932 .94592 L .47269 .95059 L p F P
0 0 0 r
s
0 .78 .71 r
.29772 .94952 m .2942 .95044 L .28184 .94163 L p F P
0 0 0 r
s
0 .647 .956 r
.26734 .94546 m .28184 .94163 L .2942 .95044 L p F P
0 0 0 r
s
.1 0 .485 r
.31181 .23604 m .31303 .22042 L .33148 .21292 L p F P
0 0 0 r
s
.1 0 .485 r
.31303 .22042 m .31181 .23604 L .29339 .24347 L p F P
0 0 0 r
s
.188 0 .528 r
.19532 .80693 m .19719 .78807 L .18448 .77807 L p F P
0 0 0 r
s
.188 0 .528 r
.18642 .75935 m .18448 .77807 L .19719 .78807 L p F P
0 0 0 r
s
.188 0 .528 r
.09088 .48071 m .09335 .4637 L .07992 .45147 L p F P
0 0 0 r
s
.188 0 .528 r
.08246 .43461 m .07992 .45147 L .09335 .4637 L p F P
0 0 0 r
s
.188 0 .528 r
.23841 .92172 m .23676 .94137 L .24912 .95026 L p F P
0 0 0 r
s
.125 0 .956 r
.2647 .94615 m .24912 .95026 L .23676 .94137 L p F P
0 0 0 r
s
.188 0 .528 r
.1431 .64382 m .14527 .62589 L .1322 .61477 L p F P
0 0 0 r
s
.188 0 .528 r
.13444 .59698 m .1322 .61477 L .14527 .62589 L p F P
0 0 0 r
s
.134 0 .891 r
.57457 .12488 m .58463 .13933 L .60409 .13153 L p F P
0 0 0 r
s
.134 0 .891 r
.58463 .13933 m .57457 .12488 L .55516 .13273 L p F P
0 0 0 r
s
.125 0 .956 r
.84425 .95026 m .84284 .94875 L .86213 .94267 L p F P
0 0 0 r
s
.125 0 .956 r
.86213 .94267 m .86467 .94546 L .84425 .95026 L p F P
0 0 0 r
s
.1 0 .485 r
.25389 .28985 m .25543 .27393 L .27368 .26662 L p F P
0 0 0 r
s
.1 0 .485 r
.25543 .27393 m .25389 .28985 L .23568 .29709 L p F P
0 0 0 r
s
.115 0 .563 r
.97399 .91033 m .97144 .89081 L .95062 .89581 L p F P
0 0 0 r
s
.115 0 .563 r
.95062 .89581 m .95304 .91529 L .97399 .91033 L p F P
0 0 0 r
s
.625 .656 0 r
.57106 .94989 m .56904 .94811 L .58977 .94445 L p F P
0 0 0 r
s
.625 .656 0 r
.58977 .94445 m .59048 .94509 L .57106 .94989 L p F P
0 0 0 r
s
.625 .656 0 r
.65922 .9395 m .66427 .94424 L .64531 .94974 L p F P
0 0 0 r
s
.625 .656 0 r
.64531 .94974 m .63947 .94434 L .65922 .9395 L p F P
0 0 0 r
s
0 .78 .71 r
.8071 .93725 m .81288 .94333 L .79408 .94966 L p F P
0 0 0 r
s
0 .78 .71 r
.79408 .94966 m .78676 .94211 L .8071 .93725 L p F P
0 0 0 r
s
.1 0 .485 r
.19593 .3437 m .19781 .32746 L .21584 .32035 L p F P
0 0 0 r
s
.1 0 .485 r
.19781 .32746 m .19593 .3437 L .17793 .35074 L p F P
0 0 0 r
s
0 .78 .71 r
.3135 .9454 m .29772 .94952 L .28569 .94062 L p F P
0 0 0 r
s
0 .78 .71 r
.28184 .94163 m .28569 .94062 L .29772 .94952 L p F P
0 0 0 r
s
.134 0 .891 r
.62369 .12367 m .63342 .13813 L .65307 .13032 L p F P
0 0 0 r
s
.134 0 .891 r
.63342 .13813 m .62369 .12367 L .60409 .13153 L p F P
0 0 0 r
s
.195 0 .31 r
.83874 .49489 m .83696 .47768 L .84523 .48974 L p F P
0 0 0 r
s
.195 0 .31 r
.84523 .48974 m .84705 .5069 L .83874 .49489 L p F P
0 0 0 r
s
.195 0 .31 r
.78613 .33056 m .78465 .31429 L .79328 .32746 L p F P
0 0 0 r
s
.195 0 .31 r
.79328 .32746 m .7948 .3437 L .78613 .33056 L p F P
0 0 0 r
s
.195 0 .31 r
.73352 .16624 m .73234 .1509 L .74132 .16518 L p F P
0 0 0 r
s
.195 0 .31 r
.74132 .16518 m .74255 .18049 L .73352 .16624 L p F P
0 0 0 r
s
.195 0 .31 r
.94396 .82355 m .94158 .80446 L .94914 .81429 L p F P
0 0 0 r
s
.195 0 .31 r
.94914 .81429 m .95155 .83331 L .94396 .82355 L p F P
0 0 0 r
s
.195 0 .31 r
.89135 .65922 m .88927 .64107 L .89719 .65201 L p F P
0 0 0 r
s
.195 0 .31 r
.89719 .65201 m .8993 .67011 L .89135 .65922 L p F P
0 0 0 r
s
.125 0 .956 r
.9138 .94471 m .89319 .94952 L .88524 .94062 L p F P
0 0 0 r
s
.125 0 .956 r
.86467 .94546 m .88524 .94062 L .89319 .94952 L p F P
0 0 0 r
s
.625 .656 0 r
.63947 .94434 m .61986 .94915 L .61004 .94025 L p F P
0 0 0 r
s
.625 .656 0 r
.59048 .94509 m .61004 .94025 L .61986 .94915 L p F P
0 0 0 r
s
.1 0 .485 r
.13794 .39757 m .14015 .38102 L .15798 .37411 L p F P
0 0 0 r
s
.1 0 .485 r
.14015 .38102 m .13794 .39757 L .12015 .40441 L p F P
0 0 0 r
s
.625 .656 0 r
.39508 .94805 m .39148 .94897 L .37629 .94104 L p F P
0 0 0 r
s
.511 .78 0 r
.36497 .94397 m .37629 .94104 L .39148 .94897 L p F P
0 0 0 r
s
.188 0 .528 r
.1322 .61477 m .13444 .59698 L .12128 .58566 L p F P
0 0 0 r
s
.188 0 .528 r
.12359 .56801 m .12128 .58566 L .13444 .59698 L p F P
0 0 0 r
s
.1 0 .485 r
.07992 .45147 m .08246 .43461 L .10008 .4279 L p F P
0 0 0 r
s
0 .78 .12 r
.349 .9481 m .34637 .94878 L .33467 .93987 L p F P
0 0 0 r
s
0 .78 .12 r
.31613 .94471 m .33467 .93987 L .34637 .94878 L p F P
0 0 0 r
s
.188 0 .528 r
.23676 .94137 m .23841 .92172 L .22596 .91262 L p F P
0 0 0 r
s
.188 0 .528 r
.22767 .89312 m .22596 .91262 L .23841 .92172 L p F P
0 0 0 r
s
.188 0 .528 r
.18448 .77807 m .18642 .75935 L .17362 .74914 L p F P
0 0 0 r
s
.188 0 .528 r
.17563 .73057 m .17362 .74914 L .18642 .75935 L p F P
0 0 0 r
s
.134 0 .891 r
.67287 .12245 m .68227 .13694 L .70211 .12912 L p F P
0 0 0 r
s
.134 0 .891 r
.68227 .13694 m .67287 .12245 L .65307 .13032 L p F P
0 0 0 r
s
0 .647 .956 r
.85651 .9365 m .86213 .94267 L .84284 .94875 L p F P
0 0 0 r
s
0 .647 .956 r
.84284 .94875 m .83598 .94137 L .85651 .9365 L p F P
0 0 0 r
s
.1 0 .485 r
.40805 .1515 m .40872 .13634 L .42755 .12851 L p F P
0 0 0 r
s
.1 0 .485 r
.40872 .13634 m .40805 .1515 L .38925 .15925 L p F P
0 0 0 r
s
.511 .78 0 r
.66871 .94842 m .66427 .94424 L .68284 .93818 L p F P
0 0 0 r
s
.511 .78 0 r
.68284 .93818 m .68851 .9436 L .66871 .94842 L p F P
0 0 0 r
s
.625 .201 0 r
.58042 .93612 m .58977 .94445 L .56904 .94811 L p F P
0 0 0 r
s
.625 .201 0 r
.56904 .94811 m .56091 .94099 L .58042 .93612 L p F P
0 0 0 r
s
.511 .78 0 r
.36497 .94397 m .349 .9481 L .33562 .93962 L p F P
0 0 0 r
s
0 .78 .12 r
.33467 .93987 m .33562 .93962 L .349 .9481 L p F P
0 0 0 r
s
.134 0 .891 r
.73117 .13574 m .7221 .12124 L .70211 .12912 L p F P
0 0 0 r
s
.195 0 .31 r
.72323 .13642 m .7221 .12124 L .73117 .13574 L p F P
0 0 0 r
s
.195 0 .31 r
.73117 .13574 m .73234 .1509 L .72323 .13642 L p F P
0 0 0 r
s
.195 0 .31 r
.7759 .30094 m .77447 .28481 L .78318 .2982 L p F P
0 0 0 r
s
.195 0 .31 r
.78318 .2982 m .78465 .31429 L .7759 .30094 L p F P
0 0 0 r
s
.1 0 .485 r
.35007 .20536 m .35107 .18989 L .3697 .18226 L p F P
0 0 0 r
s
.1 0 .485 r
.35107 .18989 m .35007 .20536 L .33148 .21292 L p F P
0 0 0 r
s
.625 .656 0 r
.41387 .94323 m .39508 .94805 L .38371 .93912 L p F P
0 0 0 r
s
.625 .656 0 r
.37629 .94104 m .38371 .93912 L .39508 .94805 L p F P
0 0 0 r
s
.195 0 .31 r
.82857 .46546 m .82684 .44839 L .83519 .46066 L p F P
0 0 0 r
s
.195 0 .31 r
.83519 .46066 m .83696 .47768 L .82857 .46546 L p F P
0 0 0 r
s
.195 0 .31 r
.93391 .79449 m .93158 .77555 L .93922 .78558 L p F P
0 0 0 r
s
.195 0 .31 r
.93922 .78558 m .94158 .80446 L .93391 .79449 L p F P
0 0 0 r
s
.195 0 .31 r
.88124 .62998 m .87921 .61197 L .88721 .62312 L p F P
0 0 0 r
s
.195 0 .31 r
.88721 .62312 m .88927 .64107 L .88124 .62998 L p F P
0 0 0 r
s
.134 0 .891 r
.44653 .12063 m .45748 .13514 L .47651 .1273 L p F P
0 0 0 r
s
.134 0 .891 r
.45748 .13514 m .44653 .12063 L .42755 .12851 L p F P
0 0 0 r
s
.1 0 .485 r
.29206 .25926 m .29339 .24347 L .31181 .23604 L p F P
0 0 0 r
s
.1 0 .485 r
.29339 .24347 m .29206 .25926 L .27368 .26662 L p F P
0 0 0 r
s
0 .78 .12 r
.71762 .94768 m .71509 .94521 L .73338 .93866 L p F P
0 0 0 r
s
0 .78 .12 r
.73338 .93866 m .73761 .94286 L .71762 .94768 L p F P
0 0 0 r
s
.1 0 .485 r
.23402 .31318 m .23568 .29709 L .25389 .28985 L p F P
0 0 0 r
s
.1 0 .485 r
.23568 .29709 m .23402 .31318 L .21584 .32035 L p F P
0 0 0 r
s
.188 0 .528 r
.17362 .74914 m .17563 .73057 L .16274 .72015 L p F P
0 0 0 r
s
.188 0 .528 r
.16481 .70172 m .16274 .72015 L .17563 .73057 L p F P
0 0 0 r
s
.188 0 .528 r
.12128 .58566 m .12359 .56801 L .11034 .55648 L p F P
0 0 0 r
s
.188 0 .528 r
.11271 .53898 m .11034 .55648 L .12359 .56801 L p F P
0 0 0 r
s
.188 0 .528 r
.22596 .91262 m .22767 .89312 L .21514 .88382 L p F P
0 0 0 r
s
.188 0 .528 r
.21691 .86446 m .21514 .88382 L .22767 .89312 L p F P
0 0 0 r
s
.625 .656 0 r
.44932 .94592 m .44385 .94731 L .43835 .94286 L closepath p F P
0 0 0 r
s
.115 0 .563 r
.95549 .93499 m .95304 .91529 L .93225 .92022 L p F P
0 0 0 r
s
.115 0 .563 r
.93225 .92022 m .93457 .93987 L .95549 .93499 L p F P
0 0 0 r
s
.1 0 .485 r
.17594 .36714 m .17793 .35074 L .19593 .3437 L p F P
0 0 0 r
s
.1 0 .485 r
.17793 .35074 m .17594 .36714 L .15798 .37411 L p F P
0 0 0 r
s
.134 0 .891 r
.49567 .11941 m .50629 .13393 L .52551 .12609 L p F P
0 0 0 r
s
.134 0 .891 r
.50629 .13393 m .49567 .11941 L .47651 .1273 L p F P
0 0 0 r
s
0 .78 .71 r
.76658 .94694 m .76422 .94455 L .78248 .9377 L p F P
0 0 0 r
s
0 .78 .71 r
.78248 .9377 m .78676 .94211 L .76658 .94694 L p F P
0 0 0 r
s
.1 0 .485 r
.11783 .42113 m .12015 .40441 L .13794 .39757 L p F P
0 0 0 r
s
.1 0 .485 r
.12015 .40441 m .11783 .42113 L .10008 .4279 L p F P
0 0 0 r
s
.195 0 .31 r
.76564 .27124 m .76427 .25527 L .77306 .26887 L p F P
0 0 0 r
s
.195 0 .31 r
.77306 .26887 m .77447 .28481 L .76564 .27124 L p F P
0 0 0 r
s
.195 0 .31 r
.92383 .76537 m .92156 .74657 L .92927 .75681 L p F P
0 0 0 r
s
.195 0 .31 r
.92927 .75681 m .93158 .77555 L .92383 .76537 L p F P
0 0 0 r
s
.625 .201 0 r
.51184 .94174 m .49267 .94657 L .48195 .93762 L p F P
0 0 0 r
s
.195 0 .31 r
.81837 .43595 m .8167 .41904 L .82513 .43152 L p F P
0 0 0 r
s
.195 0 .31 r
.82513 .43152 m .82684 .44839 L .81837 .43595 L p F P
0 0 0 r
s
.195 0 .31 r
.8711 .60066 m .86913 .5828 L .8772 .59417 L p F P
0 0 0 r
s
.195 0 .31 r
.8772 .59417 m .87921 .61197 L .8711 .60066 L p F P
0 0 0 r
s
.134 0 .891 r
.54487 .11819 m .55516 .13273 L .57457 .12488 L p F P
0 0 0 r
s
.134 0 .891 r
.55516 .13273 m .54487 .11819 L .52551 .12609 L p F P
0 0 0 r
s
0 .647 .956 r
.8156 .9462 m .81288 .94333 L .83129 .93633 L p F P
0 0 0 r
s
0 .647 .956 r
.83129 .93633 m .83598 .94137 L .8156 .9462 L p F P
0 0 0 r
s
0 .647 .956 r
.26734 .94546 m .2647 .94615 L .25237 .93721 L p F P
0 0 0 r
s
.125 0 .956 r
.23676 .94137 m .25237 .93721 L .2647 .94615 L p F P
0 0 0 r
s
.625 .201 0 r
.46283 .94248 m .44932 .94592 L .43835 .94286 L p F P
0 0 0 r
s
.1 0 .485 r
.38846 .17458 m .38925 .15925 L .40805 .1515 L p F P
0 0 0 r
s
.1 0 .485 r
.38925 .15925 m .38846 .17458 L .3697 .18226 L p F P
0 0 0 r
s
.188 0 .528 r
.21514 .88382 m .21691 .86446 L .20429 .85494 L p F P
0 0 0 r
s
.188 0 .528 r
.20613 .83573 m .20429 .85494 L .21691 .86446 L p F P
0 0 0 r
s
.188 0 .528 r
.16274 .72015 m .16481 .70172 L .15183 .69109 L p F P
0 0 0 r
s
.188 0 .528 r
.15397 .6728 m .15183 .69109 L .16481 .70172 L p F P
0 0 0 r
s
.188 0 .528 r
.11034 .55648 m .11271 .53898 L .09937 .52723 L p F P
0 0 0 r
s
.188 0 .528 r
.1018 .50988 m .09937 .52723 L .11271 .53898 L p F P
0 0 0 r
s
.625 .201 0 r
.56091 .94099 m .54155 .94583 L .53116 .93687 L p F P
0 0 0 r
s
.625 .201 0 r
.51184 .94174 m .53116 .93687 L .54155 .94583 L p F P
0 0 0 r
s
.1 0 .485 r
.33036 .22856 m .33148 .21292 L .35007 .20536 L p F P
0 0 0 r
s
.1 0 .485 r
.33148 .21292 m .33036 .22856 L .31181 .23604 L p F P
0 0 0 r
s
0 .647 .956 r
.28184 .94163 m .26734 .94546 L .25506 .9365 L p F P
0 0 0 r
s
0 .647 .956 r
.25237 .93721 m .25506 .9365 L .26734 .94546 L p F P
0 0 0 r
s
.134 0 .891 r
.59413 .11697 m .60409 .13153 L .62369 .12367 L p F P
0 0 0 r
s
.134 0 .891 r
.60409 .13153 m .59413 .11697 L .57457 .12488 L p F P
0 0 0 r
s
.125 0 .956 r
.86467 .94546 m .86213 .94267 L .88098 .93584 L p F P
0 0 0 r
s
.125 0 .956 r
.88098 .93584 m .88524 .94062 L .86467 .94546 L p F P
0 0 0 r
s
0 .78 .12 r
.31613 .94471 m .3135 .9454 L .30099 .93659 L p F P
0 0 0 r
s
0 .78 .71 r
.28569 .94062 m .30099 .93659 L .3135 .9454 L p F P
0 0 0 r
s
.511 .78 0 r
.72855 .93386 m .73338 .93866 L .71509 .94521 L p F P
0 0 0 r
s
.511 .78 0 r
.71509 .94521 m .70845 .93875 L .72855 .93386 L p F P
0 0 0 r
s
.1 0 .485 r
.27223 .28257 m .27368 .26662 L .29206 .25926 L p F P
0 0 0 r
s
.1 0 .485 r
.27368 .26662 m .27223 .28257 L .25389 .28985 L p F P
0 0 0 r
s
.195 0 .31 r
.80815 .40638 m .80653 .38961 L .81504 .40231 L p F P
0 0 0 r
s
.195 0 .31 r
.81504 .40231 m .8167 .41904 L .80815 .40638 L p F P
0 0 0 r
s
.195 0 .31 r
.91373 .73618 m .91151 .71752 L .91931 .72798 L p F P
0 0 0 r
s
.195 0 .31 r
.91931 .72798 m .92156 .74657 L .91373 .73618 L p F P
0 0 0 r
s
.195 0 .31 r
.86094 .57128 m .85902 .55357 L .86718 .56514 L p F P
0 0 0 r
s
.195 0 .31 r
.86718 .56514 m .86913 .5828 L .86094 .57128 L p F P
0 0 0 r
s
.195 0 .31 r
.75536 .24148 m .75404 .22566 L .76291 .23948 L p F P
0 0 0 r
s
.195 0 .31 r
.76291 .23948 m .76427 .25527 L .75536 .24148 L p F P
0 0 0 r
s
.195 0 .31 r
.96653 .90107 m .964 .88147 L .97144 .89081 L p F P
0 0 0 r
s
.195 0 .31 r
.97144 .89081 m .97399 .91033 L .96653 .90107 L p F P
0 0 0 r
s
.625 .656 0 r
.59048 .94509 m .58977 .94445 L .60975 .93999 L p F P
0 0 0 r
s
.625 .656 0 r
.60975 .93999 m .61004 .94025 L .59048 .94509 L p F P
0 0 0 r
s
.134 0 .891 r
.64344 .11575 m .65307 .13032 L .67287 .12245 L p F P
0 0 0 r
s
.134 0 .891 r
.65307 .13032 m .64344 .11575 L .62369 .12367 L p F P
0 0 0 r
s
.1 0 .485 r
.21407 .33661 m .21584 .32035 L .23402 .31318 L p F P
0 0 0 r
s
.1 0 .485 r
.21584 .32035 m .21407 .33661 L .19593 .3437 L p F P
0 0 0 r
s
0 .78 .12 r
.31613 .94471 m .30418 .93575 L p .32316 .93111 L F P
0 0 0 r
s
0 .78 .12 r
.32316 .93111 m .33467 .93987 L .31613 .94471 L p F P
0 0 0 r
s
0 .78 .12 r
.30099 .93659 m .30418 .93575 L .31613 .94471 L p F P
0 0 0 r
s
.125 0 .956 r
.93457 .93987 m .9138 .94471 L .90597 .93575 L p F P
0 0 0 r
s
.125 0 .956 r
.88524 .94062 m .90597 .93575 L .9138 .94471 L p F P
0 0 0 r
s
0 .78 .12 r
.77804 .93311 m .78248 .9377 L .76422 .94455 L p F P
0 0 0 r
s
0 .78 .12 r
.76422 .94455 m .75775 .938 L .77804 .93311 L p F P
0 0 0 r
s
.625 .201 0 r
.60008 .93121 m .60975 .93999 L .58977 .94445 L p F P
0 0 0 r
s
.625 .201 0 r
.58977 .94445 m .58042 .93612 L .60008 .93121 L p F P
0 0 0 r
s
.188 0 .528 r
.15183 .69109 m .15397 .6728 L .1409 .66196 L p F P
0 0 0 r
s
.188 0 .528 r
.1431 .64382 m .1409 .66196 L .15397 .6728 L p F P
0 0 0 r
s
.625 .656 0 r
.65922 .9395 m .63947 .94434 L .62974 .93537 L p F P
0 0 0 r
s
.625 .656 0 r
.61004 .94025 m .62974 .93537 L .63947 .94434 L p F P
0 0 0 r
s
.1 0 .485 r
.15587 .39068 m .15798 .37411 L .17594 .36714 L p F P
0 0 0 r
s
.1 0 .485 r
.15798 .37411 m .15587 .39068 L .13794 .39757 L p F P
0 0 0 r
s
.188 0 .528 r
.20429 .85494 m .20613 .83573 L .19342 .82601 L p F P
0 0 0 r
s
.188 0 .528 r
.19532 .80693 m .19342 .82601 L .20613 .83573 L p F P
0 0 0 r
s
.188 0 .528 r
.09937 .52723 m .1018 .50988 L .08838 .49791 L p F P
0 0 0 r
s
.188 0 .528 r
.09088 .48071 m .08838 .49791 L .1018 .50988 L p F P
0 0 0 r
s
.625 .656 0 r
.67912 .93462 m .68284 .93818 L .66427 .94424 L p F P
0 0 0 r
s
.625 .656 0 r
.66427 .94424 m .65922 .9395 L .67912 .93462 L p F P
0 0 0 r
s
.1 0 .485 r
.09763 .44478 m .10008 .4279 L .11783 .42113 L p F P
0 0 0 r
s
.1 0 .485 r
.10008 .4279 m .09763 .44478 L .07992 .45147 L p F P
0 0 0 r
s
.511 .78 0 r
.37629 .94104 m .36497 .94397 L .35335 .93499 L p F P
0 0 0 r
s
.511 .78 0 r
.33562 .93962 m .35335 .93499 L .36497 .94397 L p F P
0 0 0 r
s
.134 0 .891 r
.69281 .11452 m .70211 .12912 L .7221 .12124 L p F P
0 0 0 r
s
.134 0 .891 r
.70211 .12912 m .69281 .11452 L .67287 .12245 L p F P
0 0 0 r
s
.195 0 .31 r
.74505 .21165 m .74379 .19598 L .75274 .21002 L p F P
0 0 0 r
s
.195 0 .31 r
.75274 .21002 m .75404 .22566 L .74505 .21165 L p F P
0 0 0 r
s
.195 0 .31 r
.90361 .70692 m .90144 .6884 L .90932 .69907 L p F P
0 0 0 r
s
.195 0 .31 r
.90932 .69907 m .91151 .71752 L .90361 .70692 L p F P
0 0 0 r
s
.1 0 .485 r
.42699 .14368 m .42755 .12851 L .44653 .12063 L p F P
0 0 0 r
s
.1 0 .485 r
.42755 .12851 m .42699 .14368 L .40805 .1515 L p F P
0 0 0 r
s
.511 .78 0 r
.68851 .9436 m .68284 .93818 L .70097 .93145 L p F P
0 0 0 r
s
.511 .78 0 r
.70097 .93145 m .70845 .93875 L .68851 .9436 L p F P
0 0 0 r
s
.195 0 .31 r
.7979 .37674 m .79634 .36012 L .80493 .37304 L p F P
0 0 0 r
s
.195 0 .31 r
.80493 .37304 m .80653 .38961 L .7979 .37674 L p F P
0 0 0 r
s
.195 0 .31 r
.95646 .872 m .954 .85255 L .96151 .86209 L p F P
0 0 0 r
s
.195 0 .31 r
.96151 .86209 m .964 .88147 L .95646 .872 L p F P
0 0 0 r
s
.195 0 .31 r
.85076 .54183 m .84889 .52426 L .85713 .53606 L p F P
0 0 0 r
s
.195 0 .31 r
.85713 .53606 m .85902 .55357 L .85076 .54183 L p F P
0 0 0 r
s
0 .78 .71 r
.82758 .93235 m .83129 .93633 L .81288 .94333 L p F P
0 0 0 r
s
0 .78 .71 r
.81288 .94333 m .8071 .93725 L .82758 .93235 L p F P
0 0 0 r
s
.1 0 .485 r
.3688 .19775 m .3697 .18226 L .38846 .17458 L p F P
0 0 0 r
s
.1 0 .485 r
.3697 .18226 m .3688 .19775 L .35007 .20536 L p F P
0 0 0 r
s
.625 .656 0 r
.41387 .94323 m .42835 .93952 L .43835 .94286 L p F P
0 0 0 r
s
.625 .656 0 r
.42835 .93952 m .41387 .94323 L .40258 .93424 L p F P
0 0 0 r
s
.625 .656 0 r
.38371 .93912 m .40258 .93424 L .41387 .94323 L p F P
0 0 0 r
s
.625 .201 0 r
.45187 .93348 m .46283 .94248 L p .43835 .94286 L F P
0 0 0 r
s
.625 .201 0 r
.43835 .94286 m .4328 .93837 L .45187 .93348 L p F P
0 0 0 r
s
.625 .201 0 r
.42835 .93952 m .4328 .93837 L .43835 .94286 L closepath p F P
0 0 0 r
s
.134 0 .891 r
.46565 .11269 m .47651 .1273 L .49567 .11941 L p F P
0 0 0 r
s
.134 0 .891 r
.47651 .1273 m .46565 .11269 L .44653 .12063 L p F P
0 0 0 r
s
.1 0 .485 r
.31058 .25184 m .31181 .23604 L .33036 .22856 L p F P
0 0 0 r
s
.1 0 .485 r
.31181 .23604 m .31058 .25184 L .29206 .25926 L p F P
0 0 0 r
s
0 .78 .12 r
.73761 .94286 m .73338 .93866 L .75123 .9314 L p F P
0 0 0 r
s
0 .78 .12 r
.75123 .9314 m .75775 .938 L .73761 .94286 L p F P
0 0 0 r
s
.188 0 .528 r
.08838 .49791 m .09088 .48071 L .07736 .46853 L p F P
0 0 0 r
s
.188 0 .528 r
.07992 .45147 m .07736 .46853 L .09088 .48071 L p F P
0 0 0 r
s
.188 0 .528 r
.19342 .82601 m .19532 .80693 L .18252 .797 L p F P
0 0 0 r
s
.188 0 .528 r
.18448 .77807 m .18252 .797 L .19532 .80693 L p F P
0 0 0 r
s
.188 0 .528 r
.1409 .66196 m .1431 .64382 L .12994 .63276 L p F P
0 0 0 r
s
.188 0 .528 r
.1322 .61477 m .12994 .63276 L .1431 .64382 L p F P
0 0 0 r
s
0 .647 .956 r
.87719 .93159 m .88098 .93584 L .86213 .94267 L p F P
0 0 0 r
s
0 .647 .956 r
.86213 .94267 m .85651 .9365 L .87719 .93159 L p F P
0 0 0 r
s
.1 0 .485 r
.25232 .30597 m .25389 .28985 L .27223 .28257 L p F P
0 0 0 r
s
.1 0 .485 r
.25389 .28985 m .25232 .30597 L .23402 .31318 L p F P
0 0 0 r
s
.115 0 .563 r
.97657 .93008 m .97399 .91033 L .95304 .91529 L p F P
0 0 0 r
s
.115 0 .563 r
.95304 .91529 m .95549 .93499 L .97657 .93008 L p F P
0 0 0 r
s
.625 .201 0 r
.48195 .93762 m .46283 .94248 L .45187 .93348 L p F P
0 0 0 r
s
.1 0 .485 r
.19404 .36012 m .19593 .3437 L .21407 .33661 L p F P
0 0 0 r
s
.1 0 .485 r
.19593 .3437 m .19404 .36012 L .17594 .36714 L p F P
0 0 0 r
s
.195 0 .31 r
.78763 .34703 m .78613 .33056 L .7948 .3437 L p F P
0 0 0 r
s
.195 0 .31 r
.7948 .3437 m .79634 .36012 L .78763 .34703 L p F P
0 0 0 r
s
.134 0 .891 r
.51498 .11146 m .52551 .12609 L .54487 .11819 L p F P
0 0 0 r
s
.134 0 .891 r
.52551 .12609 m .51498 .11146 L .49567 .11941 L p F P
0 0 0 r
s
0 .78 .71 r
.78676 .94211 m .78248 .9377 L .80021 .93 L p F P
0 0 0 r
s
0 .78 .71 r
.80021 .93 m .8071 .93725 L .78676 .94211 L p F P
0 0 0 r
s
.195 0 .31 r
.94638 .84287 m .94396 .82355 L .95155 .83331 L p F P
0 0 0 r
s
.195 0 .31 r
.95155 .83331 m .954 .85255 L .94638 .84287 L p F P
0 0 0 r
s
.195 0 .31 r
.89346 .67759 m .89135 .65922 L .8993 .67011 L p F P
0 0 0 r
s
.195 0 .31 r
.8993 .67011 m .90144 .6884 L .89346 .67759 L p F P
0 0 0 r
s
.195 0 .31 r
.84055 .51231 m .83874 .49489 L .84705 .5069 L p F P
0 0 0 r
s
.195 0 .31 r
.84705 .5069 m .84889 .52426 L .84055 .51231 L p F P
0 0 0 r
s
.195 0 .31 r
.73472 .18175 m .73352 .16624 L .74255 .18049 L p F P
0 0 0 r
s
.195 0 .31 r
.74255 .18049 m .74379 .19598 L .73472 .18175 L p F P
0 0 0 r
s
.1 0 .485 r
.13571 .41431 m .13794 .39757 L .15587 .39068 L p F P
0 0 0 r
s
.1 0 .485 r
.13794 .39757 m .13571 .41431 L .11783 .42113 L p F P
0 0 0 r
s
.625 .201 0 r
.51184 .94174 m .50122 .93273 L p .52066 .92782 L F P
0 0 0 r
s
.625 .201 0 r
.52066 .92782 m .53116 .93687 L .51184 .94174 L p F P
0 0 0 r
s
.625 .201 0 r
.48195 .93762 m .50122 .93273 L .51184 .94174 L p F P
0 0 0 r
s
0 .78 .71 r
.28569 .94062 m .28184 .94163 L .26952 .93265 L p F P
0 0 0 r
s
0 .647 .956 r
.25506 .9365 m .26952 .93265 L .28184 .94163 L p F P
0 0 0 r
s
.188 0 .528 r
.12994 .63276 m .1322 .61477 L .11895 .6035 L p F P
0 0 0 r
s
.188 0 .528 r
.12128 .58566 m .11895 .6035 L .1322 .61477 L p F P
0 0 0 r
s
.1 0 .485 r
.07736 .46853 m .07992 .45147 L .09763 .44478 L p F P
0 0 0 r
s
.134 0 .891 r
.56438 .11023 m .57457 .12488 L .59413 .11697 L p F P
0 0 0 r
s
.134 0 .891 r
.57457 .12488 m .56438 .11023 L .54487 .11819 L p F P
0 0 0 r
s
.188 0 .528 r
.22596 .91262 m .22424 .93235 L .23676 .94137 L p F P
0 0 0 r
s
.125 0 .956 r
.25237 .93721 m .23676 .94137 L .22424 .93235 L p F P
0 0 0 r
s
0 .647 .956 r
.83598 .94137 m .83129 .93633 L .84896 .92823 L p F P
0 0 0 r
s
0 .647 .956 r
.84896 .92823 m .85651 .9365 L .83598 .94137 L p F P
0 0 0 r
s
.188 0 .528 r
.18252 .797 m .18448 .77807 L .1716 .76793 L p F P
0 0 0 r
s
.188 0 .528 r
.17362 .74914 m .1716 .76793 L .18448 .77807 L p F P
0 0 0 r
s
.625 .656 0 r
.38371 .93912 m .37629 .94104 L .36218 .93269 L p F P
0 0 0 r
s
.511 .78 0 r
.35335 .93499 m .36218 .93269 L .37629 .94104 L p F P
0 0 0 r
s
.1 0 .485 r
.40737 .16683 m .40805 .1515 L .42699 .14368 L p F P
0 0 0 r
s
.1 0 .485 r
.40805 .1515 m .40737 .16683 L .38846 .17458 L p F P
0 0 0 r
s
.625 .201 0 r
.58042 .93612 m .56091 .94099 L .55062 .93197 L p F P
0 0 0 r
s
.625 .201 0 r
.53116 .93687 m .55062 .93197 L .56091 .94099 L p F P
0 0 0 r
s
.195 0 .31 r
.72437 .15178 m .72323 .13642 L .73234 .1509 L p F P
0 0 0 r
s
.195 0 .31 r
.73234 .1509 m .73352 .16624 L .72437 .15178 L p F P
0 0 0 r
s
.1 0 .485 r
.34906 .22101 m .35007 .20536 L .3688 .19775 L p F P
0 0 0 r
s
.1 0 .485 r
.35007 .20536 m .34906 .22101 L .33036 .22856 L p F P
0 0 0 r
s
.195 0 .31 r
.77734 .31725 m .7759 .30094 L .78465 .31429 L p F P
0 0 0 r
s
.195 0 .31 r
.78465 .31429 m .78613 .33056 L .77734 .31725 L p F P
0 0 0 r
s
.134 0 .891 r
.61383 .109 m .62369 .12367 L .64344 .11575 L p F P
0 0 0 r
s
.134 0 .891 r
.62369 .12367 m .61383 .109 L .59413 .11697 L p F P
0 0 0 r
s
0 .78 .71 r
.30099 .93659 m .28569 .94062 L .27349 .93159 L p F P
0 0 0 r
s
0 .78 .71 r
.26952 .93265 m .27349 .93159 L .28569 .94062 L p F P
0 0 0 r
s
.195 0 .31 r
.83032 .48272 m .82857 .46546 L .83696 .47768 L p F P
0 0 0 r
s
.195 0 .31 r
.83696 .47768 m .83874 .49489 L .83032 .48272 L p F P
0 0 0 r
s
.195 0 .31 r
.93627 .81366 m .93391 .79449 L .94158 .80446 L p F P
0 0 0 r
s
.195 0 .31 r
.94158 .80446 m .94396 .82355 L .93627 .81366 L p F P
0 0 0 r
s
.195 0 .31 r
.88329 .64819 m .88124 .62998 L .88927 .64107 L p F P
0 0 0 r
s
.195 0 .31 r
.88927 .64107 m .89135 .65922 L .88329 .64819 L p F P
0 0 0 r
s
.125 0 .956 r
.88524 .94062 m .88098 .93584 L .89879 .92753 L p F P
0 0 0 r
s
.125 0 .956 r
.89879 .92753 m .90597 .93575 L .88524 .94062 L p F P
0 0 0 r
s
.1 0 .485 r
.29071 .27522 m .29206 .25926 L .31058 .25184 L p F P
0 0 0 r
s
.1 0 .485 r
.29206 .25926 m .29071 .27522 L .27223 .28257 L p F P
0 0 0 r
s
.625 .656 0 r
.61004 .94025 m .60975 .93999 L .62904 .93473 L p F P
0 0 0 r
s
.625 .656 0 r
.62904 .93473 m .62974 .93537 L .61004 .94025 L p F P
0 0 0 r
s
.625 .201 0 r
.61988 .92627 m .62904 .93473 L .60975 .93999 L p F P
0 0 0 r
s
.625 .201 0 r
.60975 .93999 m .60008 .93121 L .61988 .92627 L p F P
0 0 0 r
s
.188 0 .528 r
.1716 .76793 m .17362 .74914 L .16065 .73879 L p F P
0 0 0 r
s
.188 0 .528 r
.16274 .72015 m .16065 .73879 L .17362 .74914 L p F P
0 0 0 r
s
.1 0 .485 r
.23234 .32946 m .23402 .31318 L .25232 .30597 L p F P
0 0 0 r
s
.1 0 .485 r
.23402 .31318 m .23234 .32946 L .21407 .33661 L p F P
0 0 0 r
s
.188 0 .528 r
.11895 .6035 m .12128 .58566 L .10795 .57417 L p F P
0 0 0 r
s
.188 0 .528 r
.11034 .55648 m .10795 .57417 L .12128 .58566 L p F P
0 0 0 r
s
.134 0 .891 r
.66334 .10777 m .67287 .12245 L .69281 .11452 L p F P
0 0 0 r
s
.134 0 .891 r
.67287 .12245 m .66334 .10777 L .64344 .11575 L p F P
0 0 0 r
s
0 .78 .12 r
.33562 .93962 m .33467 .93987 L .32316 .93111 L closepath p F P
0 0 0 r
s
.188 0 .528 r
.22424 .93235 m .22596 .91262 L .21335 .9034 L p F P
0 0 0 r
s
.188 0 .528 r
.21514 .88382 m .21335 .9034 L .22596 .91262 L p F P
0 0 0 r
s
.125 0 .956 r
.95549 .93499 m .93457 .93987 L .92685 .93084 L p F P
0 0 0 r
s
.125 0 .956 r
.90597 .93575 m .92685 .93084 L .93457 .93987 L p F P
0 0 0 r
s
.511 .78 0 r
.35335 .93499 m .33562 .93962 L .32316 .93111 L p F P
0 0 0 r
s
.625 .201 0 r
.4328 .93837 m .42835 .93952 L .41068 .93214 L p F P
0 0 0 r
s
.625 .656 0 r
.40258 .93424 m .41068 .93214 L .42835 .93952 L p F P
0 0 0 r
s
.1 0 .485 r
.17392 .38373 m .17594 .36714 L .19404 .36012 L p F P
0 0 0 r
s
.1 0 .485 r
.17594 .36714 m .17392 .38373 L .15587 .39068 L p F P
0 0 0 r
s
.625 .656 0 r
.67912 .93462 m .65922 .9395 L .64959 .93046 L p F P
0 0 0 r
s
.625 .656 0 r
.62974 .93537 m .64959 .93046 L .65922 .9395 L p F P
0 0 0 r
s
.195 0 .31 r
.76702 .2874 m .76564 .27124 L .77447 .28481 L p F P
0 0 0 r
s
.195 0 .31 r
.77447 .28481 m .7759 .30094 L .76702 .2874 L p F P
0 0 0 r
s
.1 0 .485 r
.11548 .43804 m .11783 .42113 L .13571 .41431 L p F P
0 0 0 r
s
.1 0 .485 r
.11783 .42113 m .11548 .43804 L .09763 .44478 L p F P
0 0 0 r
s
.134 0 .891 r
.7221 .12124 m .71291 .10654 L .69281 .11452 L p F P
0 0 0 r
s
.195 0 .31 r
.71399 .12174 m .71291 .10654 L .7221 .12124 L p F P
0 0 0 r
s
.195 0 .31 r
.7221 .12124 m .72323 .13642 L .71399 .12174 L p F P
0 0 0 r
s
.625 .656 0 r
.40258 .93424 m .38371 .93912 L .37218 .93008 L p F P
0 0 0 r
s
.625 .656 0 r
.36218 .93269 m .37218 .93008 L .38371 .93912 L p F P
0 0 0 r
s
.195 0 .31 r
.92614 .78439 m .92383 .76537 L .93158 .77555 L p F P
0 0 0 r
s
.195 0 .31 r
.93158 .77555 m .93391 .79449 L .92614 .78439 L p F P
0 0 0 r
s
.195 0 .31 r
.82006 .45307 m .81837 .43595 L .82684 .44839 L p F P
0 0 0 r
s
.195 0 .31 r
.82684 .44839 m .82857 .46546 L .82006 .45307 L p F P
0 0 0 r
s
.195 0 .31 r
.8731 .61873 m .8711 .60066 L .87921 .61197 L p F P
0 0 0 r
s
.195 0 .31 r
.87921 .61197 m .88124 .62998 L .8731 .61873 L p F P
0 0 0 r
s
.1 0 .485 r
.44607 .13581 m .44653 .12063 L .46565 .11269 L p F P
0 0 0 r
s
.1 0 .485 r
.44653 .12063 m .44607 .13581 L .42699 .14368 L p F P
0 0 0 r
s
.511 .78 0 r
.70845 .93875 m .70097 .93145 L .71303 .9263 L p F P
0 0 0 r
s
.511 .78 0 r
.72855 .93386 m .70845 .93875 L p .71303 .9263 L F P
0 0 0 r
s
.511 .78 0 r
.74879 .92894 m .75123 .9314 L .73338 .93866 L p F P
0 0 0 r
s
.511 .78 0 r
.73338 .93866 m .72855 .93386 L .74879 .92894 L p F P
0 0 0 r
s
.1 0 .485 r
.38767 .19008 m .38846 .17458 L .40737 .16683 L p F P
0 0 0 r
s
.1 0 .485 r
.38846 .17458 m .38767 .19008 L .3688 .19775 L p F P
0 0 0 r
s
.625 .201 0 r
.45187 .93348 m .4328 .93837 L .4216 .92932 L p F P
0 0 0 r
s
.625 .201 0 r
.41068 .93214 m .4216 .92932 L .4328 .93837 L p F P
0 0 0 r
s
.188 0 .528 r
.21335 .9034 m .21514 .88382 L .20244 .87438 L p F P
0 0 0 r
s
.188 0 .528 r
.20429 .85494 m .20244 .87438 L .21514 .88382 L p F P
0 0 0 r
s
.188 0 .528 r
.16065 .73879 m .16274 .72015 L .14967 .70958 L p F P
0 0 0 r
s
.188 0 .528 r
.15183 .69109 m .14967 .70958 L .16274 .72015 L p F P
0 0 0 r
s
.188 0 .528 r
.10795 .57417 m .11034 .55648 L .09691 .54478 L p F P
0 0 0 r
s
.188 0 .528 r
.09937 .52723 m .09691 .54478 L .11034 .55648 L p F P
0 0 0 r
s
.625 .656 0 r
.69916 .9297 m .70097 .93145 L .68284 .93818 L p F P
0 0 0 r
s
.625 .656 0 r
.68284 .93818 m .67912 .93462 L .69916 .9297 L p F P
0 0 0 r
s
.134 0 .891 r
.48491 .10468 m .49567 .11941 L .51498 .11146 L p F P
0 0 0 r
s
.134 0 .891 r
.49567 .11941 m .48491 .10468 L .46565 .11269 L p F P
0 0 0 r
s
.1 0 .485 r
.32924 .24437 m .33036 .22856 L .34906 .22101 L p F P
0 0 0 r
s
.1 0 .485 r
.33036 .22856 m .32924 .24437 L .31058 .25184 L p F P
0 0 0 r
s
0 .78 .12 r
.75775 .938 m .75123 .9314 L .76447 .92513 L p F P
0 0 0 r
s
0 .78 .12 r
.77804 .93311 m .75775 .938 L p .76447 .92513 L F P
0 0 0 r
s
0 .78 .12 r
.79848 .92818 m .80021 .93 L .78248 .9377 L p F P
0 0 0 r
s
0 .78 .12 r
.78248 .9377 m .77804 .93311 L .79848 .92818 L p F P
0 0 0 r
s
.1 0 .485 r
.27077 .2987 m .27223 .28257 L .29071 .27522 L p F P
0 0 0 r
s
.1 0 .485 r
.27223 .28257 m .27077 .2987 L .25232 .30597 L p F P
0 0 0 r
s
.195 0 .31 r
.91598 .75505 m .91373 .73618 L .92156 .74657 L p F P
0 0 0 r
s
.195 0 .31 r
.92156 .74657 m .92383 .76537 L .91598 .75505 L p F P
0 0 0 r
s
.625 .201 0 r
.48195 .93762 m .47109 .92856 L p .4934 .9261 L F P
0 0 0 r
s
.625 .201 0 r
.4934 .9261 m .50122 .93273 L .48195 .93762 L p F P
0 0 0 r
s
.625 .201 0 r
.45187 .93348 m .47109 .92856 L .48195 .93762 L p F P
0 0 0 r
s
.195 0 .31 r
.96908 .9209 m .96653 .90107 L .97399 .91033 L p F P
0 0 0 r
s
.195 0 .31 r
.97399 .91033 m .97657 .93008 L .96908 .9209 L p F P
0 0 0 r
s
.195 0 .31 r
.86288 .5892 m .86094 .57128 L .86913 .5828 L p F P
0 0 0 r
s
.195 0 .31 r
.86913 .5828 m .8711 .60066 L .86288 .5892 L p F P
0 0 0 r
s
.195 0 .31 r
.80978 .42334 m .80815 .40638 L .8167 .41904 L p F P
0 0 0 r
s
.195 0 .31 r
.8167 .41904 m .81837 .43595 L .80978 .42334 L p F P
0 0 0 r
s
.195 0 .31 r
.75668 .25749 m .75536 .24148 L .76427 .25527 L p F P
0 0 0 r
s
.195 0 .31 r
.76427 .25527 m .76564 .27124 L .75668 .25749 L p F P
0 0 0 r
s
.134 0 .891 r
.53444 .10345 m .54487 .11819 L .56438 .11023 L p F P
0 0 0 r
s
.134 0 .891 r
.54487 .11819 m .53444 .10345 L .51498 .11146 L p F P
0 0 0 r
s
.1 0 .485 r
.21227 .35305 m .21407 .33661 L .23234 .32946 L p F P
0 0 0 r
s
.1 0 .485 r
.21407 .33661 m .21227 .35305 L .19404 .36012 L p F P
0 0 0 r
s
0 .78 .71 r
.8071 .93725 m .80021 .93 L .80841 .92578 L p F P
0 0 0 r
s
0 .78 .71 r
.82758 .93235 m .8071 .93725 L p .80841 .92578 L F P
0 0 0 r
s
0 .647 .956 r
.25506 .9365 m .25237 .93721 L .23996 .92813 L p F P
0 0 0 r
s
.125 0 .956 r
.22424 .93235 m .23996 .92813 L .25237 .93721 L p F P
0 0 0 r
s
.1 0 .485 r
.15373 .40744 m .15587 .39068 L .17392 .38373 L p F P
0 0 0 r
s
.1 0 .485 r
.15587 .39068 m .15373 .40744 L .13571 .41431 L p F P
0 0 0 r
s
.188 0 .528 r
.14967 .70958 m .15183 .69109 L .13867 .68031 L p F P
0 0 0 r
s
.188 0 .528 r
.1409 .66196 m .13867 .68031 L .15183 .69109 L p F P
0 0 0 r
s
.188 0 .528 r
.20244 .87438 m .20429 .85494 L .1915 .8453 L p F P
0 0 0 r
s
.188 0 .528 r
.19342 .82601 m .1915 .8453 L .20429 .85494 L p F P
0 0 0 r
s
.188 0 .528 r
.09691 .54478 m .09937 .52723 L .08585 .51531 L p F P
0 0 0 r
s
.188 0 .528 r
.08838 .49791 m .08585 .51531 L .09937 .52723 L p F P
0 0 0 r
s
.625 .201 0 r
.53116 .93687 m .52066 .92782 L .54431 .92644 L p F P
0 0 0 r
s
.625 .201 0 r
.54431 .92644 m .55062 .93197 L .53116 .93687 L p F P
0 0 0 r
s
0 .78 .12 r
.30418 .93575 m .30099 .93659 L .28868 .92755 L p F P
0 0 0 r
s
0 .78 .71 r
.27349 .93159 m .28868 .92755 L .30099 .93659 L p F P
0 0 0 r
s
0 .647 .956 r
.26952 .93265 m .25506 .9365 L .24261 .92742 L p F P
0 0 0 r
s
.1 0 .485 r
.09516 .46186 m .09763 .44478 L .11548 .43804 L p F P
0 0 0 r
s
0 .647 .956 r
.23996 .92813 m .24261 .92742 L .25506 .9365 L p F P
0 0 0 r
s
.1 0 .485 r
.09763 .44478 m .09516 .46186 L .07736 .46853 L p F P
0 0 0 r
s
.134 0 .891 r
.58403 .10221 m .59413 .11697 L .61383 .109 L p F P
0 0 0 r
s
.134 0 .891 r
.59413 .11697 m .58403 .10221 L .56438 .11023 L p F P
0 0 0 r
s
0 .647 .956 r
.85651 .9365 m .84896 .92823 L .85206 .9265 L p F P
0 0 0 r
s
0 .647 .956 r
.87719 .93159 m .85651 .9365 L p .85206 .9265 L F P
0 0 0 r
s
0 .78 .71 r
.84822 .92742 m .84896 .92823 L .83129 .93633 L p F P
0 0 0 r
s
0 .78 .71 r
.83129 .93633 m .82758 .93235 L .84822 .92742 L p F P
0 0 0 r
s
.195 0 .31 r
.9058 .72564 m .90361 .70692 L .91151 .71752 L p F P
0 0 0 r
s
.195 0 .31 r
.91151 .71752 m .91373 .73618 L .9058 .72564 L p F P
0 0 0 r
s
.195 0 .31 r
.79948 .39355 m .7979 .37674 L .80653 .38961 L p F P
0 0 0 r
s
.195 0 .31 r
.80653 .38961 m .80815 .40638 L .79948 .39355 L p F P
0 0 0 r
s
.195 0 .31 r
.74632 .2275 m .74505 .21165 L .75404 .22566 L p F P
0 0 0 r
s
.195 0 .31 r
.75404 .22566 m .75536 .24148 L .74632 .2275 L p F P
0 0 0 r
s
.1 0 .485 r
.42642 .15903 m .42699 .14368 L .44607 .13581 L p F P
0 0 0 r
s
.1 0 .485 r
.42699 .14368 m .42642 .15903 L .40737 .16683 L p F P
0 0 0 r
s
.195 0 .31 r
.95896 .89169 m .95646 .872 L .964 .88147 L p F P
0 0 0 r
s
.195 0 .31 r
.964 .88147 m .96653 .90107 L .95896 .89169 L p F P
0 0 0 r
s
.195 0 .31 r
.85264 .55959 m .85076 .54183 L .85902 .55357 L p F P
0 0 0 r
s
.195 0 .31 r
.85902 .55357 m .86094 .57128 L .85264 .55959 L p F P
0 0 0 r
s
.625 .201 0 r
.60008 .93121 m .58042 .93612 L .57023 .92703 L p F P
0 0 0 r
s
.625 .201 0 r
.55062 .93197 m .57023 .92703 L .58042 .93612 L p F P
0 0 0 r
s
0 .647 .956 r
.89803 .92665 m .89879 .92753 L .88098 .93584 L p F P
0 0 0 r
s
0 .647 .956 r
.88098 .93584 m .87719 .93159 L .89803 .92665 L p F P
0 0 0 r
s
.1 0 .485 r
.36789 .21341 m .3688 .19775 L .38767 .19008 L p F P
0 0 0 r
s
.1 0 .485 r
.3688 .19775 m .36789 .21341 L .34906 .22101 L p F P
0 0 0 r
s
0 .78 .12 r
.30418 .93575 m .32278 .93084 L .32316 .93111 L p F P
0 0 0 r
s
0 .78 .12 r
.32278 .93084 m .30418 .93575 L .29206 .92665 L p F P
0 0 0 r
s
0 .78 .12 r
.28868 .92755 m .29206 .92665 L .30418 .93575 L p F P
0 0 0 r
s
.134 0 .891 r
.63368 .10097 m .64344 .11575 L .66334 .10777 L p F P
0 0 0 r
s
.134 0 .891 r
.64344 .11575 m .63368 .10097 L .61383 .109 L p F P
0 0 0 r
s
.125 0 .956 r
.90597 .93575 m .89879 .92753 L .90145 .92584 L p F P
0 0 0 r
s
.125 0 .956 r
.92685 .93084 m .90597 .93575 L p .90145 .92584 L F P
0 0 0 r
s
.1 0 .485 r
.30933 .26782 m .31058 .25184 L .32924 .24437 L p F P
0 0 0 r
s
.1 0 .485 r
.31058 .25184 m .30933 .26782 L .29071 .27522 L p F P
0 0 0 r
s
.188 0 .528 r
.1915 .8453 m .19342 .82601 L .18053 .81615 L p F P
0 0 0 r
s
.188 0 .528 r
.18252 .797 m .18053 .81615 L .19342 .82601 L p F P
0 0 0 r
s
.188 0 .528 r
.13867 .68031 m .1409 .66196 L .12765 .65096 L p F P
0 0 0 r
s
.188 0 .528 r
.12994 .63276 m .12765 .65096 L .1409 .66196 L p F P
0 0 0 r
s
.188 0 .528 r
.08585 .51531 m .08838 .49791 L .07476 .48578 L p F P
0 0 0 r
s
.188 0 .528 r
.07736 .46853 m .07476 .48578 L .08838 .49791 L p F P
0 0 0 r
s
.625 .656 0 r
.62974 .93537 m .62904 .93473 L .64764 .92863 L p F P
0 0 0 r
s
.625 .656 0 r
.64764 .92863 m .64959 .93046 L .62974 .93537 L p F P
0 0 0 r
s
.511 .78 0 r
.36218 .93269 m .35335 .93499 L .34157 .92589 L p F P
0 0 0 r
s
.511 .78 0 r
.34157 .92589 m .35335 .93499 L p .32316 .93111 L F P
0 0 0 r
s
.134 0 .891 r
.68339 .09973 m .69281 .11452 L .71291 .10654 L p F P
0 0 0 r
s
.134 0 .891 r
.69281 .11452 m .68339 .09973 L .66334 .10777 L p F P
0 0 0 r
s
.1 0 .485 r
.25074 .32226 m .25232 .30597 L .27077 .2987 L p F P
0 0 0 r
s
.1 0 .485 r
.25232 .30597 m .25074 .32226 L .23234 .32946 L p F P
0 0 0 r
s
.125 0 .956 r
.97657 .93008 m .95549 .93499 L .94789 .92589 L p F P
0 0 0 r
s
.125 0 .956 r
.92685 .93084 m .94789 .92589 L .95549 .93499 L p F P
0 0 0 r
s
.625 .201 0 r
.63983 .92129 m .64764 .92863 L .62904 .93473 L p F P
0 0 0 r
s
.625 .201 0 r
.62904 .93473 m .61988 .92627 L .63983 .92129 L p F P
0 0 0 r
s
.625 .656 0 r
.69916 .9297 m .67912 .93462 L .66959 .92551 L p F P
0 0 0 r
s
.625 .656 0 r
.64959 .93046 m .66959 .92551 L .67912 .93462 L p F P
0 0 0 r
s
.1 0 .485 r
.19212 .37674 m .19404 .36012 L .21227 .35305 L p F P
0 0 0 r
s
.1 0 .485 r
.19404 .36012 m .19212 .37674 L .17392 .38373 L p F P
0 0 0 r
s
.195 0 .31 r
.78915 .36368 m .78763 .34703 L .79634 .36012 L p F P
0 0 0 r
s
.195 0 .31 r
.79634 .36012 m .7979 .37674 L .78915 .36368 L p F P
0 0 0 r
s
.195 0 .31 r
.94882 .86241 m .94638 .84287 L .954 .85255 L p F P
0 0 0 r
s
.195 0 .31 r
.954 .85255 m .95646 .872 L .94882 .86241 L p F P
0 0 0 r
s
.195 0 .31 r
.8956 .69616 m .89346 .67759 L .90144 .6884 L p F P
0 0 0 r
s
.195 0 .31 r
.90144 .6884 m .90361 .70692 L .8956 .69616 L p F P
0 0 0 r
s
.195 0 .31 r
.84238 .52992 m .84055 .51231 L .84889 .52426 L p F P
0 0 0 r
s
.195 0 .31 r
.84889 .52426 m .85076 .54183 L .84238 .52992 L p F P
0 0 0 r
s
.195 0 .31 r
.73593 .19744 m .73472 .18175 L .74379 .19598 L p F P
0 0 0 r
s
.195 0 .31 r
.74379 .19598 m .74505 .21165 L .73593 .19744 L p F P
0 0 0 r
s
.1 0 .485 r
.13346 .43124 m .13571 .41431 L .15373 .40744 L p F P
0 0 0 r
s
.1 0 .485 r
.13571 .41431 m .13346 .43124 L .11548 .43804 L p F P
0 0 0 r
s
.625 .656 0 r
.41068 .93214 m .40258 .93424 L .39114 .92512 L p F P
0 0 0 r
s
.625 .656 0 r
.37218 .93008 m .39114 .92512 L .40258 .93424 L p F P
0 0 0 r
s
.1 0 .485 r
.4653 .12788 m .46565 .11269 L .48491 .10468 L p F P
0 0 0 r
s
.1 0 .485 r
.46565 .11269 m .4653 .12788 L .44607 .13581 L p F P
0 0 0 r
s
.511 .78 0 r
.74879 .92894 m .72855 .93386 L .71936 .92474 L p F P
0 0 0 r
s
.511 .78 0 r
.71303 .9263 m .71936 .92474 L .72855 .93386 L p F P
0 0 0 r
s
.188 0 .528 r
.12765 .65096 m .12994 .63276 L .1166 .62155 L p F P
0 0 0 r
s
.188 0 .528 r
.11895 .6035 m .1166 .62155 L .12994 .63276 L p F P
0 0 0 r
s
.1 0 .485 r
.07476 .48578 m .07736 .46853 L .09516 .46186 L p F P
0 0 0 r
s
.188 0 .528 r
.18053 .81615 m .18252 .797 L .16954 .78693 L p F P
0 0 0 r
s
.188 0 .528 r
.1716 .76793 m .16954 .78693 L .18252 .797 L p F P
0 0 0 r
s
.1 0 .485 r
.40668 .18235 m .40737 .16683 L .42642 .15903 L p F P
0 0 0 r
s
.1 0 .485 r
.40737 .16683 m .40668 .18235 L .38767 .19008 L p F P
0 0 0 r
s
.625 .201 0 r
.45187 .93348 m .44076 .92436 L p .46012 .91941 L F P
0 0 0 r
s
.625 .201 0 r
.46012 .91941 m .47109 .92856 L .45187 .93348 L p F P
0 0 0 r
s
.625 .201 0 r
.4216 .92932 m .44076 .92436 L .45187 .93348 L p F P
0 0 0 r
s
.195 0 .31 r
.72552 .16732 m .72437 .15178 L .73352 .16624 L p F P
0 0 0 r
s
.195 0 .31 r
.73352 .16624 m .73472 .18175 L .72552 .16732 L p F P
0 0 0 r
s
.195 0 .31 r
.7788 .33375 m .77734 .31725 L .78613 .33056 L p F P
0 0 0 r
s
.195 0 .31 r
.78613 .33056 m .78763 .34703 L .7788 .33375 L p F P
0 0 0 r
s
.134 0 .891 r
.50431 .09662 m .51498 .11146 L .53444 .10345 L p F P
0 0 0 r
s
.134 0 .891 r
.51498 .11146 m .50431 .09662 L .48491 .10468 L p F P
0 0 0 r
s
.1 0 .485 r
.34803 .23684 m .34906 .22101 L .36789 .21341 L p F P
0 0 0 r
s
.1 0 .485 r
.34906 .22101 m .34803 .23684 L .32924 .24437 L p F P
0 0 0 r
s
0 .78 .12 r
.79848 .92818 m .77804 .93311 L .76919 .92398 L p F P
0 0 0 r
s
0 .78 .12 r
.76447 .92513 m .76919 .92398 L .77804 .93311 L p F P
0 0 0 r
s
.195 0 .31 r
.93866 .83305 m .93627 .81366 L .94396 .82355 L p F P
0 0 0 r
s
.195 0 .31 r
.94396 .82355 m .94638 .84287 L .93866 .83305 L p F P
0 0 0 r
s
.195 0 .31 r
.88537 .66662 m .88329 .64819 L .89135 .65922 L p F P
0 0 0 r
s
.195 0 .31 r
.89135 .65922 m .89346 .67759 L .88537 .66662 L p F P
0 0 0 r
s
.195 0 .31 r
.83209 .50019 m .83032 .48272 L .83874 .49489 L p F P
0 0 0 r
s
.195 0 .31 r
.83874 .49489 m .84055 .51231 L .83209 .50019 L p F P
0 0 0 r
s
.1 0 .485 r
.28935 .29137 m .29071 .27522 L .30933 .26782 L p F P
0 0 0 r
s
.1 0 .485 r
.29071 .27522 m .28935 .29137 L .27077 .2987 L p F P
0 0 0 r
s
.625 .201 0 r
.50122 .93273 m .52053 .92782 L .52066 .92782 L p F P
0 0 0 r
s
.625 .201 0 r
.52053 .92782 m .50122 .93273 L .4934 .9261 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.37218 .93008 m .36218 .93269 L .34897 .92394 L p F P
0 0 0 r
s
.511 .78 0 r
.34157 .92589 m .34897 .92394 L .36218 .93269 L p F P
0 0 0 r
s
0 .78 .71 r
.27349 .93159 m .26952 .93265 L .25724 .92349 L p F P
0 0 0 r
s
0 .647 .956 r
.24261 .92742 m .25724 .92349 L .26952 .93265 L p F P
0 0 0 r
s
.1 0 .485 r
.23064 .34593 m .23234 .32946 L .25074 .32226 L p F P
0 0 0 r
s
.1 0 .485 r
.23234 .32946 m .23064 .34593 L .21227 .35305 L p F P
0 0 0 r
s
.188 0 .528 r
.21335 .9034 m .21154 .92321 L .22424 .93235 L p F P
0 0 0 r
s
.125 0 .956 r
.23996 .92813 m .22424 .93235 L .21154 .92321 L p F P
0 0 0 r
s
.188 0 .528 r
.16954 .78693 m .1716 .76793 L .15853 .75764 L p F P
0 0 0 r
s
.188 0 .528 r
.16065 .73879 m .15853 .75764 L .1716 .76793 L p F P
0 0 0 r
s
.188 0 .528 r
.1166 .62155 m .11895 .6035 L .10552 .59208 L p F P
0 0 0 r
s
.188 0 .528 r
.10795 .57417 m .10552 .59208 L .11895 .6035 L p F P
0 0 0 r
s
.134 0 .891 r
.55404 .09538 m .56438 .11023 L .58403 .10221 L p F P
0 0 0 r
s
.134 0 .891 r
.56438 .11023 m .55404 .09538 L .53444 .10345 L p F P
0 0 0 r
s
0 .78 .71 r
.84822 .92742 m .82758 .93235 L .81908 .92321 L p F P
0 0 0 r
s
0 .78 .71 r
.80841 .92578 m .81908 .92321 L .82758 .93235 L p F P
0 0 0 r
s
.625 .201 0 r
.4216 .92932 m .41068 .93214 L .39496 .92413 L p F P
0 0 0 r
s
.625 .656 0 r
.39114 .92512 m .39496 .92413 L .41068 .93214 L p F P
0 0 0 r
s
.1 0 .485 r
.17189 .40052 m .17392 .38373 L .19212 .37674 L p F P
0 0 0 r
s
.1 0 .485 r
.17392 .38373 m .17189 .40052 L .15373 .40744 L p F P
0 0 0 r
s
.625 .201 0 r
.55062 .93197 m .54431 .92644 L .56629 .92353 L p F P
0 0 0 r
s
.625 .201 0 r
.56629 .92353 m .57023 .92703 L .55062 .93197 L p F P
0 0 0 r
s
0 .78 .71 r
.28868 .92755 m .27349 .93159 L .26113 .92244 L p F P
0 0 0 r
s
.1 0 .485 r
.1131 .45514 m .11548 .43804 L .13346 .43124 L p F P
0 0 0 r
s
0 .78 .71 r
.25724 .92349 m .26113 .92244 L .27349 .93159 L p F P
0 0 0 r
s
.1 0 .485 r
.11548 .43804 m .1131 .45514 L .09516 .46186 L p F P
0 0 0 r
s
.195 0 .31 r
.82177 .47038 m .82006 .45307 L .82857 .46546 L p F P
0 0 0 r
s
.195 0 .31 r
.82857 .46546 m .83032 .48272 L .82177 .47038 L p F P
0 0 0 r
s
.195 0 .31 r
.76843 .30375 m .76702 .2874 L .7759 .30094 L p F P
0 0 0 r
s
.195 0 .31 r
.7759 .30094 m .77734 .31725 L .76843 .30375 L p F P
0 0 0 r
s
.195 0 .31 r
.71508 .13712 m .71399 .12174 L .72323 .13642 L p F P
0 0 0 r
s
.195 0 .31 r
.72323 .13642 m .72437 .15178 L .71508 .13712 L p F P
0 0 0 r
s
.134 0 .891 r
.60383 .09413 m .61383 .109 L .63368 .10097 L p F P
0 0 0 r
s
.134 0 .891 r
.61383 .109 m .60383 .09413 L .58403 .10221 L p F P
0 0 0 r
s
.195 0 .31 r
.92847 .80363 m .92614 .78439 L .93391 .79449 L p F P
0 0 0 r
s
.195 0 .31 r
.93391 .79449 m .93627 .81366 L .92847 .80363 L p F P
0 0 0 r
s
.195 0 .31 r
.87512 .63701 m .8731 .61873 L .88124 .62998 L p F P
0 0 0 r
s
.195 0 .31 r
.88124 .62998 m .88329 .64819 L .87512 .63701 L p F P
0 0 0 r
s
0 .647 .956 r
.89803 .92665 m .87719 .93159 L .86902 .92244 L p F P
0 0 0 r
s
0 .647 .956 r
.85206 .9265 m .86902 .92244 L .87719 .93159 L p F P
0 0 0 r
s
.625 .656 0 r
.70097 .93145 m .69916 .9297 L .71303 .9263 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.75123 .9314 m .74879 .92894 L .76447 .92513 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.44561 .15117 m .44607 .13581 L .4653 .12788 L p F P
0 0 0 r
s
.1 0 .485 r
.44607 .13581 m .44561 .15117 L .42642 .15903 L p F P
0 0 0 r
s
.625 .201 0 r
.61988 .92627 m .60008 .93121 L .58998 .92206 L p F P
0 0 0 r
s
.625 .201 0 r
.57023 .92703 m .58998 .92206 L .60008 .93121 L p F P
0 0 0 r
s
.511 .78 0 r
.32316 .93111 m .32281 .93084 L .34157 .92589 L p F P
0 0 0 r
s
.511 .78 0 r
.32278 .93084 m .32281 .93084 L .32316 .93111 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.32281 .93084 m .32278 .93084 L .31047 .92176 L p F P
0 0 0 r
s
0 .78 .12 r
.29206 .92665 m .31047 .92176 L .32278 .93084 L p F P
0 0 0 r
s
.1 0 .485 r
.38687 .20575 m .38767 .19008 L .40668 .18235 L p F P
0 0 0 r
s
.1 0 .485 r
.38767 .19008 m .38687 .20575 L .36789 .21341 L p F P
0 0 0 r
s
.511 .78 0 r
.34157 .92589 m .32281 .93084 L .31078 .92167 L p F P
0 0 0 r
s
.511 .78 0 r
.31047 .92176 m .31078 .92167 L .32281 .93084 L p F P
0 0 0 r
s
.188 0 .528 r
.21154 .92321 m .21335 .9034 L .20056 .89405 L p F P
0 0 0 r
s
.188 0 .528 r
.20244 .87438 m .20056 .89405 L .21335 .9034 L p F P
0 0 0 r
s
.188 0 .528 r
.15853 .75764 m .16065 .73879 L .14749 .72829 L p F P
0 0 0 r
s
.188 0 .528 r
.14967 .70958 m .14749 .72829 L .16065 .73879 L p F P
0 0 0 r
s
.188 0 .528 r
.10552 .59208 m .10795 .57417 L .09442 .56253 L p F P
0 0 0 r
s
.188 0 .528 r
.09691 .54478 m .09442 .56253 L .10795 .57417 L p F P
0 0 0 r
s
.134 0 .891 r
.65368 .09288 m .66334 .10777 L .68339 .09973 L p F P
0 0 0 r
s
.134 0 .891 r
.66334 .10777 m .65368 .09288 L .63368 .10097 L p F P
0 0 0 r
s
.125 0 .956 r
.94789 .92589 m .92685 .93084 L .91902 .92167 L p F P
0 0 0 r
s
.125 0 .956 r
.90145 .92584 m .91902 .92167 L .92685 .93084 L p F P
0 0 0 r
s
.1 0 .485 r
.32809 .26037 m .32924 .24437 L .34803 .23684 L p F P
0 0 0 r
s
.1 0 .485 r
.32924 .24437 m .32809 .26037 L .30933 .26782 L p F P
0 0 0 r
s
.625 .656 0 r
.64959 .93046 m .64764 .92863 L .66549 .92158 L p F P
0 0 0 r
s
.625 .656 0 r
.66549 .92158 m .66959 .92551 L .64959 .93046 L p F P
0 0 0 r
s
.1 0 .485 r
.26929 .31501 m .27077 .2987 L .28935 .29137 L p F P
0 0 0 r
s
.1 0 .485 r
.27077 .2987 m .26929 .31501 L .25074 .32226 L p F P
0 0 0 r
s
.195 0 .31 r
.81144 .4405 m .80978 .42334 L .81837 .43595 L p F P
0 0 0 r
s
.195 0 .31 r
.81837 .43595 m .82006 .45307 L .81144 .4405 L p F P
0 0 0 r
s
.195 0 .31 r
.75803 .27368 m .75668 .25749 L .76564 .27124 L p F P
0 0 0 r
s
.195 0 .31 r
.76564 .27124 m .76702 .2874 L .75803 .27368 L p F P
0 0 0 r
s
.134 0 .891 r
.71291 .10654 m .70359 .09163 L .68339 .09973 L p F P
0 0 0 r
s
.195 0 .31 r
.70462 .10685 m .70359 .09163 L .71291 .10654 L p F P
0 0 0 r
s
.195 0 .31 r
.71291 .10654 m .71399 .12174 L .70462 .10685 L p F P
0 0 0 r
s
.625 .656 0 r
.39114 .92512 m .37218 .93008 L .36048 .9209 L p F P
0 0 0 r
s
.625 .656 0 r
.34897 .92394 m .36048 .9209 L .37218 .93008 L p F P
0 0 0 r
s
.195 0 .31 r
.91826 .77414 m .91598 .75505 L .92383 .76537 L p F P
0 0 0 r
s
.195 0 .31 r
.92383 .76537 m .92614 .78439 L .91826 .77414 L p F P
0 0 0 r
s
.195 0 .31 r
.86485 .60732 m .86288 .5892 L .8711 .60066 L p F P
0 0 0 r
s
.195 0 .31 r
.8711 .60066 m .8731 .61873 L .86485 .60732 L p F P
0 0 0 r
s
.125 0 .956 r
.94789 .92589 m .96908 .9209 L .97657 .93008 L p F P
0 0 0 r
s
0 .78 .12 r
.80021 .93 m .79848 .92818 L .80841 .92578 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.71303 .9263 m .69916 .9297 L .68975 .92052 L p F P
0 0 0 r
s
.625 .656 0 r
.66959 .92551 m .68975 .92052 L .69916 .9297 L p F P
0 0 0 r
s
.1 0 .485 r
.21045 .36969 m .21227 .35305 L .23064 .34593 L p F P
0 0 0 r
s
.1 0 .485 r
.21227 .35305 m .21045 .36969 L .19212 .37674 L p F P
0 0 0 r
s
.188 0 .528 r
.14749 .72829 m .14967 .70958 L .13642 .69887 L p F P
0 0 0 r
s
.188 0 .528 r
.13867 .68031 m .13642 .69887 L .14967 .70958 L p F P
0 0 0 r
s
.1 0 .485 r
.15157 .4244 m .15373 .40744 L .17189 .40052 L p F P
0 0 0 r
s
.1 0 .485 r
.15373 .40744 m .15157 .4244 L .13346 .43124 L p F P
0 0 0 r
s
.188 0 .528 r
.20056 .89405 m .20244 .87438 L .18955 .86482 L p F P
0 0 0 r
s
.188 0 .528 r
.1915 .8453 m .18955 .86482 L .20244 .87438 L p F P
0 0 0 r
s
.188 0 .528 r
.09442 .56253 m .09691 .54478 L .08329 .53292 L p F P
0 0 0 r
s
.188 0 .528 r
.08585 .51531 m .08329 .53292 L .09691 .54478 L p F P
0 0 0 r
s
.625 .201 0 r
.44076 .92436 m .4216 .92932 L .41025 .92013 L p F P
0 0 0 r
s
.625 .201 0 r
.39496 .92413 m .41025 .92013 L .4216 .92932 L p F P
0 0 0 r
s
.1 0 .485 r
.48467 .11989 m .48491 .10468 L .50431 .09662 L p F P
0 0 0 r
s
.1 0 .485 r
.48491 .10468 m .48467 .11989 L .4653 .12788 L p F P
0 0 0 r
s
.511 .78 0 r
.76447 .92513 m .74879 .92894 L .73971 .91975 L p F P
0 0 0 r
s
.511 .78 0 r
.71936 .92474 m .73971 .91975 L .74879 .92894 L p F P
0 0 0 r
s
.1 0 .485 r
.09266 .47914 m .09516 .46186 L .1131 .45514 L p F P
0 0 0 r
s
.1 0 .485 r
.09516 .46186 m .09266 .47914 L .07476 .48578 L p F P
0 0 0 r
s
.625 .201 0 r
.65994 .91627 m .66549 .92158 L .64764 .92863 L p F P
0 0 0 r
s
.625 .201 0 r
.64764 .92863 m .63983 .92129 L .65994 .91627 L p F P
0 0 0 r
s
.195 0 .31 r
.7476 .24353 m .74632 .2275 L .75536 .24148 L p F P
0 0 0 r
s
.195 0 .31 r
.75536 .24148 m .75668 .25749 L .7476 .24353 L p F P
0 0 0 r
s
.195 0 .31 r
.90802 .74459 m .9058 .72564 L .91373 .73618 L p F P
0 0 0 r
s
.195 0 .31 r
.91373 .73618 m .91598 .75505 L .90802 .74459 L p F P
0 0 0 r
s
.1 0 .485 r
.42584 .17456 m .42642 .15903 L .44561 .15117 L p F P
0 0 0 r
s
.1 0 .485 r
.42642 .15903 m .42584 .17456 L .40668 .18235 L p F P
0 0 0 r
s
.195 0 .31 r
.80108 .41055 m .79948 .39355 L .80815 .40638 L p F P
0 0 0 r
s
.195 0 .31 r
.80815 .40638 m .80978 .42334 L .80108 .41055 L p F P
0 0 0 r
s
.625 .201 0 r
.47109 .92856 m .48515 .92495 L .4934 .9261 L p F P
0 0 0 r
s
.625 .201 0 r
.48515 .92495 m .47109 .92856 L .46012 .91941 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.96149 .9116 m .95896 .89169 L .96653 .90107 L p F P
0 0 0 r
s
.195 0 .31 r
.96653 .90107 m .96908 .9209 L .96149 .9116 L p F P
0 0 0 r
s
.195 0 .31 r
.85455 .57757 m .85264 .55959 L .86094 .57128 L p F P
0 0 0 r
s
.195 0 .31 r
.86094 .57128 m .86288 .5892 L .85455 .57757 L p F P
0 0 0 r
s
0 .78 .71 r
.84896 .92823 m .84822 .92742 L .85206 .9265 L closepath p F P
0 0 0 r
s
.134 0 .891 r
.52386 .0885 m .53444 .10345 L .55404 .09538 L p F P
0 0 0 r
s
.134 0 .891 r
.53444 .10345 m .52386 .0885 L .50431 .09662 L p F P
0 0 0 r
s
.1 0 .485 r
.36697 .22926 m .36789 .21341 L .38687 .20575 L p F P
0 0 0 r
s
.1 0 .485 r
.36789 .21341 m .36697 .22926 L .34803 .23684 L p F P
0 0 0 r
s
0 .78 .12 r
.80841 .92578 m .79848 .92818 L .78974 .91898 L p F P
0 0 0 r
s
0 .78 .12 r
.76919 .92398 m .78974 .91898 L .79848 .92818 L p F P
0 0 0 r
s
0 .647 .956 r
.24261 .92742 m .23996 .92813 L .22746 .91889 L p F P
0 0 0 r
s
.125 0 .956 r
.21154 .92321 m .22746 .91889 L .23996 .92813 L p F P
0 0 0 r
s
.625 0 .573 r
.54018 .92283 m .54431 .92644 L .52066 .92782 L p F P
0 0 0 r
s
.625 0 .573 r
.52066 .92782 m .52063 .9278 L .54018 .92283 L p F P
0 0 0 r
s
.625 0 .573 r
.52053 .92782 m .52063 .9278 L .52066 .92782 L closepath p F P
0 0 0 r
s
.625 0 .573 r
.52063 .9278 m .52053 .92782 L .4934 .9261 L p F P
0 0 0 r
s
.1 0 .485 r
.30807 .28399 m .30933 .26782 L .32809 .26037 L p F P
0 0 0 r
s
.1 0 .485 r
.30933 .26782 m .30807 .28399 L .28935 .29137 L p F P
0 0 0 r
s
.188 0 .528 r
.18955 .86482 m .1915 .8453 L .17852 .83552 L p F P
0 0 0 r
s
.188 0 .528 r
.18053 .81615 m .17852 .83552 L .1915 .8453 L p F P
0 0 0 r
s
.188 0 .528 r
.13642 .69887 m .13867 .68031 L .12533 .66938 L p F P
0 0 0 r
s
.188 0 .528 r
.12765 .65096 m .12533 .66938 L .13867 .68031 L p F P
0 0 0 r
s
.188 0 .528 r
.08329 .53292 m .08585 .51531 L .07214 .50323 L p F P
0 0 0 r
s
.188 0 .528 r
.07476 .48578 m .07214 .50323 L .08585 .51531 L p F P
0 0 0 r
s
.625 0 .573 r
.54018 .92283 m .52063 .9278 L .50995 .91859 L p F P
0 0 0 r
s
.625 0 .573 r
.50995 .91859 m .52063 .9278 L p .4934 .9261 L F P
0 0 0 r
s
0 .78 .12 r
.29206 .92665 m .28868 .92755 L .27657 .9183 L p F P
0 0 0 r
s
0 .78 .71 r
.26113 .92244 m .27657 .9183 L .28868 .92755 L p F P
0 0 0 r
s
0 .647 .956 r
.89879 .92753 m .89803 .92665 L .90145 .92584 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.24914 .33875 m .25074 .32226 L .26929 .31501 L p F P
0 0 0 r
s
.1 0 .485 r
.25074 .32226 m .24914 .33875 L .23064 .34593 L p F P
0 0 0 r
s
.134 0 .891 r
.57379 .08724 m .58403 .10221 L .60383 .09413 L p F P
0 0 0 r
s
.134 0 .891 r
.58403 .10221 m .57379 .08724 L .55404 .09538 L p F P
0 0 0 r
s
0 .647 .956 r
.25724 .92349 m .24261 .92742 L .22999 .91821 L p F P
0 0 0 r
s
0 .647 .956 r
.22746 .91889 m .22999 .91821 L .24261 .92742 L p F P
0 0 0 r
s
0 .78 .71 r
.85206 .9265 m .84822 .92742 L .83983 .91821 L p F P
0 0 0 r
s
0 .78 .71 r
.81908 .92321 m .83983 .91821 L .84822 .92742 L p F P
0 0 0 r
s
.1 0 .485 r
.19018 .39355 m .19212 .37674 L .21045 .36969 L p F P
0 0 0 r
s
.1 0 .485 r
.19212 .37674 m .19018 .39355 L .17189 .40052 L p F P
0 0 0 r
s
.195 0 .31 r
.79069 .38053 m .78915 .36368 L .7979 .37674 L p F P
0 0 0 r
s
.195 0 .31 r
.7979 .37674 m .79948 .39355 L .79069 .38053 L p F P
0 0 0 r
s
.195 0 .31 r
.84422 .54775 m .84238 .52992 L .85076 .54183 L p F P
0 0 0 r
s
.195 0 .31 r
.85076 .54183 m .85264 .55959 L .84422 .54775 L p F P
0 0 0 r
s
.195 0 .31 r
.73716 .21332 m .73593 .19744 L .74505 .21165 L p F P
0 0 0 r
s
.195 0 .31 r
.74505 .21165 m .74632 .2275 L .73716 .21332 L p F P
0 0 0 r
s
.195 0 .31 r
.95129 .88217 m .94882 .86241 L .95646 .872 L p F P
0 0 0 r
s
.195 0 .31 r
.95646 .872 m .95896 .89169 L .95129 .88217 L p F P
0 0 0 r
s
.195 0 .31 r
.89776 .71496 m .8956 .69616 L .90361 .70692 L p F P
0 0 0 r
s
.195 0 .31 r
.90361 .70692 m .9058 .72564 L .89776 .71496 L p F P
0 0 0 r
s
.625 .201 0 r
.57023 .92703 m .56629 .92353 L .58683 .91921 L p F P
0 0 0 r
s
.625 .201 0 r
.58683 .91921 m .58998 .92206 L .57023 .92703 L p F P
0 0 0 r
s
.1 0 .485 r
.13118 .44837 m .13346 .43124 L .15157 .4244 L p F P
0 0 0 r
s
.1 0 .485 r
.13346 .43124 m .13118 .44837 L .1131 .45514 L p F P
0 0 0 r
s
.134 0 .891 r
.62378 .08599 m .63368 .10097 L .65368 .09288 L p F P
0 0 0 r
s
.134 0 .891 r
.63368 .10097 m .62378 .08599 L .60383 .09413 L p F P
0 0 0 r
s
0 .78 .12 r
.31047 .92176 m .29206 .92665 L .27978 .91743 L p F P
0 0 0 r
s
0 .78 .12 r
.27657 .9183 m .27978 .91743 L .29206 .92665 L p F P
0 0 0 r
s
0 .647 .956 r
.90145 .92584 m .89803 .92665 L .88997 .91743 L p F P
0 0 0 r
s
0 .647 .956 r
.86902 .92244 m .88997 .91743 L .89803 .92665 L p F P
0 0 0 r
s
0 .78 .71 r
.86074 .91316 m .86456 .91744 L .85206 .9265 L p F P
0 0 0 r
s
0 .78 .71 r
.83983 .91821 m .86074 .91316 L p .85206 .9265 L F P
0 0 0 r
s
0 .647 .956 r
.86456 .91744 m .86902 .92244 L .85206 .9265 L closepath p F P
0 0 0 r
s
.625 0 .573 r
.55989 .91782 m .56629 .92353 L .54431 .92644 L p F P
0 0 0 r
s
.625 0 .573 r
.54431 .92644 m .54018 .92283 L .55989 .91782 L p F P
0 0 0 r
s
.625 .656 0 r
.71005 .9155 m .71839 .92377 L .71303 .9263 L p F P
0 0 0 r
s
.625 .656 0 r
.68975 .92052 m .71005 .9155 L p .71303 .9263 L F P
0 0 0 r
s
.511 .78 0 r
.71839 .92377 m .71936 .92474 L .71303 .9263 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.46494 .14325 m .4653 .12788 L .48467 .11989 L p F P
0 0 0 r
s
.1 0 .485 r
.4653 .12788 m .46494 .14325 L .44561 .15117 L p F P
0 0 0 r
s
.1 0 .485 r
.07214 .50323 m .07476 .48578 L .09266 .47914 L p F P
0 0 0 r
s
.188 0 .528 r
.12533 .66938 m .12765 .65096 L .11421 .63982 L p F P
0 0 0 r
s
.188 0 .528 r
.1166 .62155 m .11421 .63982 L .12765 .65096 L p F P
0 0 0 r
s
.625 .201 0 r
.63983 .92129 m .61988 .92627 L .60988 .91705 L p F P
0 0 0 r
s
.625 .201 0 r
.58998 .92206 m .60988 .91705 L .61988 .92627 L p F P
0 0 0 r
s
.188 0 .528 r
.17852 .83552 m .18053 .81615 L .16747 .80615 L p F P
0 0 0 r
s
.188 0 .528 r
.16954 .78693 m .16747 .80615 L .18053 .81615 L p F P
0 0 0 r
s
.625 0 .573 r
.4934 .9261 m .49044 .92359 L .50995 .91859 L p F P
0 0 0 r
s
.625 0 .573 r
.48515 .92495 m .49044 .92359 L .4934 .9261 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.40599 .19804 m .40668 .18235 L .42584 .17456 L p F P
0 0 0 r
s
.1 0 .485 r
.40668 .18235 m .40599 .19804 L .38687 .20575 L p F P
0 0 0 r
s
.134 0 .891 r
.67383 .08473 m .68339 .09973 L .70359 .09163 L p F P
0 0 0 r
s
.134 0 .891 r
.68339 .09973 m .67383 .08473 L .65368 .09288 L p F P
0 0 0 r
s
.511 .78 0 r
.34897 .92394 m .34157 .92589 L .32963 .91666 L p F P
0 0 0 r
s
.511 .78 0 r
.31078 .92167 m .32963 .91666 L .34157 .92589 L p F P
0 0 0 r
s
.125 0 .956 r
.96908 .9209 m .94789 .92589 L .94018 .91666 L p F P
0 0 0 r
s
.125 0 .956 r
.91902 .92167 m .94018 .91666 L .94789 .92589 L p F P
0 0 0 r
s
0 .647 .956 r
.91108 .91238 m .91239 .91391 L .90145 .92584 L p F P
0 0 0 r
s
0 .647 .956 r
.88997 .91743 m .91108 .91238 L p .90145 .92584 L F P
0 0 0 r
s
.125 0 .956 r
.91239 .91391 m .91902 .92167 L .90145 .92584 L closepath p F P
0 0 0 r
s
0 .78 .12 r
.81045 .91394 m .81674 .92069 L .80841 .92578 L p F P
0 0 0 r
s
0 .78 .12 r
.78974 .91898 m .81045 .91394 L p .80841 .92578 L F P
0 0 0 r
s
0 .78 .71 r
.81674 .92069 m .81908 .92321 L .80841 .92578 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.72668 .18304 m .72552 .16732 L .73472 .18175 L p F P
0 0 0 r
s
.195 0 .31 r
.73472 .18175 m .73593 .19744 L .72668 .18304 L p F P
0 0 0 r
s
.1 0 .485 r
.347 .25286 m .34803 .23684 L .36697 .22926 L p F P
0 0 0 r
s
.1 0 .485 r
.34803 .23684 m .347 .25286 L .32809 .26037 L p F P
0 0 0 r
s
.195 0 .31 r
.78028 .35045 m .7788 .33375 L .78763 .34703 L p F P
0 0 0 r
s
.195 0 .31 r
.78763 .34703 m .78915 .36368 L .78028 .35045 L p F P
0 0 0 r
s
.195 0 .31 r
.94107 .85267 m .93866 .83305 L .94638 .84287 L p F P
0 0 0 r
s
.195 0 .31 r
.94638 .84287 m .94882 .86241 L .94107 .85267 L p F P
0 0 0 r
s
.195 0 .31 r
.83388 .51785 m .83209 .50019 L .84055 .51231 L p F P
0 0 0 r
s
.195 0 .31 r
.84055 .51231 m .84238 .52992 L .83388 .51785 L p F P
0 0 0 r
s
.195 0 .31 r
.88747 .68526 m .88537 .66662 L .89346 .67759 L p F P
0 0 0 r
s
.195 0 .31 r
.89346 .67759 m .8956 .69616 L .88747 .68526 L p F P
0 0 0 r
s
.625 .656 0 r
.66959 .92551 m .66549 .92158 L .68244 .91341 L p F P
0 0 0 r
s
.625 .656 0 r
.68244 .91341 m .68975 .92052 L .66959 .92551 L p F P
0 0 0 r
s
.511 .78 0 r
.76022 .91472 m .7683 .92306 L .76447 .92513 L p F P
0 0 0 r
s
.511 .78 0 r
.73971 .91975 m .76022 .91472 L p .76447 .92513 L F P
0 0 0 r
s
0 .78 .12 r
.7683 .92306 m .76919 .92398 L .76447 .92513 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.28797 .30771 m .28935 .29137 L .30807 .28399 L p F P
0 0 0 r
s
.1 0 .485 r
.28935 .29137 m .28797 .30771 L .26929 .31501 L p F P
0 0 0 r
s
.625 .656 0 r
.39496 .92413 m .39114 .92512 L .37954 .91588 L p F P
0 0 0 r
s
.625 .656 0 r
.36048 .9209 m .37954 .91588 L .39114 .92512 L p F P
0 0 0 r
s
.625 0 .573 r
.49044 .92359 m .48515 .92495 L .46012 .91941 L p F P
0 0 0 r
s
.511 .78 0 r
.71936 .92474 m .71839 .92377 L .7346 .91457 L p F P
0 0 0 r
s
.511 .78 0 r
.7346 .91457 m .73971 .91975 L .71936 .92474 L p F P
0 0 0 r
s
.1 0 .485 r
.22891 .36259 m .23064 .34593 L .24914 .33875 L p F P
0 0 0 r
s
.1 0 .485 r
.23064 .34593 m .22891 .36259 L .21045 .36969 L p F P
0 0 0 r
s
.188 0 .528 r
.16747 .80615 m .16954 .78693 L .15639 .77672 L p F P
0 0 0 r
s
.188 0 .528 r
.15853 .75764 m .15639 .77672 L .16954 .78693 L p F P
0 0 0 r
s
.188 0 .528 r
.11421 .63982 m .1166 .62155 L .10307 .61019 L p F P
0 0 0 r
s
.188 0 .528 r
.10552 .59208 m .10307 .61019 L .1166 .62155 L p F P
0 0 0 r
s
.1 0 .485 r
.16982 .4175 m .17189 .40052 L .19018 .39355 L p F P
0 0 0 r
s
.1 0 .485 r
.17189 .40052 m .16982 .4175 L .15157 .4244 L p F P
0 0 0 r
s
.625 .201 0 r
.44076 .92436 m .46002 .91938 L .46012 .91941 L p F P
0 0 0 r
s
.625 .201 0 r
.46002 .91938 m .44076 .92436 L .4295 .91511 L p F P
0 0 0 r
s
.625 .201 0 r
.41025 .92013 m .4295 .91511 L .44076 .92436 L p F P
0 0 0 r
s
.625 .201 0 r
.41025 .92013 m .39496 .92413 L .38089 .91553 L p F P
0 0 0 r
s
.625 .656 0 r
.37954 .91588 m .38089 .91553 L .39496 .92413 L p F P
0 0 0 r
s
.195 0 .31 r
.76985 .32029 m .76843 .30375 L .77734 .31725 L p F P
0 0 0 r
s
.195 0 .31 r
.77734 .31725 m .7788 .33375 L .76985 .32029 L p F P
0 0 0 r
s
.1 0 .485 r
.50418 .11184 m .50431 .09662 L .52386 .0885 L p F P
0 0 0 r
s
.1 0 .485 r
.50431 .09662 m .50418 .11184 L .48467 .11989 L p F P
0 0 0 r
s
.1 0 .485 r
.1107 .47245 m .1131 .45514 L .13118 .44837 L p F P
0 0 0 r
s
.1 0 .485 r
.1131 .45514 m .1107 .47245 L .09266 .47914 L p F P
0 0 0 r
s
0 .78 .12 r
.76919 .92398 m .7683 .92306 L .78381 .91273 L p F P
0 0 0 r
s
0 .78 .12 r
.78381 .91273 m .78974 .91898 L .76919 .92398 L p F P
0 0 0 r
s
.195 0 .31 r
.93083 .8231 m .92847 .80363 L .93627 .81366 L p F P
0 0 0 r
s
.195 0 .31 r
.93627 .81366 m .93866 .83305 L .93083 .8231 L p F P
0 0 0 r
s
.195 0 .31 r
.87717 .6555 m .87512 .63701 L .88329 .64819 L p F P
0 0 0 r
s
.195 0 .31 r
.88329 .64819 m .88537 .66662 L .87717 .6555 L p F P
0 0 0 r
s
.195 0 .31 r
.82351 .48789 m .82177 .47038 L .83032 .48272 L p F P
0 0 0 r
s
.195 0 .31 r
.83032 .48272 m .83209 .50019 L .82351 .48789 L p F P
0 0 0 r
s
.195 0 .31 r
.71619 .15268 m .71508 .13712 L .72437 .15178 L p F P
0 0 0 r
s
.195 0 .31 r
.72437 .15178 m .72552 .16732 L .71619 .15268 L p F P
0 0 0 r
s
.625 .656 0 r
.36048 .9209 m .34897 .92394 L .33658 .91481 L p F P
0 0 0 r
s
.511 .78 0 r
.32963 .91666 m .33658 .91481 L .34897 .92394 L p F P
0 0 0 r
s
.625 .656 0 r
.73051 .91043 m .7346 .91457 L .71839 .92377 L p F P
0 0 0 r
s
.625 .656 0 r
.71839 .92377 m .71005 .9155 L .73051 .91043 L p F P
0 0 0 r
s
.1 0 .485 r
.44514 .16671 m .44561 .15117 L .46494 .14325 L p F P
0 0 0 r
s
.1 0 .485 r
.44561 .15117 m .44514 .16671 L .42584 .17456 L p F P
0 0 0 r
s
.625 0 .573 r
.50995 .91859 m .49044 .92359 L .47952 .91433 L p F P
0 0 0 r
s
.625 0 .573 r
.47952 .91433 m .49044 .92359 L p .46012 .91941 L F P
0 0 0 r
s
.625 0 .573 r
.57974 .91277 m .58683 .91921 L .56629 .92353 L p F P
0 0 0 r
s
.625 0 .573 r
.56629 .92353 m .55989 .91782 L .57974 .91277 L p F P
0 0 0 r
s
0 .78 .71 r
.26113 .92244 m .25724 .92349 L .24501 .91413 L p F P
0 0 0 r
s
0 .647 .956 r
.22999 .91821 m .24501 .91413 L .25724 .92349 L p F P
0 0 0 r
s
.1 0 .485 r
.38605 .22162 m .38687 .20575 L .40599 .19804 L p F P
0 0 0 r
s
.1 0 .485 r
.38687 .20575 m .38605 .22162 L .36697 .22926 L p F P
0 0 0 r
s
.134 0 .891 r
.54356 .08032 m .55404 .09538 L .57379 .08724 L p F P
0 0 0 r
s
.134 0 .891 r
.55404 .09538 m .54356 .08032 L .52386 .0885 L p F P
0 0 0 r
s
.188 0 .528 r
.20056 .89405 m .19866 .91394 L .21154 .92321 L p F P
0 0 0 r
s
.125 0 .956 r
.22746 .91889 m .21154 .92321 L .19866 .91394 L p F P
0 0 0 r
s
.188 0 .528 r
.10307 .61019 m .10552 .59208 L .0919 .58049 L p F P
0 0 0 r
s
.188 0 .528 r
.09442 .56253 m .0919 .58049 L .10552 .59208 L p F P
0 0 0 r
s
0 .78 .71 r
.81908 .92321 m .81674 .92069 L .83072 .90901 L p F P
0 0 0 r
s
0 .78 .71 r
.83983 .91821 m .81908 .92321 L p .83072 .90901 L F P
0 0 0 r
s
.188 0 .528 r
.15639 .77672 m .15853 .75764 L .14528 .74722 L p F P
0 0 0 r
s
.188 0 .528 r
.14749 .72829 m .14528 .74722 L .15853 .75764 L p F P
0 0 0 r
s
.511 .78 0 r
.78088 .90965 m .78381 .91273 L .7683 .92306 L p F P
0 0 0 r
s
.511 .78 0 r
.7683 .92306 m .76022 .91472 L .78088 .90965 L p F P
0 0 0 r
s
.1 0 .485 r
.32694 .27655 m .32809 .26037 L .347 .25286 L p F P
0 0 0 r
s
.1 0 .485 r
.32809 .26037 m .32694 .27655 L .30807 .28399 L p F P
0 0 0 r
s
.625 0 .573 r
.55989 .91782 m .54018 .92283 L .5296 .91355 L p F P
0 0 0 r
s
.625 0 .573 r
.50995 .91859 m .5296 .91355 L .54018 .92283 L p F P
0 0 0 r
s
.1 0 .485 r
.26779 .33152 m .26929 .31501 L .28797 .30771 L p F P
0 0 0 r
s
.1 0 .485 r
.26929 .31501 m .26779 .33152 L .24914 .33875 L p F P
0 0 0 r
s
.134 0 .891 r
.59369 .07905 m .60383 .09413 L .62378 .08599 L p F P
0 0 0 r
s
.134 0 .891 r
.60383 .09413 m .59369 .07905 L .57379 .08724 L p F P
0 0 0 r
s
0 .78 .71 r
.27657 .9183 m .26113 .92244 L .24859 .91316 L p F P
0 0 0 r
s
0 .78 .71 r
.24501 .91413 m .24859 .91316 L .26113 .92244 L p F P
0 0 0 r
s
.195 0 .31 r
.92056 .79346 m .91826 .77414 L .92614 .78439 L p F P
0 0 0 r
s
.195 0 .31 r
.92614 .78439 m .92847 .80363 L .92056 .79346 L p F P
0 0 0 r
s
.195 0 .31 r
.86683 .62566 m .86485 .60732 L .8731 .61873 L p F P
0 0 0 r
s
.195 0 .31 r
.8731 .61873 m .87512 .63701 L .86683 .62566 L p F P
0 0 0 r
s
.195 0 .31 r
.81311 .45786 m .81144 .4405 L .82006 .45307 L p F P
0 0 0 r
s
.195 0 .31 r
.82006 .45307 m .82177 .47038 L .81311 .45786 L p F P
0 0 0 r
s
.195 0 .31 r
.70567 .12226 m .70462 .10685 L .71399 .12174 L p F P
0 0 0 r
s
.195 0 .31 r
.71399 .12174 m .71508 .13712 L .70567 .12226 L p F P
0 0 0 r
s
0 .647 .956 r
.86902 .92244 m .86456 .91744 L .87039 .91083 L p F P
0 0 0 r
s
0 .647 .956 r
.88997 .91743 m .86902 .92244 L p .87039 .91083 L F P
0 0 0 r
s
.195 0 .31 r
.75939 .29006 m .75803 .27368 L .76702 .2874 L p F P
0 0 0 r
s
.195 0 .31 r
.76702 .2874 m .76843 .30375 L .75939 .29006 L p F P
0 0 0 r
s
.1 0 .485 r
.20861 .38652 m .21045 .36969 L .22891 .36259 L p F P
0 0 0 r
s
.1 0 .485 r
.21045 .36969 m .20861 .38652 L .19018 .39355 L p F P
0 0 0 r
s
.625 .201 0 r
.58998 .92206 m .58683 .91921 L .60603 .91349 L p F P
0 0 0 r
s
.625 .201 0 r
.60603 .91349 m .60988 .91705 L .58998 .92206 L p F P
0 0 0 r
s
.511 .78 0 r
.31078 .92167 m .31047 .92176 L .29855 .91239 L p F P
0 0 0 r
s
0 .78 .12 r
.27978 .91743 m .29855 .91239 L .31047 .92176 L p F P
0 0 0 r
s
.188 0 .528 r
.14528 .74722 m .14749 .72829 L .13415 .71764 L p F P
0 0 0 r
s
.188 0 .528 r
.13642 .69887 m .13415 .71764 L .14749 .72829 L p F P
0 0 0 r
s
.1 0 .485 r
.14939 .44155 m .15157 .4244 L .16982 .4175 L p F P
0 0 0 r
s
.1 0 .485 r
.15157 .4244 m .14939 .44155 L .13118 .44837 L p F P
0 0 0 r
s
.188 0 .528 r
.0919 .58049 m .09442 .56253 L .08071 .55072 L p F P
0 0 0 r
s
.188 0 .528 r
.08329 .53292 m .08071 .55072 L .09442 .56253 L p F P
0 0 0 r
s
.134 0 .891 r
.64388 .07778 m .65368 .09288 L .67383 .08473 L p F P
0 0 0 r
s
.134 0 .891 r
.65368 .09288 m .64388 .07778 L .62378 .08599 L p F P
0 0 0 r
s
.511 .78 0 r
.32963 .91666 m .31078 .92167 L .29858 .91238 L p F P
0 0 0 r
s
.511 .78 0 r
.29855 .91239 m .29858 .91238 L .31078 .92167 L p F P
0 0 0 r
s
.188 0 .528 r
.19866 .91394 m .20056 .89405 L .18759 .88456 L p F P
0 0 0 r
s
.188 0 .528 r
.18955 .86482 m .18759 .88456 L .20056 .89405 L p F P
0 0 0 r
s
.125 0 .956 r
.91902 .92167 m .91239 .91391 L .91311 .9119 L p F P
0 0 0 r
s
.125 0 .956 r
.94018 .91666 m .91902 .92167 L p .91311 .9119 L F P
0 0 0 r
s
.625 .201 0 r
.68019 .91121 m .68244 .91341 L .66549 .92158 L p F P
0 0 0 r
s
.625 .201 0 r
.66549 .92158 m .65994 .91627 L .68019 .91121 L p F P
0 0 0 r
s
.1 0 .485 r
.48442 .13527 m .48467 .11989 L .50418 .11184 L p F P
0 0 0 r
s
.1 0 .485 r
.48467 .11989 m .48442 .13527 L .46494 .14325 L p F P
0 0 0 r
s
.1 0 .485 r
.09013 .49662 m .09266 .47914 L .1107 .47245 L p F P
0 0 0 r
s
.1 0 .485 r
.09266 .47914 m .09013 .49662 L .07214 .50323 L p F P
0 0 0 r
s
.625 .201 0 r
.65994 .91627 m .63983 .92129 L .62994 .91199 L p F P
0 0 0 r
s
.625 .201 0 r
.60988 .91705 m .62994 .91199 L .63983 .92129 L p F P
0 0 0 r
s
.195 0 .31 r
.74891 .25976 m .7476 .24353 L .75668 .25749 L p F P
0 0 0 r
s
.195 0 .31 r
.75668 .25749 m .75803 .27368 L .74891 .25976 L p F P
0 0 0 r
s
.1 0 .485 r
.42525 .19027 m .42584 .17456 L .44514 .16671 L p F P
0 0 0 r
s
.1 0 .485 r
.42584 .17456 m .42525 .19027 L .40599 .19804 L p F P
0 0 0 r
s
.134 0 .891 r
.70359 .09163 m .69413 .07652 L .67383 .08473 L p F P
0 0 0 r
s
.195 0 .31 r
.69512 .09176 m .69413 .07652 L .70359 .09163 L p F P
0 0 0 r
s
.195 0 .31 r
.70359 .09163 m .70462 .10685 L .69512 .09176 L p F P
0 0 0 r
s
.625 .656 0 r
.37954 .91588 m .36048 .9209 L .34863 .9116 L p F P
0 0 0 r
s
.625 .656 0 r
.33658 .91481 m .34863 .9116 L .36048 .9209 L p F P
0 0 0 r
s
.195 0 .31 r
.91026 .76375 m .90802 .74459 L .91598 .75505 L p F P
0 0 0 r
s
.195 0 .31 r
.91598 .75505 m .91826 .77414 L .91026 .76375 L p F P
0 0 0 r
s
.195 0 .31 r
.85648 .59576 m .85455 .57757 L .86288 .5892 L p F P
0 0 0 r
s
.195 0 .31 r
.86288 .5892 m .86485 .60732 L .85648 .59576 L p F P
0 0 0 r
s
.195 0 .31 r
.80269 .42776 m .80108 .41055 L .80978 .42334 L p F P
0 0 0 r
s
.195 0 .31 r
.80978 .42334 m .81144 .4405 L .80269 .42776 L p F P
0 0 0 r
s
.125 0 .956 r
.94018 .91666 m .96149 .9116 L .96908 .9209 L p F P
0 0 0 r
s
0 .78 .12 r
.81674 .92069 m .81045 .91394 L .83072 .90901 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.36604 .24529 m .36697 .22926 L .38605 .22162 L p F P
0 0 0 r
s
.1 0 .485 r
.36697 .22926 m .36604 .24529 L .347 .25286 L p F P
0 0 0 r
s
.625 .656 0 r
.68975 .92052 m .68244 .91341 L .69039 .90867 L p F P
0 0 0 r
s
.625 .656 0 r
.71005 .9155 m .68975 .92052 L p .69039 .90867 L F P
0 0 0 r
s
.188 0 .528 r
.18759 .88456 m .18955 .86482 L .17649 .85512 L p F P
0 0 0 r
s
.188 0 .528 r
.17852 .83552 m .17649 .85512 L .18955 .86482 L p F P
0 0 0 r
s
.188 0 .528 r
.08071 .55072 m .08329 .53292 L .06949 .52089 L p F P
0 0 0 r
s
.188 0 .528 r
.07214 .50323 m .06949 .52089 L .08329 .53292 L p F P
0 0 0 r
s
.625 .201 0 r
.4295 .91511 m .41025 .92013 L .39873 .91082 L p F P
0 0 0 r
s
.625 .201 0 r
.38089 .91553 m .39873 .91082 L .41025 .92013 L p F P
0 0 0 r
s
.188 0 .528 r
.13415 .71764 m .13642 .69887 L .12299 .688 L p F P
0 0 0 r
s
.188 0 .528 r
.12533 .66938 m .12299 .688 L .13642 .69887 L p F P
0 0 0 r
s
.1 0 .485 r
.3068 .30034 m .30807 .28399 L .32694 .27655 L p F P
0 0 0 r
s
.1 0 .485 r
.30807 .28399 m .3068 .30034 L .28797 .30771 L p F P
0 0 0 r
s
.511 .78 0 r
.73971 .91975 m .7346 .91457 L .74545 .90674 L p F P
0 0 0 r
s
.511 .78 0 r
.76022 .91472 m .73971 .91975 L p .74545 .90674 L F P
0 0 0 r
s
.1 0 .485 r
.24752 .35543 m .24914 .33875 L .26779 .33152 L p F P
0 0 0 r
s
.1 0 .485 r
.24914 .33875 m .24752 .35543 L .22891 .36259 L p F P
0 0 0 r
s
.625 0 .573 r
.46012 .91941 m .46007 .91936 L .47952 .91433 L p F P
0 0 0 r
s
.625 0 .573 r
.46002 .91938 m .46007 .91936 L .46012 .91941 L closepath p F P
0 0 0 r
s
.625 0 .573 r
.46007 .91936 m .46002 .91938 L .44124 .91204 L p F P
0 0 0 r
s
.625 .201 0 r
.4295 .91511 m .44124 .91204 L .46002 .91938 L p F P
0 0 0 r
s
.1 0 .485 r
.18821 .41055 m .19018 .39355 L .20861 .38652 L p F P
0 0 0 r
s
.1 0 .485 r
.19018 .39355 m .18821 .41055 L .16982 .4175 L p F P
0 0 0 r
s
.625 0 .573 r
.47952 .91433 m .46007 .91936 L .4489 .91004 L p F P
0 0 0 r
s
.625 0 .573 r
.44124 .91204 m .4489 .91004 L .46007 .91936 L p F P
0 0 0 r
s
.195 0 .31 r
.95379 .90217 m .95129 .88217 L .95896 .89169 L p F P
0 0 0 r
s
.195 0 .31 r
.95896 .89169 m .96149 .9116 L .95379 .90217 L p F P
0 0 0 r
s
.195 0 .31 r
.89994 .73398 m .89776 .71496 L .9058 .72564 L p F P
0 0 0 r
s
.195 0 .31 r
.9058 .72564 m .90802 .74459 L .89994 .73398 L p F P
0 0 0 r
s
.195 0 .31 r
.84609 .56578 m .84422 .54775 L .85264 .55959 L p F P
0 0 0 r
s
.195 0 .31 r
.85264 .55959 m .85455 .57757 L .84609 .56578 L p F P
0 0 0 r
s
.195 0 .31 r
.79225 .39758 m .79069 .38053 L .79948 .39355 L p F P
0 0 0 r
s
.195 0 .31 r
.79948 .39355 m .80108 .41055 L .79225 .39758 L p F P
0 0 0 r
s
.195 0 .31 r
.7384 .22939 m .73716 .21332 L .74632 .2275 L p F P
0 0 0 r
s
.195 0 .31 r
.74632 .2275 m .7476 .24353 L .7384 .22939 L p F P
0 0 0 r
s
.625 0 .573 r
.59974 .90769 m .60603 .91349 L .58683 .91921 L p F P
0 0 0 r
s
.625 0 .573 r
.58683 .91921 m .57974 .91277 L .59974 .90769 L p F P
0 0 0 r
s
.1 0 .485 r
.52385 .10373 m .52386 .0885 L .54356 .08032 L p F P
0 0 0 r
s
.1 0 .485 r
.52386 .0885 m .52385 .10373 L .50418 .11184 L p F P
0 0 0 r
s
0 .78 .12 r
.78974 .91898 m .78381 .91273 L .78978 .90747 L p F P
0 0 0 r
s
0 .78 .12 r
.81045 .91394 m .78974 .91898 L p .78978 .90747 L F P
0 0 0 r
s
.1 0 .485 r
.12887 .4657 m .13118 .44837 L .14939 .44155 L p F P
0 0 0 r
s
.1 0 .485 r
.13118 .44837 m .12887 .4657 L .1107 .47245 L p F P
0 0 0 r
s
0 .647 .956 r
.22999 .91821 m .22746 .91889 L .21489 .9095 L p F P
0 0 0 r
s
.125 0 .956 r
.19866 .91394 m .21489 .9095 L .22746 .91889 L p F P
0 0 0 r
s
.1 0 .485 r
.46458 .15881 m .46494 .14325 L .48442 .13527 L p F P
0 0 0 r
s
.1 0 .485 r
.46494 .14325 m .46458 .15881 L .44514 .16671 L p F P
0 0 0 r
s
.188 0 .528 r
.12299 .688 m .12533 .66938 L .1118 .65829 L p F P
0 0 0 r
s
.188 0 .528 r
.11421 .63982 m .1118 .65829 L .12533 .66938 L p F P
0 0 0 r
s
.1 0 .485 r
.06949 .52089 m .07214 .50323 L .09013 .49662 L p F P
0 0 0 r
s
.625 0 .573 r
.5296 .91355 m .50995 .91859 L .49912 .90926 L p F P
0 0 0 r
s
.625 0 .573 r
.47952 .91433 m .49912 .90926 L .50995 .91859 L p F P
0 0 0 r
s
.188 0 .528 r
.17649 .85512 m .17852 .83552 L .16537 .8256 L p F P
0 0 0 r
s
.188 0 .528 r
.16747 .80615 m .16537 .8256 L .17852 .83552 L p F P
0 0 0 r
s
0 .78 .12 r
.27978 .91743 m .27657 .9183 L .26466 .90881 L p F P
0 0 0 r
s
0 .78 .71 r
.24859 .91316 m .26466 .90881 L .27657 .9183 L p F P
0 0 0 r
s
.1 0 .485 r
.40528 .21392 m .40599 .19804 L .42525 .19027 L p F P
0 0 0 r
s
.1 0 .485 r
.40599 .19804 m .40528 .21392 L .38605 .22162 L p F P
0 0 0 r
s
0 .647 .956 r
.24501 .91413 m .22999 .91821 L .2172 .90887 L p F P
0 0 0 r
s
0 .647 .956 r
.21489 .9095 m .2172 .90887 L .22999 .91821 L p F P
0 0 0 r
s
0 .78 .71 r
.86074 .91316 m .83983 .91821 L .83131 .90887 L p F P
0 0 0 r
s
.134 0 .891 r
.56341 .07207 m .57379 .08724 L .59369 .07905 L p F P
0 0 0 r
s
0 .78 .71 r
.83072 .90901 m .83131 .90887 L .83983 .91821 L p F P
0 0 0 r
s
.134 0 .891 r
.57379 .08724 m .56341 .07207 L .54356 .08032 L p F P
0 0 0 r
s
.195 0 .31 r
.72786 .19894 m .72668 .18304 L .73593 .19744 L p F P
0 0 0 r
s
.195 0 .31 r
.73593 .19744 m .73716 .21332 L .72786 .19894 L p F P
0 0 0 r
s
.195 0 .31 r
.78178 .36734 m .78028 .35045 L .78915 .36368 L p F P
0 0 0 r
s
.195 0 .31 r
.78915 .36368 m .79069 .38053 L .78178 .36734 L p F P
0 0 0 r
s
.1 0 .485 r
.34595 .26906 m .347 .25286 L .36604 .24529 L p F P
0 0 0 r
s
.1 0 .485 r
.347 .25286 m .34595 .26906 L .32694 .27655 L p F P
0 0 0 r
s
.195 0 .31 r
.94351 .87252 m .94107 .85267 L .94882 .86241 L p F P
0 0 0 r
s
.195 0 .31 r
.94882 .86241 m .95129 .88217 L .94351 .87252 L p F P
0 0 0 r
s
.195 0 .31 r
.8896 .70413 m .88747 .68526 L .8956 .69616 L p F P
0 0 0 r
s
.195 0 .31 r
.8956 .69616 m .89776 .71496 L .8896 .70413 L p F P
0 0 0 r
s
.195 0 .31 r
.83569 .53573 m .83388 .51785 L .84238 .52992 L p F P
0 0 0 r
s
.195 0 .31 r
.84238 .52992 m .84422 .54775 L .83569 .53573 L p F P
0 0 0 r
s
.625 0 .573 r
.57974 .91277 m .55989 .91782 L .5494 .90847 L p F P
0 0 0 r
s
.625 0 .573 r
.5296 .91355 m .5494 .90847 L .55989 .91782 L p F P
0 0 0 r
s
0 .78 .71 r
.86456 .91744 m .86074 .91316 L .87039 .91083 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.28658 .32423 m .28797 .30771 L .3068 .30034 L p F P
0 0 0 r
s
.1 0 .485 r
.28797 .30771 m .28658 .32423 L .26779 .33152 L p F P
0 0 0 r
s
0 .78 .12 r
.29855 .91239 m .27978 .91743 L .26733 .90808 L p F P
0 0 0 r
s
0 .78 .12 r
.26466 .90881 m .26733 .90808 L .27978 .91743 L p F P
0 0 0 r
s
.134 0 .891 r
.61375 .07079 m .62378 .08599 L .64388 .07778 L p F P
0 0 0 r
s
.134 0 .891 r
.62378 .08599 m .61375 .07079 L .59369 .07905 L p F P
0 0 0 r
s
0 .647 .956 r
.91108 .91238 m .88997 .91743 L .88181 .90808 L p F P
0 0 0 r
s
0 .647 .956 r
.87039 .91083 m .88181 .90808 L .88997 .91743 L p F P
0 0 0 r
s
.1 0 .485 r
.22717 .37944 m .22891 .36259 L .24752 .35543 L p F P
0 0 0 r
s
.1 0 .485 r
.22891 .36259 m .22717 .37944 L .20861 .38652 L p F P
0 0 0 r
s
.188 0 .528 r
.16537 .8256 m .16747 .80615 L .15422 .79602 L p F P
0 0 0 r
s
.188 0 .528 r
.15639 .77672 m .15422 .79602 L .16747 .80615 L p F P
0 0 0 r
s
.188 0 .528 r
.1118 .65829 m .11421 .63982 L .10059 .62851 L p F P
0 0 0 r
s
.188 0 .528 r
.10307 .61019 m .10059 .62851 L .11421 .63982 L p F P
0 0 0 r
s
.625 .201 0 r
.60988 .91705 m .60603 .91349 L .62387 .9063 L p F P
0 0 0 r
s
.625 .201 0 r
.62387 .9063 m .62994 .91199 L .60988 .91705 L p F P
0 0 0 r
s
.1 0 .485 r
.16774 .43468 m .16982 .4175 L .18821 .41055 L p F P
0 0 0 r
s
.1 0 .485 r
.16982 .4175 m .16774 .43468 L .14939 .44155 L p F P
0 0 0 r
s
.511 .78 0 r
.33658 .91481 m .32963 .91666 L .31752 .9073 L p F P
0 0 0 r
s
.511 .78 0 r
.29858 .91238 m .31752 .9073 L .32963 .91666 L p F P
0 0 0 r
s
.134 0 .891 r
.66414 .06952 m .67383 .08473 L .69413 .07652 L p F P
0 0 0 r
s
.134 0 .891 r
.67383 .08473 m .66414 .06952 L .64388 .07778 L p F P
0 0 0 r
s
.125 0 .956 r
.96149 .9116 m .94018 .91666 L .93236 .9073 L p F P
0 0 0 r
s
.125 0 .956 r
.91311 .9119 m .93236 .9073 L .94018 .91666 L p F P
0 0 0 r
s
.1 0 .485 r
.50405 .12723 m .50418 .11184 L .52385 .10373 L p F P
0 0 0 r
s
.1 0 .485 r
.50418 .11184 m .50405 .12723 L .48442 .13527 L p F P
0 0 0 r
s
.1 0 .485 r
.10826 .48995 m .1107 .47245 L .12887 .4657 L p F P
0 0 0 r
s
.1 0 .485 r
.1107 .47245 m .10826 .48995 L .09013 .49662 L p F P
0 0 0 r
s
.195 0 .31 r
.77128 .33702 m .76985 .32029 L .7788 .33375 L p F P
0 0 0 r
s
.195 0 .31 r
.7788 .33375 m .78028 .35045 L .77128 .33702 L p F P
0 0 0 r
s
.195 0 .31 r
.71731 .16843 m .71619 .15268 L .72552 .16732 L p F P
0 0 0 r
s
.195 0 .31 r
.72552 .16732 m .72668 .18304 L .71731 .16843 L p F P
0 0 0 r
s
.195 0 .31 r
.93321 .8428 m .93083 .8231 L .93866 .83305 L p F P
0 0 0 r
s
.195 0 .31 r
.93866 .83305 m .94107 .85267 L .93321 .8428 L p F P
0 0 0 r
s
.195 0 .31 r
.87923 .67421 m .87717 .6555 L .88537 .66662 L p F P
0 0 0 r
s
.195 0 .31 r
.88537 .66662 m .88747 .68526 L .87923 .67421 L p F P
0 0 0 r
s
.195 0 .31 r
.82526 .50561 m .82351 .48789 L .83209 .50019 L p F P
0 0 0 r
s
.195 0 .31 r
.83209 .50019 m .83388 .51785 L .82526 .50561 L p F P
0 0 0 r
s
.625 .201 0 r
.68019 .91121 m .65994 .91627 L .65015 .9069 L p F P
0 0 0 r
s
.625 .201 0 r
.62994 .91199 m .65015 .9069 L .65994 .91627 L p F P
0 0 0 r
s
.1 0 .485 r
.44466 .18243 m .44514 .16671 L .46458 .15881 L p F P
0 0 0 r
s
.1 0 .485 r
.44514 .16671 m .44466 .18243 L .42525 .19027 L p F P
0 0 0 r
s
.625 .656 0 r
.38089 .91553 m .37954 .91588 L .36777 .90651 L p F P
0 0 0 r
s
.625 .656 0 r
.34863 .9116 m .36777 .90651 L .37954 .91588 L p F P
0 0 0 r
s
.625 .201 0 r
.39873 .91082 m .38089 .91553 L .36832 .90636 L p F P
0 0 0 r
s
.625 .656 0 r
.36777 .90651 m .36832 .90636 L .38089 .91553 L p F P
0 0 0 r
s
.1 0 .485 r
.38523 .23766 m .38605 .22162 L .40528 .21392 L p F P
0 0 0 r
s
.1 0 .485 r
.38605 .22162 m .38523 .23766 L .36604 .24529 L p F P
0 0 0 r
s
.188 0 .528 r
.10059 .62851 m .10307 .61019 L .08935 .59866 L p F P
0 0 0 r
s
.188 0 .528 r
.0919 .58049 m .08935 .59866 L .10307 .61019 L p F P
0 0 0 r
s
.625 .656 0 r
.73051 .91043 m .71005 .9155 L .7006 .90612 L p F P
0 0 0 r
s
.625 .656 0 r
.69039 .90867 m .7006 .90612 L .71005 .9155 L p F P
0 0 0 r
s
.188 0 .528 r
.15422 .79602 m .15639 .77672 L .14305 .76637 L p F P
0 0 0 r
s
.188 0 .528 r
.14528 .74722 m .14305 .76637 L .15639 .77672 L p F P
0 0 0 r
s
.1 0 .485 r
.32577 .29293 m .32694 .27655 L .34595 .26906 L p F P
0 0 0 r
s
.1 0 .485 r
.32694 .27655 m .32577 .29293 L .3068 .30034 L p F P
0 0 0 r
s
.625 .201 0 r
.44124 .91204 m .4295 .91511 L .41808 .90572 L p F P
0 0 0 r
s
.625 .201 0 r
.39873 .91082 m .41808 .90572 L .4295 .91511 L p F P
0 0 0 r
s
.625 .656 0 r
.34863 .9116 m .33658 .91481 L .32498 .90529 L p F P
0 0 0 r
s
.511 .78 0 r
.31752 .9073 m .32498 .90529 L .33658 .91481 L p F P
0 0 0 r
s
.511 .78 0 r
.78088 .90965 m .76022 .91472 L .75112 .90533 L p F P
0 0 0 r
s
.511 .78 0 r
.74545 .90674 m .75112 .90533 L .76022 .91472 L p F P
0 0 0 r
s
.1 0 .485 r
.26627 .34822 m .26779 .33152 L .28658 .32423 L p F P
0 0 0 r
s
.1 0 .485 r
.26779 .33152 m .26627 .34822 L .24752 .35543 L p F P
0 0 0 r
s
.195 0 .31 r
.8148 .47542 m .81311 .45786 L .82177 .47038 L p F P
0 0 0 r
s
.195 0 .31 r
.82177 .47038 m .82351 .48789 L .8148 .47542 L p F P
0 0 0 r
s
.195 0 .31 r
.70672 .13784 m .70567 .12226 L .71508 .13712 L p F P
0 0 0 r
s
.195 0 .31 r
.71508 .13712 m .71619 .15268 L .70672 .13784 L p F P
0 0 0 r
s
.195 0 .31 r
.92288 .81301 m .92056 .79346 L .92847 .80363 L p F P
0 0 0 r
s
.195 0 .31 r
.92847 .80363 m .93083 .8231 L .92288 .81301 L p F P
0 0 0 r
s
.195 0 .31 r
.86884 .64422 m .86683 .62566 L .87512 .63701 L p F P
0 0 0 r
s
.195 0 .31 r
.87512 .63701 m .87717 .6555 L .86884 .64422 L p F P
0 0 0 r
s
.195 0 .31 r
.76076 .30663 m .75939 .29006 L .76843 .30375 L p F P
0 0 0 r
s
.195 0 .31 r
.76843 .30375 m .76985 .32029 L .76076 .30663 L p F P
0 0 0 r
s
.625 .656 0 r
.7346 .91457 m .73051 .91043 L .74545 .90674 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.20674 .40355 m .20861 .38652 L .22717 .37944 L p F P
0 0 0 r
s
.1 0 .485 r
.20861 .38652 m .20674 .40355 L .18821 .41055 L p F P
0 0 0 r
s
.625 0 .573 r
.49912 .90926 m .47952 .91433 L .46844 .90494 L p F P
0 0 0 r
s
.625 0 .573 r
.4489 .91004 m .46844 .90494 L .47952 .91433 L p F P
0 0 0 r
s
0 .78 .71 r
.24859 .91316 m .24501 .91413 L .23283 .90459 L p F P
0 0 0 r
s
0 .647 .956 r
.2172 .90887 m .23283 .90459 L .24501 .91413 L p F P
0 0 0 r
s
.1 0 .485 r
.14718 .45891 m .14939 .44155 L .16774 .43468 L p F P
0 0 0 r
s
.1 0 .485 r
.14939 .44155 m .14718 .45891 L .12887 .4657 L p F P
0 0 0 r
s
.188 0 .528 r
.18759 .88456 m .1856 .90454 L .19866 .91394 L p F P
0 0 0 r
s
.125 0 .956 r
.21489 .9095 m .19866 .91394 L .1856 .90454 L p F P
0 0 0 r
s
.188 0 .528 r
.14305 .76637 m .14528 .74722 L .13184 .73664 L p F P
0 0 0 r
s
.188 0 .528 r
.13415 .71764 m .13184 .73664 L .14528 .74722 L p F P
0 0 0 r
s
.188 0 .528 r
.08935 .59866 m .0919 .58049 L .07809 .56874 L p F P
0 0 0 r
s
.188 0 .528 r
.08071 .55072 m .07809 .56874 L .0919 .58049 L p F P
0 0 0 r
s
.1 0 .485 r
.54366 .09555 m .54356 .08032 L .56341 .07207 L p F P
0 0 0 r
s
.1 0 .485 r
.54356 .08032 m .54366 .09555 L .52385 .10373 L p F P
0 0 0 r
s
0 .78 .12 r
.83072 .90901 m .81045 .91394 L .8017 .90454 L p F P
0 0 0 r
s
0 .78 .12 r
.78978 .90747 m .8017 .90454 L .81045 .91394 L p F P
0 0 0 r
s
0 .647 .956 r
.91239 .91391 m .91108 .91238 L .91311 .9119 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.48418 .15084 m .48442 .13527 L .50405 .12723 L p F P
0 0 0 r
s
.1 0 .485 r
.48442 .13527 m .48418 .15084 L .46458 .15881 L p F P
0 0 0 r
s
.1 0 .485 r
.08757 .5143 m .09013 .49662 L .10826 .48995 L p F P
0 0 0 r
s
.1 0 .485 r
.09013 .49662 m .08757 .5143 L .06949 .52089 L p F P
0 0 0 r
s
.625 0 .573 r
.5494 .90847 m .5296 .91355 L .51887 .90415 L p F P
0 0 0 r
s
.625 0 .573 r
.49912 .90926 m .51887 .90415 L .5296 .91355 L p F P
0 0 0 r
s
.625 0 .573 r
.6199 .90257 m .62387 .9063 L .60603 .91349 L p F P
0 0 0 r
s
.625 0 .573 r
.60603 .91349 m .59974 .90769 L .6199 .90257 L p F P
0 0 0 r
s
.625 .201 0 r
.68244 .91341 m .68019 .91121 L .69039 .90867 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.42466 .20616 m .42525 .19027 L .44466 .18243 L p F P
0 0 0 r
s
.1 0 .485 r
.42525 .19027 m .42466 .20616 L .40528 .21392 L p F P
0 0 0 r
s
0 .78 .71 r
.26466 .90881 m .24859 .91316 L .23587 .90375 L p F P
0 0 0 r
s
0 .78 .71 r
.23283 .90459 m .23587 .90375 L .24859 .91316 L p F P
0 0 0 r
s
.195 0 .31 r
.80432 .44516 m .80269 .42776 L .81144 .4405 L p F P
0 0 0 r
s
.195 0 .31 r
.81144 .4405 m .81311 .45786 L .80432 .44516 L p F P
0 0 0 r
s
.195 0 .31 r
.75022 .27617 m .74891 .25976 L .75803 .27368 L p F P
0 0 0 r
s
.195 0 .31 r
.75803 .27368 m .75939 .29006 L .75022 .27617 L p F P
0 0 0 r
s
.195 0 .31 r
.69612 .10718 m .69512 .09176 L .70462 .10685 L p F P
0 0 0 r
s
.195 0 .31 r
.70462 .10685 m .70567 .12226 L .69612 .10718 L p F P
0 0 0 r
s
.134 0 .891 r
.58341 .06376 m .59369 .07905 L .61375 .07079 L p F P
0 0 0 r
s
.134 0 .891 r
.59369 .07905 m .58341 .06376 L .56341 .07207 L p F P
0 0 0 r
s
.195 0 .31 r
.91253 .78315 m .91026 .76375 L .91826 .77414 L p F P
0 0 0 r
s
.195 0 .31 r
.91826 .77414 m .92056 .79346 L .91253 .78315 L p F P
0 0 0 r
s
.195 0 .31 r
.85843 .61416 m .85648 .59576 L .86485 .60732 L p F P
0 0 0 r
s
.195 0 .31 r
.86485 .60732 m .86683 .62566 L .85843 .61416 L p F P
0 0 0 r
s
0 .78 .71 r
.87039 .91083 m .86074 .91316 L .85234 .90375 L p F P
0 0 0 r
s
0 .78 .71 r
.83131 .90887 m .85234 .90375 L .86074 .91316 L p F P
0 0 0 r
s
.1 0 .485 r
.3651 .26151 m .36604 .24529 L .38523 .23766 L p F P
0 0 0 r
s
.1 0 .485 r
.36604 .24529 m .3651 .26151 L .34595 .26906 L p F P
0 0 0 r
s
.625 0 .573 r
.59974 .90769 m .57974 .91277 L .56936 .90336 L p F P
0 0 0 r
s
.625 0 .573 r
.5494 .90847 m .56936 .90336 L .57974 .91277 L p F P
0 0 0 r
s
.511 .78 0 r
.78381 .91273 m .78088 .90965 L .78978 .90747 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.29821 .9121 m .29858 .91238 L .29855 .91239 L closepath p F P
0 0 0 r
s
0 .78 .12 r
.28621 .90296 m .29821 .9121 L .29855 .91239 L p F P
0 0 0 r
s
0 .78 .12 r
.26733 .90808 m .28621 .90296 L p .29855 .91239 L F P
0 0 0 r
s
.1 0 .485 r
.30551 .31689 m .3068 .30034 L .32577 .29293 L p F P
0 0 0 r
s
.1 0 .485 r
.3068 .30034 m .30551 .31689 L .28658 .32423 L p F P
0 0 0 r
s
.511 .78 0 r
.29858 .91238 m .29821 .9121 L .28717 .9027 L p F P
0 0 0 r
s
.511 .78 0 r
.31752 .9073 m .29858 .91238 L p .28717 .9027 L F P
0 0 0 r
s
.188 0 .528 r
.1856 .90454 m .18759 .88456 L .17443 .87495 L p F P
0 0 0 r
s
.188 0 .528 r
.17649 .85512 m .17443 .87495 L .18759 .88456 L p F P
0 0 0 r
s
.188 0 .528 r
.13184 .73664 m .13415 .71764 L .12062 .70685 L p F P
0 0 0 r
s
.188 0 .528 r
.12299 .688 m .12062 .70685 L .13415 .71764 L p F P
0 0 0 r
s
.188 0 .528 r
.07809 .56874 m .08071 .55072 L .0668 .53875 L p F P
0 0 0 r
s
.188 0 .528 r
.06949 .52089 m .0668 .53875 L .08071 .55072 L p F P
0 0 0 r
s
.134 0 .891 r
.63395 .06247 m .64388 .07778 L .66414 .06952 L p F P
0 0 0 r
s
.134 0 .891 r
.64388 .07778 m .63395 .06247 L .61375 .07079 L p F P
0 0 0 r
s
0 .647 .956 r
.91311 .9119 m .91108 .91238 L .90304 .90296 L p F P
0 0 0 r
s
0 .647 .956 r
.88181 .90808 m .90304 .90296 L .91108 .91238 L p F P
0 0 0 r
s
0 .78 .12 r
.29821 .9121 m .28621 .90296 L .28717 .9027 L closepath p F P
0 0 0 r
s
.625 0 .573 r
.4489 .91004 m .44124 .91204 L .4255 .90377 L p F P
0 0 0 r
s
.625 .201 0 r
.41808 .90572 m .4255 .90377 L .44124 .91204 L p F P
0 0 0 r
s
.1 0 .485 r
.24589 .37231 m .24752 .35543 L .26627 .34822 L p F P
0 0 0 r
s
.1 0 .485 r
.24752 .35543 m .24589 .37231 L .22717 .37944 L p F P
0 0 0 r
s
.625 .201 0 r
.62994 .91199 m .62387 .9063 L .64024 .89743 L p F P
0 0 0 r
s
.625 .201 0 r
.64024 .89743 m .65015 .9069 L .62994 .91199 L p F P
0 0 0 r
s
0 .647 .956 r
.90304 .90296 m .91305 .90055 L .91311 .9119 L p F P
0 0 0 r
s
.125 0 .956 r
.93236 .9073 m .91311 .9119 L .91305 .90055 L p F P
0 0 0 r
s
.625 .656 0 r
.36777 .90651 m .34863 .9116 L .3366 .90217 L p F P
0 0 0 r
s
.1 0 .485 r
.18623 .42776 m .18821 .41055 L .20674 .40355 L p F P
0 0 0 r
s
.625 .656 0 r
.32498 .90529 m .3366 .90217 L .34863 .9116 L p F P
0 0 0 r
s
.1 0 .485 r
.18821 .41055 m .18623 .42776 L .16774 .43468 L p F P
0 0 0 r
s
.195 0 .31 r
.79382 .41483 m .79225 .39758 L .80108 .41055 L p F P
0 0 0 r
s
.195 0 .31 r
.80108 .41055 m .80269 .42776 L .79382 .41483 L p F P
0 0 0 r
s
.195 0 .31 r
.73965 .24564 m .7384 .22939 L .7476 .24353 L p F P
0 0 0 r
s
.195 0 .31 r
.7476 .24353 m .74891 .25976 L .73965 .24564 L p F P
0 0 0 r
s
.134 0 .891 r
.69413 .07652 m .68455 .06119 L .66414 .06952 L p F P
0 0 0 r
s
.195 0 .31 r
.68548 .07645 m .68455 .06119 L .69413 .07652 L p F P
0 0 0 r
s
.195 0 .31 r
.69413 .07652 m .69512 .09176 L .68548 .07645 L p F P
0 0 0 r
s
.195 0 .31 r
.84799 .58402 m .84609 .56578 L .85455 .57757 L p F P
0 0 0 r
s
.195 0 .31 r
.85455 .57757 m .85648 .59576 L .84799 .58402 L p F P
0 0 0 r
s
.125 0 .956 r
.93236 .9073 m .95379 .90217 L .96149 .9116 L p F P
0 0 0 r
s
.195 0 .31 r
.90215 .75322 m .89994 .73398 L .90802 .74459 L p F P
0 0 0 r
s
.195 0 .31 r
.90802 .74459 m .91026 .76375 L .90215 .75322 L p F P
0 0 0 r
s
.1 0 .485 r
.52383 .11913 m .52385 .10373 L .54366 .09555 L p F P
0 0 0 r
s
.1 0 .485 r
.52385 .10373 m .52383 .11913 L .50405 .12723 L p F P
0 0 0 r
s
.1 0 .485 r
.12653 .48324 m .12887 .4657 L .14718 .45891 L p F P
0 0 0 r
s
.1 0 .485 r
.12887 .4657 m .12653 .48324 L .10826 .48995 L p F P
0 0 0 r
s
.625 .201 0 r
.69039 .90867 m .68019 .91121 L .67051 .90178 L p F P
0 0 0 r
s
.625 .201 0 r
.65015 .9069 m .67051 .90178 L .68019 .91121 L p F P
0 0 0 r
s
0 .78 .71 r
.87352 .8986 m .87507 .90036 L .87039 .91083 L p F P
0 0 0 r
s
0 .78 .71 r
.85234 .90375 m .87352 .8986 L p .87039 .91083 L F P
0 0 0 r
s
0 .647 .956 r
.87507 .90036 m .88181 .90808 L .87039 .91083 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.46422 .17454 m .46458 .15881 L .48418 .15084 L p F P
0 0 0 r
s
.1 0 .485 r
.46458 .15881 m .46422 .17454 L .44466 .18243 L p F P
0 0 0 r
s
.625 .201 0 r
.41808 .90572 m .39873 .91082 L .38706 .90138 L p F P
0 0 0 r
s
.625 .201 0 r
.36832 .90636 m .38706 .90138 L .39873 .91082 L p F P
0 0 0 r
s
.188 0 .528 r
.12062 .70685 m .12299 .688 L .10936 .67699 L p F P
0 0 0 r
s
.188 0 .528 r
.1118 .65829 m .10936 .67699 L .12299 .688 L p F P
0 0 0 r
s
.1 0 .485 r
.0668 .53875 m .06949 .52089 L .08757 .5143 L p F P
0 0 0 r
s
.188 0 .528 r
.17443 .87495 m .17649 .85512 L .16324 .84528 L p F P
0 0 0 r
s
.188 0 .528 r
.16537 .8256 m .16324 .84528 L .17649 .85512 L p F P
0 0 0 r
s
.1 0 .485 r
.40457 .22998 m .40528 .21392 L .42466 .20616 L p F P
0 0 0 r
s
.1 0 .485 r
.40528 .21392 m .40457 .22998 L .38523 .23766 L p F P
0 0 0 r
s
.625 .656 0 r
.74545 .90674 m .73051 .91043 L .72117 .90098 L p F P
0 0 0 r
s
.625 .656 0 r
.7006 .90612 m .72117 .90098 L .73051 .91043 L p F P
0 0 0 r
s
.195 0 .31 r
.72906 .21504 m .72786 .19894 L .73716 .21332 L p F P
0 0 0 r
s
.195 0 .31 r
.73716 .21332 m .7384 .22939 L .72906 .21504 L p F P
0 0 0 r
s
.625 0 .573 r
.46844 .90494 m .4489 .91004 L .43757 .90059 L p F P
0 0 0 r
s
.625 0 .573 r
.4255 .90377 m .43757 .90059 L .4489 .91004 L p F P
0 0 0 r
s
.195 0 .31 r
.94599 .89261 m .94351 .87252 L .95129 .88217 L p F P
0 0 0 r
s
.195 0 .31 r
.95129 .88217 m .95379 .90217 L .94599 .89261 L p F P
0 0 0 r
s
.195 0 .31 r
.89175 .72321 m .8896 .70413 L .89776 .71496 L p F P
0 0 0 r
s
.195 0 .31 r
.89776 .71496 m .89994 .73398 L .89175 .72321 L p F P
0 0 0 r
s
.195 0 .31 r
.83752 .55382 m .83569 .53573 L .84422 .54775 L p F P
0 0 0 r
s
.195 0 .31 r
.84422 .54775 m .84609 .56578 L .83752 .55382 L p F P
0 0 0 r
s
.195 0 .31 r
.78329 .38443 m .78178 .36734 L .79069 .38053 L p F P
0 0 0 r
s
.195 0 .31 r
.79069 .38053 m .79225 .39758 L .78329 .38443 L p F P
0 0 0 r
s
.1 0 .485 r
.34489 .28545 m .34595 .26906 L .3651 .26151 L p F P
0 0 0 r
s
.1 0 .485 r
.34595 .26906 m .34489 .28545 L .32577 .29293 L p F P
0 0 0 r
s
.511 .78 0 r
.78978 .90747 m .78088 .90965 L .7719 .90019 L p F P
0 0 0 r
s
.511 .78 0 r
.75112 .90533 m .7719 .90019 L .78088 .90965 L p F P
0 0 0 r
s
.1 0 .485 r
.28517 .34096 m .28658 .32423 L .30551 .31689 L p F P
0 0 0 r
s
.1 0 .485 r
.28658 .32423 m .28517 .34096 L .26627 .34822 L p F P
0 0 0 r
s
0 .647 .956 r
.2172 .90887 m .21489 .9095 L .20225 .89994 L p F P
0 0 0 r
s
.125 0 .956 r
.1856 .90454 m .20225 .89994 L .21489 .9095 L p F P
0 0 0 r
s
.1 0 .485 r
.22541 .39649 m .22717 .37944 L .24589 .37231 L p F P
0 0 0 r
s
.1 0 .485 r
.22717 .37944 m .22541 .39649 L .20674 .40355 L p F P
0 0 0 r
s
.188 0 .528 r
.16324 .84528 m .16537 .8256 L .15203 .81555 L p F P
0 0 0 r
s
.188 0 .528 r
.15422 .79602 m .15203 .81555 L .16537 .8256 L p F P
0 0 0 r
s
.188 0 .528 r
.10936 .67699 m .1118 .65829 L .09808 .64705 L p F P
0 0 0 r
s
.188 0 .528 r
.10059 .62851 m .09808 .64705 L .1118 .65829 L p F P
0 0 0 r
s
.625 0 .573 r
.51887 .90415 m .49912 .90926 L .48814 .89979 L p F P
0 0 0 r
s
.625 0 .573 r
.46844 .90494 m .48814 .89979 L .49912 .90926 L p F P
0 0 0 r
s
0 .78 .12 r
.82268 .8994 m .83107 .9086 L .83072 .90901 L p F P
0 0 0 r
s
0 .78 .12 r
.8017 .90454 m .82268 .8994 L p .83072 .90901 L F P
0 0 0 r
s
0 .78 .71 r
.83107 .9086 m .83131 .90887 L .83072 .90901 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.16562 .45206 m .16774 .43468 L .18623 .42776 L p F P
0 0 0 r
s
.1 0 .485 r
.16774 .43468 m .16562 .45206 L .14718 .45891 L p F P
0 0 0 r
s
0 .647 .956 r
.23283 .90459 m .2172 .90887 L .20422 .8994 L p F P
0 0 0 r
s
0 .647 .956 r
.20225 .89994 m .20422 .8994 L .2172 .90887 L p F P
0 0 0 r
s
.1 0 .485 r
.56363 .08732 m .56341 .07207 L .58341 .06376 L p F P
0 0 0 r
s
.1 0 .485 r
.56341 .07207 m .56363 .08732 L .54366 .09555 L p F P
0 0 0 r
s
0 .78 .71 r
.83131 .90887 m .83107 .9086 L .83804 .89563 L p F P
0 0 0 r
s
0 .78 .71 r
.85234 .90375 m .83131 .90887 L p .83804 .89563 L F P
0 0 0 r
s
0 .78 .12 r
.26733 .90808 m .26466 .90881 L .25298 .89907 L p F P
0 0 0 r
s
0 .78 .71 r
.23587 .90375 m .25298 .89907 L .26466 .90881 L p F P
0 0 0 r
s
.625 .201 0 r
.69103 .89661 m .69785 .90338 L .69039 .90867 L p F P
0 0 0 r
s
.625 .201 0 r
.67051 .90178 m .69103 .89661 L p .69039 .90867 L F P
0 0 0 r
s
.625 .656 0 r
.69785 .90338 m .7006 .90612 L .69039 .90867 L closepath p F P
0 0 0 r
s
0 .78 .12 r
.83107 .9086 m .82268 .8994 L .83804 .89563 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.77274 .35395 m .77128 .33702 L .78028 .35045 L p F P
0 0 0 r
s
.195 0 .31 r
.78028 .35045 m .78178 .36734 L .77274 .35395 L p F P
0 0 0 r
s
.1 0 .485 r
.50392 .14281 m .50405 .12723 L .52383 .11913 L p F P
0 0 0 r
s
.1 0 .485 r
.50405 .12723 m .50392 .14281 L .48418 .15084 L p F P
0 0 0 r
s
.1 0 .485 r
.1058 .50767 m .10826 .48995 L .12653 .48324 L p F P
0 0 0 r
s
.1 0 .485 r
.10826 .48995 m .1058 .50767 L .08757 .5143 L p F P
0 0 0 r
s
.195 0 .31 r
.93562 .86273 m .93321 .8428 L .94107 .85267 L p F P
0 0 0 r
s
.195 0 .31 r
.94107 .85267 m .94351 .87252 L .93562 .86273 L p F P
0 0 0 r
s
.195 0 .31 r
.82703 .52355 m .82526 .50561 L .83388 .51785 L p F P
0 0 0 r
s
.195 0 .31 r
.83388 .51785 m .83569 .53573 L .82703 .52355 L p F P
0 0 0 r
s
.195 0 .31 r
.71844 .18436 m .71731 .16843 L .72668 .18304 L p F P
0 0 0 r
s
.195 0 .31 r
.72668 .18304 m .72786 .19894 L .71844 .18436 L p F P
0 0 0 r
s
.195 0 .31 r
.88133 .69314 m .87923 .67421 L .88747 .68526 L p F P
0 0 0 r
s
.195 0 .31 r
.88747 .68526 m .8896 .70413 L .88133 .69314 L p F P
0 0 0 r
s
.625 0 .573 r
.56936 .90336 m .5494 .90847 L .53877 .899 L p F P
0 0 0 r
s
.625 0 .573 r
.51887 .90415 m .53877 .899 L .5494 .90847 L p F P
0 0 0 r
s
.1 0 .485 r
.44418 .19834 m .44466 .18243 L .46422 .17454 L p F P
0 0 0 r
s
.1 0 .485 r
.44466 .18243 m .44418 .19834 L .42466 .20616 L p F P
0 0 0 r
s
.134 0 .891 r
.60357 .05539 m .61375 .07079 L .63395 .06247 L p F P
0 0 0 r
s
.134 0 .891 r
.61375 .07079 m .60357 .05539 L .58341 .06376 L p F P
0 0 0 r
s
0 .78 .12 r
.28621 .90296 m .26733 .90808 L .2547 .8986 L p F P
0 0 0 r
s
0 .78 .12 r
.25298 .89907 m .2547 .8986 L .26733 .90808 L p F P
0 0 0 r
s
0 .647 .956 r
.88181 .90808 m .87507 .90036 L .87541 .89814 L p F P
0 0 0 r
s
0 .647 .956 r
.90304 .90296 m .88181 .90808 L p .87541 .89814 L F P
0 0 0 r
s
.1 0 .485 r
.3844 .2539 m .38523 .23766 L .40457 .22998 L p F P
0 0 0 r
s
.1 0 .485 r
.38523 .23766 m .3844 .2539 L .3651 .26151 L p F P
0 0 0 r
s
.188 0 .528 r
.09808 .64705 m .10059 .62851 L .08678 .61705 L p F P
0 0 0 r
s
.188 0 .528 r
.08935 .59866 m .08678 .61705 L .10059 .62851 L p F P
0 0 0 r
s
.625 0 .573 r
.6199 .90257 m .59974 .90769 L .58946 .8982 L p F P
0 0 0 r
s
.625 0 .573 r
.56936 .90336 m .58946 .8982 L .59974 .90769 L p F P
0 0 0 r
s
.188 0 .528 r
.15203 .81555 m .15422 .79602 L .14078 .78574 L p F P
0 0 0 r
s
.188 0 .528 r
.14305 .76637 m .14078 .78574 L .15422 .79602 L p F P
0 0 0 r
s
.511 .78 0 r
.79283 .89501 m .79665 .89911 L .78978 .90747 L p F P
0 0 0 r
s
.511 .78 0 r
.7719 .90019 m .79283 .89501 L p .78978 .90747 L F P
0 0 0 r
s
0 .78 .12 r
.79665 .89911 m .8017 .90454 L .78978 .90747 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.32459 .30949 m .32577 .29293 L .34489 .28545 L p F P
0 0 0 r
s
.1 0 .485 r
.32577 .29293 m .32459 .30949 L .30551 .31689 L p F P
0 0 0 r
s
.134 0 .891 r
.65431 .05409 m .66414 .06952 L .68455 .06119 L p F P
0 0 0 r
s
.134 0 .891 r
.66414 .06952 m .65431 .05409 L .63395 .06247 L p F P
0 0 0 r
s
.511 .78 0 r
.32498 .90529 m .31752 .9073 L .30523 .8978 L p F P
0 0 0 r
s
.511 .78 0 r
.28717 .9027 m .30523 .8978 L .31752 .9073 L p F P
0 0 0 r
s
.125 0 .956 r
.95379 .90217 m .93236 .9073 L .92443 .8978 L p F P
0 0 0 r
s
.125 0 .956 r
.91305 .90055 m .92443 .8978 L .93236 .9073 L p F P
0 0 0 r
s
.1 0 .485 r
.26474 .36512 m .26627 .34822 L .28517 .34096 L p F P
0 0 0 r
s
.1 0 .485 r
.26627 .34822 m .26474 .36512 L .24589 .37231 L p F P
0 0 0 r
s
.195 0 .31 r
.92524 .83279 m .92288 .81301 L .93083 .8231 L p F P
0 0 0 r
s
.195 0 .31 r
.93083 .8231 m .93321 .8428 L .92524 .83279 L p F P
0 0 0 r
s
.195 0 .31 r
.87088 .66299 m .86884 .64422 L .87717 .6555 L p F P
0 0 0 r
s
.195 0 .31 r
.87717 .6555 m .87923 .67421 L .87088 .66299 L p F P
0 0 0 r
s
.195 0 .31 r
.81652 .4932 m .8148 .47542 L .82351 .48789 L p F P
0 0 0 r
s
.195 0 .31 r
.82351 .48789 m .82526 .50561 L .81652 .4932 L p F P
0 0 0 r
s
.195 0 .31 r
.7078 .15361 m .70672 .13784 L .71619 .15268 L p F P
0 0 0 r
s
.195 0 .31 r
.71619 .15268 m .71731 .16843 L .7078 .15361 L p F P
0 0 0 r
s
.625 .201 0 r
.65015 .9069 m .64024 .89743 L .64031 .89738 L p F P
0 0 0 r
s
.625 .201 0 r
.67051 .90178 m .65015 .9069 L p .64031 .89738 L F P
0 0 0 r
s
.195 0 .31 r
.76216 .3234 m .76076 .30663 L .76985 .32029 L p F P
0 0 0 r
s
.195 0 .31 r
.76985 .32029 m .77128 .33702 L .76216 .3234 L p F P
0 0 0 r
s
.625 .656 0 r
.7419 .89581 m .74919 .90334 L .74545 .90674 L p F P
0 0 0 r
s
.625 .656 0 r
.72117 .90098 m .7419 .89581 L p .74545 .90674 L F P
0 0 0 r
s
.511 .78 0 r
.74919 .90334 m .75112 .90533 L .74545 .90674 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.36832 .90636 m .36777 .90651 L .35583 .89701 L p F P
0 0 0 r
s
.1 0 .485 r
.20486 .42078 m .20674 .40355 L .22541 .39649 L p F P
0 0 0 r
s
.625 .656 0 r
.3366 .90217 m .35583 .89701 L .36777 .90651 L p F P
0 0 0 r
s
.1 0 .485 r
.20674 .40355 m .20486 .42078 L .18623 .42776 L p F P
0 0 0 r
s
.625 .201 0 r
.38706 .90138 m .36832 .90636 L .3572 .89664 L p F P
0 0 0 r
s
.625 .656 0 r
.35583 .89701 m .3572 .89664 L .36832 .90636 L p F P
0 0 0 r
s
.625 0 .573 r
.64021 .89741 m .64024 .89743 L .62387 .9063 L p F P
0 0 0 r
s
.625 0 .573 r
.62387 .9063 m .6199 .90257 L .64021 .89741 L p F P
0 0 0 r
s
.1 0 .485 r
.54376 .11097 m .54366 .09555 L .56363 .08732 L p F P
0 0 0 r
s
.1 0 .485 r
.54366 .09555 m .54376 .11097 L .52383 .11913 L p F P
0 0 0 r
s
.1 0 .485 r
.14494 .47647 m .14718 .45891 L .16562 .45206 L p F P
0 0 0 r
s
.1 0 .485 r
.14718 .45891 m .14494 .47647 L .12653 .48324 L p F P
0 0 0 r
s
.188 0 .528 r
.14078 .78574 m .14305 .76637 L .12951 .75586 L p F P
0 0 0 r
s
.188 0 .528 r
.13184 .73664 m .12951 .75586 L .14305 .76637 L p F P
0 0 0 r
s
.188 0 .528 r
.08678 .61705 m .08935 .59866 L .07544 .58697 L p F P
0 0 0 r
s
.188 0 .528 r
.07809 .56874 m .07544 .58697 L .08935 .59866 L p F P
0 0 0 r
s
.625 .656 0 r
.7006 .90612 m .69785 .90338 L .70988 .89186 L p F P
0 0 0 r
s
.625 .656 0 r
.72117 .90098 m .7006 .90612 L p .70988 .89186 L F P
0 0 0 r
s
.1 0 .485 r
.48393 .16659 m .48418 .15084 L .50392 .14281 L p F P
0 0 0 r
s
.1 0 .485 r
.48418 .15084 m .48393 .16659 L .46422 .17454 L p F P
0 0 0 r
s
.1 0 .485 r
.08498 .5322 m .08757 .5143 L .1058 .50767 L p F P
0 0 0 r
s
.1 0 .485 r
.08757 .5143 m .08498 .5322 L .0668 .53875 L p F P
0 0 0 r
s
.625 .201 0 r
.4255 .90377 m .41808 .90572 L .40649 .89621 L p F P
0 0 0 r
s
.625 .201 0 r
.38706 .90138 m .40649 .89621 L .41808 .90572 L p F P
0 0 0 r
s
.195 0 .31 r
.75155 .29278 m .75022 .27617 L .75939 .29006 L p F P
0 0 0 r
s
.195 0 .31 r
.75939 .29006 m .76076 .30663 L .75155 .29278 L p F P
0 0 0 r
s
.1 0 .485 r
.42406 .22224 m .42466 .20616 L .44418 .19834 L p F P
0 0 0 r
s
.1 0 .485 r
.42466 .20616 m .42406 .22224 L .40457 .22998 L p F P
0 0 0 r
s
.195 0 .31 r
.91483 .80277 m .91253 .78315 L .92056 .79346 L p F P
0 0 0 r
s
.195 0 .31 r
.92056 .79346 m .92288 .81301 L .91483 .80277 L p F P
0 0 0 r
s
.195 0 .31 r
.8604 .63278 m .85843 .61416 L .86683 .62566 L p F P
0 0 0 r
s
.195 0 .31 r
.86683 .62566 m .86884 .64422 L .8604 .63278 L p F P
0 0 0 r
s
.195 0 .31 r
.80598 .46278 m .80432 .44516 L .81311 .45786 L p F P
0 0 0 r
s
.195 0 .31 r
.81311 .45786 m .8148 .47542 L .80598 .46278 L p F P
0 0 0 r
s
.195 0 .31 r
.69713 .12279 m .69612 .10718 L .70567 .12226 L p F P
0 0 0 r
s
.195 0 .31 r
.70567 .12226 m .70672 .13784 L .69713 .12279 L p F P
0 0 0 r
s
.511 .78 0 r
.75112 .90533 m .74919 .90334 L .75837 .8917 L p F P
0 0 0 r
s
.511 .78 0 r
.7719 .90019 m .75112 .90533 L p .75837 .8917 L F P
0 0 0 r
s
.625 .656 0 r
.3366 .90217 m .32498 .90529 L .31422 .89537 L p F P
0 0 0 r
s
.511 .78 0 r
.30523 .8978 m .31422 .89537 L .32498 .90529 L p F P
0 0 0 r
s
.1 0 .485 r
.36415 .27792 m .3651 .26151 L .3844 .2539 L p F P
0 0 0 r
s
.1 0 .485 r
.3651 .26151 m .36415 .27792 L .34489 .28545 L p F P
0 0 0 r
s
.625 0 .573 r
.48814 .89979 m .46844 .90494 L .45721 .89541 L p F P
0 0 0 r
s
.625 0 .573 r
.43757 .90059 m .45721 .89541 L .46844 .90494 L p F P
0 0 0 r
s
0 .78 .71 r
.23587 .90375 m .23283 .90459 L .22074 .89483 L p F P
0 0 0 r
s
0 .647 .956 r
.20422 .8994 m .22074 .89483 L .23283 .90459 L p F P
0 0 0 r
s
.188 0 .528 r
.07544 .58697 m .07809 .56874 L .06408 .55683 L p F P
0 0 0 r
s
.188 0 .528 r
.0668 .53875 m .06408 .55683 L .07809 .56874 L p F P
0 0 0 r
s
0 .78 .12 r
.8017 .90454 m .79665 .89911 L .79975 .8933 L p F P
0 0 0 r
s
0 .78 .12 r
.82268 .8994 m .8017 .90454 L p .79975 .8933 L F P
0 0 0 r
s
.1 0 .485 r
.30421 .33363 m .30551 .31689 L .32459 .30949 L p F P
0 0 0 r
s
.1 0 .485 r
.30551 .31689 m .30421 .33363 L .28517 .34096 L p F P
0 0 0 r
s
.188 0 .528 r
.17443 .87495 m .17235 .89501 L .1856 .90454 L p F P
0 0 0 r
s
.125 0 .956 r
.20225 .89994 m .1856 .90454 L .17235 .89501 L p F P
0 0 0 r
s
.188 0 .528 r
.12951 .75586 m .13184 .73664 L .11822 .72592 L p F P
0 0 0 r
s
.188 0 .528 r
.12062 .70685 m .11822 .72592 L .13184 .73664 L p F P
0 0 0 r
s
.625 0 .573 r
.53877 .899 m .51887 .90415 L .50799 .89461 L p F P
0 0 0 r
s
.625 0 .573 r
.48814 .89979 m .50799 .89461 L .51887 .90415 L p F P
0 0 0 r
s
.1 0 .485 r
.24423 .38938 m .24589 .37231 L .26474 .36512 L p F P
0 0 0 r
s
.1 0 .485 r
.24589 .37231 m .24423 .38938 L .22541 .39649 L p F P
0 0 0 r
s
.625 0 .573 r
.43757 .90059 m .4255 .90377 L .41252 .8946 L p F P
0 0 0 r
s
.625 .201 0 r
.40649 .89621 m .41252 .8946 L .4255 .90377 L p F P
0 0 0 r
s
.195 0 .31 r
.68643 .09189 m .68548 .07645 L .69512 .09176 L p F P
0 0 0 r
s
.195 0 .31 r
.69512 .09176 m .69612 .10718 L .68643 .09189 L p F P
0 0 0 r
s
.1 0 .485 r
.58375 .07902 m .58341 .06376 L .60357 .05539 L p F P
0 0 0 r
s
.1 0 .485 r
.58341 .06376 m .58375 .07902 L .56363 .08732 L p F P
0 0 0 r
s
.1 0 .485 r
.18422 .44516 m .18623 .42776 L .20486 .42078 L p F P
0 0 0 r
s
.1 0 .485 r
.18623 .42776 m .18422 .44516 L .16562 .45206 L p F P
0 0 0 r
s
0 .78 .71 r
.25298 .89907 m .23587 .90375 L .22298 .89421 L p F P
0 0 0 r
s
0 .78 .71 r
.22074 .89483 m .22298 .89421 L .23587 .90375 L p F P
0 0 0 r
s
.195 0 .31 r
.8499 .60249 m .84799 .58402 L .85648 .59576 L p F P
0 0 0 r
s
.195 0 .31 r
.85648 .59576 m .85843 .61416 L .8499 .60249 L p F P
0 0 0 r
s
.195 0 .31 r
.79541 .43229 m .79382 .41483 L .80269 .42776 L p F P
0 0 0 r
s
.195 0 .31 r
.80269 .42776 m .80432 .44516 L .79541 .43229 L p F P
0 0 0 r
s
0 .78 .71 r
.87352 .8986 m .85234 .90375 L .84382 .89421 L p F P
0 0 0 r
s
0 .78 .71 r
.83804 .89563 m .84382 .89421 L .85234 .90375 L p F P
0 0 0 r
s
.195 0 .31 r
.74092 .26209 m .73965 .24564 L .74891 .25976 L p F P
0 0 0 r
s
.195 0 .31 r
.74891 .25976 m .75022 .27617 L .74092 .26209 L p F P
0 0 0 r
s
.195 0 .31 r
.90439 .77269 m .90215 .75322 L .91026 .76375 L p F P
0 0 0 r
s
.195 0 .31 r
.91026 .76375 m .91253 .78315 L .90439 .77269 L p F P
0 0 0 r
s
.625 .201 0 r
.69785 .90338 m .69103 .89661 L .70988 .89186 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.52382 .13472 m .52383 .11913 L .54376 .11097 L p F P
0 0 0 r
s
.1 0 .485 r
.52383 .11913 m .52382 .13472 L .50392 .14281 L p F P
0 0 0 r
s
.1 0 .485 r
.12417 .50098 m .12653 .48324 L .14494 .47647 L p F P
0 0 0 r
s
.1 0 .485 r
.12653 .48324 m .12417 .50098 L .1058 .50767 L p F P
0 0 0 r
s
.625 0 .573 r
.58946 .8982 m .56936 .90336 L .55883 .89381 L p F P
0 0 0 r
s
.625 0 .573 r
.53877 .899 m .55883 .89381 L .56936 .90336 L p F P
0 0 0 r
s
.625 .656 0 r
.74919 .90334 m .7419 .89581 L .75837 .8917 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.46385 .19046 m .46422 .17454 L .48393 .16659 L p F P
0 0 0 r
s
.1 0 .485 r
.46422 .17454 m .46385 .19046 L .44418 .19834 L p F P
0 0 0 r
s
.1 0 .485 r
.06408 .55683 m .0668 .53875 L .08498 .5322 L p F P
0 0 0 r
s
.134 0 .891 r
.62387 .04695 m .63395 .06247 L .65431 .05409 L p F P
0 0 0 r
s
.134 0 .891 r
.63395 .06247 m .62387 .04695 L .60357 .05539 L p F P
0 0 0 r
s
0 .78 .12 r
.28717 .9027 m .28621 .90296 L .27366 .89341 L p F P
0 0 0 r
s
0 .78 .12 r
.2547 .8986 m .27366 .89341 L .28621 .90296 L p F P
0 0 0 r
s
.188 0 .528 r
.11822 .72592 m .12062 .70685 L .10689 .6959 L p F P
0 0 0 r
s
.188 0 .528 r
.10936 .67699 m .10689 .6959 L .12062 .70685 L p F P
0 0 0 r
s
0 .647 .956 r
.91305 .90055 m .90304 .90296 L .89487 .89341 L p F P
0 0 0 r
s
0 .647 .956 r
.87541 .89814 m .89487 .89341 L .90304 .90296 L p F P
0 0 0 r
s
.188 0 .528 r
.17235 .89501 m .17443 .87495 L .16109 .86519 L p F P
0 0 0 r
s
.188 0 .528 r
.16324 .84528 m .16109 .86519 L .17443 .87495 L p F P
0 0 0 r
s
.511 .78 0 r
.30523 .8978 m .28717 .9027 L .27637 .89267 L p F P
0 0 0 r
s
0 .78 .12 r
.27366 .89341 m .27637 .89267 L .28717 .9027 L p F P
0 0 0 r
s
.1 0 .485 r
.40385 .24623 m .40457 .22998 L .42406 .22224 L p F P
0 0 0 r
s
.1 0 .485 r
.40457 .22998 m .40385 .24623 L .3844 .2539 L p F P
0 0 0 r
s
.625 0 .573 r
.64021 .89741 m .6199 .90257 L .60972 .89301 L p F P
0 0 0 r
s
.625 0 .573 r
.58946 .8982 m .60972 .89301 L .6199 .90257 L p F P
0 0 0 r
s
.195 0 .31 r
.73027 .23132 m .72906 .21504 L .7384 .22939 L p F P
0 0 0 r
s
.195 0 .31 r
.7384 .22939 m .73965 .24564 L .73027 .23132 L p F P
0 0 0 r
s
.1 0 .485 r
.34381 .30204 m .34489 .28545 L .36415 .27792 L p F P
0 0 0 r
s
.1 0 .485 r
.34489 .28545 m .34381 .30204 L .32459 .30949 L p F P
0 0 0 r
s
.195 0 .31 r
.78482 .40172 m .78329 .38443 L .79225 .39758 L p F P
0 0 0 r
s
.195 0 .31 r
.79225 .39758 m .79382 .41483 L .78482 .40172 L p F P
0 0 0 r
s
.134 0 .891 r
.68455 .06119 m .67483 .04564 L .65431 .05409 L p F P
0 0 0 r
s
.195 0 .31 r
.67571 .06092 m .67483 .04564 L .68455 .06119 L p F P
0 0 0 r
s
.195 0 .31 r
.68455 .06119 m .68548 .07645 L .67571 .06092 L p F P
0 0 0 r
s
.625 .656 0 r
.35583 .89701 m .3366 .90217 L .32441 .89261 L p F P
0 0 0 r
s
.625 .656 0 r
.31422 .89537 m .32441 .89261 L .3366 .90217 L p F P
0 0 0 r
s
.195 0 .31 r
.83938 .57213 m .83752 .55382 L .84609 .56578 L p F P
0 0 0 r
s
.195 0 .31 r
.84609 .56578 m .84799 .58402 L .83938 .57213 L p F P
0 0 0 r
s
.125 0 .956 r
.92443 .8978 m .94599 .89261 L .95379 .90217 L p F P
0 0 0 r
s
.195 0 .31 r
.89393 .74253 m .89175 .72321 L .89994 .73398 L p F P
0 0 0 r
s
.195 0 .31 r
.89994 .73398 m .90215 .75322 L .89393 .74253 L p F P
0 0 0 r
s
.1 0 .485 r
.28374 .35788 m .28517 .34096 L .30421 .33363 L p F P
0 0 0 r
s
.1 0 .485 r
.28517 .34096 m .28374 .35788 L .26474 .36512 L p F P
0 0 0 r
s
.625 .201 0 r
.69103 .89661 m .67051 .90178 L .66068 .8922 L p F P
0 0 0 r
s
.625 .201 0 r
.64031 .89738 m .66068 .8922 L .67051 .90178 L p F P
0 0 0 r
s
.625 .201 0 r
.40649 .89621 m .38706 .90138 L .37521 .8918 L p F P
0 0 0 r
s
.1 0 .485 r
.22363 .41375 m .22541 .39649 L .24423 .38938 L p F P
0 0 0 r
s
.625 .201 0 r
.3572 .89664 m .37521 .8918 L .38706 .90138 L p F P
0 0 0 r
s
.1 0 .485 r
.22541 .39649 m .22363 .41375 L .20486 .42078 L p F P
0 0 0 r
s
.188 0 .528 r
.16109 .86519 m .16324 .84528 L .14981 .8353 L p F P
0 0 0 r
s
.188 0 .528 r
.15203 .81555 m .14981 .8353 L .16324 .84528 L p F P
0 0 0 r
s
.188 0 .528 r
.10689 .6959 m .10936 .67699 L .09554 .66581 L p F P
0 0 0 r
s
.188 0 .528 r
.09808 .64705 m .09554 .66581 L .10936 .67699 L p F P
0 0 0 r
s
.1 0 .485 r
.56385 .10274 m .56363 .08732 L .58375 .07902 L p F P
0 0 0 r
s
.1 0 .485 r
.56363 .08732 m .56385 .10274 L .54376 .11097 L p F P
0 0 0 r
s
.1 0 .485 r
.16349 .46965 m .16562 .45206 L .18422 .44516 L p F P
0 0 0 r
s
.1 0 .485 r
.16562 .45206 m .16349 .46965 L .14494 .47647 L p F P
0 0 0 r
s
.625 .656 0 r
.7419 .89581 m .72117 .90098 L .7117 .8914 L p F P
0 0 0 r
s
.625 .656 0 r
.70988 .89186 m .7117 .8914 L .72117 .90098 L p F P
0 0 0 r
s
.1 0 .485 r
.50379 .15857 m .50392 .14281 L .52382 .13472 L p F P
0 0 0 r
s
.1 0 .485 r
.50392 .14281 m .50379 .15857 L .48393 .16659 L p F P
0 0 0 r
s
.195 0 .31 r
.77421 .37109 m .77274 .35395 L .78178 .36734 L p F P
0 0 0 r
s
.195 0 .31 r
.78178 .36734 m .78329 .38443 L .77421 .37109 L p F P
0 0 0 r
s
.195 0 .31 r
.71959 .20048 m .71844 .18436 L .72786 .19894 L p F P
0 0 0 r
s
.195 0 .31 r
.72786 .19894 m .72906 .21504 L .71959 .20048 L p F P
0 0 0 r
s
.625 0 .573 r
.45721 .89541 m .43757 .90059 L .42608 .891 L p F P
0 0 0 r
s
.625 0 .573 r
.41252 .8946 m .42608 .891 L .43757 .90059 L p F P
0 0 0 r
s
.1 0 .485 r
.10331 .52559 m .1058 .50767 L .12417 .50098 L p F P
0 0 0 r
s
.1 0 .485 r
.1058 .50767 m .10331 .52559 L .08498 .5322 L p F P
0 0 0 r
s
.195 0 .31 r
.93807 .8829 m .93562 .86273 L .94351 .87252 L p F P
0 0 0 r
s
.195 0 .31 r
.94351 .87252 m .94599 .89261 L .93807 .8829 L p F P
0 0 0 r
s
.195 0 .31 r
.88345 .7123 m .88133 .69314 L .8896 .70413 L p F P
0 0 0 r
s
.195 0 .31 r
.8896 .70413 m .89175 .72321 L .88345 .7123 L p F P
0 0 0 r
s
.195 0 .31 r
.82883 .54169 m .82703 .52355 L .83569 .53573 L p F P
0 0 0 r
s
.195 0 .31 r
.83569 .53573 m .83752 .55382 L .82883 .54169 L p F P
0 0 0 r
s
0 .647 .956 r
.89487 .89341 m .90964 .88982 L .91305 .90055 L p F P
0 0 0 r
s
.125 0 .956 r
.92443 .8978 m .91305 .90055 L .90964 .88982 L p F P
0 0 0 r
s
0 .78 .71 r
.87507 .90036 m .87352 .8986 L .87541 .89814 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.44369 .21443 m .44418 .19834 L .46385 .19046 L p F P
0 0 0 r
s
.1 0 .485 r
.44418 .19834 m .44369 .21443 L .42406 .22224 L p F P
0 0 0 r
s
.511 .78 0 r
.79283 .89501 m .7719 .90019 L .76278 .8906 L p F P
0 0 0 r
s
.511 .78 0 r
.75837 .8917 m .76278 .8906 L .7719 .90019 L p F P
0 0 0 r
s
0 .647 .956 r
.20422 .8994 m .20225 .89994 L .18957 .8902 L p F P
0 0 0 r
s
.125 0 .956 r
.17235 .89501 m .18957 .8902 L .20225 .89994 L p F P
0 0 0 r
s
.188 0 .528 r
.09554 .66581 m .09808 .64705 L .08417 .63565 L p F P
0 0 0 r
s
.188 0 .528 r
.08678 .61705 m .08417 .63565 L .09808 .64705 L p F P
0 0 0 r
s
.1 0 .485 r
.38356 .27033 m .3844 .2539 L .40385 .24623 L p F P
0 0 0 r
s
.1 0 .485 r
.3844 .2539 m .38356 .27033 L .36415 .27792 L p F P
0 0 0 r
s
.625 0 .573 r
.50799 .89461 m .48814 .89979 L .477 .89019 L p F P
0 0 0 r
s
.625 0 .573 r
.45721 .89541 m .477 .89019 L .48814 .89979 L p F P
0 0 0 r
s
.188 0 .528 r
.14981 .8353 m .15203 .81555 L .1385 .80535 L p F P
0 0 0 r
s
.188 0 .528 r
.14078 .78574 m .1385 .80535 L .15203 .81555 L p F P
0 0 0 r
s
0 .647 .956 r
.22074 .89483 m .20422 .8994 L .19105 .88979 L p F P
0 0 0 r
s
0 .647 .956 r
.18957 .8902 m .19105 .88979 L .20422 .8994 L p F P
0 0 0 r
s
0 .78 .12 r
.83804 .89563 m .82268 .8994 L .81392 .88979 L p F P
0 0 0 r
s
0 .78 .12 r
.79975 .8933 m .81392 .88979 L .82268 .8994 L p F P
0 0 0 r
s
.1 0 .485 r
.32339 .32626 m .32459 .30949 L .34381 .30204 L p F P
0 0 0 r
s
.1 0 .485 r
.32459 .30949 m .32339 .32626 L .30421 .33363 L p F P
0 0 0 r
s
.511 .78 0 r
.79665 .89911 m .79283 .89501 L .79975 .8933 L closepath p F P
0 0 0 r
s
0 .78 .12 r
.2547 .8986 m .25298 .89907 L .24162 .88906 L p F P
0 0 0 r
s
0 .78 .71 r
.22298 .89421 m .24162 .88906 L .25298 .89907 L p F P
0 0 0 r
s
.195 0 .31 r
.70888 .16957 m .7078 .15361 L .71731 .16843 L p F P
0 0 0 r
s
.195 0 .31 r
.71731 .16843 m .71844 .18436 L .70888 .16957 L p F P
0 0 0 r
s
.1 0 .485 r
.26319 .38222 m .26474 .36512 L .28374 .35788 L p F P
0 0 0 r
s
.1 0 .485 r
.26474 .36512 m .26319 .38222 L .24423 .38938 L p F P
0 0 0 r
s
.195 0 .31 r
.92762 .8528 m .92524 .83279 L .93321 .8428 L p F P
0 0 0 r
s
.195 0 .31 r
.93321 .8428 m .93562 .86273 L .92762 .8528 L p F P
0 0 0 r
s
.195 0 .31 r
.87294 .68199 m .87088 .66299 L .87923 .67421 L p F P
0 0 0 r
s
.195 0 .31 r
.87923 .67421 m .88133 .69314 L .87294 .68199 L p F P
0 0 0 r
s
.195 0 .31 r
.81825 .51118 m .81652 .4932 L .82526 .50561 L p F P
0 0 0 r
s
.195 0 .31 r
.82526 .50561 m .82703 .52355 L .81825 .51118 L p F P
0 0 0 r
s
.195 0 .31 r
.76357 .34038 m .76216 .3234 L .77128 .33702 L p F P
0 0 0 r
s
.195 0 .31 r
.77128 .33702 m .77274 .35395 L .76357 .34038 L p F P
0 0 0 r
s
.625 0 .573 r
.55883 .89381 m .53877 .899 L .52799 .88939 L p F P
0 0 0 r
s
.625 0 .573 r
.50799 .89461 m .52799 .88939 L .53877 .899 L p F P
0 0 0 r
s
.1 0 .485 r
.60402 .07065 m .60357 .05539 L .62387 .04695 L p F P
0 0 0 r
s
.1 0 .485 r
.60357 .05539 m .60402 .07065 L .58375 .07902 L p F P
0 0 0 r
s
0 .78 .12 r
.27366 .89341 m .2547 .8986 L .24188 .88898 L p F P
0 0 0 r
s
0 .78 .12 r
.24162 .88906 m .24188 .88898 L .2547 .8986 L p F P
0 0 0 r
s
0 .78 .71 r
.87541 .89814 m .87352 .8986 L .86512 .88898 L p F P
0 0 0 r
s
0 .78 .71 r
.84382 .89421 m .86512 .88898 L .87352 .8986 L p F P
0 0 0 r
s
.1 0 .485 r
.20295 .43821 m .20486 .42078 L .22363 .41375 L p F P
0 0 0 r
s
.1 0 .485 r
.20486 .42078 m .20295 .43821 L .18422 .44516 L p F P
0 0 0 r
s
.1 0 .485 r
.14267 .49424 m .14494 .47647 L .16349 .46965 L p F P
0 0 0 r
s
.1 0 .485 r
.14494 .47647 m .14267 .49424 L .12417 .50098 L p F P
0 0 0 r
s
.188 0 .528 r
.1385 .80535 m .14078 .78574 L .12716 .77532 L p F P
0 0 0 r
s
.188 0 .528 r
.12951 .75586 m .12716 .77532 L .14078 .78574 L p F P
0 0 0 r
s
.188 0 .528 r
.08417 .63565 m .08678 .61705 L .07276 .60542 L p F P
0 0 0 r
s
.188 0 .528 r
.07544 .58697 m .07276 .60542 L .08678 .61705 L p F P
0 0 0 r
s
.1 0 .485 r
.54387 .12657 m .54376 .11097 L .56385 .10274 L p F P
0 0 0 r
s
.1 0 .485 r
.54376 .11097 m .54387 .12657 L .52382 .13472 L p F P
0 0 0 r
s
.625 0 .573 r
.60972 .89301 m .58946 .8982 L .57903 .88858 L p F P
0 0 0 r
s
.625 0 .573 r
.55883 .89381 m .57903 .88858 L .58946 .8982 L p F P
0 0 0 r
s
0 .78 .71 r
.86512 .88898 m .87453 .88667 L .87541 .89814 L p F P
0 0 0 r
s
0 .647 .956 r
.89487 .89341 m .87541 .89814 L .87453 .88667 L p F P
0 0 0 r
s
.134 0 .891 r
.64434 .03844 m .65431 .05409 L .67483 .04564 L p F P
0 0 0 r
s
.134 0 .891 r
.65431 .05409 m .64434 .03844 L .62387 .04695 L p F P
0 0 0 r
s
.1 0 .485 r
.48368 .18252 m .48393 .16659 L .50379 .15857 L p F P
0 0 0 r
s
.1 0 .485 r
.48393 .16659 m .48368 .18252 L .46385 .19046 L p F P
0 0 0 r
s
.511 .78 0 r
.31422 .89537 m .30523 .8978 L .29278 .88818 L p F P
0 0 0 r
s
.511 .78 0 r
.27637 .89267 m .29278 .88818 L .30523 .8978 L p F P
0 0 0 r
s
.1 0 .485 r
.08236 .5503 m .08498 .5322 L .10331 .52559 L p F P
0 0 0 r
s
.1 0 .485 r
.08498 .5322 m .08236 .5503 L .06408 .55683 L p F P
0 0 0 r
s
.125 0 .956 r
.94599 .89261 m .92443 .8978 L .91639 .88818 L p F P
0 0 0 r
s
.125 0 .956 r
.90964 .88982 m .91639 .88818 L .92443 .8978 L p F P
0 0 0 r
s
.625 0 .573 r
.64024 .89743 m .64021 .89741 L .64031 .89738 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.42345 .23851 m .42406 .22224 L .44369 .21443 L p F P
0 0 0 r
s
.1 0 .485 r
.42406 .22224 m .42345 .23851 L .40385 .24623 L p F P
0 0 0 r
s
.195 0 .31 r
.91715 .82263 m .91483 .80277 L .92288 .81301 L p F P
0 0 0 r
s
.195 0 .31 r
.92288 .81301 m .92524 .83279 L .91715 .82263 L p F P
0 0 0 r
s
.195 0 .31 r
.8624 .65162 m .8604 .63278 L .86884 .64422 L p F P
0 0 0 r
s
.195 0 .31 r
.86884 .64422 m .87088 .66299 L .8624 .65162 L p F P
0 0 0 r
s
.195 0 .31 r
.80765 .48061 m .80598 .46278 L .8148 .47542 L p F P
0 0 0 r
s
.195 0 .31 r
.8148 .47542 m .81652 .4932 L .80765 .48061 L p F P
0 0 0 r
s
.195 0 .31 r
.7529 .30959 m .75155 .29278 L .76076 .30663 L p F P
0 0 0 r
s
.195 0 .31 r
.76076 .30663 m .76216 .3234 L .7529 .30959 L p F P
0 0 0 r
s
.195 0 .31 r
.69815 .13858 m .69713 .12279 L .70672 .13784 L p F P
0 0 0 r
s
.195 0 .31 r
.70672 .13784 m .7078 .15361 L .69815 .13858 L p F P
0 0 0 r
s
.625 0 .573 r
.64031 .89738 m .64021 .89741 L .63014 .88777 L p F P
0 0 0 r
s
.625 0 .573 r
.60972 .89301 m .63014 .88777 L .64021 .89741 L p F P
0 0 0 r
s
.625 0 .573 r
.65072 .88249 m .65345 .88516 L .64031 .89738 L p F P
0 0 0 r
s
.625 0 .573 r
.63014 .88777 m .65072 .88249 L p .64031 .89738 L F P
0 0 0 r
s
.625 .201 0 r
.65345 .88516 m .66068 .8922 L .64031 .89738 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.36319 .29453 m .36415 .27792 L .38356 .27033 L p F P
0 0 0 r
s
.1 0 .485 r
.36415 .27792 m .36319 .29453 L .34381 .30204 L p F P
0 0 0 r
s
.625 .656 0 r
.3572 .89664 m .35583 .89701 L .34373 .88737 L p F P
0 0 0 r
s
.625 .656 0 r
.32441 .89261 m .34373 .88737 L .35583 .89701 L p F P
0 0 0 r
s
.625 .201 0 r
.37521 .8918 m .3572 .89664 L .34762 .88631 L p F P
0 0 0 r
s
.625 .656 0 r
.34373 .88737 m .34762 .88631 L .3572 .89664 L p F P
0 0 0 r
s
.1 0 .485 r
.30289 .35058 m .30421 .33363 L .32339 .32626 L p F P
0 0 0 r
s
.1 0 .485 r
.30421 .33363 m .30289 .35058 L .28374 .35788 L p F P
0 0 0 r
s
.188 0 .528 r
.07276 .60542 m .07544 .58697 L .06133 .57512 L p F P
0 0 0 r
s
.188 0 .528 r
.06408 .55683 m .06133 .57512 L .07544 .58697 L p F P
0 0 0 r
s
.625 .201 0 r
.70988 .89186 m .69103 .89661 L .68131 .88696 L p F P
0 0 0 r
s
.625 .201 0 r
.66068 .8922 m .68131 .88696 L .69103 .89661 L p F P
0 0 0 r
s
.188 0 .528 r
.12716 .77532 m .12951 .75586 L .11579 .74521 L p F P
0 0 0 r
s
.188 0 .528 r
.11822 .72592 m .11579 .74521 L .12951 .75586 L p F P
0 0 0 r
s
.1 0 .485 r
.24255 .40666 m .24423 .38938 L .26319 .38222 L p F P
0 0 0 r
s
.1 0 .485 r
.24423 .38938 m .24255 .40666 L .22363 .41375 L p F P
0 0 0 r
s
.625 .201 0 r
.41252 .8946 m .40649 .89621 L .39474 .88656 L p F P
0 0 0 r
s
.625 .201 0 r
.37521 .8918 m .39474 .88656 L .40649 .89621 L p F P
0 0 0 r
s
.1 0 .485 r
.18218 .46278 m .18422 .44516 L .20295 .43821 L p F P
0 0 0 r
s
.1 0 .485 r
.18422 .44516 m .18218 .46278 L .16349 .46965 L p F P
0 0 0 r
s
.195 0 .31 r
.85184 .62117 m .8499 .60249 L .85843 .61416 L p F P
0 0 0 r
s
.195 0 .31 r
.85843 .61416 m .8604 .63278 L .85184 .62117 L p F P
0 0 0 r
s
.195 0 .31 r
.79702 .44995 m .79541 .43229 L .80432 .44516 L p F P
0 0 0 r
s
.195 0 .31 r
.80432 .44516 m .80598 .46278 L .79702 .44995 L p F P
0 0 0 r
s
.195 0 .31 r
.74221 .27873 m .74092 .26209 L .75022 .27617 L p F P
0 0 0 r
s
.195 0 .31 r
.75022 .27617 m .75155 .29278 L .74221 .27873 L p F P
0 0 0 r
s
.195 0 .31 r
.68739 .10752 m .68643 .09189 L .69612 .10718 L p F P
0 0 0 r
s
.195 0 .31 r
.69612 .10718 m .69713 .12279 L .68739 .10752 L p F P
0 0 0 r
s
.1 0 .485 r
.58409 .09445 m .58375 .07902 L .60402 .07065 L p F P
0 0 0 r
s
.1 0 .485 r
.58375 .07902 m .58409 .09445 L .56385 .10274 L p F P
0 0 0 r
s
.625 .656 0 r
.75837 .8917 m .7419 .89581 L .73254 .88615 L p F P
0 0 0 r
s
.625 .656 0 r
.7117 .8914 m .73254 .88615 L .7419 .89581 L p F P
0 0 0 r
s
.195 0 .31 r
.90666 .79239 m .90439 .77269 L .91253 .78315 L p F P
0 0 0 r
s
.195 0 .31 r
.91253 .78315 m .91483 .80277 L .90666 .79239 L p F P
0 0 0 r
s
0 .78 .12 r
.83518 .88453 m .83937 .88922 L .83804 .89563 L p F P
0 0 0 r
s
0 .78 .12 r
.81392 .88979 m .83518 .88453 L p .83804 .89563 L F P
0 0 0 r
s
0 .78 .71 r
.83937 .88922 m .84382 .89421 L .83804 .89563 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.5238 .1505 m .52382 .13472 L .54387 .12657 L p F P
0 0 0 r
s
.1 0 .485 r
.52382 .13472 m .5238 .1505 L .50379 .15857 L p F P
0 0 0 r
s
.1 0 .485 r
.12177 .51893 m .12417 .50098 L .14267 .49424 L p F P
0 0 0 r
s
.1 0 .485 r
.12417 .50098 m .12177 .51893 L .10331 .52559 L p F P
0 0 0 r
s
.625 0 .573 r
.477 .89019 m .45721 .89541 L .44581 .88575 L p F P
0 0 0 r
s
.625 0 .573 r
.42608 .891 m .44581 .88575 L .45721 .89541 L p F P
0 0 0 r
s
.625 .656 0 r
.32441 .89261 m .31422 .89537 L .30441 .88499 L p F P
0 0 0 r
s
.511 .78 0 r
.29278 .88818 m .30441 .88499 L .31422 .89537 L p F P
0 0 0 r
s
.1 0 .485 r
.46348 .20657 m .46385 .19046 L .48368 .18252 L p F P
0 0 0 r
s
.1 0 .485 r
.46385 .19046 m .46348 .20657 L .44369 .21443 L p F P
0 0 0 r
s
.1 0 .485 r
.06133 .57512 m .06408 .55683 L .08236 .5503 L p F P
0 0 0 r
s
.188 0 .528 r
.16109 .86519 m .15892 .88534 L .17235 .89501 L p F P
0 0 0 r
s
.125 0 .956 r
.18957 .8902 m .17235 .89501 L .15892 .88534 L p F P
0 0 0 r
s
.188 0 .528 r
.11579 .74521 m .11822 .72592 L .1044 .71504 L p F P
0 0 0 r
s
.188 0 .528 r
.10689 .6959 m .1044 .71504 L .11822 .72592 L p F P
0 0 0 r
s
.511 .78 0 r
.79975 .8933 m .79283 .89501 L .78383 .88534 L p F P
0 0 0 r
s
.511 .78 0 r
.76278 .8906 m .78383 .88534 L .79283 .89501 L p F P
0 0 0 r
s
0 .78 .71 r
.22298 .89421 m .22074 .89483 L .20879 .88484 L p F P
0 0 0 r
s
0 .647 .956 r
.19105 .88979 m .20879 .88484 L .22074 .89483 L p F P
0 0 0 r
s
.1 0 .485 r
.40312 .26268 m .40385 .24623 L .42345 .23851 L p F P
0 0 0 r
s
.1 0 .485 r
.40385 .24623 m .40312 .26268 L .38356 .27033 L p F P
0 0 0 r
s
.625 0 .573 r
.52799 .88939 m .50799 .89461 L .49695 .88493 L p F P
0 0 0 r
s
.625 0 .573 r
.477 .89019 m .49695 .88493 L .50799 .89461 L p F P
0 0 0 r
s
.625 0 .573 r
.42608 .891 m .41252 .8946 L .40224 .88454 L p F P
0 0 0 r
s
.625 .201 0 r
.39474 .88656 m .40224 .88454 L .41252 .8946 L p F P
0 0 0 r
s
0 .78 .71 r
.24162 .88906 m .22298 .89421 L .2099 .88453 L p F P
0 0 0 r
s
0 .78 .71 r
.20879 .88484 m .2099 .88453 L .22298 .89421 L p F P
0 0 0 r
s
.195 0 .31 r
.84125 .59065 m .83938 .57213 L .84799 .58402 L p F P
0 0 0 r
s
.195 0 .31 r
.84799 .58402 m .8499 .60249 L .84125 .59065 L p F P
0 0 0 r
s
.195 0 .31 r
.78637 .41923 m .78482 .40172 L .79382 .41483 L p F P
0 0 0 r
s
.195 0 .31 r
.79382 .41483 m .79541 .43229 L .78637 .41923 L p F P
0 0 0 r
s
.195 0 .31 r
.73149 .2478 m .73027 .23132 L .73965 .24564 L p F P
0 0 0 r
s
.195 0 .31 r
.73965 .24564 m .74092 .26209 L .73149 .2478 L p F P
0 0 0 r
s
.195 0 .31 r
.67661 .07638 m .67571 .06092 L .68548 .07645 L p F P
0 0 0 r
s
.195 0 .31 r
.68548 .07645 m .68643 .09189 L .67661 .07638 L p F P
0 0 0 r
s
0 .78 .71 r
.84382 .89421 m .83937 .88922 L .83945 .88347 L p F P
0 0 0 r
s
0 .78 .71 r
.86512 .88898 m .84382 .89421 L p .83945 .88347 L F P
0 0 0 r
s
.1 0 .485 r
.34273 .31882 m .34381 .30204 L .36319 .29453 L p F P
0 0 0 r
s
.1 0 .485 r
.34381 .30204 m .34273 .31882 L .32339 .32626 L p F P
0 0 0 r
s
.195 0 .31 r
.89614 .76207 m .89393 .74253 L .90215 .75322 L p F P
0 0 0 r
s
.195 0 .31 r
.90215 .75322 m .90439 .77269 L .89614 .76207 L p F P
0 0 0 r
s
.1 0 .485 r
.2823 .375 m .28374 .35788 L .30289 .35058 L p F P
0 0 0 r
s
.1 0 .485 r
.28374 .35788 m .2823 .375 L .26319 .38222 L p F P
0 0 0 r
s
.625 0 .573 r
.57903 .88858 m .55883 .89381 L .54814 .88412 L p F P
0 0 0 r
s
.625 0 .573 r
.52799 .88939 m .54814 .88412 L .55883 .89381 L p F P
0 0 0 r
s
.1 0 .485 r
.22183 .43121 m .22363 .41375 L .24255 .40666 L p F P
0 0 0 r
s
.1 0 .485 r
.22363 .41375 m .22183 .43121 L .20295 .43821 L p F P
0 0 0 r
s
0 .78 .12 r
.27637 .89267 m .27366 .89341 L .26094 .88372 L p F P
0 0 0 r
s
0 .78 .12 r
.24188 .88898 m .26094 .88372 L .27366 .89341 L p F P
0 0 0 r
s
.188 0 .528 r
.15892 .88534 m .16109 .86519 L .14756 .8553 L p F P
0 0 0 r
s
.188 0 .528 r
.14981 .8353 m .14756 .8553 L .16109 .86519 L p F P
0 0 0 r
s
.188 0 .528 r
.1044 .71504 m .10689 .6959 L .09298 .6848 L p F P
0 0 0 r
s
.188 0 .528 r
.09554 .66581 m .09298 .6848 L .10689 .6959 L p F P
0 0 0 r
s
0 .647 .956 r
.90964 .88982 m .89487 .89341 L .88659 .88372 L p F P
0 0 0 r
s
.1 0 .485 r
.62446 .06222 m .62387 .04695 L .64434 .03844 L p F P
0 0 0 r
s
0 .647 .956 r
.87453 .88667 m .88659 .88372 L .89487 .89341 L p F P
0 0 0 r
s
.1 0 .485 r
.62387 .04695 m .62446 .06222 L .60402 .07065 L p F P
0 0 0 r
s
.511 .78 0 r
.78383 .88534 m .80292 .88058 L .79975 .8933 L p F P
0 0 0 r
s
0 .78 .12 r
.81392 .88979 m .79975 .8933 L .80292 .88058 L p F P
0 0 0 r
s
.1 0 .485 r
.16133 .48745 m .16349 .46965 L .18218 .46278 L p F P
0 0 0 r
s
.1 0 .485 r
.16349 .46965 m .16133 .48745 L .14267 .49424 L p F P
0 0 0 r
s
.1 0 .485 r
.56407 .11836 m .56385 .10274 L .58409 .09445 L p F P
0 0 0 r
s
.1 0 .485 r
.56385 .10274 m .56407 .11836 L .54387 .12657 L p F P
0 0 0 r
s
.625 0 .573 r
.63014 .88777 m .60972 .89301 L .5994 .88331 L p F P
0 0 0 r
s
.625 0 .573 r
.57903 .88858 m .5994 .88331 L .60972 .89301 L p F P
0 0 0 r
s
.511 .78 0 r
.29278 .88818 m .27637 .89267 L .26625 .88225 L p F P
0 0 0 r
s
0 .78 .12 r
.26094 .88372 m .26625 .88225 L .27637 .89267 L p F P
0 0 0 r
s
.1 0 .485 r
.50365 .17452 m .50379 .15857 L .5238 .1505 L p F P
0 0 0 r
s
.1 0 .485 r
.50379 .15857 m .50365 .17452 L .48368 .18252 L p F P
0 0 0 r
s
.625 .656 0 r
.34373 .88737 m .32441 .89261 L .31204 .8829 L p F P
0 0 0 r
s
.625 .656 0 r
.30441 .88499 m .31204 .8829 L .32441 .89261 L p F P
0 0 0 r
s
.1 0 .485 r
.10079 .54373 m .10331 .52559 L .12177 .51893 L p F P
0 0 0 r
s
.1 0 .485 r
.10331 .52559 m .10079 .54373 L .08236 .5503 L p F P
0 0 0 r
s
.195 0 .31 r
.83064 .56006 m .82883 .54169 L .83752 .55382 L p F P
0 0 0 r
s
.195 0 .31 r
.83752 .55382 m .83938 .57213 L .83064 .56006 L p F P
0 0 0 r
s
.195 0 .31 r
.77569 .38843 m .77421 .37109 L .78329 .38443 L p F P
0 0 0 r
s
.195 0 .31 r
.78329 .38443 m .78482 .40172 L .77569 .38843 L p F P
0 0 0 r
s
.195 0 .31 r
.72075 .2168 m .71959 .20048 L .72906 .21504 L p F P
0 0 0 r
s
.195 0 .31 r
.72906 .21504 m .73027 .23132 L .72075 .2168 L p F P
0 0 0 r
s
.134 0 .891 r
.67483 .04564 m .66497 .02988 L .64434 .03844 L p F P
0 0 0 r
s
.195 0 .31 r
.6658 .04517 m .66497 .02988 L .67483 .04564 L p F P
0 0 0 r
s
.195 0 .31 r
.67483 .04564 m .67571 .06092 L .6658 .04517 L p F P
0 0 0 r
s
.125 0 .956 r
.91639 .88818 m .93807 .8829 L .94599 .89261 L p F P
0 0 0 r
s
.195 0 .31 r
.88559 .73168 m .88345 .7123 L .89175 .72321 L p F P
0 0 0 r
s
.195 0 .31 r
.89175 .72321 m .89393 .74253 L .88559 .73168 L p F P
0 0 0 r
s
.1 0 .485 r
.4432 .23072 m .44369 .21443 L .46348 .20657 L p F P
0 0 0 r
s
.1 0 .485 r
.44369 .21443 m .4432 .23072 L .42345 .23851 L p F P
0 0 0 r
s
.625 .201 0 r
.66068 .8922 m .65345 .88516 L .65636 .88105 L p F P
0 0 0 r
s
.625 .201 0 r
.68131 .88696 m .66068 .8922 L p .65636 .88105 L F P
0 0 0 r
s
.625 .201 0 r
.7021 .88168 m .71086 .89055 L .70988 .89186 L p F P
0 0 0 r
s
.625 .201 0 r
.68131 .88696 m .7021 .88168 L p .70988 .89186 L F P
0 0 0 r
s
.625 .656 0 r
.71086 .89055 m .7117 .8914 L .70988 .89186 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.38271 .28695 m .38356 .27033 L .40312 .26268 L p F P
0 0 0 r
s
.1 0 .485 r
.38356 .27033 m .38271 .28695 L .36319 .29453 L p F P
0 0 0 r
s
.188 0 .528 r
.09298 .6848 m .09554 .66581 L .08153 .65448 L p F P
0 0 0 r
s
.188 0 .528 r
.08417 .63565 m .08153 .65448 L .09554 .66581 L p F P
0 0 0 r
s
.625 .201 0 r
.39474 .88656 m .37521 .8918 L .3632 .88209 L p F P
0 0 0 r
s
.625 .201 0 r
.34762 .88631 m .3632 .88209 L .37521 .8918 L p F P
0 0 0 r
s
.188 0 .528 r
.14756 .8553 m .14981 .8353 L .13618 .82518 L p F P
0 0 0 r
s
.188 0 .528 r
.1385 .80535 m .13618 .82518 L .14981 .8353 L p F P
0 0 0 r
s
.625 .656 0 r
.75354 .88086 m .76026 .88794 L .75837 .8917 L p F P
0 0 0 r
s
.625 .656 0 r
.73254 .88615 m .75354 .88086 L p .75837 .8917 L F P
0 0 0 r
s
.511 .78 0 r
.76026 .88794 m .76278 .8906 L .75837 .8917 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.32218 .34322 m .32339 .32626 L .34273 .31882 L p F P
0 0 0 r
s
.1 0 .485 r
.32339 .32626 m .32218 .34322 L .30289 .35058 L p F P
0 0 0 r
s
.625 .656 0 r
.7117 .8914 m .71086 .89055 L .71697 .8779 L p F P
0 0 0 r
s
.625 .656 0 r
.73254 .88615 m .7117 .8914 L p .71697 .8779 L F P
0 0 0 r
s
.195 0 .31 r
.70998 .18572 m .70888 .16957 L .71844 .18436 L p F P
0 0 0 r
s
.195 0 .31 r
.71844 .18436 m .71959 .20048 L .70998 .18572 L p F P
0 0 0 r
s
.625 0 .573 r
.44581 .88575 m .42608 .891 L .41442 .88127 L p F P
0 0 0 r
s
.1 0 .485 r
.26162 .39952 m .26319 .38222 L .2823 .375 L p F P
0 0 0 r
s
.625 0 .573 r
.40224 .88454 m .41442 .88127 L .42608 .891 L p F P
0 0 0 r
s
.1 0 .485 r
.26319 .38222 m .26162 .39952 L .24255 .40666 L p F P
0 0 0 r
s
.195 0 .31 r
.93003 .87306 m .92762 .8528 L .93562 .86273 L p F P
0 0 0 r
s
.195 0 .31 r
.93562 .86273 m .93807 .8829 L .93003 .87306 L p F P
0 0 0 r
s
.195 0 .31 r
.87502 .70122 m .87294 .68199 L .88133 .69314 L p F P
0 0 0 r
s
.195 0 .31 r
.88133 .69314 m .88345 .7123 L .87502 .70122 L p F P
0 0 0 r
s
.195 0 .31 r
.82001 .52939 m .81825 .51118 L .82703 .52355 L p F P
0 0 0 r
s
.195 0 .31 r
.82703 .52355 m .82883 .54169 L .82001 .52939 L p F P
0 0 0 r
s
.195 0 .31 r
.76499 .35755 m .76357 .34038 L .77274 .35395 L p F P
0 0 0 r
s
.195 0 .31 r
.77274 .35395 m .77421 .37109 L .76499 .35755 L p F P
0 0 0 r
s
.1 0 .485 r
.60449 .0861 m .60402 .07065 L .62446 .06222 L p F P
0 0 0 r
s
.1 0 .485 r
.60402 .07065 m .60449 .0861 L .58409 .09445 L p F P
0 0 0 r
s
.1 0 .485 r
.20102 .45585 m .20295 .43821 L .22183 .43121 L p F P
0 0 0 r
s
.1 0 .485 r
.20295 .43821 m .20102 .45585 L .18218 .46278 L p F P
0 0 0 r
s
.511 .78 0 r
.76278 .8906 m .76026 .88794 L .76288 .87851 L p F P
0 0 0 r
s
.511 .78 0 r
.78383 .88534 m .76278 .8906 L p .76288 .87851 L F P
0 0 0 r
s
.625 .201 0 r
.71086 .89055 m .7021 .88168 L .71697 .8779 L closepath p F P
0 0 0 r
s
0 .647 .956 r
.19105 .88979 m .18957 .8902 L .17687 .88028 L p F P
0 0 0 r
s
.125 0 .956 r
.15892 .88534 m .17687 .88028 L .18957 .8902 L p F P
0 0 0 r
s
.1 0 .485 r
.14038 .51222 m .14267 .49424 L .16133 .48745 L p F P
0 0 0 r
s
.1 0 .485 r
.14267 .49424 m .14038 .51222 L .12177 .51893 L p F P
0 0 0 r
s
.188 0 .528 r
.13618 .82518 m .1385 .80535 L .12477 .795 L p F P
0 0 0 r
s
.188 0 .528 r
.12716 .77532 m .12477 .795 L .1385 .80535 L p F P
0 0 0 r
s
.188 0 .528 r
.08153 .65448 m .08417 .63565 L .07005 .62409 L p F P
0 0 0 r
s
.188 0 .528 r
.07276 .60542 m .07005 .62409 L .08417 .63565 L p F P
0 0 0 r
s
.1 0 .485 r
.54397 .14236 m .54387 .12657 L .56407 .11836 L p F P
0 0 0 r
s
.1 0 .485 r
.54387 .12657 m .54397 .14236 L .5238 .1505 L p F P
0 0 0 r
s
.625 0 .573 r
.49695 .88493 m .477 .89019 L .46571 .88045 L p F P
0 0 0 r
s
.625 0 .573 r
.44581 .88575 m .46571 .88045 L .477 .89019 L p F P
0 0 0 r
s
0 .647 .956 r
.88659 .88372 m .90451 .87932 L .90964 .88982 L p F P
0 0 0 r
s
.125 0 .956 r
.91639 .88818 m .90964 .88982 L .90451 .87932 L p F P
0 0 0 r
s
.1 0 .485 r
.48342 .19865 m .48368 .18252 L .50365 .17452 L p F P
0 0 0 r
s
.1 0 .485 r
.48368 .18252 m .48342 .19865 L .46348 .20657 L p F P
0 0 0 r
s
.1 0 .485 r
.07971 .56862 m .08236 .5503 L .10079 .54373 L p F P
0 0 0 r
s
.1 0 .485 r
.08236 .5503 m .07971 .56862 L .06133 .57512 L p F P
0 0 0 r
s
0 .78 .12 r
.83518 .88453 m .81392 .88979 L .80504 .88005 L p F P
0 0 0 r
s
0 .78 .12 r
.80292 .88058 m .80504 .88005 L .81392 .88979 L p F P
0 0 0 r
s
0 .647 .956 r
.20879 .88484 m .19105 .88979 L .1777 .88005 L p F P
0 0 0 r
s
0 .647 .956 r
.17687 .88028 m .1777 .88005 L .19105 .88979 L p F P
0 0 0 r
s
.195 0 .31 r
.75426 .3266 m .7529 .30959 L .76216 .3234 L p F P
0 0 0 r
s
.195 0 .31 r
.76216 .3234 m .76357 .34038 L .75426 .3266 L p F P
0 0 0 r
s
.195 0 .31 r
.80934 .49865 m .80765 .48061 L .81652 .4932 L p F P
0 0 0 r
s
.195 0 .31 r
.81652 .4932 m .81825 .51118 L .80934 .49865 L p F P
0 0 0 r
s
.195 0 .31 r
.69918 .15456 m .69815 .13858 L .7078 .15361 L p F P
0 0 0 r
s
.195 0 .31 r
.7078 .15361 m .70888 .16957 L .69918 .15456 L p F P
0 0 0 r
s
.195 0 .31 r
.9195 .84273 m .91715 .82263 L .92524 .83279 L p F P
0 0 0 r
s
.195 0 .31 r
.92524 .83279 m .92762 .8528 L .9195 .84273 L p F P
0 0 0 r
s
.195 0 .31 r
.86442 .67069 m .8624 .65162 L .87088 .66299 L p F P
0 0 0 r
s
.195 0 .31 r
.87088 .66299 m .87294 .68199 L .86442 .67069 L p F P
0 0 0 r
s
.1 0 .485 r
.42283 .25497 m .42345 .23851 L .4432 .23072 L p F P
0 0 0 r
s
.1 0 .485 r
.42345 .23851 m .42283 .25497 L .40312 .26268 L p F P
0 0 0 r
s
.625 0 .573 r
.54814 .88412 m .52799 .88939 L .51705 .87964 L p F P
0 0 0 r
s
.625 0 .573 r
.49695 .88493 m .51705 .87964 L .52799 .88939 L p F P
0 0 0 r
s
0 .78 .12 r
.83937 .88922 m .83518 .88453 L .83945 .88347 L closepath p F P
0 0 0 r
s
0 .78 .12 r
.24011 .88765 m .24188 .88898 L .24162 .88906 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.22889 .87923 m .24011 .88765 L .24162 .88906 L p F P
0 0 0 r
s
0 .78 .71 r
.2099 .88453 m .22889 .87923 L p .24162 .88906 L F P
0 0 0 r
s
0 .78 .71 r
.87453 .88667 m .86512 .88898 L .8566 .87923 L p F P
0 0 0 r
s
0 .78 .71 r
.83945 .88347 m .8566 .87923 L .86512 .88898 L p F P
0 0 0 r
s
.1 0 .485 r
.36221 .31133 m .36319 .29453 L .38271 .28695 L p F P
0 0 0 r
s
.1 0 .485 r
.36319 .29453 m .36221 .31133 L .34273 .31882 L p F P
0 0 0 r
s
0 .78 .12 r
.24188 .88898 m .24011 .88765 L .23088 .87867 L p F P
0 0 0 r
s
0 .78 .12 r
.26094 .88372 m .24188 .88898 L p .23088 .87867 L F P
0 0 0 r
s
.188 0 .528 r
.07005 .62409 m .07276 .60542 L .05855 .59362 L p F P
0 0 0 r
s
.188 0 .528 r
.06133 .57512 m .05855 .59362 L .07276 .60542 L p F P
0 0 0 r
s
.1 0 .485 r
.30155 .36772 m .30289 .35058 L .32218 .34322 L p F P
0 0 0 r
s
.1 0 .485 r
.30289 .35058 m .30155 .36772 L .2823 .375 L p F P
0 0 0 r
s
.625 0 .573 r
.5994 .88331 m .57903 .88858 L .56846 .87882 L p F P
0 0 0 r
s
.625 0 .573 r
.54814 .88412 m .56846 .87882 L .57903 .88858 L p F P
0 0 0 r
s
.188 0 .528 r
.12477 .795 m .12716 .77532 L .11333 .76474 L p F P
0 0 0 r
s
.188 0 .528 r
.11579 .74521 m .11333 .76474 L .12716 .77532 L p F P
0 0 0 r
s
.1 0 .485 r
.64505 .05373 m .64434 .03844 L .66497 .02988 L p F P
0 0 0 r
s
.1 0 .485 r
.64434 .03844 m .64505 .05373 L .62446 .06222 L p F P
0 0 0 r
s
.511 .78 0 r
.30441 .88499 m .29278 .88818 L .28014 .87841 L p F P
0 0 0 r
s
.511 .78 0 r
.26625 .88225 m .28014 .87841 L .29278 .88818 L p F P
0 0 0 r
s
.125 0 .956 r
.93807 .8829 m .91639 .88818 L .90823 .87841 L p F P
0 0 0 r
s
.125 0 .956 r
.90451 .87932 m .90823 .87841 L .91639 .88818 L p F P
0 0 0 r
s
.1 0 .485 r
.24086 .42415 m .24255 .40666 L .26162 .39952 L p F P
0 0 0 r
s
.1 0 .485 r
.24255 .40666 m .24086 .42415 L .22183 .43121 L p F P
0 0 0 r
s
.625 .656 0 r
.76026 .88794 m .75354 .88086 L .76288 .87851 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.79865 .46783 m .79702 .44995 L .80598 .46278 L p F P
0 0 0 r
s
.195 0 .31 r
.80598 .46278 m .80765 .48061 L .79865 .46783 L p F P
0 0 0 r
s
.195 0 .31 r
.68836 .12333 m .68739 .10752 L .69713 .12279 L p F P
0 0 0 r
s
.195 0 .31 r
.69713 .12279 m .69815 .13858 L .68836 .12333 L p F P
0 0 0 r
s
.1 0 .485 r
.58444 .11008 m .58409 .09445 L .60449 .0861 L p F P
0 0 0 r
s
.1 0 .485 r
.58409 .09445 m .58444 .11008 L .56407 .11836 L p F P
0 0 0 r
s
.1 0 .485 r
.18012 .48061 m .18218 .46278 L .20102 .45585 L p F P
0 0 0 r
s
.1 0 .485 r
.18218 .46278 m .18012 .48061 L .16133 .48745 L p F P
0 0 0 r
s
.195 0 .31 r
.8538 .64008 m .85184 .62117 L .8604 .63278 L p F P
0 0 0 r
s
.195 0 .31 r
.8604 .63278 m .8624 .65162 L .8538 .64008 L p F P
0 0 0 r
s
.625 0 .573 r
.65072 .88249 m .63014 .88777 L .61993 .878 L p F P
0 0 0 r
s
.625 0 .573 r
.5994 .88331 m .61993 .878 L .63014 .88777 L p F P
0 0 0 r
s
.195 0 .31 r
.90895 .81233 m .90666 .79239 L .91483 .80277 L p F P
0 0 0 r
s
.195 0 .31 r
.91483 .80277 m .91715 .82263 L .90895 .81233 L p F P
0 0 0 r
s
.195 0 .31 r
.74351 .29558 m .74221 .27873 L .75155 .29278 L p F P
0 0 0 r
s
.195 0 .31 r
.75155 .29278 m .7529 .30959 L .74351 .29558 L p F P
0 0 0 r
s
0 .78 .71 r
.24011 .88765 m .22889 .87923 L .23088 .87867 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.52379 .16646 m .5238 .1505 L .54397 .14236 L p F P
0 0 0 r
s
.1 0 .485 r
.5238 .1505 m .52379 .16646 L .50365 .17452 L p F P
0 0 0 r
s
.1 0 .485 r
.11935 .5371 m .12177 .51893 L .14038 .51222 L p F P
0 0 0 r
s
.1 0 .485 r
.12177 .51893 m .11935 .5371 L .10079 .54373 L p F P
0 0 0 r
s
.625 .656 0 r
.34762 .88631 m .34373 .88737 L .33145 .87759 L p F P
0 0 0 r
s
.625 .656 0 r
.31204 .8829 m .33145 .87759 L .34373 .88737 L p F P
0 0 0 r
s
.1 0 .485 r
.4631 .22287 m .46348 .20657 L .48342 .19865 L p F P
0 0 0 r
s
.1 0 .485 r
.46348 .20657 m .4631 .22287 L .4432 .23072 L p F P
0 0 0 r
s
.1 0 .485 r
.05855 .59362 m .06133 .57512 L .07971 .56862 L p F P
0 0 0 r
s
.625 .201 0 r
.7021 .88168 m .68131 .88696 L .67145 .87718 L p F P
0 0 0 r
s
.625 .201 0 r
.65636 .88105 m .67145 .87718 L .68131 .88696 L p F P
0 0 0 r
s
.188 0 .528 r
.11333 .76474 m .11579 .74521 L .10187 .73441 L p F P
0 0 0 r
s
.188 0 .528 r
.1044 .71504 m .10187 .73441 L .11579 .74521 L p F P
0 0 0 r
s
0 .78 .71 r
.8566 .87923 m .87123 .87561 L .87453 .88667 L p F P
0 0 0 r
s
0 .647 .956 r
.88659 .88372 m .87453 .88667 L .87123 .87561 L p F P
0 0 0 r
s
.1 0 .485 r
.40238 .27932 m .40312 .26268 L .42283 .25497 L p F P
0 0 0 r
s
.1 0 .485 r
.40312 .26268 m .40238 .27932 L .38271 .28695 L p F P
0 0 0 r
s
.625 .201 0 r
.40224 .88454 m .39474 .88656 L .38282 .87677 L p F P
0 0 0 r
s
.625 .201 0 r
.3632 .88209 m .38282 .87677 L .39474 .88656 L p F P
0 0 0 r
s
.625 .201 0 r
.3632 .88209 m .34762 .88631 L .33978 .87531 L p F P
0 0 0 r
s
.625 .656 0 r
.33145 .87759 m .33978 .87531 L .34762 .88631 L p F P
0 0 0 r
s
.195 0 .31 r
.73273 .26448 m .73149 .2478 L .74092 .26209 L p F P
0 0 0 r
s
.195 0 .31 r
.74092 .26209 m .74221 .27873 L .73273 .26448 L p F P
0 0 0 r
s
.1 0 .485 r
.34163 .33581 m .34273 .31882 L .36221 .31133 L p F P
0 0 0 r
s
.1 0 .485 r
.34273 .31882 m .34163 .33581 L .32218 .34322 L p F P
0 0 0 r
s
.195 0 .31 r
.78794 .43694 m .78637 .41923 L .79541 .43229 L p F P
0 0 0 r
s
.195 0 .31 r
.79541 .43229 m .79702 .44995 L .78794 .43694 L p F P
0 0 0 r
s
.195 0 .31 r
.67751 .09202 m .67661 .07638 L .68643 .09189 L p F P
0 0 0 r
s
.195 0 .31 r
.68643 .09189 m .68739 .10752 L .67751 .09202 L p F P
0 0 0 r
s
.195 0 .31 r
.84315 .6094 m .84125 .59065 L .8499 .60249 L p F P
0 0 0 r
s
.195 0 .31 r
.8499 .60249 m .85184 .62117 L .84315 .6094 L p F P
0 0 0 r
s
.625 .656 0 r
.75354 .88086 m .73254 .88615 L .72305 .87636 L p F P
0 0 0 r
s
.625 .656 0 r
.71697 .8779 m .72305 .87636 L .73254 .88615 L p F P
0 0 0 r
s
.195 0 .31 r
.89837 .78185 m .89614 .76207 L .90439 .77269 L p F P
0 0 0 r
s
.195 0 .31 r
.90439 .77269 m .90666 .79239 L .89837 .78185 L p F P
0 0 0 r
s
.1 0 .485 r
.28083 .39232 m .2823 .375 L .30155 .36772 L p F P
0 0 0 r
s
.1 0 .485 r
.2823 .375 m .28083 .39232 L .26162 .39952 L p F P
0 0 0 r
s
.625 0 .573 r
.46571 .88045 m .44581 .88575 L .43426 .87594 L p F P
0 0 0 r
s
.625 0 .573 r
.41442 .88127 m .43426 .87594 L .44581 .88575 L p F P
0 0 0 r
s
.1 0 .485 r
.22 .44888 m .22183 .43121 L .24086 .42415 L p F P
0 0 0 r
s
.1 0 .485 r
.22183 .43121 m .22 .44888 L .20102 .45585 L p F P
0 0 0 r
s
.188 0 .528 r
.14756 .8553 m .14529 .87553 L .15892 .88534 L p F P
0 0 0 r
s
.125 0 .956 r
.17687 .88028 m .15892 .88534 L .14529 .87553 L p F P
0 0 0 r
s
.1 0 .485 r
.62504 .07768 m .62446 .06222 L .64505 .05373 L p F P
0 0 0 r
s
.1 0 .485 r
.62446 .06222 m .62504 .07768 L .60449 .0861 L p F P
0 0 0 r
s
.511 .78 0 r
.80292 .88058 m .78383 .88534 L .7747 .87553 L p F P
0 0 0 r
s
.511 .78 0 r
.76288 .87851 m .7747 .87553 L .78383 .88534 L p F P
0 0 0 r
s
.188 0 .528 r
.10187 .73441 m .1044 .71504 L .09038 .70401 L p F P
0 0 0 r
s
.188 0 .528 r
.09298 .6848 m .09038 .70401 L .1044 .71504 L p F P
0 0 0 r
s
.625 0 .573 r
.65345 .88516 m .65072 .88249 L .65636 .88105 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.31204 .8829 m .30441 .88499 L .29575 .87409 L p F P
0 0 0 r
s
.511 .78 0 r
.28014 .87841 m .29575 .87409 L .30441 .88499 L p F P
0 0 0 r
s
.1 0 .485 r
.5643 .13415 m .56407 .11836 L .58444 .11008 L p F P
0 0 0 r
s
.1 0 .485 r
.56407 .11836 m .5643 .13415 L .54397 .14236 L p F P
0 0 0 r
s
.1 0 .485 r
.15914 .50546 m .16133 .48745 L .18012 .48061 L p F P
0 0 0 r
s
.1 0 .485 r
.16133 .48745 m .15914 .50546 L .14038 .51222 L p F P
0 0 0 r
s
.625 0 .573 r
.51705 .87964 m .49695 .88493 L .48575 .87512 L p F P
0 0 0 r
s
.625 0 .573 r
.46571 .88045 m .48575 .87512 L .49695 .88493 L p F P
0 0 0 r
s
0 .78 .71 r
.20035 .87746 m .2099 .88453 L .20879 .88484 L closepath p F P
0 0 0 r
s
0 .647 .956 r
.19663 .87471 m .20035 .87746 L .20879 .88484 L p F P
0 0 0 r
s
0 .647 .956 r
.1777 .88005 m .19663 .87471 L p .20879 .88484 L F P
0 0 0 r
s
.625 0 .573 r
.41442 .88127 m .40224 .88454 L .39479 .87352 L p F P
0 0 0 r
s
.625 .201 0 r
.38282 .87677 m .39479 .87352 L .40224 .88454 L p F P
0 0 0 r
s
.1 0 .485 r
.50352 .19066 m .50365 .17452 L .52379 .16646 L p F P
0 0 0 r
s
.1 0 .485 r
.50365 .17452 m .50352 .19066 L .48342 .19865 L p F P
0 0 0 r
s
.195 0 .31 r
.83248 .57864 m .83064 .56006 L .83938 .57213 L p F P
0 0 0 r
s
.195 0 .31 r
.83938 .57213 m .84125 .59065 L .83248 .57864 L p F P
0 0 0 r
s
.195 0 .31 r
.7772 .40598 m .77569 .38843 L .78482 .40172 L p F P
0 0 0 r
s
.195 0 .31 r
.78482 .40172 m .78637 .41923 L .7772 .40598 L p F P
0 0 0 r
s
.195 0 .31 r
.66664 .06064 m .6658 .04517 L .67571 .06092 L p F P
0 0 0 r
s
.195 0 .31 r
.67571 .06092 m .67661 .07638 L .66664 .06064 L p F P
0 0 0 r
s
.1 0 .485 r
.09824 .56208 m .10079 .54373 L .11935 .5371 L p F P
0 0 0 r
s
.1 0 .485 r
.10079 .54373 m .09824 .56208 L .07971 .56862 L p F P
0 0 0 r
s
0 .78 .71 r
.2099 .88453 m .20035 .87746 L .19713 .87457 L p F P
0 0 0 r
s
0 .78 .71 r
.22889 .87923 m .2099 .88453 L p .19713 .87457 L F P
0 0 0 r
s
.195 0 .31 r
.88776 .75131 m .88559 .73168 L .89393 .74253 L p F P
0 0 0 r
s
.195 0 .31 r
.89393 .74253 m .89614 .76207 L .88776 .75131 L p F P
0 0 0 r
s
.195 0 .31 r
.72192 .23331 m .72075 .2168 L .73027 .23132 L p F P
0 0 0 r
s
.195 0 .31 r
.73027 .23132 m .73149 .2478 L .72192 .23331 L p F P
0 0 0 r
s
0 .78 .12 r
.83945 .88347 m .83518 .88453 L .82642 .87471 L p F P
0 0 0 r
s
0 .78 .12 r
.80504 .88005 m .82642 .87471 L .83518 .88453 L p F P
0 0 0 r
s
.1 0 .485 r
.4427 .2472 m .4432 .23072 L .4631 .22287 L p F P
0 0 0 r
s
.1 0 .485 r
.4432 .23072 m .4427 .2472 L .42283 .25497 L p F P
0 0 0 r
s
.625 0 .573 r
.56846 .87882 m .54814 .88412 L .53731 .8743 L p F P
0 0 0 r
s
.625 0 .573 r
.51705 .87964 m .53731 .8743 L .54814 .88412 L p F P
0 0 0 r
s
0 .78 .12 r
.26625 .88225 m .26094 .88372 L .24803 .87388 L p F P
0 0 0 r
s
0 .78 .12 r
.23088 .87867 m .24803 .87388 L .26094 .88372 L p F P
0 0 0 r
s
.188 0 .528 r
.09038 .70401 m .09298 .6848 L .07886 .67353 L p F P
0 0 0 r
s
.188 0 .528 r
.08153 .65448 m .07886 .67353 L .09298 .6848 L p F P
0 0 0 r
s
0 .647 .956 r
.90451 .87932 m .88659 .88372 L .87819 .87388 L p F P
0 0 0 r
s
0 .647 .956 r
.87123 .87561 m .87819 .87388 L .88659 .88372 L p F P
0 0 0 r
s
.1 0 .485 r
.38185 .30378 m .38271 .28695 L .40238 .27932 L p F P
0 0 0 r
s
.1 0 .485 r
.38271 .28695 m .38185 .30378 L .36221 .31133 L p F P
0 0 0 r
s
.188 0 .528 r
.14529 .87553 m .14756 .8553 L .13384 .84526 L p F P
0 0 0 r
s
.188 0 .528 r
.13618 .82518 m .13384 .84526 L .14756 .8553 L p F P
0 0 0 r
s
0 .78 .12 r
.82642 .87471 m .83733 .87198 L .83945 .88347 L p F P
0 0 0 r
s
0 .78 .71 r
.8566 .87923 m .83945 .88347 L .83733 .87198 L p F P
0 0 0 r
s
.625 0 .573 r
.61993 .878 m .5994 .88331 L .58893 .87347 L p F P
0 0 0 r
s
.625 0 .573 r
.56846 .87882 m .58893 .87347 L .5994 .88331 L p F P
0 0 0 r
s
.1 0 .485 r
.32096 .36039 m .32218 .34322 L .34163 .33581 L p F P
0 0 0 r
s
.1 0 .485 r
.32218 .34322 m .32096 .36039 L .30155 .36772 L p F P
0 0 0 r
s
.195 0 .31 r
.82178 .54781 m .82001 .52939 L .82883 .54169 L p F P
0 0 0 r
s
.195 0 .31 r
.82883 .54169 m .83064 .56006 L .82178 .54781 L p F P
0 0 0 r
s
.195 0 .31 r
.71109 .20206 m .70998 .18572 L .71959 .20048 L p F P
0 0 0 r
s
.195 0 .31 r
.71959 .20048 m .72075 .2168 L .71109 .20206 L p F P
0 0 0 r
s
.125 0 .956 r
.90823 .87841 m .93003 .87306 L .93807 .8829 L p F P
0 0 0 r
s
.1 0 .485 r
.66497 .02988 m .6658 .04517 L .64505 .05373 L p F P
0 0 0 r
s
.1 0 .485 r
.26003 .41703 m .26162 .39952 L .28083 .39232 L p F P
0 0 0 r
s
.1 0 .485 r
.26162 .39952 m .26003 .41703 L .24086 .42415 L p F P
0 0 0 r
s
.625 .656 0 r
.33145 .87759 m .31204 .8829 L .29949 .87306 L p F P
0 0 0 r
s
.625 .656 0 r
.29575 .87409 m .29949 .87306 L .31204 .8829 L p F P
0 0 0 r
s
.195 0 .31 r
.87713 .72068 m .87502 .70122 L .88345 .7123 L p F P
0 0 0 r
s
.195 0 .31 r
.88345 .7123 m .88559 .73168 L .87713 .72068 L p F P
0 0 0 r
s
.195 0 .31 r
.76643 .37494 m .76499 .35755 L .77421 .37109 L p F P
0 0 0 r
s
.195 0 .31 r
.77421 .37109 m .77569 .38843 L .76643 .37494 L p F P
0 0 0 r
s
.1 0 .485 r
.60496 .10173 m .60449 .0861 L .62504 .07768 L p F P
0 0 0 r
s
.1 0 .485 r
.60449 .0861 m .60496 .10173 L .58444 .11008 L p F P
0 0 0 r
s
.1 0 .485 r
.19907 .47371 m .20102 .45585 L .22 .44888 L p F P
0 0 0 r
s
.1 0 .485 r
.20102 .45585 m .19907 .47371 L .18012 .48061 L p F P
0 0 0 r
s
.625 0 .573 r
.65636 .88105 m .65072 .88249 L .64061 .87265 L p F P
0 0 0 r
s
.625 0 .573 r
.61993 .878 m .64061 .87265 L .65072 .88249 L p F P
0 0 0 r
s
.511 .78 0 r
.28014 .87841 m .26625 .88225 L .25704 .87137 L p F P
0 0 0 r
s
0 .78 .12 r
.24803 .87388 m .25704 .87137 L .26625 .88225 L p F P
0 0 0 r
s
.1 0 .485 r
.54408 .15833 m .54397 .14236 L .5643 .13415 L p F P
0 0 0 r
s
.1 0 .485 r
.54397 .14236 m .54408 .15833 L .52379 .16646 L p F P
0 0 0 r
s
.625 .201 0 r
.38282 .87677 m .3632 .88209 L .35101 .87223 L p F P
0 0 0 r
s
.625 .201 0 r
.33978 .87531 m .35101 .87223 L .3632 .88209 L p F P
0 0 0 r
s
.1 0 .485 r
.13807 .53042 m .14038 .51222 L .15914 .50546 L p F P
0 0 0 r
s
.1 0 .485 r
.14038 .51222 m .13807 .53042 L .11935 .5371 L p F P
0 0 0 r
s
.188 0 .528 r
.13384 .84526 m .13618 .82518 L .12236 .81492 L p F P
0 0 0 r
s
.188 0 .528 r
.12477 .795 m .12236 .81492 L .13618 .82518 L p F P
0 0 0 r
s
.188 0 .528 r
.07886 .67353 m .08153 .65448 L .06731 .64298 L p F P
0 0 0 r
s
.188 0 .528 r
.07005 .62409 m .06731 .64298 L .08153 .65448 L p F P
0 0 0 r
s
.1 0 .485 r
.48316 .21497 m .48342 .19865 L .50352 .19066 L p F P
0 0 0 r
s
.1 0 .485 r
.48342 .19865 m .48316 .21497 L .4631 .22287 L p F P
0 0 0 r
s
.1 0 .485 r
.07703 .58716 m .07971 .56862 L .09824 .56208 L p F P
0 0 0 r
s
.1 0 .485 r
.07971 .56862 m .07703 .58716 L .05855 .59362 L p F P
0 0 0 r
s
.625 .201 0 r
.71697 .8779 m .7021 .88168 L .69235 .87182 L p F P
0 0 0 r
s
.625 .201 0 r
.67145 .87718 m .69235 .87182 L .7021 .88168 L p F P
0 0 0 r
s
.1 0 .485 r
.42221 .27163 m .42283 .25497 L .4427 .2472 L p F P
0 0 0 r
s
.1 0 .485 r
.42283 .25497 m .42221 .27163 L .40238 .27932 L p F P
0 0 0 r
s
.195 0 .31 r
.92188 .86307 m .9195 .84273 L .92762 .8528 L p F P
0 0 0 r
s
.195 0 .31 r
.92762 .8528 m .93003 .87306 L .92188 .86307 L p F P
0 0 0 r
s
.195 0 .31 r
.86647 .68999 m .86442 .67069 L .87294 .68199 L p F P
0 0 0 r
s
.195 0 .31 r
.87294 .68199 m .87502 .70122 L .86647 .68999 L p F P
0 0 0 r
s
.195 0 .31 r
.81106 .5169 m .80934 .49865 L .81825 .51118 L p F P
0 0 0 r
s
.195 0 .31 r
.81825 .51118 m .82001 .52939 L .81106 .5169 L p F P
0 0 0 r
s
.195 0 .31 r
.75564 .34382 m .75426 .3266 L .76357 .34038 L p F P
0 0 0 r
s
.195 0 .31 r
.76357 .34038 m .76499 .35755 L .75564 .34382 L p F P
0 0 0 r
s
.195 0 .31 r
.70023 .17074 m .69918 .15456 L .70888 .16957 L p F P
0 0 0 r
s
.195 0 .31 r
.70888 .16957 m .70998 .18572 L .70023 .17074 L p F P
0 0 0 r
s
.625 0 .573 r
.43426 .87594 m .41442 .88127 L .4026 .8714 L p F P
0 0 0 r
s
.625 0 .573 r
.39479 .87352 m .4026 .8714 L .41442 .88127 L p F P
0 0 0 r
s
.625 0 .573 r
.66146 .86725 m .66151 .8673 L .65636 .88105 L p F P
0 0 0 r
s
.625 0 .573 r
.64061 .87265 m .66146 .86725 L p .65636 .88105 L F P
0 0 0 r
s
.625 .201 0 r
.66151 .8673 m .67145 .87718 L .65636 .88105 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.36122 .32834 m .36221 .31133 L .38185 .30378 L p F P
0 0 0 r
s
.1 0 .485 r
.36221 .31133 m .36122 .32834 L .34163 .33581 L p F P
0 0 0 r
s
.625 .656 0 r
.76288 .87851 m .75354 .88086 L .74416 .87099 L p F P
0 0 0 r
s
.625 .656 0 r
.72305 .87636 m .74416 .87099 L .75354 .88086 L p F P
0 0 0 r
s
.511 .78 0 r
.79603 .87016 m .80297 .87777 L .80292 .88058 L p F P
0 0 0 r
s
.511 .78 0 r
.7747 .87553 m .79603 .87016 L p .80292 .88058 L F P
0 0 0 r
s
0 .78 .12 r
.80297 .87777 m .80504 .88005 L .80292 .88058 L closepath p F P
0 0 0 r
s
.188 0 .528 r
.06731 .64298 m .07005 .62409 L .05573 .61236 L p F P
0 0 0 r
s
.188 0 .528 r
.05855 .59362 m .05573 .61236 L .07005 .62409 L p F P
0 0 0 r
s
.625 0 .573 r
.48575 .87512 m .46571 .88045 L .45424 .87058 L p F P
0 0 0 r
s
.1 0 .485 r
.3002 .38507 m .30155 .36772 L .32096 .36039 L p F P
0 0 0 r
s
.625 0 .573 r
.43426 .87594 m .45424 .87058 L .46571 .88045 L p F P
0 0 0 r
s
.1 0 .485 r
.30155 .36772 m .3002 .38507 L .28083 .39232 L p F P
0 0 0 r
s
.188 0 .528 r
.12236 .81492 m .12477 .795 L .11085 .7845 L p F P
0 0 0 r
s
.188 0 .528 r
.11333 .76474 m .11085 .7845 L .12477 .795 L p F P
0 0 0 r
s
0 .647 .956 r
.16475 .8706 m .1777 .88005 L .17687 .88028 L closepath p F P
0 0 0 r
s
.125 0 .956 r
.16415 .87016 m .16475 .8706 L .17687 .88028 L p F P
0 0 0 r
s
.125 0 .956 r
.14529 .87553 m .16415 .87016 L p .17687 .88028 L F P
0 0 0 r
s
.1 0 .485 r
.64576 .0692 m .64505 .05373 L .6658 .04517 L p F P
0 0 0 r
s
.1 0 .485 r
.64505 .05373 m .64576 .0692 L .62504 .07768 L p F P
0 0 0 r
s
0 .647 .956 r
.1777 .88005 m .16475 .8706 L .1642 .87015 L p F P
0 0 0 r
s
0 .647 .956 r
.19663 .87471 m .1777 .88005 L p .1642 .87015 L F P
0 0 0 r
s
.1 0 .485 r
.23914 .44184 m .24086 .42415 L .26003 .41703 L p F P
0 0 0 r
s
.1 0 .485 r
.24086 .42415 m .23914 .44184 L .22 .44888 L p F P
0 0 0 r
s
0 .78 .12 r
.80504 .88005 m .80297 .87777 L .80182 .8687 L p F P
0 0 0 r
s
0 .78 .12 r
.82642 .87471 m .80504 .88005 L p .80182 .8687 L F P
0 0 0 r
s
.1 0 .485 r
.17804 .49865 m .18012 .48061 L .19907 .47371 L p F P
0 0 0 r
s
.1 0 .485 r
.18012 .48061 m .17804 .49865 L .15914 .50546 L p F P
0 0 0 r
s
.195 0 .31 r
.80031 .48592 m .79865 .46783 L .80765 .48061 L p F P
0 0 0 r
s
.195 0 .31 r
.80765 .48061 m .80934 .49865 L .80031 .48592 L p F P
0 0 0 r
s
.195 0 .31 r
.74482 .31263 m .74351 .29558 L .7529 .30959 L p F P
0 0 0 r
s
.195 0 .31 r
.7529 .30959 m .75426 .3266 L .74482 .31263 L p F P
0 0 0 r
s
.195 0 .31 r
.68934 .13934 m .68836 .12333 L .69815 .13858 L p F P
0 0 0 r
s
.195 0 .31 r
.69815 .13858 m .69918 .15456 L .68934 .13934 L p F P
0 0 0 r
s
.1 0 .485 r
.58479 .12589 m .58444 .11008 L .60496 .10173 L p F P
0 0 0 r
s
.1 0 .485 r
.58444 .11008 m .58479 .12589 L .5643 .13415 L p F P
0 0 0 r
s
.195 0 .31 r
.85579 .65922 m .8538 .64008 L .8624 .65162 L p F P
0 0 0 r
s
.195 0 .31 r
.8624 .65162 m .86442 .67069 L .85579 .65922 L p F P
0 0 0 r
s
.625 0 .573 r
.53731 .8743 m .51705 .87964 L .50595 .86975 L p F P
0 0 0 r
s
.625 0 .573 r
.48575 .87512 m .50595 .86975 L .51705 .87964 L p F P
0 0 0 r
s
.195 0 .31 r
.91127 .83251 m .90895 .81233 L .91715 .82263 L p F P
0 0 0 r
s
.195 0 .31 r
.91715 .82263 m .9195 .84273 L .91127 .83251 L p F P
0 0 0 r
s
0 .647 .956 r
.87819 .87388 m .89836 .86889 L .90451 .87932 L p F P
0 0 0 r
s
.125 0 .956 r
.90823 .87841 m .90451 .87932 L .89836 .86889 L p F P
0 0 0 r
s
.1 0 .485 r
.52377 .18261 m .52379 .16646 L .54408 .15833 L p F P
0 0 0 r
s
.1 0 .485 r
.52379 .16646 m .52377 .18261 L .50352 .19066 L p F P
0 0 0 r
s
.1 0 .485 r
.1169 .55548 m .11935 .5371 L .13807 .53042 L p F P
0 0 0 r
s
.1 0 .485 r
.11935 .5371 m .1169 .55548 L .09824 .56208 L p F P
0 0 0 r
s
0 .78 .71 r
.23088 .87867 m .22889 .87923 L .21571 .86933 L p F P
0 0 0 r
s
0 .78 .71 r
.19713 .87457 m .21571 .86933 L .22889 .87923 L p F P
0 0 0 r
s
0 .78 .71 r
.87123 .87561 m .8566 .87923 L .84796 .86933 L p F P
0 0 0 r
s
0 .78 .71 r
.83733 .87198 m .84796 .86933 L .8566 .87923 L p F P
0 0 0 r
s
.1 0 .485 r
.05573 .61236 m .05855 .59362 L .07703 .58716 L p F P
0 0 0 r
s
.1 0 .485 r
.46272 .23937 m .4631 .22287 L .48316 .21497 L p F P
0 0 0 r
s
.1 0 .485 r
.4631 .22287 m .46272 .23937 L .4427 .2472 L p F P
0 0 0 r
s
.625 0 .573 r
.58893 .87347 m .56846 .87882 L .55773 .86892 L p F P
0 0 0 r
s
.625 0 .573 r
.53731 .8743 m .55773 .86892 L .56846 .87882 L p F P
0 0 0 r
s
.188 0 .528 r
.11085 .7845 m .11333 .76474 L .09931 .75401 L p F P
0 0 0 r
s
.188 0 .528 r
.10187 .73441 m .09931 .75401 L .11333 .76474 L p F P
0 0 0 r
s
0 .78 .12 r
.24803 .87388 m .23088 .87867 L .22085 .86788 L p F P
0 0 0 r
s
0 .78 .71 r
.21571 .86933 m .22085 .86788 L .23088 .87867 L p F P
0 0 0 r
s
.625 .656 0 r
.74416 .87099 m .76319 .86616 L .76288 .87851 L p F P
0 0 0 r
s
.511 .78 0 r
.7747 .87553 m .76288 .87851 L .76319 .86616 L p F P
0 0 0 r
s
.511 .78 0 r
.29575 .87409 m .28014 .87841 L .26732 .8685 L p F P
0 0 0 r
s
.511 .78 0 r
.25704 .87137 m .26732 .8685 L .28014 .87841 L p F P
0 0 0 r
s
.125 0 .956 r
.93003 .87306 m .90823 .87841 L .89995 .8685 L p F P
0 0 0 r
s
.125 0 .956 r
.89836 .86889 m .89995 .8685 L .90823 .87841 L p F P
0 0 0 r
s
.1 0 .485 r
.40164 .29617 m .40238 .27932 L .42221 .27163 L p F P
0 0 0 r
s
.1 0 .485 r
.40238 .27932 m .40164 .29617 L .38185 .30378 L p F P
0 0 0 r
s
.195 0 .31 r
.84508 .62837 m .84315 .6094 L .85184 .62117 L p F P
0 0 0 r
s
.195 0 .31 r
.85184 .62117 m .8538 .64008 L .84508 .62837 L p F P
0 0 0 r
s
.195 0 .31 r
.78953 .45487 m .78794 .43694 L .79702 .44995 L p F P
0 0 0 r
s
.195 0 .31 r
.79702 .44995 m .79865 .46783 L .78953 .45487 L p F P
0 0 0 r
s
.195 0 .31 r
.73398 .28136 m .73273 .26448 L .74221 .27873 L p F P
0 0 0 r
s
.195 0 .31 r
.74221 .27873 m .74351 .29558 L .73398 .28136 L p F P
0 0 0 r
s
.195 0 .31 r
.67843 .10786 m .67751 .09202 L .68739 .10752 L p F P
0 0 0 r
s
.195 0 .31 r
.68739 .10752 m .68836 .12333 L .67843 .10786 L p F P
0 0 0 r
s
.1 0 .485 r
.34051 .353 m .34163 .33581 L .36122 .32834 L p F P
0 0 0 r
s
.1 0 .485 r
.34163 .33581 m .34051 .353 L .32096 .36039 L p F P
0 0 0 r
s
.625 0 .573 r
.64061 .87265 m .61993 .878 L .60956 .86808 L p F P
0 0 0 r
s
.625 0 .573 r
.58893 .87347 m .60956 .86808 L .61993 .878 L p F P
0 0 0 r
s
.195 0 .31 r
.90062 .80188 m .89837 .78185 L .90666 .79239 L p F P
0 0 0 r
s
.195 0 .31 r
.90666 .79239 m .90895 .81233 L .90062 .80188 L p F P
0 0 0 r
s
.625 .201 0 r
.71342 .86642 m .71825 .87141 L .71697 .8779 L p F P
0 0 0 r
s
.625 .201 0 r
.69235 .87182 m .71342 .86642 L p .71697 .8779 L F P
0 0 0 r
s
.625 .656 0 r
.71825 .87141 m .72305 .87636 L .71697 .8779 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.80297 .87777 m .79603 .87016 L .80182 .8687 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.27935 .40986 m .28083 .39232 L .3002 .38507 L p F P
0 0 0 r
s
.1 0 .485 r
.28083 .39232 m .27935 .40986 L .26003 .41703 L p F P
0 0 0 r
s
.625 .656 0 r
.33978 .87531 m .33145 .87759 L .31899 .86767 L p F P
0 0 0 r
s
.625 .656 0 r
.29949 .87306 m .31899 .86767 L .33145 .87759 L p F P
0 0 0 r
s
0 .647 .956 r
.20035 .87746 m .19663 .87471 L .19713 .87457 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.62564 .09332 m .62504 .07768 L .64576 .0692 L p F P
0 0 0 r
s
.1 0 .485 r
.62504 .07768 m .62564 .09332 L .60496 .10173 L p F P
0 0 0 r
s
.1 0 .485 r
.21816 .46676 m .22 .44888 L .23914 .44184 L p F P
0 0 0 r
s
.1 0 .485 r
.22 .44888 m .21816 .46676 L .19907 .47371 L p F P
0 0 0 r
s
.625 .201 0 r
.67145 .87718 m .66151 .8673 L .66152 .86724 L p F P
0 0 0 r
s
.625 .201 0 r
.69235 .87182 m .67145 .87718 L p .66152 .86724 L F P
0 0 0 r
s
.188 0 .528 r
.09931 .75401 m .10187 .73441 L .08774 .72345 L p F P
0 0 0 r
s
.188 0 .528 r
.09038 .70401 m .08774 .72345 L .10187 .73441 L p F P
0 0 0 r
s
.1 0 .485 r
.56453 .15014 m .5643 .13415 L .58479 .12589 L p F P
0 0 0 r
s
.1 0 .485 r
.5643 .13415 m .56453 .15014 L .54408 .15833 L p F P
0 0 0 r
s
.1 0 .485 r
.15692 .52369 m .15914 .50546 L .17804 .49865 L p F P
0 0 0 r
s
.1 0 .485 r
.15914 .50546 m .15692 .52369 L .13807 .53042 L p F P
0 0 0 r
s
.625 .201 0 r
.39479 .87352 m .38282 .87677 L .37073 .86683 L p F P
0 0 0 r
s
.625 .201 0 r
.35101 .87223 m .37073 .86683 L .38282 .87677 L p F P
0 0 0 r
s
.1 0 .485 r
.50338 .207 m .50352 .19066 L .52377 .18261 L p F P
0 0 0 r
s
.1 0 .485 r
.50352 .19066 m .50338 .207 L .48316 .21497 L p F P
0 0 0 r
s
.1 0 .485 r
.09565 .58065 m .09824 .56208 L .1169 .55548 L p F P
0 0 0 r
s
.1 0 .485 r
.09824 .56208 m .09565 .58065 L .07703 .58716 L p F P
0 0 0 r
s
.195 0 .31 r
.83434 .59745 m .83248 .57864 L .84125 .59065 L p F P
0 0 0 r
s
.195 0 .31 r
.84125 .59065 m .84315 .6094 L .83434 .59745 L p F P
0 0 0 r
s
.195 0 .31 r
.77872 .42374 m .7772 .40598 L .78637 .41923 L p F P
0 0 0 r
s
.195 0 .31 r
.78637 .41923 m .78794 .43694 L .77872 .42374 L p F P
0 0 0 r
s
.195 0 .31 r
.72311 .25002 m .72192 .23331 L .73149 .2478 L p F P
0 0 0 r
s
.195 0 .31 r
.73149 .2478 m .73273 .26448 L .72311 .25002 L p F P
0 0 0 r
s
.195 0 .31 r
.66749 .07631 m .66664 .06064 L .67661 .07638 L p F P
0 0 0 r
s
.195 0 .31 r
.67661 .07638 m .67751 .09202 L .66749 .07631 L p F P
0 0 0 r
s
.625 .656 0 r
.72305 .87636 m .71825 .87141 L .71837 .86515 L p F P
0 0 0 r
s
.625 .656 0 r
.74416 .87099 m .72305 .87636 L p .71837 .86515 L F P
0 0 0 r
s
.195 0 .31 r
.88996 .77117 m .88776 .75131 L .89614 .76207 L p F P
0 0 0 r
s
.195 0 .31 r
.89614 .76207 m .89837 .78185 L .88996 .77117 L p F P
0 0 0 r
s
.1 0 .485 r
.4422 .26388 m .4427 .2472 L .46272 .23937 L p F P
0 0 0 r
s
.1 0 .485 r
.4427 .2472 m .4422 .26388 L .42221 .27163 L p F P
0 0 0 r
s
.625 0 .573 r
.45424 .87058 m .43426 .87594 L .42253 .866 L p F P
0 0 0 r
s
.625 0 .573 r
.4026 .8714 m .42253 .866 L .43426 .87594 L p F P
0 0 0 r
s
0 .78 .71 r
.84796 .86933 m .86638 .86473 L .87123 .87561 L p F P
0 0 0 r
s
0 .647 .956 r
.87819 .87388 m .87123 .87561 L .86638 .86473 L p F P
0 0 0 r
s
.1 0 .485 r
.38098 .32081 m .38185 .30378 L .40164 .29617 L p F P
0 0 0 r
s
.1 0 .485 r
.38185 .30378 m .38098 .32081 L .36122 .32834 L p F P
0 0 0 r
s
.188 0 .528 r
.13384 .84526 m .13147 .86558 L .14529 .87553 L p F P
0 0 0 r
s
.125 0 .956 r
.16415 .87016 m .14529 .87553 L .13147 .86558 L p F P
0 0 0 r
s
.188 0 .528 r
.08774 .72345 m .09038 .70401 L .07615 .69281 L p F P
0 0 0 r
s
.188 0 .528 r
.07886 .67353 m .07615 .69281 L .09038 .70401 L p F P
0 0 0 r
s
.511 .78 0 r
.79603 .87016 m .7747 .87553 L .76544 .86558 L p F P
0 0 0 r
s
.511 .78 0 r
.76319 .86616 m .76544 .86558 L .7747 .87553 L p F P
0 0 0 r
s
.625 .201 0 r
.35101 .87223 m .33978 .87531 L .33403 .86351 L p F P
0 0 0 r
s
.625 .656 0 r
.31899 .86767 m .33403 .86351 L .33978 .87531 L p F P
0 0 0 r
s
.1 0 .485 r
.31972 .37776 m .32096 .36039 L .34051 .353 L p F P
0 0 0 r
s
.1 0 .485 r
.32096 .36039 m .31972 .37776 L .3002 .38507 L p F P
0 0 0 r
s
.625 0 .573 r
.50595 .86975 m .48575 .87512 L .47439 .86516 L p F P
0 0 0 r
s
.625 0 .573 r
.45424 .87058 m .47439 .86516 L .48575 .87512 L p F P
0 0 0 r
s
.1 0 .485 r
.25842 .43475 m .26003 .41703 L .27935 .40986 L p F P
0 0 0 r
s
.1 0 .485 r
.26003 .41703 m .25842 .43475 L .23914 .44184 L p F P
0 0 0 r
s
0 .647 .956 r
.19713 .87457 m .19663 .87471 L .18317 .86475 L p F P
0 0 0 r
s
0 .647 .956 r
.1642 .87015 m .18317 .86475 L .19663 .87471 L p F P
0 0 0 r
s
.195 0 .31 r
.82358 .56646 m .82178 .54781 L .83064 .56006 L p F P
0 0 0 r
s
.195 0 .31 r
.83064 .56006 m .83248 .57864 L .82358 .56646 L p F P
0 0 0 r
s
.1 0 .485 r
.6658 .04517 m .66664 .06064 L .64576 .0692 L p F P
0 0 0 r
s
.195 0 .31 r
.7679 .39253 m .76643 .37494 L .77569 .38843 L p F P
0 0 0 r
s
.195 0 .31 r
.77569 .38843 m .7772 .40598 L .7679 .39253 L p F P
0 0 0 r
s
.195 0 .31 r
.71221 .2186 m .71109 .20206 L .72075 .2168 L p F P
0 0 0 r
s
.195 0 .31 r
.72075 .2168 m .72192 .23331 L .71221 .2186 L p F P
0 0 0 r
s
.195 0 .31 r
.87926 .74038 m .87713 .72068 L .88559 .73168 L p F P
0 0 0 r
s
.195 0 .31 r
.88559 .73168 m .88776 .75131 L .87926 .74038 L p F P
0 0 0 r
s
0 .78 .12 r
.83733 .87198 m .82642 .87471 L .81752 .86475 L p F P
0 0 0 r
s
0 .78 .12 r
.80182 .8687 m .81752 .86475 L .82642 .87471 L p F P
0 0 0 r
s
0 .78 .71 r
.21571 .86933 m .19713 .87457 L .18605 .86392 L p F P
0 0 0 r
s
0 .647 .956 r
.18317 .86475 m .18605 .86392 L .19713 .87457 L p F P
0 0 0 r
s
.1 0 .485 r
.60543 .11756 m .60496 .10173 L .62564 .09332 L p F P
0 0 0 r
s
.1 0 .485 r
.60496 .10173 m .60543 .11756 L .58479 .12589 L p F P
0 0 0 r
s
.625 0 .573 r
.55773 .86892 m .53731 .8743 L .52632 .86433 L p F P
0 0 0 r
s
.625 0 .573 r
.50595 .86975 m .52632 .86433 L .53731 .8743 L p F P
0 0 0 r
s
.1 0 .485 r
.19709 .49178 m .19907 .47371 L .21816 .46676 L p F P
0 0 0 r
s
.1 0 .485 r
.19907 .47371 m .19709 .49178 L .17804 .49865 L p F P
0 0 0 r
s
.625 .656 0 r
.29076 .86621 m .29949 .87306 L .29575 .87409 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.28676 .86307 m .29076 .86621 L .29575 .87409 L p F P
0 0 0 r
s
.511 .78 0 r
.26732 .8685 m .28676 .86307 L p .29575 .87409 L F P
0 0 0 r
s
.1 0 .485 r
.54419 .1745 m .54408 .15833 L .56453 .15014 L p F P
0 0 0 r
s
.1 0 .485 r
.54408 .15833 m .54419 .1745 L .52377 .18261 L p F P
0 0 0 r
s
.1 0 .485 r
.13572 .54884 m .13807 .53042 L .15692 .52369 L p F P
0 0 0 r
s
.1 0 .485 r
.13807 .53042 m .13572 .54884 L .1169 .55548 L p F P
0 0 0 r
s
.188 0 .528 r
.13147 .86558 m .13384 .84526 L .11991 .83508 L p F P
0 0 0 r
s
.188 0 .528 r
.12236 .81492 m .11991 .83508 L .13384 .84526 L p F P
0 0 0 r
s
.188 0 .528 r
.07615 .69281 m .07886 .67353 L .06453 .6621 L p F P
0 0 0 r
s
.188 0 .528 r
.06731 .64298 m .06453 .6621 L .07886 .67353 L p F P
0 0 0 r
s
0 .78 .12 r
.25704 .87137 m .24803 .87388 L .23493 .86391 L p F P
0 0 0 r
s
0 .78 .12 r
.22085 .86788 m .23493 .86391 L .24803 .87388 L p F P
0 0 0 r
s
0 .647 .956 r
.89836 .86889 m .87819 .87388 L .86967 .86391 L p F P
0 0 0 r
s
0 .647 .956 r
.86638 .86473 m .86967 .86391 L .87819 .87388 L p F P
0 0 0 r
s
.625 0 .573 r
.4026 .8714 m .39479 .87352 L .39055 .86141 L p F P
0 0 0 r
s
.625 .201 0 r
.37073 .86683 m .39055 .86141 L .39479 .87352 L p F P
0 0 0 r
s
.1 0 .485 r
.4829 .23148 m .48316 .21497 L .50338 .207 L p F P
0 0 0 r
s
.1 0 .485 r
.48316 .21497 m .4829 .23148 L .46272 .23937 L p F P
0 0 0 r
s
.1 0 .485 r
.07431 .60593 m .07703 .58716 L .09565 .58065 L p F P
0 0 0 r
s
.1 0 .485 r
.07703 .58716 m .07431 .60593 L .05573 .61236 L p F P
0 0 0 r
s
.625 0 .573 r
.60956 .86808 m .58893 .87347 L .5783 .86349 L p F P
0 0 0 r
s
.625 0 .573 r
.55773 .86892 m .5783 .86349 L .58893 .87347 L p F P
0 0 0 r
s
.625 .656 0 r
.29949 .87306 m .29076 .86621 L .28882 .8625 L p F P
0 0 0 r
s
.625 .656 0 r
.31899 .86767 m .29949 .87306 L p .28882 .8625 L F P
0 0 0 r
s
.195 0 .31 r
.81279 .53539 m .81106 .5169 L .82001 .52939 L p F P
0 0 0 r
s
.195 0 .31 r
.82001 .52939 m .82178 .54781 L .81279 .53539 L p F P
0 0 0 r
s
.195 0 .31 r
.75704 .36125 m .75564 .34382 L .76499 .35755 L p F P
0 0 0 r
s
.195 0 .31 r
.76499 .35755 m .76643 .37494 L .75704 .36125 L p F P
0 0 0 r
s
.195 0 .31 r
.70129 .18711 m .70023 .17074 L .70998 .18572 L p F P
0 0 0 r
s
.195 0 .31 r
.70998 .18572 m .71109 .20206 L .70129 .18711 L p F P
0 0 0 r
s
.125 0 .956 r
.89995 .8685 m .92188 .86307 L .93003 .87306 L p F P
0 0 0 r
s
.1 0 .485 r
.42158 .2885 m .42221 .27163 L .4422 .26388 L p F P
0 0 0 r
s
.1 0 .485 r
.42221 .27163 m .42158 .2885 L .40164 .29617 L p F P
0 0 0 r
s
.195 0 .31 r
.86854 .70952 m .86647 .68999 L .87502 .70122 L p F P
0 0 0 r
s
.195 0 .31 r
.87502 .70122 m .87713 .72068 L .86854 .70952 L p F P
0 0 0 r
s
.625 0 .573 r
.66146 .86725 m .64061 .87265 L .63035 .86265 L p F P
0 0 0 r
s
.625 0 .573 r
.60956 .86808 m .63035 .86265 L .64061 .87265 L p F P
0 0 0 r
s
.1 0 .485 r
.36023 .34555 m .36122 .32834 L .38098 .32081 L p F P
0 0 0 r
s
.1 0 .485 r
.36122 .32834 m .36023 .34555 L .34051 .353 L p F P
0 0 0 r
s
.625 .201 0 r
.37073 .86683 m .35101 .87223 L .33865 .86223 L p F P
0 0 0 r
s
.625 .201 0 r
.33403 .86351 m .33865 .86223 L .35101 .87223 L p F P
0 0 0 r
s
.188 0 .528 r
.06453 .6621 m .06731 .64298 L .05288 .63132 L p F P
0 0 0 r
s
.188 0 .528 r
.05573 .61236 m .05288 .63132 L .06731 .64298 L p F P
0 0 0 r
s
.1 0 .485 r
.29883 .40263 m .3002 .38507 L .31972 .37776 L p F P
0 0 0 r
s
.1 0 .485 r
.3002 .38507 m .29883 .40263 L .27935 .40986 L p F P
0 0 0 r
s
.188 0 .528 r
.11991 .83508 m .12236 .81492 L .10833 .8045 L p F P
0 0 0 r
s
.188 0 .528 r
.11085 .7845 m .10833 .8045 L .12236 .81492 L p F P
0 0 0 r
s
0 .78 .12 r
.81752 .86475 m .83335 .86076 L .83733 .87198 L p F P
0 0 0 r
s
0 .78 .71 r
.84796 .86933 m .83733 .87198 L .83335 .86076 L p F P
0 0 0 r
s
.1 0 .485 r
.64648 .08485 m .64576 .0692 L .66664 .06064 L p F P
0 0 0 r
s
.1 0 .485 r
.64576 .0692 m .64648 .08485 L .62564 .09332 L p F P
0 0 0 r
s
.1 0 .485 r
.2374 .45975 m .23914 .44184 L .25842 .43475 L p F P
0 0 0 r
s
.1 0 .485 r
.23914 .44184 m .2374 .45975 L .21816 .46676 L p F P
0 0 0 r
s
.625 .201 0 r
.71342 .86642 m .69235 .87182 L .68247 .86181 L p F P
0 0 0 r
s
.625 .201 0 r
.66152 .86724 m .68247 .86181 L .69235 .87182 L p F P
0 0 0 r
s
.625 .201 0 r
.71825 .87141 m .71342 .86642 L .71837 .86515 L closepath p F P
0 0 0 r
s
.625 0 .573 r
.42253 .866 m .4026 .8714 L .3906 .86139 L p F P
0 0 0 r
s
.625 0 .573 r
.39055 .86141 m .3906 .86139 L .4026 .8714 L p F P
0 0 0 r
s
.1 0 .485 r
.17593 .5169 m .17804 .49865 L .19709 .49178 L p F P
0 0 0 r
s
.1 0 .485 r
.17804 .49865 m .17593 .5169 L .15692 .52369 L p F P
0 0 0 r
s
.195 0 .31 r
.8578 .67859 m .85579 .65922 L .86442 .67069 L p F P
0 0 0 r
s
.195 0 .31 r
.86442 .67069 m .86647 .68999 L .8578 .67859 L p F P
0 0 0 r
s
.195 0 .31 r
.80198 .50424 m .80031 .48592 L .80934 .49865 L p F P
0 0 0 r
s
.195 0 .31 r
.80934 .49865 m .81106 .5169 L .80198 .50424 L p F P
0 0 0 r
s
.195 0 .31 r
.69034 .15554 m .68934 .13934 L .69918 .15456 L p F P
0 0 0 r
s
.195 0 .31 r
.69918 .15456 m .70023 .17074 L .69034 .15554 L p F P
0 0 0 r
s
.1 0 .485 r
.58514 .14189 m .58479 .12589 L .60543 .11756 L p F P
0 0 0 r
s
.1 0 .485 r
.58479 .12589 m .58514 .14189 L .56453 .15014 L p F P
0 0 0 r
s
.195 0 .31 r
.74616 .32989 m .74482 .31263 L .75426 .3266 L p F P
0 0 0 r
s
.195 0 .31 r
.75426 .3266 m .75564 .34382 L .74616 .32989 L p F P
0 0 0 r
s
.195 0 .31 r
.91361 .85294 m .91127 .83251 L .9195 .84273 L p F P
0 0 0 r
s
.195 0 .31 r
.9195 .84273 m .92188 .86307 L .91361 .85294 L p F P
0 0 0 r
s
.511 .78 0 r
.26732 .8685 m .25704 .87137 L .24905 .85993 L p F P
0 0 0 r
s
0 .78 .12 r
.23493 .86391 m .24905 .85993 L .25704 .87137 L p F P
0 0 0 r
s
.1 0 .485 r
.52376 .19896 m .52377 .18261 L .54419 .1745 L p F P
0 0 0 r
s
.1 0 .485 r
.52377 .18261 m .52376 .19896 L .50338 .207 L p F P
0 0 0 r
s
.1 0 .485 r
.11443 .57409 m .1169 .55548 L .13572 .54884 L p F P
0 0 0 r
s
.1 0 .485 r
.1169 .55548 m .11443 .57409 L .09565 .58065 L p F P
0 0 0 r
s
.625 .656 0 r
.76319 .86616 m .74416 .87099 L .73465 .86097 L p F P
0 0 0 r
s
.625 .656 0 r
.71837 .86515 m .73465 .86097 L .74416 .87099 L p F P
0 0 0 r
s
.125 0 .956 r
.16475 .8706 m .16415 .87016 L .1642 .87015 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.46234 .25607 m .46272 .23937 L .4829 .23148 L p F P
0 0 0 r
s
.1 0 .485 r
.46272 .23937 m .46234 .25607 L .4422 .26388 L p F P
0 0 0 r
s
.1 0 .485 r
.05288 .63132 m .05573 .61236 L .07431 .60593 L p F P
0 0 0 r
s
.625 0 .573 r
.47439 .86516 m .45424 .87058 L .44262 .86055 L p F P
0 0 0 r
s
.625 0 .573 r
.42253 .866 m .44262 .86055 L .45424 .87058 L p F P
0 0 0 r
s
.188 0 .528 r
.10833 .8045 m .11085 .7845 L .09672 .77385 L p F P
0 0 0 r
s
.188 0 .528 r
.09931 .75401 m .09672 .77385 L .11085 .7845 L p F P
0 0 0 r
s
.1 0 .485 r
.40088 .31322 m .40164 .29617 L .42158 .2885 L p F P
0 0 0 r
s
.1 0 .485 r
.40164 .29617 m .40088 .31322 L .38098 .32081 L p F P
0 0 0 r
s
.125 0 .956 r
.1642 .87015 m .16415 .87016 L .15041 .86013 L p F P
0 0 0 r
s
.125 0 .956 r
.13147 .86558 m .15041 .86013 L .16415 .87016 L p F P
0 0 0 r
s
.511 .78 0 r
.80182 .8687 m .79603 .87016 L .78689 .86013 L p F P
0 0 0 r
s
.511 .78 0 r
.76544 .86558 m .78689 .86013 L .79603 .87016 L p F P
0 0 0 r
s
0 .647 .956 r
.18317 .86475 m .1642 .87015 L .1518 .85973 L p F P
0 0 0 r
s
.125 0 .956 r
.15041 .86013 m .1518 .85973 L .1642 .87015 L p F P
0 0 0 r
s
.195 0 .31 r
.73525 .29845 m .73398 .28136 L .74351 .29558 L p F P
0 0 0 r
s
.195 0 .31 r
.74351 .29558 m .74482 .31263 L .73525 .29845 L p F P
0 0 0 r
s
.195 0 .31 r
.84702 .64758 m .84508 .62837 L .8538 .64008 L p F P
0 0 0 r
s
.195 0 .31 r
.8538 .64008 m .85579 .65922 L .84702 .64758 L p F P
0 0 0 r
s
.195 0 .31 r
.79114 .47302 m .78953 .45487 L .79865 .46783 L p F P
0 0 0 r
s
.195 0 .31 r
.79865 .46783 m .80031 .48592 L .79114 .47302 L p F P
0 0 0 r
s
.195 0 .31 r
.67936 .12389 m .67843 .10786 L .68836 .12333 L p F P
0 0 0 r
s
.195 0 .31 r
.68836 .12333 m .68934 .13934 L .67936 .12389 L p F P
0 0 0 r
s
.625 0 .573 r
.52632 .86433 m .50595 .86975 L .4947 .85971 L p F P
0 0 0 r
s
.1 0 .485 r
.33939 .37039 m .34051 .353 L .36023 .34555 L p F P
0 0 0 r
s
.625 0 .573 r
.47439 .86516 m .4947 .85971 L .50595 .86975 L p F P
0 0 0 r
s
.1 0 .485 r
.34051 .353 m .33939 .37039 L .31972 .37776 L p F P
0 0 0 r
s
.195 0 .31 r
.90291 .82214 m .90062 .80188 L .90895 .81233 L p F P
0 0 0 r
s
.195 0 .31 r
.90895 .81233 m .91127 .83251 L .90291 .82214 L p F P
0 0 0 r
s
0 .78 .71 r
.22085 .86788 m .21571 .86933 L .20233 .85929 L p F P
0 0 0 r
s
0 .78 .71 r
.18605 .86392 m .20233 .85929 L .21571 .86933 L p F P
0 0 0 r
s
.1 0 .485 r
.27786 .42761 m .27935 .40986 L .29883 .40263 L p F P
0 0 0 r
s
.1 0 .485 r
.27935 .40986 m .27786 .42761 L .25842 .43475 L p F P
0 0 0 r
s
0 .78 .71 r
.86638 .86473 m .84796 .86933 L .83919 .85929 L p F P
0 0 0 r
s
0 .78 .71 r
.83335 .86076 m .83919 .85929 L .84796 .86933 L p F P
0 0 0 r
s
.1 0 .485 r
.62624 .10916 m .62564 .09332 L .64648 .08485 L p F P
0 0 0 r
s
.1 0 .485 r
.62564 .09332 m .62624 .10916 L .60543 .11756 L p F P
0 0 0 r
s
.1 0 .485 r
.21629 .48486 m .21816 .46676 L .2374 .45975 L p F P
0 0 0 r
s
.1 0 .485 r
.21816 .46676 m .21629 .48486 L .19709 .49178 L p F P
0 0 0 r
s
.625 0 .573 r
.5783 .86349 m .55773 .86892 L .54684 .85887 L p F P
0 0 0 r
s
.625 0 .573 r
.52632 .86433 m .54684 .85887 L .55773 .86892 L p F P
0 0 0 r
s
.188 0 .528 r
.09672 .77385 m .09931 .75401 L .08508 .74313 L p F P
0 0 0 r
s
.188 0 .528 r
.08774 .72345 m .08508 .74313 L .09931 .75401 L p F P
0 0 0 r
s
0 .647 .956 r
.86967 .86391 m .8915 .85846 L .89836 .86889 L p F P
0 0 0 r
s
.125 0 .956 r
.89995 .8685 m .89836 .86889 L .8915 .85846 L p F P
0 0 0 r
s
.511 .78 0 r
.78689 .86013 m .79836 .85722 L .80182 .8687 L p F P
0 0 0 r
s
0 .78 .12 r
.81752 .86475 m .80182 .8687 L .79836 .85722 L p F P
0 0 0 r
s
.1 0 .485 r
.15468 .54214 m .15692 .52369 L .17593 .5169 L p F P
0 0 0 r
s
.1 0 .485 r
.15692 .52369 m .15468 .54214 L .13572 .54884 L p F P
0 0 0 r
s
.1 0 .485 r
.56476 .16633 m .56453 .15014 L .58514 .14189 L p F P
0 0 0 r
s
.1 0 .485 r
.56453 .15014 m .56476 .16633 L .54419 .1745 L p F P
0 0 0 r
s
.511 .78 0 r
.28676 .86307 m .26732 .8685 L .25431 .85845 L p F P
0 0 0 r
s
.511 .78 0 r
.24905 .85993 m .25431 .85845 L .26732 .8685 L p F P
0 0 0 r
s
.125 0 .956 r
.92188 .86307 m .89995 .8685 L .89156 .85845 L p F P
0 0 0 r
s
.125 0 .956 r
.8915 .85846 m .89156 .85845 L .89995 .8685 L p F P
0 0 0 r
s
.1 0 .485 r
.09304 .59946 m .09565 .58065 L .11443 .57409 L p F P
0 0 0 r
s
.1 0 .485 r
.09565 .58065 m .09304 .59946 L .07431 .60593 L p F P
0 0 0 r
s
.195 0 .31 r
.83622 .61649 m .83434 .59745 L .84315 .6094 L p F P
0 0 0 r
s
.195 0 .31 r
.84315 .6094 m .84508 .62837 L .83622 .61649 L p F P
0 0 0 r
s
.195 0 .31 r
.78027 .44172 m .77872 .42374 L .78794 .43694 L p F P
0 0 0 r
s
.195 0 .31 r
.78794 .43694 m .78953 .45487 L .78027 .44172 L p F P
0 0 0 r
s
.195 0 .31 r
.66836 .09216 m .66749 .07631 L .67751 .09202 L p F P
0 0 0 r
s
.195 0 .31 r
.67751 .09202 m .67843 .10786 L .66836 .09216 L p F P
0 0 0 r
s
.1 0 .485 r
.50324 .22353 m .50338 .207 L .52376 .19896 L p F P
0 0 0 r
s
.1 0 .485 r
.50338 .207 m .50324 .22353 L .4829 .23148 L p F P
0 0 0 r
s
.625 0 .573 r
.63035 .86265 m .60956 .86808 L .59904 .85802 L p F P
0 0 0 r
s
.625 0 .573 r
.5783 .86349 m .59904 .85802 L .60956 .86808 L p F P
0 0 0 r
s
.195 0 .31 r
.89218 .79127 m .88996 .77117 L .89837 .78185 L p F P
0 0 0 r
s
.195 0 .31 r
.89837 .78185 m .90062 .80188 L .89218 .79127 L p F P
0 0 0 r
s
.195 0 .31 r
.72431 .26694 m .72311 .25002 L .73273 .26448 L p F P
0 0 0 r
s
.195 0 .31 r
.73273 .26448 m .73398 .28136 L .72431 .26694 L p F P
0 0 0 r
s
0 .78 .12 r
.23493 .86391 m .22085 .86788 L .21182 .85659 L p F P
0 0 0 r
s
0 .78 .71 r
.20233 .85929 m .21182 .85659 L .22085 .86788 L p F P
0 0 0 r
s
.1 0 .485 r
.44169 .28077 m .4422 .26388 L .46234 .25607 L p F P
0 0 0 r
s
.1 0 .485 r
.4422 .26388 m .44169 .28077 L .42158 .2885 L p F P
0 0 0 r
s
.625 .656 0 r
.33403 .86351 m .31899 .86767 L .30635 .8576 L p F P
0 0 0 r
s
.625 .656 0 r
.28882 .8625 m .30635 .8576 L .31899 .86767 L p F P
0 0 0 r
s
.625 0 .573 r
.66151 .8673 m .66146 .86725 L .66152 .86724 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.38009 .33804 m .38098 .32081 L .40088 .31322 L p F P
0 0 0 r
s
.1 0 .485 r
.38098 .32081 m .38009 .33804 L .36023 .34555 L p F P
0 0 0 r
s
.625 0 .573 r
.66152 .86724 m .66146 .86725 L .65131 .85718 L p F P
0 0 0 r
s
.625 0 .573 r
.63035 .86265 m .65131 .85718 L .66146 .86725 L p F P
0 0 0 r
s
.188 0 .528 r
.08508 .74313 m .08774 .72345 L .07342 .71233 L p F P
0 0 0 r
s
.188 0 .528 r
.07615 .69281 m .07342 .71233 L .08774 .72345 L p F P
0 0 0 r
s
.625 0 .573 r
.65131 .85718 m .65961 .85501 L .66152 .86724 L p F P
0 0 0 r
s
.625 .201 0 r
.68247 .86181 m .66152 .86724 L .65961 .85501 L p F P
0 0 0 r
s
.1 0 .485 r
.31846 .39535 m .31972 .37776 L .33939 .37039 L p F P
0 0 0 r
s
.1 0 .485 r
.31972 .37776 m .31846 .39535 L .29883 .40263 L p F P
0 0 0 r
s
.625 .201 0 r
.39055 .86141 m .37073 .86683 L .35846 .85676 L p F P
0 0 0 r
s
.625 .201 0 r
.33865 .86223 m .35846 .85676 L .37073 .86683 L p F P
0 0 0 r
s
.1 0 .485 r
.25679 .45269 m .25842 .43475 L .27786 .42761 L p F P
0 0 0 r
s
.1 0 .485 r
.25842 .43475 m .25679 .45269 L .2374 .45975 L p F P
0 0 0 r
s
.195 0 .31 r
.8254 .58533 m .82358 .56646 L .83248 .57864 L p F P
0 0 0 r
s
.195 0 .31 r
.83248 .57864 m .83434 .59745 L .8254 .58533 L p F P
0 0 0 r
s
.195 0 .31 r
.71335 .23535 m .71221 .2186 L .72192 .23331 L p F P
0 0 0 r
s
.195 0 .31 r
.72192 .23331 m .72311 .25002 L .71335 .23535 L p F P
0 0 0 r
s
.1 0 .485 r
.66664 .06064 m .66749 .07631 L .64648 .08485 L p F P
0 0 0 r
s
.625 .201 0 r
.71837 .86515 m .71342 .86642 L .70365 .85633 L p F P
0 0 0 r
s
.625 .201 0 r
.68247 .86181 m .70365 .85633 L .71342 .86642 L p F P
0 0 0 r
s
.195 0 .31 r
.88142 .76032 m .87926 .74038 L .88776 .75131 L p F P
0 0 0 r
s
.195 0 .31 r
.88776 .75131 m .88996 .77117 L .88142 .76032 L p F P
0 0 0 r
s
.195 0 .31 r
.76937 .41034 m .7679 .39253 L .7772 .40598 L p F P
0 0 0 r
s
.195 0 .31 r
.7772 .40598 m .77872 .42374 L .76937 .41034 L p F P
0 0 0 r
s
.511 .78 0 r
.29076 .86621 m .28676 .86307 L .28882 .8625 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.75604 .85549 m .76251 .86244 L .76319 .86616 L p F P
0 0 0 r
s
.625 .656 0 r
.73465 .86097 m .75604 .85549 L p .76319 .86616 L F P
0 0 0 r
s
.511 .78 0 r
.76251 .86244 m .76544 .86558 L .76319 .86616 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.60591 .13357 m .60543 .11756 L .62624 .10916 L p F P
0 0 0 r
s
.1 0 .485 r
.60543 .11756 m .60591 .13357 L .58514 .14189 L p F P
0 0 0 r
s
.625 0 .573 r
.44262 .86055 m .42253 .866 L .41063 .85591 L p F P
0 0 0 r
s
.625 0 .573 r
.3906 .86139 m .41063 .85591 L .42253 .866 L p F P
0 0 0 r
s
.1 0 .485 r
.19509 .51007 m .19709 .49178 L .21629 .48486 L p F P
0 0 0 r
s
.1 0 .485 r
.19709 .49178 m .19509 .51007 L .17593 .5169 L p F P
0 0 0 r
s
.1 0 .485 r
.54429 .19087 m .54419 .1745 L .56476 .16633 L p F P
0 0 0 r
s
.1 0 .485 r
.54419 .1745 m .54429 .19087 L .52376 .19896 L p F P
0 0 0 r
s
.1 0 .485 r
.13335 .56748 m .13572 .54884 L .15468 .54214 L p F P
0 0 0 r
s
.1 0 .485 r
.13572 .54884 m .13335 .56748 L .11443 .57409 L p F P
0 0 0 r
s
.188 0 .528 r
.11991 .83508 m .11744 .85549 L .13147 .86558 L p F P
0 0 0 r
s
.125 0 .956 r
.15041 .86013 m .13147 .86558 L .11744 .85549 L p F P
0 0 0 r
s
.188 0 .528 r
.07342 .71233 m .07615 .69281 L .06172 .68145 L p F P
0 0 0 r
s
.188 0 .528 r
.06453 .6621 m .06172 .68145 L .07615 .69281 L p F P
0 0 0 r
s
.511 .78 0 r
.76544 .86558 m .76251 .86244 L .76019 .85442 L p F P
0 0 0 r
s
.511 .78 0 r
.78689 .86013 m .76544 .86558 L p .76019 .85442 L F P
0 0 0 r
s
.1 0 .485 r
.48264 .2482 m .4829 .23148 L .50324 .22353 L p F P
0 0 0 r
s
.1 0 .485 r
.4829 .23148 m .48264 .2482 L .46234 .25607 L p F P
0 0 0 r
s
.1 0 .485 r
.07156 .62493 m .07431 .60593 L .09304 .59946 L p F P
0 0 0 r
s
.1 0 .485 r
.07431 .60593 m .07156 .62493 L .05288 .63132 L p F P
0 0 0 r
s
.625 0 .573 r
.4947 .85971 m .47439 .86516 L .46286 .85506 L p F P
0 0 0 r
s
.625 0 .573 r
.44262 .86055 m .46286 .85506 L .47439 .86516 L p F P
0 0 0 r
s
.625 .201 0 r
.70365 .85633 m .71586 .85317 L .71837 .86515 L p F P
0 0 0 r
s
.625 .656 0 r
.73465 .86097 m .71837 .86515 L .71586 .85317 L p F P
0 0 0 r
s
.1 0 .485 r
.42095 .30557 m .42158 .2885 L .44169 .28077 L p F P
0 0 0 r
s
.1 0 .485 r
.42158 .2885 m .42095 .30557 L .40088 .31322 L p F P
0 0 0 r
s
.195 0 .31 r
.81455 .55409 m .81279 .53539 L .82178 .54781 L p F P
0 0 0 r
s
.195 0 .31 r
.82178 .54781 m .82358 .56646 L .81455 .55409 L p F P
0 0 0 r
s
.195 0 .31 r
.75845 .37889 m .75704 .36125 L .76643 .37494 L p F P
0 0 0 r
s
.195 0 .31 r
.76643 .37494 m .7679 .39253 L .75845 .37889 L p F P
0 0 0 r
s
.195 0 .31 r
.87064 .7293 m .86854 .70952 L .87713 .72068 L p F P
0 0 0 r
s
.195 0 .31 r
.87713 .72068 m .87926 .74038 L .87064 .7293 L p F P
0 0 0 r
s
.195 0 .31 r
.70236 .20368 m .70129 .18711 L .71109 .20206 L p F P
0 0 0 r
s
.195 0 .31 r
.71109 .20206 m .71221 .2186 L .70236 .20368 L p F P
0 0 0 r
s
0 .78 .12 r
.83335 .86076 m .81752 .86475 L .8085 .85464 L p F P
0 0 0 r
s
0 .78 .12 r
.79836 .85722 m .8085 .85464 L .81752 .86475 L p F P
0 0 0 r
s
0 .647 .956 r
.18605 .86392 m .18317 .86475 L .16951 .85464 L p F P
0 0 0 r
s
0 .647 .956 r
.1518 .85973 m .16951 .85464 L .18317 .86475 L p F P
0 0 0 r
s
0 .78 .71 r
.83919 .85929 m .86044 .85394 L .86638 .86473 L p F P
0 0 0 r
s
0 .647 .956 r
.86967 .86391 m .86638 .86473 L .86044 .85394 L p F P
0 0 0 r
s
.625 0 .573 r
.54684 .85887 m .52632 .86433 L .51516 .85421 L p F P
0 0 0 r
s
.1 0 .485 r
.35922 .36297 m .36023 .34555 L .38009 .33804 L p F P
0 0 0 r
s
.625 0 .573 r
.4947 .85971 m .51516 .85421 L .52632 .86433 L p F P
0 0 0 r
s
.1 0 .485 r
.36023 .34555 m .35922 .36297 L .33939 .37039 L p F P
0 0 0 r
s
0 .78 .71 r
.20233 .85929 m .18605 .86392 L .17568 .85286 L p F P
0 0 0 r
s
0 .647 .956 r
.16951 .85464 m .17568 .85286 L .18605 .86392 L p F P
0 0 0 r
s
.1 0 .485 r
.29745 .42041 m .29883 .40263 L .31846 .39535 L p F P
0 0 0 r
s
.1 0 .485 r
.29883 .40263 m .29745 .42041 L .27786 .42761 L p F P
0 0 0 r
s
0 .78 .12 r
.24905 .85993 m .23493 .86391 L .22164 .85379 L p F P
0 0 0 r
s
0 .78 .12 r
.21182 .85659 m .22164 .85379 L .23493 .86391 L p F P
0 0 0 r
s
.188 0 .528 r
.06172 .68145 m .06453 .6621 L .05 .6505 L p F P
0 0 0 r
s
.188 0 .528 r
.05288 .63132 m .05 .6505 L .06453 .6621 L p F P
0 0 0 r
s
.188 0 .528 r
.11744 .85549 m .11991 .83508 L .10578 .82475 L p F P
0 0 0 r
s
.188 0 .528 r
.10833 .8045 m .10578 .82475 L .11991 .83508 L p F P
0 0 0 r
s
0 .647 .956 r
.8915 .85846 m .86967 .86391 L .86103 .85379 L p F P
0 0 0 r
s
0 .647 .956 r
.86044 .85394 m .86103 .85379 L .86967 .86391 L p F P
0 0 0 r
s
.625 .201 0 r
.33239 .85717 m .33865 .86223 L .33403 .86351 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.3261 .85209 m .33239 .85717 L .33403 .86351 L p F P
0 0 0 r
s
.625 .656 0 r
.30635 .8576 m .3261 .85209 L p .33403 .86351 L F P
0 0 0 r
s
.1 0 .485 r
.64722 .10069 m .64648 .08485 L .66749 .07631 L p F P
0 0 0 r
s
.1 0 .485 r
.64648 .08485 m .64722 .10069 L .62624 .10916 L p F P
0 0 0 r
s
.1 0 .485 r
.23564 .47788 m .2374 .45975 L .25679 .45269 L p F P
0 0 0 r
s
.1 0 .485 r
.2374 .45975 m .23564 .47788 L .21629 .48486 L p F P
0 0 0 r
s
.625 0 .573 r
.59904 .85802 m .5783 .86349 L .56752 .85336 L p F P
0 0 0 r
s
.625 0 .573 r
.54684 .85887 m .56752 .85336 L .5783 .86349 L p F P
0 0 0 r
s
.1 0 .485 r
.5855 .15809 m .58514 .14189 L .60591 .13357 L p F P
0 0 0 r
s
.1 0 .485 r
.58514 .14189 m .5855 .15809 L .56476 .16633 L p F P
0 0 0 r
s
.1 0 .485 r
.1738 .53539 m .17593 .5169 L .19509 .51007 L p F P
0 0 0 r
s
.1 0 .485 r
.17593 .5169 m .1738 .53539 L .15468 .54214 L p F P
0 0 0 r
s
.195 0 .31 r
.80367 .52278 m .80198 .50424 L .81106 .5169 L p F P
0 0 0 r
s
.195 0 .31 r
.81106 .5169 m .81279 .53539 L .80367 .52278 L p F P
0 0 0 r
s
.195 0 .31 r
.69134 .17194 m .69034 .15554 L .70023 .17074 L p F P
0 0 0 r
s
.195 0 .31 r
.70023 .17074 m .70129 .18711 L .69134 .17194 L p F P
0 0 0 r
s
.195 0 .31 r
.85983 .6982 m .8578 .67859 L .86647 .68999 L p F P
0 0 0 r
s
.195 0 .31 r
.86647 .68999 m .86854 .70952 L .85983 .6982 L p F P
0 0 0 r
s
.195 0 .31 r
.74751 .34736 m .74616 .32989 L .75564 .34382 L p F P
0 0 0 r
s
.195 0 .31 r
.75564 .34382 m .75704 .36125 L .74751 .34736 L p F P
0 0 0 r
s
.125 0 .956 r
.89156 .85845 m .91361 .85294 L .92188 .86307 L p F P
0 0 0 r
s
.511 .78 0 r
.28882 .8625 m .28676 .86307 L .27384 .85294 L p F P
0 0 0 r
s
.511 .78 0 r
.25431 .85845 m .27384 .85294 L .28676 .86307 L p F P
0 0 0 r
s
.1 0 .485 r
.11192 .59293 m .11443 .57409 L .13335 .56748 L p F P
0 0 0 r
s
.1 0 .485 r
.11443 .57409 m .11192 .59293 L .09304 .59946 L p F P
0 0 0 r
s
.1 0 .485 r
.52374 .21551 m .52376 .19896 L .54429 .19087 L p F P
0 0 0 r
s
.1 0 .485 r
.52376 .19896 m .52374 .21551 L .50324 .22353 L p F P
0 0 0 r
s
.625 0 .573 r
.65131 .85718 m .63035 .86265 L .61995 .85251 L p F P
0 0 0 r
s
.625 0 .573 r
.59904 .85802 m .61995 .85251 L .63035 .86265 L p F P
0 0 0 r
s
.625 .656 0 r
.30635 .8576 m .28882 .8625 L .2848 .84985 L p F P
0 0 0 r
s
.511 .78 0 r
.27384 .85294 m .2848 .84985 L .28882 .8625 L p F P
0 0 0 r
s
.625 .656 0 r
.76251 .86244 m .75604 .85549 L .76019 .85442 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.05 .6505 m .05288 .63132 L .07156 .62493 L p F P
0 0 0 r
s
.1 0 .485 r
.46195 .27298 m .46234 .25607 L .48264 .2482 L p F P
0 0 0 r
s
.1 0 .485 r
.46234 .25607 m .46195 .27298 L .44169 .28077 L p F P
0 0 0 r
s
.625 .201 0 r
.33865 .86223 m .33239 .85717 L .33184 .85049 L p F P
0 0 0 r
s
.625 .201 0 r
.35846 .85676 m .33865 .86223 L p .33184 .85049 L F P
0 0 0 r
s
.188 0 .528 r
.10578 .82475 m .10833 .8045 L .0941 .79394 L p F P
0 0 0 r
s
.188 0 .528 r
.09672 .77385 m .0941 .79394 L .10833 .8045 L p F P
0 0 0 r
s
.1 0 .485 r
.40012 .33047 m .40088 .31322 L .42095 .30557 L p F P
0 0 0 r
s
.1 0 .485 r
.40088 .31322 m .40012 .33047 L .38009 .33804 L p F P
0 0 0 r
s
.625 .201 0 r
.70365 .85633 m .68247 .86181 L .67244 .85166 L p F P
0 0 0 r
s
.625 .201 0 r
.65961 .85501 m .67244 .85166 L .68247 .86181 L p F P
0 0 0 r
s
.625 0 .573 r
.39054 .86134 m .3906 .86139 L .39055 .86141 L closepath p F P
0 0 0 r
s
.625 .201 0 r
.37843 .85124 m .39054 .86134 L .39055 .86141 L p F P
0 0 0 r
s
.625 .201 0 r
.35846 .85676 m .37843 .85124 L p .39055 .86141 L F P
0 0 0 r
s
.195 0 .31 r
.73653 .31575 m .73525 .29845 L .74482 .31263 L p F P
0 0 0 r
s
.195 0 .31 r
.74482 .31263 m .74616 .32989 L .73653 .31575 L p F P
0 0 0 r
s
.625 0 .573 r
.3906 .86139 m .39054 .86134 L .39305 .84719 L p F P
0 0 0 r
s
.625 0 .573 r
.41063 .85591 m .3906 .86139 L p .39305 .84719 L F P
0 0 0 r
s
.195 0 .31 r
.84899 .66702 m .84702 .64758 L .85579 .65922 L p F P
0 0 0 r
s
.195 0 .31 r
.85579 .65922 m .8578 .67859 L .84899 .66702 L p F P
0 0 0 r
s
.195 0 .31 r
.79276 .49139 m .79114 .47302 L .80031 .48592 L p F P
0 0 0 r
s
.195 0 .31 r
.80031 .48592 m .80198 .50424 L .79276 .49139 L p F P
0 0 0 r
s
.195 0 .31 r
.6803 .14012 m .67936 .12389 L .68934 .13934 L p F P
0 0 0 r
s
.195 0 .31 r
.68934 .13934 m .69034 .15554 L .6803 .14012 L p F P
0 0 0 r
s
.1 0 .485 r
.33825 .38801 m .33939 .37039 L .35922 .36297 L p F P
0 0 0 r
s
.1 0 .485 r
.33939 .37039 m .33825 .38801 L .31846 .39535 L p F P
0 0 0 r
s
.195 0 .31 r
.90522 .84266 m .90291 .82214 L .91127 .83251 L p F P
0 0 0 r
s
.195 0 .31 r
.91127 .83251 m .91361 .85294 L .90522 .84266 L p F P
0 0 0 r
s
.625 .201 0 r
.39054 .86134 m .37843 .85124 L .39305 .84719 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.75604 .85549 m .73465 .86097 L .72499 .85081 L p F P
0 0 0 r
s
.625 .656 0 r
.71586 .85317 m .72499 .85081 L .73465 .86097 L p F P
0 0 0 r
s
.1 0 .485 r
.27634 .44557 m .27786 .42761 L .29745 .42041 L p F P
0 0 0 r
s
.1 0 .485 r
.27786 .42761 m .27634 .44557 L .25679 .45269 L p F P
0 0 0 r
s
0 .78 .12 r
.8085 .85464 m .82801 .84968 L .83335 .86076 L p F P
0 0 0 r
s
0 .78 .71 r
.83919 .85929 m .83335 .86076 L .82801 .84968 L p F P
0 0 0 r
s
.1 0 .485 r
.2144 .50317 m .21629 .48486 L .23564 .47788 L p F P
0 0 0 r
s
.1 0 .485 r
.21629 .48486 m .2144 .50317 L .19509 .51007 L p F P
0 0 0 r
s
.1 0 .485 r
.62685 .12519 m .62624 .10916 L .64722 .10069 L p F P
0 0 0 r
s
.1 0 .485 r
.62624 .10916 m .62685 .12519 L .60591 .13357 L p F P
0 0 0 r
s
.625 0 .573 r
.46286 .85506 m .44262 .86055 L .43082 .85038 L p F P
0 0 0 r
s
.625 0 .573 r
.41063 .85591 m .43082 .85038 L .44262 .86055 L p F P
0 0 0 r
s
.188 0 .528 r
.0941 .79394 m .09672 .77385 L .08239 .76305 L p F P
0 0 0 r
s
.188 0 .528 r
.08508 .74313 m .08239 .76305 L .09672 .77385 L p F P
0 0 0 r
s
.1 0 .485 r
.15242 .56081 m .15468 .54214 L .1738 .53539 L p F P
0 0 0 r
s
.1 0 .485 r
.15468 .54214 m .15242 .56081 L .13335 .56748 L p F P
0 0 0 r
s
.125 0 .956 r
.1518 .85973 m .15041 .86013 L .13647 .84996 L p F P
0 0 0 r
s
.125 0 .956 r
.11744 .85549 m .13647 .84996 L .15041 .86013 L p F P
0 0 0 r
s
.1 0 .485 r
.565 .18271 m .56476 .16633 L .5855 .15809 L p F P
0 0 0 r
s
.1 0 .485 r
.56476 .16633 m .565 .18271 L .54429 .19087 L p F P
0 0 0 r
s
.511 .78 0 r
.79836 .85722 m .78689 .86013 L .77761 .84996 L p F P
0 0 0 r
s
.511 .78 0 r
.76019 .85442 m .77761 .84996 L .78689 .86013 L p F P
0 0 0 r
s
.511 .78 0 r
.24418 .85062 m .25431 .85845 L .24905 .85993 L closepath p F P
0 0 0 r
s
0 .78 .12 r
.24111 .84825 m .24418 .85062 L .24905 .85993 L p F P
0 0 0 r
s
0 .78 .12 r
.22164 .85379 m .24111 .84825 L p .24905 .85993 L F P
0 0 0 r
s
0 .647 .956 r
.16951 .85464 m .1518 .85973 L .13974 .84901 L p F P
0 0 0 r
s
.125 0 .956 r
.13647 .84996 m .13974 .84901 L .1518 .85973 L p F P
0 0 0 r
s
.195 0 .31 r
.66923 .10821 m .66836 .09216 L .67843 .10786 L p F P
0 0 0 r
s
.195 0 .31 r
.67843 .10786 m .67936 .12389 L .66923 .10821 L p F P
0 0 0 r
s
.1 0 .485 r
.5031 .24026 m .50324 .22353 L .52374 .21551 L p F P
0 0 0 r
s
.1 0 .485 r
.50324 .22353 m .5031 .24026 L .48264 .2482 L p F P
0 0 0 r
s
.1 0 .485 r
.0904 .61849 m .09304 .59946 L .11192 .59293 L p F P
0 0 0 r
s
.1 0 .485 r
.09304 .59946 m .0904 .61849 L .07156 .62493 L p F P
0 0 0 r
s
.195 0 .31 r
.83813 .63577 m .83622 .61649 L .84508 .62837 L p F P
0 0 0 r
s
.195 0 .31 r
.84508 .62837 m .84702 .64758 L .83813 .63577 L p F P
0 0 0 r
s
.195 0 .31 r
.78183 .45992 m .78027 .44172 L .78953 .45487 L p F P
0 0 0 r
s
.195 0 .31 r
.78953 .45487 m .79114 .47302 L .78183 .45992 L p F P
0 0 0 r
s
.195 0 .31 r
.72553 .28407 m .72431 .26694 L .73398 .28136 L p F P
0 0 0 r
s
.195 0 .31 r
.73398 .28136 m .73525 .29845 L .72553 .28407 L p F P
0 0 0 r
s
.625 0 .573 r
.51516 .85421 m .4947 .85971 L .48327 .84953 L p F P
0 0 0 r
s
.625 0 .573 r
.46286 .85506 m .48327 .84953 L .4947 .85971 L p F P
0 0 0 r
s
.195 0 .31 r
.89443 .81162 m .89218 .79127 L .90062 .80188 L p F P
0 0 0 r
s
.195 0 .31 r
.90062 .80188 m .90291 .82214 L .89443 .81162 L p F P
0 0 0 r
s
.1 0 .485 r
.44117 .29786 m .44169 .28077 L .46195 .27298 L p F P
0 0 0 r
s
.1 0 .485 r
.44169 .28077 m .44117 .29786 L .42095 .30557 L p F P
0 0 0 r
s
0 .78 .71 r
.21182 .85659 m .20233 .85929 L .18876 .8491 L p F P
0 0 0 r
s
0 .78 .71 r
.17568 .85286 m .18876 .8491 L .20233 .85929 L p F P
0 0 0 r
s
0 .78 .71 r
.86044 .85394 m .83919 .85929 L .83029 .8491 L p F P
0 0 0 r
s
0 .78 .71 r
.82801 .84968 m .83029 .8491 L .83919 .85929 L p F P
0 0 0 r
s
.1 0 .485 r
.3792 .35549 m .38009 .33804 L .40012 .33047 L p F P
0 0 0 r
s
.1 0 .485 r
.38009 .33804 m .3792 .35549 L .35922 .36297 L p F P
0 0 0 r
s
.625 0 .573 r
.56752 .85336 m .54684 .85887 L .53579 .84867 L p F P
0 0 0 r
s
.625 0 .573 r
.51516 .85421 m .53579 .84867 L .54684 .85887 L p F P
0 0 0 r
s
.188 0 .528 r
.08239 .76305 m .08508 .74313 L .07065 .73208 L p F P
0 0 0 r
s
.188 0 .528 r
.07342 .71233 m .07065 .73208 L .08508 .74313 L p F P
0 0 0 r
s
0 .647 .956 r
.88304 .84825 m .89118 .858 L .8915 .85846 L p F P
0 0 0 r
s
0 .647 .956 r
.86103 .85379 m .88304 .84825 L p .8915 .85846 L F P
0 0 0 r
s
.125 0 .956 r
.89118 .858 m .89156 .85845 L .8915 .85846 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.25431 .85845 m .24418 .85062 L .24306 .84769 L p F P
0 0 0 r
s
.511 .78 0 r
.27384 .85294 m .25431 .85845 L p .24306 .84769 L F P
0 0 0 r
s
.1 0 .485 r
.31719 .41315 m .31846 .39535 L .33825 .38801 L p F P
0 0 0 r
s
.1 0 .485 r
.31846 .39535 m .31719 .41315 L .29745 .42041 L p F P
0 0 0 r
s
.125 0 .956 r
.89156 .85845 m .89118 .858 L .88402 .848 L p F P
0 0 0 r
s
.125 0 .956 r
.91361 .85294 m .89156 .85845 L p .88402 .848 L F P
0 0 0 r
s
.1 0 .485 r
.66749 .07631 m .66836 .09216 L .64722 .10069 L p F P
0 0 0 r
s
.1 0 .485 r
.25515 .47085 m .25679 .45269 L .27634 .44557 L p F P
0 0 0 r
s
.1 0 .485 r
.25679 .45269 m .25515 .47085 L .23564 .47788 L p F P
0 0 0 r
s
.195 0 .31 r
.82724 .60444 m .8254 .58533 L .83434 .59745 L p F P
0 0 0 r
s
.195 0 .31 r
.83434 .59745 m .83622 .61649 L .82724 .60444 L p F P
0 0 0 r
s
.625 0 .573 r
.61995 .85251 m .59904 .85802 L .58837 .84782 L p F P
0 0 0 r
s
.625 0 .573 r
.56752 .85336 m .58837 .84782 L .59904 .85802 L p F P
0 0 0 r
s
.195 0 .31 r
.88361 .78051 m .88142 .76032 L .88996 .77117 L p F P
0 0 0 r
s
.195 0 .31 r
.88996 .77117 m .89218 .79127 L .88361 .78051 L p F P
0 0 0 r
s
.195 0 .31 r
.77087 .42837 m .76937 .41034 L .77872 .42374 L p F P
0 0 0 r
s
.195 0 .31 r
.77872 .42374 m .78027 .44172 L .77087 .42837 L p F P
0 0 0 r
s
.195 0 .31 r
.7145 .2523 m .71335 .23535 L .72311 .25002 L p F P
0 0 0 r
s
.195 0 .31 r
.72311 .25002 m .72431 .26694 L .7145 .2523 L p F P
0 0 0 r
s
0 .647 .956 r
.89118 .858 m .88304 .84825 L .88402 .848 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.6064 .14978 m .60591 .13357 L .62685 .12519 L p F P
0 0 0 r
s
.1 0 .485 r
.60591 .13357 m .6064 .14978 L .5855 .15809 L p F P
0 0 0 r
s
.1 0 .485 r
.19306 .52858 m .19509 .51007 L .2144 .50317 L p F P
0 0 0 r
s
.1 0 .485 r
.19509 .51007 m .19306 .52858 L .1738 .53539 L p F P
0 0 0 r
s
.625 .656 0 r
.3261 .85209 m .30635 .8576 L .29353 .84739 L p F P
0 0 0 r
s
.625 .656 0 r
.2848 .84985 m .29353 .84739 L .30635 .8576 L p F P
0 0 0 r
s
.511 .78 0 r
.77761 .84996 m .79329 .84593 L .79836 .85722 L p F P
0 0 0 r
s
0 .78 .12 r
.8085 .85464 m .79836 .85722 L .79329 .84593 L p F P
0 0 0 r
s
.1 0 .485 r
.13094 .58635 m .13335 .56748 L .15242 .56081 L p F P
0 0 0 r
s
.1 0 .485 r
.13335 .56748 m .13094 .58635 L .11192 .59293 L p F P
0 0 0 r
s
.1 0 .485 r
.5444 .20743 m .54429 .19087 L .565 .18271 L p F P
0 0 0 r
s
.1 0 .485 r
.54429 .19087 m .5444 .20743 L .52374 .21551 L p F P
0 0 0 r
s
.625 0 .573 r
.65961 .85501 m .65131 .85718 L .64102 .84696 L p F P
0 0 0 r
s
.625 0 .573 r
.61995 .85251 m .64102 .84696 L .65131 .85718 L p F P
0 0 0 r
s
.188 0 .528 r
.07065 .73208 m .07342 .71233 L .05888 .70105 L p F P
0 0 0 r
s
.188 0 .528 r
.06172 .68145 m .05888 .70105 L .07342 .71233 L p F P
0 0 0 r
s
.625 .656 0 r
.33239 .85717 m .3261 .85209 L .33184 .85049 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.06878 .64415 m .07156 .62493 L .0904 .61849 L p F P
0 0 0 r
s
.1 0 .485 r
.07156 .62493 m .06878 .64415 L .05 .6505 L p F P
0 0 0 r
s
.1 0 .485 r
.48237 .26512 m .48264 .2482 L .5031 .24026 L p F P
0 0 0 r
s
.1 0 .485 r
.48264 .2482 m .48237 .26512 L .46195 .27298 L p F P
0 0 0 r
s
.625 .201 0 r
.37843 .85124 m .35846 .85676 L .34601 .84653 L p F P
0 0 0 r
s
.625 .201 0 r
.33184 .85049 m .34601 .84653 L .35846 .85676 L p F P
0 0 0 r
s
0 .78 .12 r
.22164 .85379 m .21182 .85659 L .20427 .84464 L p F P
0 0 0 r
s
0 .78 .71 r
.18876 .8491 m .20427 .84464 L .21182 .85659 L p F P
0 0 0 r
s
.195 0 .31 r
.75988 .39675 m .75845 .37889 L .7679 .39253 L p F P
0 0 0 r
s
.195 0 .31 r
.7679 .39253 m .76937 .41034 L .75988 .39675 L p F P
0 0 0 r
s
.195 0 .31 r
.70345 .22046 m .70236 .20368 L .71221 .2186 L p F P
0 0 0 r
s
.195 0 .31 r
.71221 .2186 m .71335 .23535 L .70345 .22046 L p F P
0 0 0 r
s
.195 0 .31 r
.81632 .57303 m .81455 .55409 L .82358 .56646 L p F P
0 0 0 r
s
.195 0 .31 r
.82358 .56646 m .8254 .58533 L .81632 .57303 L p F P
0 0 0 r
s
.625 .201 0 r
.71586 .85317 m .70365 .85633 L .69373 .8461 L p F P
0 0 0 r
s
.625 .201 0 r
.67244 .85166 m .69373 .8461 L .70365 .85633 L p F P
0 0 0 r
s
.1 0 .485 r
.4203 .32285 m .42095 .30557 L .44117 .29786 L p F P
0 0 0 r
s
.1 0 .485 r
.42095 .30557 m .4203 .32285 L .40012 .33047 L p F P
0 0 0 r
s
.195 0 .31 r
.87276 .74932 m .87064 .7293 L .87926 .74038 L p F P
0 0 0 r
s
.195 0 .31 r
.87926 .74038 m .88142 .76032 L .87276 .74932 L p F P
0 0 0 r
s
.1 0 .485 r
.35819 .3806 m .35922 .36297 L .3792 .35549 L p F P
0 0 0 r
s
.1 0 .485 r
.35922 .36297 m .35819 .3806 L .33825 .38801 L p F P
0 0 0 r
s
.625 0 .573 r
.43082 .85038 m .41063 .85591 L .39856 .84567 L p F P
0 0 0 r
s
.625 0 .573 r
.39305 .84719 m .39856 .84567 L .41063 .85591 L p F P
0 0 0 r
s
.1 0 .485 r
.29605 .4384 m .29745 .42041 L .31719 .41315 L p F P
0 0 0 r
s
.1 0 .485 r
.29745 .42041 m .29605 .4384 L .27634 .44557 L p F P
0 0 0 r
s
.188 0 .528 r
.10578 .82475 m .1032 .84524 L .11744 .85549 L p F P
0 0 0 r
s
.125 0 .956 r
.13647 .84996 m .11744 .85549 L .1032 .84524 L p F P
0 0 0 r
s
.188 0 .528 r
.05888 .70105 m .06172 .68145 L .04708 .66993 L p F P
0 0 0 r
s
.188 0 .528 r
.05 .6505 m .04708 .66993 L .06172 .68145 L p F P
0 0 0 r
s
.625 .656 0 r
.76019 .85442 m .75604 .85549 L .74651 .84524 L p F P
0 0 0 r
s
.625 .656 0 r
.72499 .85081 m .74651 .84524 L .75604 .85549 L p F P
0 0 0 r
s
.1 0 .485 r
.64796 .11673 m .64722 .10069 L .66836 .09216 L p F P
0 0 0 r
s
.1 0 .485 r
.64722 .10069 m .64796 .11673 L .62685 .12519 L p F P
0 0 0 r
s
.625 0 .573 r
.48327 .84953 m .46286 .85506 L .45117 .84481 L p F P
0 0 0 r
s
.625 0 .573 r
.43082 .85038 m .45117 .84481 L .46286 .85506 L p F P
0 0 0 r
s
.1 0 .485 r
.23386 .49623 m .23564 .47788 L .25515 .47085 L p F P
0 0 0 r
s
.1 0 .485 r
.23564 .47788 m .23386 .49623 L .2144 .50317 L p F P
0 0 0 r
s
.625 0 .573 r
.64102 .84696 m .65413 .84351 L .65961 .85501 L p F P
0 0 0 r
s
.625 .201 0 r
.67244 .85166 m .65961 .85501 L .65413 .84351 L p F P
0 0 0 r
s
.1 0 .485 r
.58586 .17448 m .5855 .15809 L .6064 .14978 L p F P
0 0 0 r
s
.1 0 .485 r
.5855 .15809 m .58586 .17448 L .565 .18271 L p F P
0 0 0 r
s
.1 0 .485 r
.17164 .55409 m .1738 .53539 L .19306 .52858 L p F P
0 0 0 r
s
.1 0 .485 r
.1738 .53539 m .17164 .55409 L .15242 .56081 L p F P
0 0 0 r
s
0 .647 .956 r
.17568 .85286 m .16951 .85464 L .15565 .84438 L p F P
0 0 0 r
s
0 .647 .956 r
.13974 .84901 m .15565 .84438 L .16951 .85464 L p F P
0 0 0 r
s
.195 0 .31 r
.80538 .54155 m .80367 .52278 L .81279 .53539 L p F P
0 0 0 r
s
.195 0 .31 r
.81279 .53539 m .81455 .55409 L .80538 .54155 L p F P
0 0 0 r
s
.195 0 .31 r
.86189 .71805 m .85983 .6982 L .86854 .70952 L p F P
0 0 0 r
s
.195 0 .31 r
.86854 .70952 m .87064 .7293 L .86189 .71805 L p F P
0 0 0 r
s
.195 0 .31 r
.74887 .36504 m .74751 .34736 L .75704 .36125 L p F P
0 0 0 r
s
.195 0 .31 r
.75704 .36125 m .75845 .37889 L .74887 .36504 L p F P
0 0 0 r
s
.195 0 .31 r
.69236 .18854 m .69134 .17194 L .70129 .18711 L p F P
0 0 0 r
s
.195 0 .31 r
.70129 .18711 m .70236 .20368 L .69236 .18854 L p F P
0 0 0 r
s
0 .78 .12 r
.82801 .84968 m .8085 .85464 L .79935 .84438 L p F P
0 0 0 r
s
0 .78 .12 r
.79329 .84593 m .79935 .84438 L .8085 .85464 L p F P
0 0 0 r
s
.625 .656 0 r
.74651 .84524 m .75505 .84303 L .76019 .85442 L p F P
0 0 0 r
s
.511 .78 0 r
.77761 .84996 m .76019 .85442 L .75505 .84303 L p F P
0 0 0 r
s
.1 0 .485 r
.52373 .23227 m .52374 .21551 L .5444 .20743 L p F P
0 0 0 r
s
.1 0 .485 r
.52374 .21551 m .52373 .23227 L .5031 .24026 L p F P
0 0 0 r
s
.1 0 .485 r
.10938 .61199 m .11192 .59293 L .13094 .58635 L p F P
0 0 0 r
s
.1 0 .485 r
.11192 .59293 m .10938 .61199 L .0904 .61849 L p F P
0 0 0 r
s
.625 0 .573 r
.53579 .84867 m .51516 .85421 L .50384 .84395 L p F P
0 0 0 r
s
.625 0 .573 r
.48327 .84953 m .50384 .84395 L .51516 .85421 L p F P
0 0 0 r
s
0 .78 .71 r
.85225 .84352 m .85859 .85094 L .86044 .85394 L p F P
0 0 0 r
s
0 .78 .71 r
.83029 .8491 m .85225 .84352 L p .86044 .85394 L F P
0 0 0 r
s
0 .647 .956 r
.85859 .85094 m .86103 .85379 L .86044 .85394 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.46155 .29009 m .46195 .27298 L .48237 .26512 L p F P
0 0 0 r
s
.1 0 .485 r
.46195 .27298 m .46155 .29009 L .44117 .29786 L p F P
0 0 0 r
s
.1 0 .485 r
.04708 .66993 m .05 .6505 L .06878 .64415 L p F P
0 0 0 r
s
0 .78 .12 r
.24111 .84825 m .22164 .85379 L .20816 .84352 L p F P
0 0 0 r
s
0 .78 .12 r
.20427 .84464 m .20816 .84352 L .22164 .85379 L p F P
0 0 0 r
s
.188 0 .528 r
.1032 .84524 m .10578 .82475 L .09145 .81427 L p F P
0 0 0 r
s
.188 0 .528 r
.0941 .79394 m .09145 .81427 L .10578 .82475 L p F P
0 0 0 r
s
0 .647 .956 r
.86103 .85379 m .85859 .85094 L .85354 .84319 L p F P
0 0 0 r
s
0 .647 .956 r
.88304 .84825 m .86103 .85379 L p .85354 .84319 L F P
0 0 0 r
s
.625 0 .573 r
.58837 .84782 m .56752 .85336 L .55658 .84309 L p F P
0 0 0 r
s
.1 0 .485 r
.39934 .34794 m .40012 .33047 L .4203 .32285 L p F P
0 0 0 r
s
.625 0 .573 r
.53579 .84867 m .55658 .84309 L .56752 .85336 L p F P
0 0 0 r
s
.1 0 .485 r
.40012 .33047 m .39934 .34794 L .3792 .35549 L p F P
0 0 0 r
s
.625 .201 0 r
.69373 .8461 m .71087 .84163 L .71586 .85317 L p F P
0 0 0 r
s
.625 .656 0 r
.72499 .85081 m .71586 .85317 L .71087 .84163 L p F P
0 0 0 r
s
.195 0 .31 r
.79441 .50998 m .79276 .49139 L .80198 .50424 L p F P
0 0 0 r
s
.195 0 .31 r
.80198 .50424 m .80367 .52278 L .79441 .50998 L p F P
0 0 0 r
s
.195 0 .31 r
.73783 .33326 m .73653 .31575 L .74616 .32989 L p F P
0 0 0 r
s
.195 0 .31 r
.74616 .32989 m .74751 .34736 L .73783 .33326 L p F P
0 0 0 r
s
.195 0 .31 r
.68125 .15654 m .6803 .14012 L .69034 .15554 L p F P
0 0 0 r
s
.195 0 .31 r
.69034 .15554 m .69134 .17194 L .68125 .15654 L p F P
0 0 0 r
s
.511 .78 0 r
.2848 .84985 m .27384 .85294 L .26073 .84266 L p F P
0 0 0 r
s
.511 .78 0 r
.24306 .84769 m .26073 .84266 L .27384 .85294 L p F P
0 0 0 r
s
.1 0 .485 r
.33709 .40583 m .33825 .38801 L .35819 .3806 L p F P
0 0 0 r
s
.1 0 .485 r
.33825 .38801 m .33709 .40583 L .31719 .41315 L p F P
0 0 0 r
s
.195 0 .31 r
.85099 .68671 m .84899 .66702 L .8578 .67859 L p F P
0 0 0 r
s
.195 0 .31 r
.8578 .67859 m .85983 .6982 L .85099 .68671 L p F P
0 0 0 r
s
.125 0 .956 r
.88402 .848 m .90522 .84266 L .91361 .85294 L p F P
0 0 0 r
s
0 .78 .71 r
.18876 .8491 m .17568 .85286 L .16647 .84124 L p F P
0 0 0 r
s
0 .647 .956 r
.15565 .84438 m .16647 .84124 L .17568 .85286 L p F P
0 0 0 r
s
.1 0 .485 r
.27481 .46376 m .27634 .44557 L .29605 .4384 L p F P
0 0 0 r
s
.1 0 .485 r
.27634 .44557 m .27481 .46376 L .25515 .47085 L p F P
0 0 0 r
s
.625 0 .573 r
.64102 .84696 m .61995 .85251 L .60939 .84223 L p F P
0 0 0 r
s
.625 0 .573 r
.58837 .84782 m .60939 .84223 L .61995 .85251 L p F P
0 0 0 r
s
.1 0 .485 r
.21248 .52172 m .2144 .50317 L .23386 .49623 L p F P
0 0 0 r
s
.1 0 .485 r
.2144 .50317 m .21248 .52172 L .19306 .52858 L p F P
0 0 0 r
s
.1 0 .485 r
.62747 .14141 m .62685 .12519 L .64796 .11673 L p F P
0 0 0 r
s
.1 0 .485 r
.62685 .12519 m .62747 .14141 L .6064 .14978 L p F P
0 0 0 r
s
.625 .656 0 r
.33184 .85049 m .3261 .85209 L .31337 .84179 L p F P
0 0 0 r
s
.625 .656 0 r
.29353 .84739 m .31337 .84179 L .3261 .85209 L p F P
0 0 0 r
s
.188 0 .528 r
.09145 .81427 m .0941 .79394 L .07966 .78321 L p F P
0 0 0 r
s
.188 0 .528 r
.08239 .76305 m .07966 .78321 L .0941 .79394 L p F P
0 0 0 r
s
.1 0 .485 r
.15012 .57972 m .15242 .56081 L .17164 .55409 L p F P
0 0 0 r
s
.1 0 .485 r
.15242 .56081 m .15012 .57972 L .13094 .58635 L p F P
0 0 0 r
s
.625 .201 0 r
.69373 .8461 m .67244 .85166 L .66226 .84136 L p F P
0 0 0 r
s
.625 .201 0 r
.65413 .84351 m .66226 .84136 L .67244 .85166 L p F P
0 0 0 r
s
.1 0 .485 r
.56523 .19929 m .565 .18271 L .58586 .17448 L p F P
0 0 0 r
s
.1 0 .485 r
.565 .18271 m .56523 .19929 L .5444 .20743 L p F P
0 0 0 r
s
.195 0 .31 r
.78341 .47834 m .78183 .45992 L .79114 .47302 L p F P
0 0 0 r
s
.195 0 .31 r
.79114 .47302 m .79276 .49139 L .78341 .47834 L p F P
0 0 0 r
s
.195 0 .31 r
.67011 .12446 m .66923 .10821 L .67936 .12389 L p F P
0 0 0 r
s
.195 0 .31 r
.67936 .12389 m .6803 .14012 L .67011 .12446 L p F P
0 0 0 r
s
.625 .201 0 r
.39305 .84719 m .37843 .85124 L .36608 .84093 L p F P
0 0 0 r
s
.625 .201 0 r
.34601 .84653 m .36608 .84093 L .37843 .85124 L p F P
0 0 0 r
s
.1 0 .485 r
.08772 .63775 m .0904 .61849 L .10938 .61199 L p F P
0 0 0 r
s
.1 0 .485 r
.0904 .61849 m .08772 .63775 L .06878 .64415 L p F P
0 0 0 r
s
.195 0 .31 r
.84006 .65528 m .83813 .63577 L .84702 .64758 L p F P
0 0 0 r
s
.195 0 .31 r
.84702 .64758 m .84899 .66702 L .84006 .65528 L p F P
0 0 0 r
s
.1 0 .485 r
.50296 .25721 m .5031 .24026 L .52373 .23227 L p F P
0 0 0 r
s
.1 0 .485 r
.5031 .24026 m .50296 .25721 L .48237 .26512 L p F P
0 0 0 r
s
.195 0 .31 r
.89671 .83222 m .89443 .81162 L .90291 .82214 L p F P
0 0 0 r
s
.195 0 .31 r
.90291 .82214 m .90522 .84266 L .89671 .83222 L p F P
0 0 0 r
s
.195 0 .31 r
.72676 .3014 m .72553 .28407 L .73525 .29845 L p F P
0 0 0 r
s
.195 0 .31 r
.73525 .29845 m .73653 .31575 L .72676 .3014 L p F P
0 0 0 r
s
0 .78 .71 r
.85859 .85094 m .85225 .84352 L .85354 .84319 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.44065 .31516 m .44117 .29786 L .46155 .29009 L p F P
0 0 0 r
s
.1 0 .485 r
.44117 .29786 m .44065 .31516 L .4203 .32285 L p F P
0 0 0 r
s
.625 .656 0 r
.74651 .84524 m .72499 .85081 L .71519 .8405 L p F P
0 0 0 r
s
.625 .656 0 r
.71087 .84163 m .71519 .8405 L .72499 .85081 L p F P
0 0 0 r
s
0 .78 .12 r
.24418 .85062 m .24111 .84825 L .24306 .84769 L closepath p F P
0 0 0 r
s
.625 .201 0 r
.3345 .83707 m .34601 .84653 L .33184 .85049 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.33338 .83615 m .3345 .83707 L .33184 .85049 L p F P
0 0 0 r
s
.625 .656 0 r
.31337 .84179 m .33338 .83615 L p .33184 .85049 L F P
0 0 0 r
s
.1 0 .485 r
.3783 .37314 m .3792 .35549 L .39934 .34794 L p F P
0 0 0 r
s
.1 0 .485 r
.3792 .35549 m .3783 .37314 L .35819 .3806 L p F P
0 0 0 r
s
.625 0 .573 r
.45117 .84481 m .43082 .85038 L .41885 .84006 L p F P
0 0 0 r
s
.625 0 .573 r
.39856 .84567 m .41885 .84006 L .43082 .85038 L p F P
0 0 0 r
s
.188 0 .528 r
.07966 .78321 m .08239 .76305 L .06784 .75208 L p F P
0 0 0 r
s
.188 0 .528 r
.07065 .73208 m .06784 .75208 L .08239 .76305 L p F P
0 0 0 r
s
.1 0 .485 r
.31591 .43117 m .31719 .41315 L .33709 .40583 L p F P
0 0 0 r
s
.1 0 .485 r
.31719 .41315 m .31591 .43117 L .29605 .4384 L p F P
0 0 0 r
s
.125 0 .956 r
.13974 .84901 m .13647 .84996 L .12232 .83963 L p F P
0 0 0 r
s
.125 0 .956 r
.1032 .84524 m .12232 .83963 L .13647 .84996 L p F P
0 0 0 r
s
.511 .78 0 r
.79329 .84593 m .77761 .84996 L .76819 .83963 L p F P
0 0 0 r
s
.511 .78 0 r
.75505 .84303 m .76819 .83963 L .77761 .84996 L p F P
0 0 0 r
s
.625 .656 0 r
.28411 .83989 m .29353 .84739 L .2848 .84985 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.28052 .83702 m .28411 .83989 L .2848 .84985 L p F P
0 0 0 r
s
.511 .78 0 r
.26073 .84266 m .28052 .83702 L p .2848 .84985 L F P
0 0 0 r
s
0 .78 .12 r
.82126 .83876 m .82251 .84019 L .82801 .84968 L p F P
0 0 0 r
s
0 .78 .12 r
.79935 .84438 m .82126 .83876 L p .82801 .84968 L F P
0 0 0 r
s
0 .78 .71 r
.82251 .84019 m .83029 .8491 L .82801 .84968 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.8291 .62378 m .82724 .60444 L .83622 .61649 L p F P
0 0 0 r
s
.195 0 .31 r
.83622 .61649 m .83813 .63577 L .8291 .62378 L p F P
0 0 0 r
s
.195 0 .31 r
.71567 .26946 m .7145 .2523 L .72431 .26694 L p F P
0 0 0 r
s
.195 0 .31 r
.72431 .26694 m .72553 .28407 L .71567 .26946 L p F P
0 0 0 r
s
.1 0 .485 r
.66836 .09216 m .66923 .10821 L .64796 .11673 L p F P
0 0 0 r
s
.1 0 .485 r
.25348 .48923 m .25515 .47085 L .27481 .46376 L p F P
0 0 0 r
s
.1 0 .485 r
.25515 .47085 m .25348 .48923 L .23386 .49623 L p F P
0 0 0 r
s
.625 0 .573 r
.50384 .84395 m .48327 .84953 L .47168 .8392 L p F P
0 0 0 r
s
.625 0 .573 r
.45117 .84481 m .47168 .8392 L .48327 .84953 L p F P
0 0 0 r
s
.195 0 .31 r
.88582 .80094 m .88361 .78051 L .89218 .79127 L p F P
0 0 0 r
s
.195 0 .31 r
.89218 .79127 m .89443 .81162 L .88582 .80094 L p F P
0 0 0 r
s
.195 0 .31 r
.77239 .44662 m .77087 .42837 L .78027 .44172 L p F P
0 0 0 r
s
.195 0 .31 r
.78027 .44172 m .78183 .45992 L .77239 .44662 L p F P
0 0 0 r
s
0 .78 .71 r
.20427 .84464 m .18876 .8491 L .17499 .83876 L p F P
0 0 0 r
s
0 .78 .71 r
.16647 .84124 m .17499 .83876 L .18876 .8491 L p F P
0 0 0 r
s
.1 0 .485 r
.60689 .16619 m .6064 .14978 L .62747 .14141 L p F P
0 0 0 r
s
.1 0 .485 r
.6064 .14978 m .60689 .16619 L .58586 .17448 L p F P
0 0 0 r
s
.1 0 .485 r
.19101 .54732 m .19306 .52858 L .21248 .52172 L p F P
0 0 0 r
s
.1 0 .485 r
.19306 .52858 m .19101 .54732 L .17164 .55409 L p F P
0 0 0 r
s
0 .78 .71 r
.83029 .8491 m .82251 .84019 L .82157 .83868 L p F P
0 0 0 r
s
0 .78 .71 r
.85225 .84352 m .83029 .8491 L p .82157 .83868 L F P
0 0 0 r
s
0 .647 .956 r
.15565 .84438 m .13974 .84901 L .12833 .83787 L p F P
0 0 0 r
s
.125 0 .956 r
.12232 .83963 m .12833 .83787 L .13974 .84901 L p F P
0 0 0 r
s
.1 0 .485 r
.12851 .60545 m .13094 .58635 L .15012 .57972 L p F P
0 0 0 r
s
.1 0 .485 r
.13094 .58635 m .12851 .60545 L .10938 .61199 L p F P
0 0 0 r
s
.1 0 .485 r
.54452 .2242 m .5444 .20743 L .56523 .19929 L p F P
0 0 0 r
s
.1 0 .485 r
.5444 .20743 m .54452 .2242 L .52373 .23227 L p F P
0 0 0 r
s
.625 0 .573 r
.55658 .84309 m .53579 .84867 L .52458 .83833 L p F P
0 0 0 r
s
.625 0 .573 r
.50384 .84395 m .52458 .83833 L .53579 .84867 L p F P
0 0 0 r
s
.188 0 .528 r
.06784 .75208 m .07065 .73208 L .056 .72088 L p F P
0 0 0 r
s
.188 0 .528 r
.05888 .70105 m .056 .72088 L .07065 .73208 L p F P
0 0 0 r
s
.1 0 .485 r
.4821 .28225 m .48237 .26512 L .50296 .25721 L p F P
0 0 0 r
s
.1 0 .485 r
.48237 .26512 m .4821 .28225 L .46155 .29009 L p F P
0 0 0 r
s
.1 0 .485 r
.06597 .66362 m .06878 .64415 L .08772 .63775 L p F P
0 0 0 r
s
.1 0 .485 r
.06878 .64415 m .06597 .66362 L .04708 .66993 L p F P
0 0 0 r
s
0 .78 .12 r
.24306 .84769 m .24111 .84825 L .22772 .83789 L p F P
0 0 0 r
s
0 .78 .12 r
.20816 .84352 m .22772 .83789 L .24111 .84825 L p F P
0 0 0 r
s
0 .647 .956 r
.88402 .848 m .88304 .84825 L .87439 .83789 L p F P
0 0 0 r
s
0 .647 .956 r
.85354 .84319 m .87439 .83789 L .88304 .84825 L p F P
0 0 0 r
s
0 .647 .956 r
.87439 .83789 m .87615 .83745 L .88402 .848 L p F P
0 0 0 r
s
.125 0 .956 r
.90522 .84266 m .88402 .848 L .87615 .83745 L p F P
0 0 0 r
s
.195 0 .31 r
.81812 .59221 m .81632 .57303 L .8254 .58533 L p F P
0 0 0 r
s
.195 0 .31 r
.8254 .58533 m .82724 .60444 L .81812 .59221 L p F P
0 0 0 r
s
.195 0 .31 r
.76133 .41483 m .75988 .39675 L .76937 .41034 L p F P
0 0 0 r
s
.195 0 .31 r
.76937 .41034 m .77087 .42837 L .76133 .41483 L p F P
0 0 0 r
s
.1 0 .485 r
.41965 .34034 m .4203 .32285 L .44065 .31516 L p F P
0 0 0 r
s
.1 0 .485 r
.4203 .32285 m .41965 .34034 L .39934 .34794 L p F P
0 0 0 r
s
.625 0 .573 r
.60939 .84223 m .58837 .84782 L .57754 .83746 L p F P
0 0 0 r
s
.625 0 .573 r
.55658 .84309 m .57754 .83746 L .58837 .84782 L p F P
0 0 0 r
s
.195 0 .31 r
.87491 .76958 m .87276 .74932 L .88142 .76032 L p F P
0 0 0 r
s
.195 0 .31 r
.88142 .76032 m .88361 .78051 L .87491 .76958 L p F P
0 0 0 r
s
.195 0 .31 r
.70454 .23745 m .70345 .22046 L .71335 .23535 L p F P
0 0 0 r
s
.195 0 .31 r
.71335 .23535 m .7145 .2523 L .70454 .23745 L p F P
0 0 0 r
s
.511 .78 0 r
.26073 .84266 m .24306 .84769 L .24093 .83409 L p F P
0 0 0 r
s
0 .78 .12 r
.22772 .83789 m .24093 .83409 L .24306 .84769 L p F P
0 0 0 r
s
.1 0 .485 r
.35716 .39846 m .35819 .3806 L .3783 .37314 L p F P
0 0 0 r
s
.1 0 .485 r
.35819 .3806 m .35716 .39846 L .33709 .40583 L p F P
0 0 0 r
s
.625 .656 0 r
.29353 .84739 m .28411 .83989 L .2847 .83583 L p F P
0 0 0 r
s
.625 .656 0 r
.31337 .84179 m .29353 .84739 L p .2847 .83583 L F P
0 0 0 r
s
.625 0 .573 r
.39523 .84285 m .39856 .84567 L .39305 .84719 L closepath p F P
0 0 0 r
s
.625 .201 0 r
.38631 .83528 m .39523 .84285 L .39305 .84719 L p F P
0 0 0 r
s
.625 .201 0 r
.36608 .84093 m .38631 .83528 L p .39305 .84719 L F P
0 0 0 r
s
.625 0 .573 r
.65413 .84351 m .64102 .84696 L .63057 .83659 L p F P
0 0 0 r
s
.625 0 .573 r
.60939 .84223 m .63057 .83659 L .64102 .84696 L p F P
0 0 0 r
s
.1 0 .485 r
.29463 .45661 m .29605 .4384 L .31591 .43117 L p F P
0 0 0 r
s
.1 0 .485 r
.29605 .4384 m .29463 .45661 L .27481 .46376 L p F P
0 0 0 r
s
.188 0 .528 r
.056 .72088 m .05888 .70105 L .04412 .68959 L p F P
0 0 0 r
s
.188 0 .528 r
.04708 .66993 m .04412 .68959 L .05888 .70105 L p F P
0 0 0 r
s
.1 0 .485 r
.64871 .13297 m .64796 .11673 L .66923 .10821 L p F P
0 0 0 r
s
.1 0 .485 r
.64796 .11673 m .64871 .13297 L .62747 .14141 L p F P
0 0 0 r
s
.1 0 .485 r
.23206 .5148 m .23386 .49623 L .25348 .48923 L p F P
0 0 0 r
s
.1 0 .485 r
.23386 .49623 m .23206 .5148 L .21248 .52172 L p F P
0 0 0 r
s
.625 .201 0 r
.34601 .84653 m .3345 .83707 L .33514 .83566 L p F P
0 0 0 r
s
.625 .201 0 r
.36608 .84093 m .34601 .84653 L p .33514 .83566 L F P
0 0 0 r
s
.1 0 .485 r
.16945 .57303 m .17164 .55409 L .19101 .54732 L p F P
0 0 0 r
s
.1 0 .485 r
.17164 .55409 m .16945 .57303 L .15012 .57972 L p F P
0 0 0 r
s
.195 0 .31 r
.80711 .56055 m .80538 .54155 L .81455 .55409 L p F P
0 0 0 r
s
.195 0 .31 r
.81455 .55409 m .81632 .57303 L .80711 .56055 L p F P
0 0 0 r
s
.195 0 .31 r
.69339 .20535 m .69236 .18854 L .70236 .20368 L p F P
0 0 0 r
s
.195 0 .31 r
.70236 .20368 m .70345 .22046 L .69339 .20535 L p F P
0 0 0 r
s
.1 0 .485 r
.58623 .19108 m .58586 .17448 L .60689 .16619 L p F P
0 0 0 r
s
.1 0 .485 r
.58586 .17448 m .58623 .19108 L .56523 .19929 L p F P
0 0 0 r
s
.625 .201 0 r
.71087 .84163 m .69373 .8461 L .68367 .83572 L p F P
0 0 0 r
s
.625 .201 0 r
.66226 .84136 m .68367 .83572 L .69373 .8461 L p F P
0 0 0 r
s
.195 0 .31 r
.86397 .73815 m .86189 .71805 L .87064 .7293 L p F P
0 0 0 r
s
.195 0 .31 r
.87064 .7293 m .87276 .74932 L .86397 .73815 L p F P
0 0 0 r
s
.195 0 .31 r
.75025 .38295 m .74887 .36504 L .75845 .37889 L p F P
0 0 0 r
s
.195 0 .31 r
.75845 .37889 m .75988 .39675 L .75025 .38295 L p F P
0 0 0 r
s
.511 .78 0 r
.76819 .83963 m .78694 .83478 L .79329 .84593 L p F P
0 0 0 r
s
0 .78 .12 r
.79935 .84438 m .79329 .84593 L .78694 .83478 L p F P
0 0 0 r
s
.1 0 .485 r
.1068 .6313 m .10938 .61199 L .12851 .60545 L p F P
0 0 0 r
s
.1 0 .485 r
.10938 .61199 m .1068 .6313 L .08772 .63775 L p F P
0 0 0 r
s
.1 0 .485 r
.52371 .24923 m .52373 .23227 L .54452 .2242 L p F P
0 0 0 r
s
.1 0 .485 r
.52373 .23227 m .52371 .24923 L .50296 .25721 L p F P
0 0 0 r
s
.625 0 .573 r
.39856 .84567 m .39523 .84285 L .4066 .82962 L p F P
0 0 0 r
s
.625 0 .573 r
.41885 .84006 m .39856 .84567 L p .4066 .82962 L F P
0 0 0 r
s
.1 0 .485 r
.46115 .30741 m .46155 .29009 L .4821 .28225 L p F P
0 0 0 r
s
.1 0 .485 r
.46155 .29009 m .46115 .30741 L .44065 .31516 L p F P
0 0 0 r
s
.1 0 .485 r
.04412 .68959 m .04708 .66993 L .06597 .66362 L p F P
0 0 0 r
s
.625 .656 0 r
.75505 .84303 m .74651 .84524 L .73683 .83485 L p F P
0 0 0 r
s
.625 .656 0 r
.71519 .8405 m .73683 .83485 L .74651 .84524 L p F P
0 0 0 r
s
.188 0 .528 r
.09145 .81427 m .08876 .83485 L .1032 .84524 L p F P
0 0 0 r
s
.125 0 .956 r
.12232 .83963 m .1032 .84524 L .08876 .83485 L p F P
0 0 0 r
s
.1 0 .485 r
.39856 .36562 m .39934 .34794 L .41965 .34034 L p F P
0 0 0 r
s
.1 0 .485 r
.39934 .34794 m .39856 .36562 L .3783 .37314 L p F P
0 0 0 r
s
.625 0 .573 r
.47168 .8392 m .45117 .84481 L .4393 .83441 L p F P
0 0 0 r
s
.625 0 .573 r
.41885 .84006 m .4393 .83441 L .45117 .84481 L p F P
0 0 0 r
s
0 .78 .12 r
.20157 .8385 m .20816 .84352 L .20427 .84464 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.19448 .8331 m .20157 .8385 L .20427 .84464 L p F P
0 0 0 r
s
0 .78 .71 r
.17499 .83876 m .19448 .8331 L p .20427 .84464 L F P
0 0 0 r
s
.195 0 .31 r
.79608 .52881 m .79441 .50998 L .80367 .52278 L p F P
0 0 0 r
s
.195 0 .31 r
.80367 .52278 m .80538 .54155 L .79608 .52881 L p F P
0 0 0 r
s
.195 0 .31 r
.73915 .35099 m .73783 .33326 L .74751 .34736 L p F P
0 0 0 r
s
.195 0 .31 r
.74751 .34736 m .74887 .36504 L .73915 .35099 L p F P
0 0 0 r
s
.1 0 .485 r
.33593 .42388 m .33709 .40583 L .35716 .39846 L p F P
0 0 0 r
s
.1 0 .485 r
.33709 .40583 m .33593 .42388 L .31591 .43117 L p F P
0 0 0 r
s
.195 0 .31 r
.68222 .17317 m .68125 .15654 L .69134 .17194 L p F P
0 0 0 r
s
.195 0 .31 r
.69134 .17194 m .69236 .18854 L .68222 .17317 L p F P
0 0 0 r
s
0 .647 .956 r
.16647 .84124 m .15565 .84438 L .14158 .83397 L p F P
0 0 0 r
s
0 .647 .956 r
.12833 .83787 m .14158 .83397 L .15565 .84438 L p F P
0 0 0 r
s
.195 0 .31 r
.85301 .70663 m .85099 .68671 L .85983 .6982 L p F P
0 0 0 r
s
.195 0 .31 r
.85983 .6982 m .86189 .71805 L .85301 .70663 L p F P
0 0 0 r
s
0 .78 .12 r
.82126 .83876 m .79935 .84438 L .79006 .83397 L p F P
0 0 0 r
s
0 .78 .12 r
.78694 .83478 m .79006 .83397 L .79935 .84438 L p F P
0 0 0 r
s
.625 0 .573 r
.52458 .83833 m .50384 .84395 L .49236 .83354 L p F P
0 0 0 r
s
.625 0 .573 r
.47168 .8392 m .49236 .83354 L .50384 .84395 L p F P
0 0 0 r
s
.1 0 .485 r
.27325 .48217 m .27481 .46376 L .29463 .45661 L p F P
0 0 0 r
s
.1 0 .485 r
.27481 .46376 m .27325 .48217 L .25348 .48923 L p F P
0 0 0 r
s
.1 0 .485 r
.62809 .15783 m .62747 .14141 L .64871 .13297 L p F P
0 0 0 r
s
.1 0 .485 r
.62747 .14141 m .62809 .15783 L .60689 .16619 L p F P
0 0 0 r
s
.1 0 .485 r
.21054 .54049 m .21248 .52172 L .23206 .5148 L p F P
0 0 0 r
s
.1 0 .485 r
.21248 .52172 m .21054 .54049 L .19101 .54732 L p F P
0 0 0 r
s
0 .78 .12 r
.20816 .84352 m .20157 .8385 L .19982 .83155 L p F P
0 0 0 r
s
0 .78 .12 r
.22772 .83789 m .20816 .84352 L p .19982 .83155 L F P
0 0 0 r
s
.188 0 .528 r
.08876 .83485 m .09145 .81427 L .0769 .80363 L p F P
0 0 0 r
s
.188 0 .528 r
.07966 .78321 m .0769 .80363 L .09145 .81427 L p F P
0 0 0 r
s
0 .78 .71 r
.85354 .84319 m .85225 .84352 L .84335 .8331 L p F P
0 0 0 r
s
0 .78 .71 r
.82157 .83868 m .84335 .8331 L .85225 .84352 L p F P
0 0 0 r
s
.625 0 .573 r
.63057 .83659 m .64532 .83267 L .65413 .84351 L p F P
0 0 0 r
s
.625 .201 0 r
.66226 .84136 m .65413 .84351 L .64532 .83267 L p F P
0 0 0 r
s
0 .78 .71 r
.84335 .8331 m .84599 .83242 L .85354 .84319 L p F P
0 0 0 r
s
0 .647 .956 r
.87439 .83789 m .85354 .84319 L .84599 .83242 L p F P
0 0 0 r
s
.1 0 .485 r
.56547 .21608 m .56523 .19929 L .58623 .19108 L p F P
0 0 0 r
s
.1 0 .485 r
.56523 .19929 m .56547 .21608 L .54452 .2242 L p F P
0 0 0 r
s
.1 0 .485 r
.14779 .59885 m .15012 .57972 L .16945 .57303 L p F P
0 0 0 r
s
.1 0 .485 r
.15012 .57972 m .14779 .59885 L .12851 .60545 L p F P
0 0 0 r
s
.625 0 .573 r
.57754 .83746 m .55658 .84309 L .54548 .83266 L p F P
0 0 0 r
s
.625 0 .573 r
.52458 .83833 m .54548 .83266 L .55658 .84309 L p F P
0 0 0 r
s
.625 .656 0 r
.73683 .83485 m .74837 .83183 L .75505 .84303 L p F P
0 0 0 r
s
.511 .78 0 r
.76819 .83963 m .75505 .84303 L .74837 .83183 L p F P
0 0 0 r
s
.625 .201 0 r
.39523 .84285 m .38631 .83528 L .4066 .82962 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.50281 .27436 m .50296 .25721 L .52371 .24923 L p F P
0 0 0 r
s
.1 0 .485 r
.50296 .25721 m .50281 .27436 L .4821 .28225 L p F P
0 0 0 r
s
.1 0 .485 r
.08501 .65725 m .08772 .63775 L .1068 .6313 L p F P
0 0 0 r
s
.1 0 .485 r
.08772 .63775 m .08501 .65725 L .06597 .66362 L p F P
0 0 0 r
s
.195 0 .31 r
.78501 .497 m .78341 .47834 L .79276 .49139 L p F P
0 0 0 r
s
.195 0 .31 r
.79276 .49139 m .79441 .50998 L .78501 .497 L p F P
0 0 0 r
s
.195 0 .31 r
.67101 .14091 m .67011 .12446 L .6803 .14012 L p F P
0 0 0 r
s
.195 0 .31 r
.6803 .14012 m .68125 .15654 L .67101 .14091 L p F P
0 0 0 r
s
.195 0 .31 r
.72801 .31896 m .72676 .3014 L .73653 .31575 L p F P
0 0 0 r
s
.195 0 .31 r
.73653 .31575 m .73783 .33326 L .72801 .31896 L p F P
0 0 0 r
s
.511 .78 0 r
.28052 .83702 m .26073 .84266 L .24743 .83222 L p F P
0 0 0 r
s
.511 .78 0 r
.24093 .83409 m .24743 .83222 L .26073 .84266 L p F P
0 0 0 r
s
.195 0 .31 r
.84201 .67504 m .84006 .65528 L .84899 .66702 L p F P
0 0 0 r
s
.195 0 .31 r
.84899 .66702 m .85099 .68671 L .84201 .67504 L p F P
0 0 0 r
s
.125 0 .956 r
.87615 .83745 m .89671 .83222 L .90522 .84266 L p F P
0 0 0 r
s
.625 0 .573 r
.63057 .83659 m .60939 .84223 L .59867 .83179 L p F P
0 0 0 r
s
.1 0 .485 r
.44012 .33267 m .44065 .31516 L .46115 .30741 L p F P
0 0 0 r
s
.625 0 .573 r
.57754 .83746 m .59867 .83179 L .60939 .84223 L p F P
0 0 0 r
s
.1 0 .485 r
.44065 .31516 m .44012 .33267 L .41965 .34034 L p F P
0 0 0 r
s
.625 .656 0 r
.33338 .83615 m .31337 .84179 L .30046 .83135 L p F P
0 0 0 r
s
.625 .656 0 r
.2847 .83583 m .30046 .83135 L .31337 .84179 L p F P
0 0 0 r
s
.1 0 .485 r
.37738 .39102 m .3783 .37314 L .39856 .36562 L p F P
0 0 0 r
s
.1 0 .485 r
.3783 .37314 m .37738 .39102 L .35716 .39846 L p F P
0 0 0 r
s
.188 0 .528 r
.0769 .80363 m .07966 .78321 L .065 .77233 L p F P
0 0 0 r
s
.188 0 .528 r
.06784 .75208 m .065 .77233 L .07966 .78321 L p F P
0 0 0 r
s
.625 .201 0 r
.68367 .83572 m .70371 .83044 L .71087 .84163 L p F P
0 0 0 r
s
.625 .656 0 r
.71519 .8405 m .71087 .84163 L .70371 .83044 L p F P
0 0 0 r
s
.625 .201 0 r
.68367 .83572 m .66226 .84136 L .65193 .83091 L p F P
0 0 0 r
s
.625 .201 0 r
.64532 .83267 m .65193 .83091 L .66226 .84136 L p F P
0 0 0 r
s
.1 0 .485 r
.3146 .44941 m .31591 .43117 L .33593 .42388 L p F P
0 0 0 r
s
.1 0 .485 r
.31591 .43117 m .3146 .44941 L .29463 .45661 L p F P
0 0 0 r
s
0 .78 .71 r
.17499 .83876 m .16647 .84124 L .15928 .82878 L p F P
0 0 0 r
s
0 .647 .956 r
.14158 .83397 m .15928 .82878 L .16647 .84124 L p F P
0 0 0 r
s
.195 0 .31 r
.83099 .64337 m .8291 .62378 L .83813 .63577 L p F P
0 0 0 r
s
.195 0 .31 r
.83813 .63577 m .84006 .65528 L .83099 .64337 L p F P
0 0 0 r
s
.1 0 .485 r
.66923 .10821 m .67011 .12446 L .64871 .13297 L p F P
0 0 0 r
s
.1 0 .485 r
.25179 .50783 m .25348 .48923 L .27325 .48217 L p F P
0 0 0 r
s
.1 0 .485 r
.25348 .48923 m .25179 .50783 L .23206 .5148 L p F P
0 0 0 r
s
.195 0 .31 r
.71685 .28684 m .71567 .26946 L .72553 .28407 L p F P
0 0 0 r
s
.195 0 .31 r
.72553 .28407 m .72676 .3014 L .71685 .28684 L p F P
0 0 0 r
s
.625 .201 0 r
.38631 .83528 m .36608 .84093 L .35354 .83047 L p F P
0 0 0 r
s
.625 .201 0 r
.33514 .83566 m .35354 .83047 L .36608 .84093 L p F P
0 0 0 r
s
.195 0 .31 r
.88806 .82163 m .88582 .80094 L .89443 .81162 L p F P
0 0 0 r
s
.195 0 .31 r
.89443 .81162 m .89671 .83222 L .88806 .82163 L p F P
0 0 0 r
s
.195 0 .31 r
.77392 .4651 m .77239 .44662 L .78183 .45992 L p F P
0 0 0 r
s
.195 0 .31 r
.78183 .45992 m .78341 .47834 L .77392 .4651 L p F P
0 0 0 r
s
.625 .656 0 r
.73683 .83485 m .71519 .8405 L .70525 .83003 L p F P
0 0 0 r
s
.625 .656 0 r
.70371 .83044 m .70525 .83003 L .71519 .8405 L p F P
0 0 0 r
s
.1 0 .485 r
.18894 .56629 m .19101 .54732 L .21054 .54049 L p F P
0 0 0 r
s
.1 0 .485 r
.19101 .54732 m .18894 .56629 L .16945 .57303 L p F P
0 0 0 r
s
.1 0 .485 r
.60739 .1828 m .60689 .16619 L .62809 .15783 L p F P
0 0 0 r
s
.1 0 .485 r
.60689 .16619 m .60739 .1828 L .58623 .19108 L p F P
0 0 0 r
s
0 .78 .12 r
.82251 .84019 m .82126 .83876 L .82157 .83868 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.12605 .62479 m .12851 .60545 L .14779 .59885 L p F P
0 0 0 r
s
.1 0 .485 r
.12851 .60545 m .12605 .62479 L .1068 .6313 L p F P
0 0 0 r
s
.625 0 .573 r
.4393 .83441 m .41885 .84006 L .4067 .82959 L p F P
0 0 0 r
s
.625 0 .573 r
.4066 .82962 m .4067 .82959 L .41885 .84006 L p F P
0 0 0 r
s
.188 0 .528 r
.065 .77233 m .06784 .75208 L .05308 .74096 L p F P
0 0 0 r
s
.188 0 .528 r
.056 .72088 m .05308 .74096 L .06784 .75208 L p F P
0 0 0 r
s
.1 0 .485 r
.54463 .24118 m .54452 .2242 L .56547 .21608 L p F P
0 0 0 r
s
.1 0 .485 r
.54452 .2242 m .54463 .24118 L .52371 .24923 L p F P
0 0 0 r
s
.511 .78 0 r
.28411 .83989 m .28052 .83702 L .2847 .83583 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.78694 .83478 m .76819 .83963 L .75864 .82915 L p F P
0 0 0 r
s
.511 .78 0 r
.74837 .83183 m .75864 .82915 L .76819 .83963 L p F P
0 0 0 r
s
.1 0 .485 r
.48183 .29959 m .4821 .28225 L .50281 .27436 L p F P
0 0 0 r
s
.1 0 .485 r
.4821 .28225 m .48183 .29959 L .46115 .30741 L p F P
0 0 0 r
s
.125 0 .956 r
.12833 .83787 m .12232 .83963 L .10796 .82915 L p F P
0 0 0 r
s
.1 0 .485 r
.06311 .68332 m .06597 .66362 L .08501 .65725 L p F P
0 0 0 r
s
.125 0 .956 r
.08876 .83485 m .10796 .82915 L .12232 .83963 L p F P
0 0 0 r
s
.1 0 .485 r
.06597 .66362 m .06311 .68332 L .04412 .68959 L p F P
0 0 0 r
s
.195 0 .31 r
.81994 .61162 m .81812 .59221 L .82724 .60444 L p F P
0 0 0 r
s
.195 0 .31 r
.82724 .60444 m .8291 .62378 L .81994 .61162 L p F P
0 0 0 r
s
.195 0 .31 r
.7628 .43313 m .76133 .41483 L .77087 .42837 L p F P
0 0 0 r
s
.195 0 .31 r
.77087 .42837 m .77239 .44662 L .7628 .43313 L p F P
0 0 0 r
s
.195 0 .31 r
.70566 .25464 m .70454 .23745 L .7145 .2523 L p F P
0 0 0 r
s
.195 0 .31 r
.7145 .2523 m .71567 .26946 L .70566 .25464 L p F P
0 0 0 r
s
.1 0 .485 r
.41899 .35804 m .41965 .34034 L .44012 .33267 L p F P
0 0 0 r
s
.1 0 .485 r
.41965 .34034 m .41899 .35804 L .39856 .36562 L p F P
0 0 0 r
s
.625 0 .573 r
.49236 .83354 m .47168 .8392 L .45992 .82871 L p F P
0 0 0 r
s
.625 0 .573 r
.4393 .83441 m .45992 .82871 L .47168 .8392 L p F P
0 0 0 r
s
.195 0 .31 r
.87709 .7901 m .87491 .76958 L .88361 .78051 L p F P
0 0 0 r
s
.195 0 .31 r
.88361 .78051 m .88582 .80094 L .87709 .7901 L p F P
0 0 0 r
s
0 .78 .12 r
.82157 .83868 m .82126 .83876 L .8121 .82827 L p F P
0 0 0 r
s
0 .78 .12 r
.79006 .83397 m .8121 .82827 L .82126 .83876 L p F P
0 0 0 r
s
.1 0 .485 r
.35611 .41653 m .35716 .39846 L .37738 .39102 L p F P
0 0 0 r
s
.1 0 .485 r
.35716 .39846 m .35611 .41653 L .33593 .42388 L p F P
0 0 0 r
s
0 .78 .71 r
.19448 .8331 m .17499 .83876 L .16101 .82827 L p F P
0 0 0 r
s
0 .78 .71 r
.15928 .82878 m .16101 .82827 L .17499 .83876 L p F P
0 0 0 r
s
0 .78 .12 r
.8121 .82827 m .8141 .82775 L .82157 .83868 L p F P
0 0 0 r
s
0 .78 .71 r
.84335 .8331 m .82157 .83868 L .8141 .82775 L p F P
0 0 0 r
s
0 .78 .71 r
.20157 .8385 m .19448 .8331 L .19982 .83155 L closepath p F P
0 0 0 r
s
.625 0 .573 r
.54548 .83266 m .52458 .83833 L .5132 .82783 L p F P
0 0 0 r
s
.625 0 .573 r
.49236 .83354 m .5132 .82783 L .52458 .83833 L p F P
0 0 0 r
s
.1 0 .485 r
.29319 .47505 m .29463 .45661 L .3146 .44941 L p F P
0 0 0 r
s
.1 0 .485 r
.29463 .45661 m .29319 .47505 L .27325 .48217 L p F P
0 0 0 r
s
.188 0 .528 r
.05308 .74096 m .056 .72088 L .04113 .7095 L p F P
0 0 0 r
s
.188 0 .528 r
.04412 .68959 m .04113 .7095 L .056 .72088 L p F P
0 0 0 r
s
.1 0 .485 r
.64947 .14941 m .64871 .13297 L .67011 .12446 L p F P
0 0 0 r
s
.1 0 .485 r
.64871 .13297 m .64947 .14941 L .62809 .15783 L p F P
0 0 0 r
s
.1 0 .485 r
.23023 .53361 m .23206 .5148 L .25179 .50783 L p F P
0 0 0 r
s
.1 0 .485 r
.23206 .5148 m .23023 .53361 L .21054 .54049 L p F P
0 0 0 r
s
0 .78 .12 r
.24093 .83409 m .22772 .83789 L .21412 .82739 L p F P
0 0 0 r
s
0 .78 .12 r
.19982 .83155 m .21412 .82739 L .22772 .83789 L p F P
0 0 0 r
s
0 .647 .956 r
.87615 .83745 m .87439 .83789 L .86562 .82739 L p F P
0 0 0 r
s
0 .647 .956 r
.84599 .83242 m .86562 .82739 L .87439 .83789 L p F P
0 0 0 r
s
0 .647 .956 r
.14158 .83397 m .12833 .83787 L .11821 .82611 L p F P
0 0 0 r
s
.125 0 .956 r
.10796 .82915 m .11821 .82611 L .12833 .83787 L p F P
0 0 0 r
s
.1 0 .485 r
.16724 .59221 m .16945 .57303 L .18894 .56629 L p F P
0 0 0 r
s
.1 0 .485 r
.16945 .57303 m .16724 .59221 L .14779 .59885 L p F P
0 0 0 r
s
.195 0 .31 r
.80887 .57979 m .80711 .56055 L .81632 .57303 L p F P
0 0 0 r
s
.195 0 .31 r
.81632 .57303 m .81812 .59221 L .80887 .57979 L p F P
0 0 0 r
s
.195 0 .31 r
.75165 .40108 m .75025 .38295 L .75988 .39675 L p F P
0 0 0 r
s
.195 0 .31 r
.75988 .39675 m .76133 .41483 L .75165 .40108 L p F P
0 0 0 r
s
.195 0 .31 r
.69444 .22237 m .69339 .20535 L .70345 .22046 L p F P
0 0 0 r
s
.195 0 .31 r
.70345 .22046 m .70454 .23745 L .69444 .22237 L p F P
0 0 0 r
s
.1 0 .485 r
.5866 .20788 m .58623 .19108 L .60739 .1828 L p F P
0 0 0 r
s
.1 0 .485 r
.58623 .19108 m .5866 .20788 L .56547 .21608 L p F P
0 0 0 r
s
.625 0 .573 r
.59867 .83179 m .57754 .83746 L .56655 .82695 L p F P
0 0 0 r
s
.625 0 .573 r
.54548 .83266 m .56655 .82695 L .57754 .83746 L p F P
0 0 0 r
s
.195 0 .31 r
.86608 .7585 m .86397 .73815 L .87276 .74932 L p F P
0 0 0 r
s
.195 0 .31 r
.87276 .74932 m .87491 .76958 L .86608 .7585 L p F P
0 0 0 r
s
0 .647 .956 r
.86562 .82739 m .86797 .82679 L .87615 .83745 L p F P
0 0 0 r
s
.125 0 .956 r
.89671 .83222 m .87615 .83745 L .86797 .82679 L p F P
0 0 0 r
s
.625 .656 0 r
.3345 .83707 m .33338 .83615 L .33514 .83566 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.52369 .2664 m .52371 .24923 L .54463 .24118 L p F P
0 0 0 r
s
.1 0 .485 r
.52371 .24923 m .52369 .2664 L .50281 .27436 L p F P
0 0 0 r
s
.1 0 .485 r
.1042 .65084 m .1068 .6313 L .12605 .62479 L p F P
0 0 0 r
s
.1 0 .485 r
.1068 .6313 m .1042 .65084 L .08501 .65725 L p F P
0 0 0 r
s
.511 .78 0 r
.2847 .83583 m .28052 .83702 L .26731 .82651 L p F P
0 0 0 r
s
.511 .78 0 r
.24743 .83222 m .26731 .82651 L .28052 .83702 L p F P
0 0 0 r
s
.625 0 .573 r
.64532 .83267 m .63057 .83659 L .61997 .82606 L p F P
0 0 0 r
s
.1 0 .485 r
.46075 .32494 m .46115 .30741 L .48183 .29959 L p F P
0 0 0 r
s
.625 0 .573 r
.59867 .83179 m .61997 .82606 L .63057 .83659 L p F P
0 0 0 r
s
.1 0 .485 r
.46115 .30741 m .46075 .32494 L .44012 .33267 L p F P
0 0 0 r
s
.1 0 .485 r
.04113 .7095 m .04412 .68959 L .06311 .68332 L p F P
0 0 0 r
s
.1 0 .485 r
.39777 .38353 m .39856 .36562 L .41899 .35804 L p F P
0 0 0 r
s
.1 0 .485 r
.39856 .36562 m .39777 .38353 L .37738 .39102 L p F P
0 0 0 r
s
.625 .656 0 r
.33514 .83566 m .33338 .83615 L .32056 .82562 L p F P
0 0 0 r
s
.625 .656 0 r
.30046 .83135 m .32056 .82562 L .33338 .83615 L p F P
0 0 0 r
s
.625 .656 0 r
.29012 .82299 m .30046 .83135 L .2847 .83583 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.28734 .82074 m .29012 .82299 L .2847 .83583 L p F P
0 0 0 r
s
.511 .78 0 r
.26731 .82651 m .28734 .82074 L p .2847 .83583 L F P
0 0 0 r
s
.195 0 .31 r
.79776 .54788 m .79608 .52881 L .80538 .54155 L p F P
0 0 0 r
s
.195 0 .31 r
.80538 .54155 m .80711 .56055 L .79776 .54788 L p F P
0 0 0 r
s
.195 0 .31 r
.74048 .36894 m .73915 .35099 L .74887 .36504 L p F P
0 0 0 r
s
.195 0 .31 r
.74887 .36504 m .75025 .38295 L .74048 .36894 L p F P
0 0 0 r
s
.195 0 .31 r
.68319 .19001 m .68222 .17317 L .69236 .18854 L p F P
0 0 0 r
s
.195 0 .31 r
.69236 .18854 m .69339 .20535 L .68319 .19001 L p F P
0 0 0 r
s
.1 0 .485 r
.33474 .44215 m .33593 .42388 L .35611 .41653 L p F P
0 0 0 r
s
.1 0 .485 r
.33593 .42388 m .33474 .44215 L .3146 .44941 L p F P
0 0 0 r
s
.195 0 .31 r
.85505 .72681 m .85301 .70663 L .86189 .71805 L p F P
0 0 0 r
s
.195 0 .31 r
.86189 .71805 m .86397 .73815 L .85505 .72681 L p F P
0 0 0 r
s
.625 .201 0 r
.70371 .83044 m .68367 .83572 L .67346 .82518 L p F P
0 0 0 r
s
.625 .201 0 r
.65193 .83091 m .67346 .82518 L .68367 .83572 L p F P
0 0 0 r
s
.625 .201 0 r
.34452 .82294 m .35354 .83047 L .33514 .83566 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.34082 .81985 m .34452 .82294 L .33514 .83566 L p F P
0 0 0 r
s
.625 .656 0 r
.32056 .82562 m .34082 .81985 L p .33514 .83566 L F P
0 0 0 r
s
.1 0 .485 r
.27168 .50081 m .27325 .48217 L .29319 .47505 L p F P
0 0 0 r
s
.1 0 .485 r
.27325 .48217 m .27168 .50081 L .25179 .50783 L p F P
0 0 0 r
s
.625 .201 0 r
.4066 .82962 m .38631 .83528 L .37387 .82474 L p F P
0 0 0 r
s
.625 .201 0 r
.35354 .83047 m .37387 .82474 L .38631 .83528 L p F P
0 0 0 r
s
.1 0 .485 r
.20858 .5595 m .21054 .54049 L .23023 .53361 L p F P
0 0 0 r
s
.1 0 .485 r
.21054 .54049 m .20858 .5595 L .18894 .56629 L p F P
0 0 0 r
s
.188 0 .528 r
.0769 .80363 m .0741 .8243 L .08876 .83485 L p F P
0 0 0 r
s
.125 0 .956 r
.10796 .82915 m .08876 .83485 L .0741 .8243 L p F P
0 0 0 r
s
.1 0 .485 r
.62873 .17446 m .62809 .15783 L .64947 .14941 L p F P
0 0 0 r
s
.1 0 .485 r
.62809 .15783 m .62873 .17446 L .60739 .1828 L p F P
0 0 0 r
s
.625 .656 0 r
.74837 .83183 m .73683 .83485 L .72701 .8243 L p F P
0 0 0 r
s
.625 .656 0 r
.70525 .83003 m .72701 .8243 L .73683 .83485 L p F P
0 0 0 r
s
.511 .78 0 r
.75864 .82915 m .77951 .8237 L .78694 .83478 L p F P
0 0 0 r
s
0 .78 .12 r
.79006 .83397 m .78694 .83478 L .77951 .8237 L p F P
0 0 0 r
s
.1 0 .485 r
.14544 .61823 m .14779 .59885 L .16724 .59221 L p F P
0 0 0 r
s
.1 0 .485 r
.14779 .59885 m .14544 .61823 L .12605 .62479 L p F P
0 0 0 r
s
.1 0 .485 r
.56572 .23307 m .56547 .21608 L .5866 .20788 L p F P
0 0 0 r
s
.1 0 .485 r
.56547 .21608 m .56572 .23307 L .54463 .24118 L p F P
0 0 0 r
s
.625 0 .573 r
.45992 .82871 m .4393 .83441 L .42725 .82385 L p F P
0 0 0 r
s
.625 0 .573 r
.4067 .82959 m .42725 .82385 L .4393 .83441 L p F P
0 0 0 r
s
.511 .78 0 r
.24167 .8277 m .24743 .83222 L .24093 .83409 L closepath p F P
0 0 0 r
s
0 .78 .12 r
.23393 .82163 m .24167 .8277 L .24093 .83409 L p F P
0 0 0 r
s
0 .78 .12 r
.21412 .82739 m .23393 .82163 L p .24093 .83409 L F P
0 0 0 r
s
.195 0 .31 r
.78663 .51589 m .78501 .497 L .79441 .50998 L p F P
0 0 0 r
s
.195 0 .31 r
.79441 .50998 m .79608 .52881 L .78663 .51589 L p F P
0 0 0 r
s
.1 0 .485 r
.50267 .29172 m .50281 .27436 L .52369 .2664 L p F P
0 0 0 r
s
.1 0 .485 r
.50281 .27436 m .50267 .29172 L .48183 .29959 L p F P
0 0 0 r
s
.195 0 .31 r
.84399 .69505 m .84201 .67504 L .85099 .68671 L p F P
0 0 0 r
s
.195 0 .31 r
.85099 .68671 m .85301 .70663 L .84399 .69505 L p F P
0 0 0 r
s
.195 0 .31 r
.72928 .33673 m .72801 .31896 L .73783 .33326 L p F P
0 0 0 r
s
.195 0 .31 r
.73783 .33326 m .73915 .35099 L .72928 .33673 L p F P
0 0 0 r
s
.195 0 .31 r
.67192 .15757 m .67101 .14091 L .68125 .15654 L p F P
0 0 0 r
s
.195 0 .31 r
.68125 .15654 m .68222 .17317 L .67192 .15757 L p F P
0 0 0 r
s
0 .78 .12 r
.8121 .82827 m .79006 .83397 L .78063 .82341 L p F P
0 0 0 r
s
0 .78 .12 r
.77951 .8237 m .78063 .82341 L .79006 .83397 L p F P
0 0 0 r
s
0 .647 .956 r
.15928 .82878 m .14158 .83397 L .12731 .82341 L p F P
0 0 0 r
s
.1 0 .485 r
.08226 .677 m .08501 .65725 L .1042 .65084 L p F P
0 0 0 r
s
0 .647 .956 r
.11821 .82611 m .12731 .82341 L .14158 .83397 L p F P
0 0 0 r
s
.1 0 .485 r
.08501 .65725 m .08226 .677 L .06311 .68332 L p F P
0 0 0 r
s
.1 0 .485 r
.43958 .3504 m .44012 .33267 L .46075 .32494 L p F P
0 0 0 r
s
.1 0 .485 r
.44012 .33267 m .43958 .3504 L .41899 .35804 L p F P
0 0 0 r
s
.625 0 .573 r
.5132 .82783 m .49236 .83354 L .4807 .82297 L p F P
0 0 0 r
s
.625 0 .573 r
.45992 .82871 m .4807 .82297 L .49236 .83354 L p F P
0 0 0 r
s
.1 0 .485 r
.37645 .40912 m .37738 .39102 L .39777 .38353 L p F P
0 0 0 r
s
.1 0 .485 r
.37738 .39102 m .37645 .40912 L .35611 .41653 L p F P
0 0 0 r
s
0 .78 .71 r
.19982 .83155 m .19448 .8331 L .18059 .82252 L p F P
0 0 0 r
s
0 .78 .71 r
.16101 .82827 m .18059 .82252 L .19448 .8331 L p F P
0 0 0 r
s
.188 0 .528 r
.0741 .8243 m .0769 .80363 L .06213 .79283 L p F P
0 0 0 r
s
.188 0 .528 r
.065 .77233 m .06213 .79283 L .0769 .80363 L p F P
0 0 0 r
s
0 .78 .71 r
.84599 .83242 m .84335 .8331 L .83431 .82252 L p F P
0 0 0 r
s
0 .78 .71 r
.8141 .82775 m .83431 .82252 L .84335 .8331 L p F P
0 0 0 r
s
.625 0 .573 r
.61997 .82606 m .63322 .82251 L .64532 .83267 L p F P
0 0 0 r
s
.625 .201 0 r
.65193 .83091 m .64532 .83267 L .63322 .82251 L p F P
0 0 0 r
s
.1 0 .485 r
.31329 .46788 m .3146 .44941 L .33474 .44215 L p F P
0 0 0 r
s
.1 0 .485 r
.3146 .44941 m .31329 .46788 L .29319 .47505 L p F P
0 0 0 r
s
.625 0 .573 r
.56655 .82695 m .54548 .83266 L .53422 .82208 L p F P
0 0 0 r
s
.625 0 .573 r
.5132 .82783 m .53422 .82208 L .54548 .83266 L p F P
0 0 0 r
s
0 .78 .71 r
.83431 .82252 m .83794 .82158 L .84599 .83242 L p F P
0 0 0 r
s
0 .647 .956 r
.86562 .82739 m .84599 .83242 L .83794 .82158 L p F P
0 0 0 r
s
.1 0 .485 r
.67011 .12446 m .67101 .14091 L .64947 .14941 L p F P
0 0 0 r
s
.1 0 .485 r
.25008 .52667 m .25179 .50783 L .27168 .50081 L p F P
0 0 0 r
s
.1 0 .485 r
.25179 .50783 m .25008 .52667 L .23023 .53361 L p F P
0 0 0 r
s
.511 .78 0 r
.24743 .83222 m .24167 .8277 L .24532 .81832 L p F P
0 0 0 r
s
.511 .78 0 r
.26731 .82651 m .24743 .83222 L p .24532 .81832 L F P
0 0 0 r
s
.195 0 .31 r
.8329 .6632 m .83099 .64337 L .84006 .65528 L p F P
0 0 0 r
s
.195 0 .31 r
.84006 .65528 m .84201 .67504 L .8329 .6632 L p F P
0 0 0 r
s
.195 0 .31 r
.77547 .48382 m .77392 .4651 L .78341 .47834 L p F P
0 0 0 r
s
.195 0 .31 r
.78341 .47834 m .78501 .497 L .77547 .48382 L p F P
0 0 0 r
s
.195 0 .31 r
.71804 .30444 m .71685 .28684 L .72676 .3014 L p F P
0 0 0 r
s
.195 0 .31 r
.72676 .3014 m .72801 .31896 L .71804 .30444 L p F P
0 0 0 r
s
.125 0 .956 r
.86797 .82679 m .88806 .82163 L .89671 .83222 L p F P
0 0 0 r
s
.625 .656 0 r
.72701 .8243 m .74032 .82079 L .74837 .83183 L p F P
0 0 0 r
s
.511 .78 0 r
.75864 .82915 m .74837 .83183 L .74032 .82079 L p F P
0 0 0 r
s
.1 0 .485 r
.6079 .19962 m .60739 .1828 L .62873 .17446 L p F P
0 0 0 r
s
.1 0 .485 r
.60739 .1828 m .6079 .19962 L .5866 .20788 L p F P
0 0 0 r
s
.625 0 .573 r
.61997 .82606 m .59867 .83179 L .5878 .82119 L p F P
0 0 0 r
s
.625 0 .573 r
.56655 .82695 m .5878 .82119 L .59867 .83179 L p F P
0 0 0 r
s
.1 0 .485 r
.18684 .5855 m .18894 .56629 L .20858 .5595 L p F P
0 0 0 r
s
.1 0 .485 r
.18894 .56629 m .18684 .5855 L .16724 .59221 L p F P
0 0 0 r
s
0 .78 .12 r
.20072 .81703 m .21412 .82739 L .19982 .83155 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.20033 .81673 m .20072 .81703 L .19982 .83155 L p F P
0 0 0 r
s
0 .78 .71 r
.18059 .82252 m .20033 .81673 L p .19982 .83155 L F P
0 0 0 r
s
.1 0 .485 r
.54474 .25837 m .54463 .24118 L .56572 .23307 L p F P
0 0 0 r
s
.1 0 .485 r
.54463 .24118 m .54474 .25837 L .52369 .2664 L p F P
0 0 0 r
s
.1 0 .485 r
.12355 .64437 m .12605 .62479 L .14544 .61823 L p F P
0 0 0 r
s
.1 0 .485 r
.12605 .62479 m .12355 .64437 L .1042 .65084 L p F P
0 0 0 r
s
.625 .656 0 r
.30046 .83135 m .29012 .82299 L .29287 .81915 L p F P
0 0 0 r
s
.625 .656 0 r
.32056 .82562 m .30046 .83135 L p .29287 .81915 L F P
0 0 0 r
s
.188 0 .528 r
.06213 .79283 m .065 .77233 L .05013 .76128 L p F P
0 0 0 r
s
.188 0 .528 r
.05308 .74096 m .05013 .76128 L .065 .77233 L p F P
0 0 0 r
s
.1 0 .485 r
.48155 .31715 m .48183 .29959 L .50267 .29172 L p F P
0 0 0 r
s
.1 0 .485 r
.48183 .29959 m .48155 .31715 L .46075 .32494 L p F P
0 0 0 r
s
.625 .201 0 r
.67346 .82518 m .65193 .83091 L .64145 .8203 L p F P
0 0 0 r
s
.625 .201 0 r
.63322 .82251 m .64145 .8203 L .65193 .83091 L p F P
0 0 0 r
s
.1 0 .485 r
.06023 .70327 m .06311 .68332 L .08226 .677 L p F P
0 0 0 r
s
.1 0 .485 r
.06311 .68332 m .06023 .70327 L .04113 .7095 L p F P
0 0 0 r
s
.625 .201 0 r
.35354 .83047 m .34452 .82294 L .351 .81695 L p F P
0 0 0 r
s
.625 .201 0 r
.37387 .82474 m .35354 .83047 L p .351 .81695 L F P
0 0 0 r
s
.195 0 .31 r
.82179 .63127 m .81994 .61162 L .8291 .62378 L p F P
0 0 0 r
s
.195 0 .31 r
.8291 .62378 m .83099 .64337 L .82179 .63127 L p F P
0 0 0 r
s
.195 0 .31 r
.76429 .45167 m .7628 .43313 L .77239 .44662 L p F P
0 0 0 r
s
.195 0 .31 r
.77239 .44662 m .77392 .4651 L .76429 .45167 L p F P
0 0 0 r
s
.1 0 .485 r
.41832 .37597 m .41899 .35804 L .43958 .3504 L p F P
0 0 0 r
s
.1 0 .485 r
.41899 .35804 m .41832 .37597 L .39777 .38353 L p F P
0 0 0 r
s
.195 0 .31 r
.87929 .81088 m .87709 .7901 L .88582 .80094 L p F P
0 0 0 r
s
.195 0 .31 r
.88582 .80094 m .88806 .82163 L .87929 .81088 L p F P
0 0 0 r
s
.195 0 .31 r
.70678 .27206 m .70566 .25464 L .71567 .26946 L p F P
0 0 0 r
s
.195 0 .31 r
.71567 .26946 m .71685 .28684 L .70678 .27206 L p F P
0 0 0 r
s
.625 .201 0 r
.67346 .82518 m .69454 .81957 L .70371 .83044 L p F P
0 0 0 r
s
.625 .656 0 r
.70525 .83003 m .70371 .83044 L .69454 .81957 L p F P
0 0 0 r
s
.625 .656 0 r
.72701 .8243 m .70525 .83003 L .69516 .81941 L p F P
0 0 0 r
s
.625 .656 0 r
.69454 .81957 m .69516 .81941 L .70525 .83003 L p F P
0 0 0 r
s
.1 0 .485 r
.35505 .43483 m .35611 .41653 L .37645 .40912 L p F P
0 0 0 r
s
.1 0 .485 r
.35611 .41653 m .35505 .43483 L .33474 .44215 L p F P
0 0 0 r
s
.625 0 .573 r
.40666 .82956 m .4067 .82959 L .4066 .82962 L closepath p F P
0 0 0 r
s
.625 .201 0 r
.39436 .81896 m .40666 .82956 L .4066 .82962 L p F P
0 0 0 r
s
.625 .201 0 r
.37387 .82474 m .39436 .81896 L p .4066 .82962 L F P
0 0 0 r
s
.625 0 .573 r
.4067 .82959 m .40666 .82956 L .42246 .81965 L p F P
0 0 0 r
s
.625 0 .573 r
.42246 .81965 m .42725 .82385 L .4067 .82959 L p F P
0 0 0 r
s
.1 0 .485 r
.29174 .49372 m .29319 .47505 L .31329 .46788 L p F P
0 0 0 r
s
.1 0 .485 r
.29319 .47505 m .29174 .49372 L .27168 .50081 L p F P
0 0 0 r
s
.188 0 .528 r
.05013 .76128 m .05308 .74096 L .0381 .72966 L p F P
0 0 0 r
s
.188 0 .528 r
.04113 .7095 m .0381 .72966 L .05308 .74096 L p F P
0 0 0 r
s
.625 .201 0 r
.41502 .81314 m .42246 .81965 L .40666 .82956 L p F P
0 0 0 r
s
.625 .201 0 r
.40666 .82956 m .39436 .81896 L .41502 .81314 L p F P
0 0 0 r
s
.1 0 .485 r
.22838 .55265 m .23023 .53361 L .25008 .52667 L p F P
0 0 0 r
s
.1 0 .485 r
.23023 .53361 m .22838 .55265 L .20858 .5595 L p F P
0 0 0 r
s
.1 0 .485 r
.65023 .16605 m .64947 .14941 L .67101 .14091 L p F P
0 0 0 r
s
.1 0 .485 r
.64947 .14941 m .65023 .16605 L .62873 .17446 L p F P
0 0 0 r
s
.125 0 .956 r
.11821 .82611 m .10796 .82915 L .09338 .81851 L p F P
0 0 0 r
s
.125 0 .956 r
.0741 .8243 m .09338 .81851 L .10796 .82915 L p F P
0 0 0 r
s
.511 .78 0 r
.77951 .8237 m .75864 .82915 L .74894 .81851 L p F P
0 0 0 r
s
.511 .78 0 r
.74032 .82079 m .74894 .81851 L .75864 .82915 L p F P
0 0 0 r
s
0 .78 .71 r
.1584 .82631 m .16101 .82827 L .15928 .82878 L closepath p F P
0 0 0 r
s
0 .647 .956 r
.14682 .81762 m .1584 .82631 L .15928 .82878 L p F P
0 0 0 r
s
0 .647 .956 r
.12731 .82341 m .14682 .81762 L p .15928 .82878 L F P
0 0 0 r
s
.1 0 .485 r
.16499 .61162 m .16724 .59221 L .18684 .5855 L p F P
0 0 0 r
s
.1 0 .485 r
.16724 .59221 m .16499 .61162 L .14544 .61823 L p F P
0 0 0 r
s
.195 0 .31 r
.81065 .59927 m .80887 .57979 L .81812 .59221 L p F P
0 0 0 r
s
.195 0 .31 r
.81812 .59221 m .81994 .61162 L .81065 .59927 L p F P
0 0 0 r
s
.195 0 .31 r
.6955 .2396 m .69444 .22237 L .70454 .23745 L p F P
0 0 0 r
s
.195 0 .31 r
.70454 .23745 m .70566 .25464 L .6955 .2396 L p F P
0 0 0 r
s
.625 0 .573 r
.4807 .82297 m .45992 .82871 L .44798 .81807 L p F P
0 0 0 r
s
.625 0 .573 r
.42725 .82385 m .44798 .81807 L .45992 .82871 L p F P
0 0 0 r
s
.195 0 .31 r
.86822 .7791 m .86608 .7585 L .87491 .76958 L p F P
0 0 0 r
s
.195 0 .31 r
.87491 .76958 m .87709 .7901 L .86822 .7791 L p F P
0 0 0 r
s
.195 0 .31 r
.75307 .41944 m .75165 .40108 L .76133 .41483 L p F P
0 0 0 r
s
.195 0 .31 r
.76133 .41483 m .7628 .43313 L .75307 .41944 L p F P
0 0 0 r
s
.1 0 .485 r
.58698 .2249 m .5866 .20788 L .6079 .19962 L p F P
0 0 0 r
s
.1 0 .485 r
.5866 .20788 m .58698 .2249 L .56572 .23307 L p F P
0 0 0 r
s
.1 0 .485 r
.52368 .28378 m .52369 .2664 L .54474 .25837 L p F P
0 0 0 r
s
.1 0 .485 r
.52369 .2664 m .52368 .28378 L .50267 .29172 L p F P
0 0 0 r
s
0 .78 .71 r
.16101 .82827 m .1584 .82631 L .15744 .81447 L p F P
0 0 0 r
s
0 .78 .71 r
.18059 .82252 m .16101 .82827 L p .15744 .81447 L F P
0 0 0 r
s
.1 0 .485 r
.10157 .67062 m .1042 .65084 L .12355 .64437 L p F P
0 0 0 r
s
.1 0 .485 r
.1042 .65084 m .10157 .67062 L .08226 .677 L p F P
0 0 0 r
s
0 .78 .12 r
.8141 .82775 m .8121 .82827 L .80279 .81762 L p F P
0 0 0 r
s
0 .78 .12 r
.78063 .82341 m .80279 .81762 L .8121 .82827 L p F P
0 0 0 r
s
.1 0 .485 r
.46034 .3427 m .46075 .32494 L .48155 .31715 L p F P
0 0 0 r
s
.1 0 .485 r
.46075 .32494 m .46034 .3427 L .43958 .3504 L p F P
0 0 0 r
s
.625 0 .573 r
.53422 .82208 m .5132 .82783 L .50165 .81717 L p F P
0 0 0 r
s
.625 0 .573 r
.4807 .82297 m .50165 .81717 L .5132 .82783 L p F P
0 0 0 r
s
.1 0 .485 r
.0381 .72966 m .04113 .7095 L .06023 .70327 L p F P
0 0 0 r
s
0 .78 .12 r
.80279 .81762 m .80596 .81679 L .8141 .82775 L p F P
0 0 0 r
s
0 .78 .71 r
.83431 .82252 m .8141 .82775 L .80596 .81679 L p F P
0 0 0 r
s
0 .78 .12 r
.24167 .8277 m .23393 .82163 L .24532 .81832 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.39696 .40165 m .39777 .38353 L .41832 .37597 L p F P
0 0 0 r
s
.1 0 .485 r
.39777 .38353 m .39696 .40165 L .37645 .40912 L p F P
0 0 0 r
s
0 .78 .12 r
.21412 .82739 m .20072 .81703 L .20089 .81656 L p F P
0 0 0 r
s
0 .78 .12 r
.23393 .82163 m .21412 .82739 L p .20089 .81656 L F P
0 0 0 r
s
0 .647 .956 r
.86797 .82679 m .86562 .82739 L .85671 .81673 L p F P
0 0 0 r
s
0 .647 .956 r
.83794 .82158 m .85671 .81673 L .86562 .82739 L p F P
0 0 0 r
s
.195 0 .31 r
.79947 .56718 m .79776 .54788 L .80711 .56055 L p F P
0 0 0 r
s
.195 0 .31 r
.80711 .56055 m .80887 .57979 L .79947 .56718 L p F P
0 0 0 r
s
.195 0 .31 r
.74183 .38712 m .74048 .36894 L .75025 .38295 L p F P
0 0 0 r
s
.195 0 .31 r
.75025 .38295 m .75165 .40108 L .74183 .38712 L p F P
0 0 0 r
s
.625 0 .573 r
.5878 .82119 m .56655 .82695 L .5554 .81628 L p F P
0 0 0 r
s
.625 0 .573 r
.53422 .82208 m .5554 .81628 L .56655 .82695 L p F P
0 0 0 r
s
.1 0 .485 r
.33355 .46065 m .33474 .44215 L .35505 .43483 L p F P
0 0 0 r
s
.1 0 .485 r
.33474 .44215 m .33355 .46065 L .31329 .46788 L p F P
0 0 0 r
s
.195 0 .31 r
.85712 .74724 m .85505 .72681 L .86397 .73815 L p F P
0 0 0 r
s
.195 0 .31 r
.86397 .73815 m .86608 .7585 L .85712 .74724 L p F P
0 0 0 r
s
.195 0 .31 r
.68418 .20706 m .68319 .19001 L .69339 .20535 L p F P
0 0 0 r
s
.195 0 .31 r
.69339 .20535 m .69444 .22237 L .68418 .20706 L p F P
0 0 0 r
s
0 .647 .956 r
.85671 .81673 m .8595 .816 L .86797 .82679 L p F P
0 0 0 r
s
.125 0 .956 r
.88806 .82163 m .86797 .82679 L .8595 .816 L p F P
0 0 0 r
s
.1 0 .485 r
.27009 .51968 m .27168 .50081 L .29174 .49372 L p F P
0 0 0 r
s
.1 0 .485 r
.27168 .50081 m .27009 .51968 L .25008 .52667 L p F P
0 0 0 r
s
.511 .78 0 r
.28734 .82074 m .26731 .82651 L .2539 .81583 L p F P
0 0 0 r
s
.511 .78 0 r
.24532 .81832 m .2539 .81583 L .26731 .82651 L p F P
0 0 0 r
s
0 .647 .956 r
.1584 .82631 m .14682 .81762 L .15744 .81447 L closepath p F P
0 0 0 r
s
0 .647 .956 r
.12731 .82341 m .11821 .82611 L .11096 .81324 L p F P
0 0 0 r
s
.125 0 .956 r
.09338 .81851 m .11096 .81324 L .11821 .82611 L p F P
0 0 0 r
s
.1 0 .485 r
.62937 .1913 m .62873 .17446 L .65023 .16605 L p F P
0 0 0 r
s
.1 0 .485 r
.62873 .17446 m .62937 .1913 L .6079 .19962 L p F P
0 0 0 r
s
.1 0 .485 r
.20659 .57874 m .20858 .5595 L .22838 .55265 L p F P
0 0 0 r
s
.1 0 .485 r
.20858 .5595 m .20659 .57874 L .18684 .5855 L p F P
0 0 0 r
s
.625 0 .573 r
.63322 .82251 m .61997 .82606 L .60921 .81538 L p F P
0 0 0 r
s
.625 0 .573 r
.5878 .82119 m .60921 .81538 L .61997 .82606 L p F P
0 0 0 r
s
.1 0 .485 r
.56596 .25028 m .56572 .23307 L .58698 .2249 L p F P
0 0 0 r
s
.1 0 .485 r
.56572 .23307 m .56596 .25028 L .54474 .25837 L p F P
0 0 0 r
s
.1 0 .485 r
.14306 .63785 m .14544 .61823 L .16499 .61162 L p F P
0 0 0 r
s
.1 0 .485 r
.14544 .61823 m .14306 .63785 L .12355 .64437 L p F P
0 0 0 r
s
.625 .656 0 r
.34082 .81985 m .32056 .82562 L .30754 .81493 L p F P
0 0 0 r
s
.625 .656 0 r
.29287 .81915 m .30754 .81493 L .32056 .82562 L p F P
0 0 0 r
s
.195 0 .31 r
.78827 .53502 m .78663 .51589 L .79608 .52881 L p F P
0 0 0 r
s
.195 0 .31 r
.79608 .52881 m .79776 .54788 L .78827 .53502 L p F P
0 0 0 r
s
.195 0 .31 r
.67284 .17444 m .67192 .15757 L .68222 .17317 L p F P
0 0 0 r
s
.195 0 .31 r
.68222 .17317 m .68319 .19001 L .67284 .17444 L p F P
0 0 0 r
s
.625 .201 0 r
.69454 .81957 m .67346 .82518 L .66309 .81448 L p F P
0 0 0 r
s
.1 0 .485 r
.50252 .3093 m .50267 .29172 L .52368 .28378 L p F P
0 0 0 r
s
.625 .201 0 r
.64145 .8203 m .66309 .81448 L .67346 .82518 L p F P
0 0 0 r
s
.1 0 .485 r
.50267 .29172 m .50252 .3093 L .48155 .31715 L p F P
0 0 0 r
s
.1 0 .485 r
.07948 .69699 m .08226 .677 L .10157 .67062 L p F P
0 0 0 r
s
.1 0 .485 r
.08226 .677 m .07948 .69699 L .06023 .70327 L p F P
0 0 0 r
s
.195 0 .31 r
.84599 .7153 m .84399 .69505 L .85301 .70663 L p F P
0 0 0 r
s
.195 0 .31 r
.85301 .70663 m .85505 .72681 L .84599 .7153 L p F P
0 0 0 r
s
.195 0 .31 r
.73055 .35473 m .72928 .33673 L .73915 .35099 L p F P
0 0 0 r
s
.195 0 .31 r
.73915 .35099 m .74048 .36894 L .73055 .35473 L p F P
0 0 0 r
s
.1 0 .485 r
.43904 .36836 m .43958 .3504 L .46034 .3427 L p F P
0 0 0 r
s
.1 0 .485 r
.43958 .3504 m .43904 .36836 L .41832 .37597 L p F P
0 0 0 r
s
.625 .201 0 r
.39436 .81896 m .37387 .82474 L .36125 .81403 L p F P
0 0 0 r
s
.625 .201 0 r
.351 .81695 m .36125 .81403 L .37387 .82474 L p F P
0 0 0 r
s
.1 0 .485 r
.37551 .42745 m .37645 .40912 L .39696 .40165 L p F P
0 0 0 r
s
.1 0 .485 r
.37645 .40912 m .37551 .42745 L .35505 .43483 L p F P
0 0 0 r
s
.188 0 .528 r
.06213 .79283 m .05922 .81358 L .0741 .8243 L p F P
0 0 0 r
s
.125 0 .956 r
.09338 .81851 m .0741 .8243 L .05922 .81358 L p F P
0 0 0 r
s
.625 .656 0 r
.74032 .82079 m .72701 .8243 L .71704 .81358 L p F P
0 0 0 r
s
.625 .656 0 r
.69516 .81941 m .71704 .81358 L .72701 .8243 L p F P
0 0 0 r
s
.1 0 .485 r
.31195 .48658 m .31329 .46788 L .33355 .46065 L p F P
0 0 0 r
s
.1 0 .485 r
.31329 .46788 m .31195 .48658 L .29174 .49372 L p F P
0 0 0 r
s
.625 0 .573 r
.42725 .82385 m .42246 .81965 L .4405 .81141 L p F P
0 0 0 r
s
.625 0 .573 r
.4405 .81141 m .44798 .81807 L .42725 .82385 L p F P
0 0 0 r
s
.511 .78 0 r
.77106 .81269 m .77134 .81301 L .77951 .8237 L p F P
0 0 0 r
s
.511 .78 0 r
.74894 .81851 m .77106 .81269 L p .77951 .8237 L F P
0 0 0 r
s
0 .78 .12 r
.77134 .81301 m .78063 .82341 L .77951 .8237 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.24835 .54575 m .25008 .52667 L .27009 .51968 L p F P
0 0 0 r
s
.1 0 .485 r
.25008 .52667 m .24835 .54575 L .22838 .55265 L p F P
0 0 0 r
s
.195 0 .31 r
.83484 .68328 m .8329 .6632 L .84201 .67504 L p F P
0 0 0 r
s
.195 0 .31 r
.84201 .67504 m .84399 .69505 L .83484 .68328 L p F P
0 0 0 r
s
.195 0 .31 r
.77705 .50277 m .77547 .48382 L .78501 .497 L p F P
0 0 0 r
s
.195 0 .31 r
.78501 .497 m .78663 .51589 L .77705 .50277 L p F P
0 0 0 r
s
.195 0 .31 r
.71925 .32225 m .71804 .30444 L .72801 .31896 L p F P
0 0 0 r
s
.195 0 .31 r
.72801 .31896 m .72928 .33673 L .71925 .32225 L p F P
0 0 0 r
s
.1 0 .485 r
.67101 .14091 m .67192 .15757 L .65023 .16605 L p F P
0 0 0 r
s
0 .78 .12 r
.78063 .82341 m .77134 .81301 L .77109 .81268 L p F P
0 0 0 r
s
0 .78 .12 r
.80279 .81762 m .78063 .82341 L p .77109 .81268 L F P
0 0 0 r
s
0 .647 .956 r
.14682 .81762 m .12731 .82341 L .11282 .81269 L p F P
0 0 0 r
s
0 .647 .956 r
.11096 .81324 m .11282 .81269 L .12731 .82341 L p F P
0 0 0 r
s
.511 .78 0 r
.29012 .82299 m .28734 .82074 L .29287 .81915 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.60841 .21666 m .6079 .19962 L .62937 .1913 L p F P
0 0 0 r
s
.1 0 .485 r
.6079 .19962 m .60841 .21666 L .58698 .2249 L p F P
0 0 0 r
s
.625 0 .573 r
.50165 .81717 m .4807 .82297 L .46887 .81223 L p F P
0 0 0 r
s
.625 0 .573 r
.44798 .81807 m .46887 .81223 L .4807 .82297 L p F P
0 0 0 r
s
.1 0 .485 r
.18471 .60495 m .18684 .5855 L .20659 .57874 L p F P
0 0 0 r
s
.1 0 .485 r
.18684 .5855 m .18471 .60495 L .16499 .61162 L p F P
0 0 0 r
s
.625 .656 0 r
.34452 .82294 m .34082 .81985 L .351 .81695 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.12103 .66419 m .12355 .64437 L .14306 .63785 L p F P
0 0 0 r
s
.1 0 .485 r
.12355 .64437 m .12103 .66419 L .10157 .67062 L p F P
0 0 0 r
s
.1 0 .485 r
.54486 .27578 m .54474 .25837 L .56596 .25028 L p F P
0 0 0 r
s
.1 0 .485 r
.54474 .25837 m .54486 .27578 L .52368 .28378 L p F P
0 0 0 r
s
0 .78 .71 r
.20033 .81673 m .18059 .82252 L .16649 .81178 L p F P
0 0 0 r
s
0 .78 .71 r
.15744 .81447 m .16649 .81178 L .18059 .82252 L p F P
0 0 0 r
s
.188 0 .528 r
.05922 .81358 m .06213 .79283 L .04714 .78187 L p F P
0 0 0 r
s
.188 0 .528 r
.05013 .76128 m .04714 .78187 L .06213 .79283 L p F P
0 0 0 r
s
0 .78 .71 r
.83794 .82158 m .83431 .82252 L .82514 .81178 L p F P
0 0 0 r
s
0 .78 .71 r
.80596 .81679 m .82514 .81178 L .83431 .82252 L p F P
0 0 0 r
s
.625 0 .573 r
.60921 .81538 m .6177 .81308 L .63322 .82251 L p F P
0 0 0 r
s
.625 .201 0 r
.64145 .8203 m .63322 .82251 L .6177 .81308 L p F P
0 0 0 r
s
.1 0 .485 r
.48127 .33493 m .48155 .31715 L .50252 .3093 L p F P
0 0 0 r
s
.1 0 .485 r
.48155 .31715 m .48127 .33493 L .46034 .3427 L p F P
0 0 0 r
s
.625 0 .573 r
.5554 .81628 m .53422 .82208 L .52278 .81133 L p F P
0 0 0 r
s
.625 0 .573 r
.50165 .81717 m .52278 .81133 L .53422 .82208 L p F P
0 0 0 r
s
.1 0 .485 r
.0573 .72347 m .06023 .70327 L .07948 .69699 L p F P
0 0 0 r
s
.1 0 .485 r
.06023 .70327 m .0573 .72347 L .0381 .72966 L p F P
0 0 0 r
s
.195 0 .31 r
.82366 .65118 m .82179 .63127 L .83099 .64337 L p F P
0 0 0 r
s
.195 0 .31 r
.83099 .64337 m .8329 .6632 L .82366 .65118 L p F P
0 0 0 r
s
.195 0 .31 r
.76579 .47044 m .76429 .45167 L .77392 .4651 L p F P
0 0 0 r
s
.195 0 .31 r
.77392 .4651 m .77547 .48382 L .76579 .47044 L p F P
0 0 0 r
s
.195 0 .31 r
.70793 .28969 m .70678 .27206 L .71685 .28684 L p F P
0 0 0 r
s
.195 0 .31 r
.71685 .28684 m .71804 .30444 L .70793 .28969 L p F P
0 0 0 r
s
.125 0 .956 r
.8595 .816 m .87929 .81088 L .88806 .82163 L p F P
0 0 0 r
s
.1 0 .485 r
.41764 .39413 m .41832 .37597 L .43904 .36836 L p F P
0 0 0 r
s
.1 0 .485 r
.41832 .37597 m .41764 .39413 L .39696 .40165 L p F P
0 0 0 r
s
0 .78 .12 r
.24532 .81832 m .23393 .82163 L .22023 .81088 L p F P
0 0 0 r
s
0 .78 .12 r
.20089 .81656 m .22023 .81088 L .23393 .82163 L p F P
0 0 0 r
s
0 .78 .71 r
.82514 .81178 m .82945 .81066 L .83794 .82158 L p F P
0 0 0 r
s
0 .647 .956 r
.85671 .81673 m .83794 .82158 L .82945 .81066 L p F P
0 0 0 r
s
.625 0 .573 r
.60921 .81538 m .5878 .82119 L .57676 .81043 L p F P
0 0 0 r
s
.625 0 .573 r
.5554 .81628 m .57676 .81043 L .5878 .82119 L p F P
0 0 0 r
s
.1 0 .485 r
.35397 .45336 m .35505 .43483 L .37551 .42745 L p F P
0 0 0 r
s
.1 0 .485 r
.35505 .43483 m .35397 .45336 L .33355 .46065 L p F P
0 0 0 r
s
.625 .656 0 r
.71704 .81358 m .73099 .80987 L .74032 .82079 L p F P
0 0 0 r
s
.511 .78 0 r
.74894 .81851 m .74032 .82079 L .73099 .80987 L p F P
0 0 0 r
s
.511 .78 0 r
.29287 .81915 m .28734 .82074 L .27403 .80998 L p F P
0 0 0 r
s
.511 .78 0 r
.2539 .81583 m .27403 .80998 L .28734 .82074 L p F P
0 0 0 r
s
.1 0 .485 r
.29026 .51263 m .29174 .49372 L .31195 .48658 L p F P
0 0 0 r
s
.1 0 .485 r
.29174 .49372 m .29026 .51263 L .27009 .51968 L p F P
0 0 0 r
s
.188 0 .528 r
.04714 .78187 m .05013 .76128 L .03503 .75007 L p F P
0 0 0 r
s
.188 0 .528 r
.0381 .72966 m .03503 .75007 L .05013 .76128 L p F P
0 0 0 r
s
.1 0 .485 r
.65101 .1829 m .65023 .16605 L .67192 .15757 L p F P
0 0 0 r
s
.1 0 .485 r
.65023 .16605 m .65101 .1829 L .62937 .1913 L p F P
0 0 0 r
s
.625 .201 0 r
.66309 .81448 m .64145 .8203 L .6308 .80953 L p F P
0 0 0 r
s
.625 .201 0 r
.6177 .81308 m .6308 .80953 L .64145 .8203 L p F P
0 0 0 r
s
.1 0 .485 r
.22651 .57193 m .22838 .55265 L .24835 .54575 L p F P
0 0 0 r
s
.1 0 .485 r
.22838 .55265 m .22651 .57193 L .20659 .57874 L p F P
0 0 0 r
s
.1 0 .485 r
.58736 .24212 m .58698 .2249 L .60841 .21666 L p F P
0 0 0 r
s
.1 0 .485 r
.58698 .2249 m .58736 .24212 L .56596 .25028 L p F P
0 0 0 r
s
.1 0 .485 r
.16273 .63127 m .16499 .61162 L .18471 .60495 L p F P
0 0 0 r
s
.1 0 .485 r
.16499 .61162 m .16273 .63127 L .14306 .63785 L p F P
0 0 0 r
s
.195 0 .31 r
.81244 .619 m .81065 .59927 L .81994 .61162 L p F P
0 0 0 r
s
.195 0 .31 r
.81994 .61162 m .82179 .63127 L .81244 .619 L p F P
0 0 0 r
s
.195 0 .31 r
.87038 .79997 m .86822 .7791 L .87709 .7901 L p F P
0 0 0 r
s
.195 0 .31 r
.87709 .7901 m .87929 .81088 L .87038 .79997 L p F P
0 0 0 r
s
.195 0 .31 r
.75451 .43802 m .75307 .41944 L .7628 .43313 L p F P
0 0 0 r
s
.195 0 .31 r
.7628 .43313 m .76429 .45167 L .75451 .43802 L p F P
0 0 0 r
s
.195 0 .31 r
.69657 .25705 m .6955 .2396 L .70566 .25464 L p F P
0 0 0 r
s
.195 0 .31 r
.70566 .25464 m .70678 .27206 L .69657 .25705 L p F P
0 0 0 r
s
.625 .656 0 r
.351 .81695 m .34082 .81985 L .32791 .80907 L p F P
0 0 0 r
s
.625 .656 0 r
.30754 .81493 m .32791 .80907 L .34082 .81985 L p F P
0 0 0 r
s
.625 .201 0 r
.43585 .80726 m .4405 .81141 L .42246 .81965 L p F P
0 0 0 r
s
.625 .201 0 r
.42246 .81965 m .41502 .81314 L .43585 .80726 L p F P
0 0 0 r
s
.625 .201 0 r
.66309 .81448 m .68336 .80904 L .69454 .81957 L p F P
0 0 0 r
s
.625 .656 0 r
.69516 .81941 m .69454 .81957 L .68336 .80904 L p F P
0 0 0 r
s
.625 .656 0 r
.71704 .81358 m .69516 .81941 L .68492 .80862 L p F P
0 0 0 r
s
.1 0 .485 r
.52366 .30138 m .52368 .28378 L .54486 .27578 L p F P
0 0 0 r
s
.625 .656 0 r
.68336 .80904 m .68492 .80862 L .69516 .81941 L p F P
0 0 0 r
s
.1 0 .485 r
.52368 .28378 m .52366 .30138 L .50252 .3093 L p F P
0 0 0 r
s
.1 0 .485 r
.0989 .69065 m .10157 .67062 L .12103 .66419 L p F P
0 0 0 r
s
.1 0 .485 r
.10157 .67062 m .0989 .69065 L .07948 .69699 L p F P
0 0 0 r
s
.625 .656 0 r
.30172 .81015 m .30754 .81493 L .29287 .81915 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.29433 .80408 m .30172 .81015 L .29287 .81915 L p F P
0 0 0 r
s
.511 .78 0 r
.27403 .80998 m .29433 .80408 L p .29287 .81915 L F P
0 0 0 r
s
.1 0 .485 r
.45993 .36068 m .46034 .3427 L .48127 .33493 L p F P
0 0 0 r
s
.1 0 .485 r
.46034 .3427 m .45993 .36068 L .43904 .36836 L p F P
0 0 0 r
s
.625 .201 0 r
.41502 .81314 m .39436 .81896 L .38185 .80817 L p F P
0 0 0 r
s
.625 .201 0 r
.36125 .81403 m .38185 .80817 L .39436 .81896 L p F P
0 0 0 r
s
.1 0 .485 r
.03503 .75007 m .0381 .72966 L .0573 .72347 L p F P
0 0 0 r
s
.1 0 .485 r
.39615 .42001 m .39696 .40165 L .41764 .39413 L p F P
0 0 0 r
s
.1 0 .485 r
.39696 .40165 m .39615 .42001 L .37551 .42745 L p F P
0 0 0 r
s
.511 .78 0 r
.77106 .81269 m .74894 .81851 L .7391 .80772 L p F P
0 0 0 r
s
.511 .78 0 r
.73099 .80987 m .7391 .80772 L .74894 .81851 L p F P
0 0 0 r
s
.125 0 .956 r
.11096 .81324 m .09338 .81851 L .07858 .80772 L p F P
0 0 0 r
s
.125 0 .956 r
.05922 .81358 m .07858 .80772 L .09338 .81851 L p F P
0 0 0 r
s
.511 .78 0 r
.24945 .81228 m .2539 .81583 L .24532 .81832 L closepath p F P
0 0 0 r
s
0 .78 .12 r
.24029 .80499 m .24945 .81228 L .24532 .81832 L p F P
0 0 0 r
s
0 .78 .12 r
.22023 .81088 m .24029 .80499 L p .24532 .81832 L F P
0 0 0 r
s
.195 0 .31 r
.74319 .40553 m .74183 .38712 L .75165 .40108 L p F P
0 0 0 r
s
.195 0 .31 r
.75165 .40108 m .75307 .41944 L .74319 .40553 L p F P
0 0 0 r
s
.195 0 .31 r
.68518 .22433 m .68418 .20706 L .69444 .22237 L p F P
0 0 0 r
s
.195 0 .31 r
.69444 .22237 m .6955 .2396 L .68518 .22433 L p F P
0 0 0 r
s
.195 0 .31 r
.80121 .58673 m .79947 .56718 L .80887 .57979 L p F P
0 0 0 r
s
.195 0 .31 r
.80887 .57979 m .81065 .59927 L .80121 .58673 L p F P
0 0 0 r
s
.1 0 .485 r
.33233 .47938 m .33355 .46065 L .35397 .45336 L p F P
0 0 0 r
s
.1 0 .485 r
.33355 .46065 m .33233 .47938 L .31195 .48658 L p F P
0 0 0 r
s
.195 0 .31 r
.85922 .76793 m .85712 .74724 L .86608 .7585 L p F P
0 0 0 r
s
.195 0 .31 r
.86608 .7585 m .86822 .7791 L .85922 .76793 L p F P
0 0 0 r
s
.625 0 .573 r
.44798 .81807 m .4405 .81141 L .46058 .80472 L p F P
0 0 0 r
s
.625 0 .573 r
.46058 .80472 m .46887 .81223 L .44798 .81807 L p F P
0 0 0 r
s
.1 0 .485 r
.26848 .53879 m .27009 .51968 L .29026 .51263 L p F P
0 0 0 r
s
.1 0 .485 r
.27009 .51968 m .26848 .53879 L .24835 .54575 L p F P
0 0 0 r
s
0 .78 .12 r
.80596 .81679 m .80279 .81762 L .79335 .80681 L p F P
0 0 0 r
s
0 .78 .12 r
.77109 .81268 m .79335 .80681 L .80279 .81762 L p F P
0 0 0 r
s
0 .647 .956 r
.15744 .81447 m .14682 .81762 L .13242 .80681 L p F P
0 0 0 r
s
0 .647 .956 r
.11282 .81269 m .13242 .80681 L .14682 .81762 L p F P
0 0 0 r
s
.625 0 .573 r
.52278 .81133 m .50165 .81717 L .48993 .80635 L p F P
0 0 0 r
s
.625 0 .573 r
.46887 .81223 m .48993 .80635 L .50165 .81717 L p F P
0 0 0 r
s
.1 0 .485 r
.20458 .59823 m .20659 .57874 L .22651 .57193 L p F P
0 0 0 r
s
.1 0 .485 r
.20659 .57874 m .20458 .59823 L .18471 .60495 L p F P
0 0 0 r
s
.1 0 .485 r
.63002 .20835 m .62937 .1913 L .65101 .1829 L p F P
0 0 0 r
s
.1 0 .485 r
.62937 .1913 m .63002 .20835 L .60841 .21666 L p F P
0 0 0 r
s
0 .78 .71 r
.20072 .81703 m .20033 .81673 L .20089 .81656 L closepath p F P
0 0 0 r
s
.625 .201 0 r
.35826 .8115 m .36125 .81403 L .351 .81695 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.34844 .80317 m .35826 .8115 L .351 .81695 L p F P
0 0 0 r
s
.625 .656 0 r
.32791 .80907 m .34844 .80317 L p .351 .81695 L F P
0 0 0 r
s
0 .78 .12 r
.79335 .80681 m .7972 .80579 L .80596 .81679 L p F P
0 0 0 r
s
0 .78 .71 r
.82514 .81178 m .80596 .81679 L .7972 .80579 L p F P
0 0 0 r
s
.1 0 .485 r
.14065 .65771 m .14306 .63785 L .16273 .63127 L p F P
0 0 0 r
s
.1 0 .485 r
.14306 .63785 m .14065 .65771 L .12103 .66419 L p F P
0 0 0 r
s
0 .647 .956 r
.8595 .816 m .85671 .81673 L .84767 .8059 L p F P
0 0 0 r
s
0 .647 .956 r
.82945 .81066 m .84767 .8059 L .85671 .81673 L p F P
0 0 0 r
s
.1 0 .485 r
.56621 .26771 m .56596 .25028 L .58736 .24212 L p F P
0 0 0 r
s
.1 0 .485 r
.56596 .25028 m .56621 .26771 L .54486 .27578 L p F P
0 0 0 r
s
0 .78 .71 r
.20089 .81656 m .20033 .81673 L .18632 .8059 L p F P
0 0 0 r
s
0 .78 .71 r
.16649 .81178 m .18632 .8059 L .20033 .81673 L p F P
0 0 0 r
s
0 .78 .12 r
.21013 .80296 m .22023 .81088 L .20089 .81656 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.20631 .79997 m .21013 .80296 L .20089 .81656 L p F P
0 0 0 r
s
0 .78 .71 r
.18632 .8059 m .20631 .79997 L p .20089 .81656 L F P
0 0 0 r
s
.195 0 .31 r
.78994 .55439 m .78827 .53502 L .79776 .54788 L p F P
0 0 0 r
s
.195 0 .31 r
.79776 .54788 m .79947 .56718 L .78994 .55439 L p F P
0 0 0 r
s
.195 0 .31 r
.84802 .73582 m .84599 .7153 L .85505 .72681 L p F P
0 0 0 r
s
.195 0 .31 r
.85505 .72681 m .85712 .74724 L .84802 .73582 L p F P
0 0 0 r
s
.195 0 .31 r
.73185 .37295 m .73055 .35473 L .74048 .36894 L p F P
0 0 0 r
s
.195 0 .31 r
.74048 .36894 m .74183 .38712 L .73185 .37295 L p F P
0 0 0 r
s
.195 0 .31 r
.67376 .19152 m .67284 .17444 L .68319 .19001 L p F P
0 0 0 r
s
.195 0 .31 r
.68319 .19001 m .68418 .20706 L .67376 .19152 L p F P
0 0 0 r
s
.1 0 .485 r
.50237 .3271 m .50252 .3093 L .52366 .30138 L p F P
0 0 0 r
s
.1 0 .485 r
.50252 .3093 m .50237 .3271 L .48127 .33493 L p F P
0 0 0 r
s
.625 0 .573 r
.57676 .81043 m .5554 .81628 L .54408 .80545 L p F P
0 0 0 r
s
.625 0 .573 r
.52278 .81133 m .54408 .80545 L .5554 .81628 L p F P
0 0 0 r
s
.1 0 .485 r
.07667 .71723 m .07948 .69699 L .0989 .69065 L p F P
0 0 0 r
s
.1 0 .485 r
.07948 .69699 m .07667 .71723 L .0573 .72347 L p F P
0 0 0 r
s
0 .647 .956 r
.84767 .8059 m .85076 .80509 L .8595 .816 L p F P
0 0 0 r
s
.125 0 .956 r
.87929 .81088 m .8595 .816 L .85076 .80509 L p F P
0 0 0 r
s
.1 0 .485 r
.43849 .38654 m .43904 .36836 L .45993 .36068 L p F P
0 0 0 r
s
.1 0 .485 r
.43904 .36836 m .43849 .38654 L .41764 .39413 L p F P
0 0 0 r
s
.511 .78 0 r
.2539 .81583 m .24945 .81228 L .26188 .80015 L p F P
0 0 0 r
s
.511 .78 0 r
.26188 .80015 m .27403 .80998 L .2539 .81583 L p F P
0 0 0 r
s
.625 0 .573 r
.6177 .81308 m .60921 .81538 L .59829 .80454 L p F P
0 0 0 r
s
.625 0 .573 r
.57676 .81043 m .59829 .80454 L .60921 .81538 L p F P
0 0 0 r
s
.1 0 .485 r
.37456 .44601 m .37551 .42745 L .39615 .42001 L p F P
0 0 0 r
s
.1 0 .485 r
.37551 .42745 m .37456 .44601 L .35397 .45336 L p F P
0 0 0 r
s
.1 0 .485 r
.3106 .50552 m .31195 .48658 L .33233 .47938 L p F P
0 0 0 r
s
.1 0 .485 r
.31195 .48658 m .3106 .50552 L .29026 .51263 L p F P
0 0 0 r
s
.625 .656 0 r
.30754 .81493 m .30172 .81015 L .31619 .7993 L p F P
0 0 0 r
s
.625 .656 0 r
.31619 .7993 m .32791 .80907 L .30754 .81493 L p F P
0 0 0 r
s
.1 0 .485 r
.67192 .15757 m .67284 .17444 L .65101 .1829 L p F P
0 0 0 r
s
.1 0 .485 r
.2466 .56506 m .24835 .54575 L .26848 .53879 L p F P
0 0 0 r
s
.1 0 .485 r
.24835 .54575 m .2466 .56506 L .22651 .57193 L p F P
0 0 0 r
s
.625 .201 0 r
.68336 .80904 m .66309 .81448 L .65257 .80362 L p F P
0 0 0 r
s
.625 .201 0 r
.6308 .80953 m .65257 .80362 L .66309 .81448 L p F P
0 0 0 r
s
.195 0 .31 r
.8368 .70362 m .83484 .68328 L .84399 .69505 L p F P
0 0 0 r
s
.195 0 .31 r
.84399 .69505 m .84599 .7153 L .8368 .70362 L p F P
0 0 0 r
s
.195 0 .31 r
.77864 .52196 m .77705 .50277 L .78663 .51589 L p F P
0 0 0 r
s
.195 0 .31 r
.78663 .51589 m .78827 .53502 L .77864 .52196 L p F P
0 0 0 r
s
.195 0 .31 r
.72048 .34029 m .71925 .32225 L .72928 .33673 L p F P
0 0 0 r
s
.195 0 .31 r
.72928 .33673 m .73055 .35473 L .72048 .34029 L p F P
0 0 0 r
s
0 .78 .71 r
.15994 .8068 m .16649 .81178 L .15744 .81447 L closepath p F P
0 0 0 r
s
0 .647 .956 r
.15218 .80088 m .15994 .8068 L .15744 .81447 L p F P
0 0 0 r
s
0 .647 .956 r
.13242 .80681 m .15218 .80088 L p .15744 .81447 L F P
0 0 0 r
s
.1 0 .485 r
.60893 .2339 m .60841 .21666 L .63002 .20835 L p F P
0 0 0 r
s
.1 0 .485 r
.60841 .21666 m .60893 .2339 L .58736 .24212 L p F P
0 0 0 r
s
.1 0 .485 r
.18255 .62465 m .18471 .60495 L .20458 .59823 L p F P
0 0 0 r
s
.1 0 .485 r
.18471 .60495 m .18255 .62465 L .16273 .63127 L p F P
0 0 0 r
s
.625 .201 0 r
.36125 .81403 m .35826 .8115 L .37458 .80191 L p F P
0 0 0 r
s
.625 .201 0 r
.37458 .80191 m .38185 .80817 L .36125 .81403 L p F P
0 0 0 r
s
.625 .656 0 r
.73099 .80987 m .71704 .81358 L .70692 .80271 L p F P
0 0 0 r
s
.1 0 .485 r
.54498 .2934 m .54486 .27578 L .56621 .26771 L p F P
0 0 0 r
s
.625 .656 0 r
.68492 .80862 m .70692 .80271 L .71704 .81358 L p F P
0 0 0 r
s
.1 0 .485 r
.54486 .27578 m .54498 .2934 L .52366 .30138 L p F P
0 0 0 r
s
.1 0 .485 r
.11847 .68427 m .12103 .66419 L .14065 .65771 L p F P
0 0 0 r
s
.1 0 .485 r
.12103 .66419 m .11847 .68427 L .0989 .69065 L p F P
0 0 0 r
s
.188 0 .528 r
.04714 .78187 m .04411 .80271 L .05922 .81358 L p F P
0 0 0 r
s
.125 0 .956 r
.07858 .80772 m .05922 .81358 L .04411 .80271 L p F P
0 0 0 r
s
0 .647 .956 r
.11043 .81091 m .11282 .81269 L .11096 .81324 L closepath p F P
0 0 0 r
s
.125 0 .956 r
.09811 .8018 m .11043 .81091 L .11096 .81324 L p F P
0 0 0 r
s
.125 0 .956 r
.07858 .80772 m .09811 .8018 L p .11096 .81324 L F P
0 0 0 r
s
.1 0 .485 r
.48099 .35294 m .48127 .33493 L .50237 .3271 L p F P
0 0 0 r
s
.1 0 .485 r
.48127 .33493 m .48099 .35294 L .45993 .36068 L p F P
0 0 0 r
s
.625 .201 0 r
.43585 .80726 m .41502 .81314 L .40261 .80226 L p F P
0 0 0 r
s
.625 .201 0 r
.38185 .80817 m .40261 .80226 L .41502 .81314 L p F P
0 0 0 r
s
.1 0 .485 r
.05434 .74393 m .0573 .72347 L .07667 .71723 L p F P
0 0 0 r
s
.1 0 .485 r
.0573 .72347 m .05434 .74393 L .03503 .75007 L p F P
0 0 0 r
s
.625 0 .573 r
.59829 .80454 m .59835 .80452 L .6177 .81308 L p F P
0 0 0 r
s
.625 .201 0 r
.6308 .80953 m .6177 .81308 L .59835 .80452 L p F P
0 0 0 r
s
.511 .78 0 r
.77134 .81301 m .77106 .81269 L .77109 .81268 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.76731 .48945 m .76579 .47044 L .77547 .48382 L p F P
0 0 0 r
s
.195 0 .31 r
.77547 .48382 m .77705 .50277 L .76731 .48945 L p F P
0 0 0 r
s
.1 0 .485 r
.41695 .41251 m .41764 .39413 L .43849 .38654 L p F P
0 0 0 r
s
.1 0 .485 r
.41764 .39413 m .41695 .41251 L .39615 .42001 L p F P
0 0 0 r
s
0 .647 .956 r
.11282 .81269 m .11043 .81091 L .11456 .79681 L p F P
0 0 0 r
s
0 .647 .956 r
.13242 .80681 m .11282 .81269 L p .11456 .79681 L F P
0 0 0 r
s
.195 0 .31 r
.82555 .67134 m .82366 .65118 L .8329 .6632 L p F P
0 0 0 r
s
.195 0 .31 r
.8329 .6632 m .83484 .68328 L .82555 .67134 L p F P
0 0 0 r
s
.195 0 .31 r
.70908 .30755 m .70793 .28969 L .71804 .30444 L p F P
0 0 0 r
s
.195 0 .31 r
.71804 .30444 m .71925 .32225 L .70908 .30755 L p F P
0 0 0 r
s
.511 .78 0 r
.77109 .81268 m .77106 .81269 L .76134 .8018 L p F P
0 0 0 r
s
.511 .78 0 r
.7391 .80772 m .76134 .8018 L .77106 .81269 L p F P
0 0 0 r
s
.511 .78 0 r
.76134 .8018 m .76171 .8017 L .77109 .81268 L p F P
0 0 0 r
s
0 .78 .12 r
.79335 .80681 m .77109 .81268 L .76171 .8017 L p F P
0 0 0 r
s
0 .78 .12 r
.26052 .79905 m .26188 .80015 L .24945 .81228 L p F P
0 0 0 r
s
0 .78 .12 r
.24945 .81228 m .24029 .80499 L .26052 .79905 L p F P
0 0 0 r
s
.1 0 .485 r
.35288 .47212 m .35397 .45336 L .37456 .44601 L p F P
0 0 0 r
s
.1 0 .485 r
.35397 .45336 m .35288 .47212 L .33233 .47938 L p F P
0 0 0 r
s
.625 0 .573 r
.46887 .81223 m .46058 .80472 L .4826 .79959 L p F P
0 0 0 r
s
.625 0 .573 r
.4826 .79959 m .48993 .80635 L .46887 .81223 L p F P
0 0 0 r
s
0 .78 .71 r
.82945 .81066 m .82514 .81178 L .81583 .80088 L p F P
0 0 0 r
s
0 .78 .71 r
.7972 .80579 m .81583 .80088 L .82514 .81178 L p F P
0 0 0 r
s
.1 0 .485 r
.28877 .53177 m .29026 .51263 L .3106 .50552 L p F P
0 0 0 r
s
.1 0 .485 r
.29026 .51263 m .28877 .53177 L .26848 .53879 L p F P
0 0 0 r
s
0 .78 .71 r
.16649 .81178 m .15994 .8068 L .1684 .79602 L p F P
0 0 0 r
s
0 .78 .71 r
.18632 .8059 m .16649 .81178 L p .1684 .79602 L F P
0 0 0 r
s
.188 0 .528 r
.04411 .80271 m .04714 .78187 L .03192 .77074 L p F P
0 0 0 r
s
.188 0 .528 r
.03503 .75007 m .03192 .77074 L .04714 .78187 L p F P
0 0 0 r
s
.625 .656 0 r
.36914 .79721 m .37458 .80191 L .35826 .8115 L p F P
0 0 0 r
s
.625 .656 0 r
.35826 .8115 m .34844 .80317 L .36914 .79721 L p F P
0 0 0 r
s
.625 .201 0 r
.45686 .80134 m .46058 .80472 L .4405 .81141 L p F P
0 0 0 r
s
.625 .201 0 r
.4405 .81141 m .43585 .80726 L .45686 .80134 L p F P
0 0 0 r
s
.1 0 .485 r
.6518 .19997 m .65101 .1829 L .67284 .17444 L p F P
0 0 0 r
s
.1 0 .485 r
.65101 .1829 m .6518 .19997 L .63002 .20835 L p F P
0 0 0 r
s
.625 0 .573 r
.54408 .80545 m .52278 .81133 L .51117 .80043 L p F P
0 0 0 r
s
.625 0 .573 r
.48993 .80635 m .51117 .80043 L .52278 .81133 L p F P
0 0 0 r
s
.1 0 .485 r
.22462 .59146 m .22651 .57193 L .2466 .56506 L p F P
0 0 0 r
s
.1 0 .485 r
.22651 .57193 m .22462 .59146 L .20458 .59823 L p F P
0 0 0 r
s
.125 0 .956 r
.11043 .81091 m .09811 .8018 L .11456 .79681 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.58774 .25957 m .58736 .24212 L .60893 .2339 L p F P
0 0 0 r
s
.1 0 .485 r
.58736 .24212 m .58774 .25957 L .56621 .26771 L p F P
0 0 0 r
s
0 .78 .12 r
.22023 .81088 m .21013 .80296 L .21671 .79688 L p F P
0 0 0 r
s
0 .78 .12 r
.24029 .80499 m .22023 .81088 L p .21671 .79688 L F P
0 0 0 r
s
.1 0 .485 r
.16043 .65118 m .16273 .63127 L .18255 .62465 L p F P
0 0 0 r
s
.1 0 .485 r
.16273 .63127 m .16043 .65118 L .14065 .65771 L p F P
0 0 0 r
s
.195 0 .31 r
.81427 .63898 m .81244 .619 L .82179 .63127 L p F P
0 0 0 r
s
.195 0 .31 r
.82179 .63127 m .82366 .65118 L .81427 .63898 L p F P
0 0 0 r
s
.195 0 .31 r
.75596 .45685 m .75451 .43802 L .76429 .45167 L p F P
0 0 0 r
s
.195 0 .31 r
.76429 .45167 m .76579 .47044 L .75596 .45685 L p F P
0 0 0 r
s
.195 0 .31 r
.69765 .27473 m .69657 .25705 L .70678 .27206 L p F P
0 0 0 r
s
.195 0 .31 r
.70678 .27206 m .70793 .28969 L .69765 .27473 L p F P
0 0 0 r
s
.125 0 .956 r
.85076 .80509 m .87038 .79997 L .87929 .81088 L p F P
0 0 0 r
s
0 .78 .71 r
.81583 .80088 m .82055 .79964 L .82945 .81066 L p F P
0 0 0 r
s
0 .647 .956 r
.84767 .8059 m .82945 .81066 L .82055 .79964 L p F P
0 0 0 r
s
.1 0 .485 r
.52364 .31921 m .52366 .30138 L .54498 .2934 L p F P
0 0 0 r
s
.1 0 .485 r
.52366 .30138 m .52364 .31921 L .50237 .3271 L p F P
0 0 0 r
s
.625 0 .573 r
.57676 .81043 m .56555 .79951 L p .59823 .80448 L F P
0 0 0 r
s
.625 0 .573 r
.59823 .80448 m .59829 .80454 L .57676 .81043 L p F P
0 0 0 r
s
.625 0 .573 r
.54408 .80545 m .56555 .79951 L .57676 .81043 L p F P
0 0 0 r
s
.1 0 .485 r
.09619 .71094 m .0989 .69065 L .11847 .68427 L p F P
0 0 0 r
s
.1 0 .485 r
.0989 .69065 m .09619 .71094 L .07667 .71723 L p F P
0 0 0 r
s
.511 .78 0 r
.31479 .79813 m .31619 .7993 L .30172 .81015 L p F P
0 0 0 r
s
.511 .78 0 r
.30172 .81015 m .29433 .80408 L .31479 .79813 L p F P
0 0 0 r
s
.1 0 .485 r
.45951 .37888 m .45993 .36068 L .48099 .35294 L p F P
0 0 0 r
s
.1 0 .485 r
.45993 .36068 m .45951 .37888 L .43849 .38654 L p F P
0 0 0 r
s
.511 .78 0 r
.27403 .80998 m .26188 .80015 L .26522 .79767 L p F P
0 0 0 r
s
.511 .78 0 r
.29433 .80408 m .27403 .80998 L p .26522 .79767 L F P
0 0 0 r
s
.1 0 .485 r
.03192 .77074 m .03503 .75007 L .05434 .74393 L p F P
0 0 0 r
s
.625 .656 0 r
.70692 .80271 m .72039 .7991 L .73099 .80987 L p F P
0 0 0 r
s
.511 .78 0 r
.7391 .80772 m .73099 .80987 L .72039 .7991 L p F P
0 0 0 r
s
.625 .201 0 r
.65257 .80362 m .6308 .80953 L .62 .79859 L p F P
0 0 0 r
s
.625 .201 0 r
.59835 .80452 m .62 .79859 L .6308 .80953 L p F P
0 0 0 r
s
.1 0 .485 r
.39533 .4386 m .39615 .42001 L .41695 .41251 L p F P
0 0 0 r
s
.1 0 .485 r
.39615 .42001 m .39533 .4386 L .37456 .44601 L p F P
0 0 0 r
s
.195 0 .31 r
.80296 .60653 m .80121 .58673 L .81065 .59927 L p F P
0 0 0 r
s
.195 0 .31 r
.81065 .59927 m .81244 .619 L .80296 .60653 L p F P
0 0 0 r
s
.195 0 .31 r
.74458 .42417 m .74319 .40553 L .75307 .41944 L p F P
0 0 0 r
s
.195 0 .31 r
.75307 .41944 m .75451 .43802 L .74458 .42417 L p F P
0 0 0 r
s
.195 0 .31 r
.68619 .24182 m .68518 .22433 L .6955 .2396 L p F P
0 0 0 r
s
.195 0 .31 r
.6955 .2396 m .69657 .25705 L .68619 .24182 L p F P
0 0 0 r
s
.1 0 .485 r
.33111 .49835 m .33233 .47938 L .35288 .47212 L p F P
0 0 0 r
s
.1 0 .485 r
.33233 .47938 m .33111 .49835 L .3106 .50552 L p F P
0 0 0 r
s
.625 .656 0 r
.32791 .80907 m .31619 .7993 L .32123 .79626 L p F P
0 0 0 r
s
.625 .656 0 r
.34844 .80317 m .32791 .80907 L p .32123 .79626 L F P
0 0 0 r
s
.195 0 .31 r
.86134 .78889 m .85922 .76793 L .86822 .7791 L p F P
0 0 0 r
s
.195 0 .31 r
.86822 .7791 m .87038 .79997 L .86134 .78889 L p F P
0 0 0 r
s
.625 .201 0 r
.65257 .80362 m .6701 .79887 L .68336 .80904 L p F P
0 0 0 r
s
.625 .656 0 r
.68492 .80862 m .68336 .80904 L .6701 .79887 L p F P
0 0 0 r
s
.1 0 .485 r
.26685 .55814 m .26848 .53879 L .28877 .53177 L p F P
0 0 0 r
s
.1 0 .485 r
.26848 .53879 m .26685 .55814 L .2466 .56506 L p F P
0 0 0 r
s
.625 .656 0 r
.70692 .80271 m .68492 .80862 L .67452 .79767 L p F P
0 0 0 r
s
.625 .656 0 r
.6701 .79887 m .67452 .79767 L .68492 .80862 L p F P
0 0 0 r
s
.1 0 .485 r
.20254 .61796 m .20458 .59823 L .22462 .59146 L p F P
0 0 0 r
s
.1 0 .485 r
.20458 .59823 m .20254 .61796 L .18255 .62465 L p F P
0 0 0 r
s
.1 0 .485 r
.63067 .22561 m .63002 .20835 L .6518 .19997 L p F P
0 0 0 r
s
.1 0 .485 r
.63002 .20835 m .63067 .22561 L .60893 .2339 L p F P
0 0 0 r
s
.625 .201 0 r
.38185 .80817 m .37458 .80191 L .39255 .79344 L p F P
0 0 0 r
s
.625 .201 0 r
.39255 .79344 m .40261 .80226 L .38185 .80817 L p F P
0 0 0 r
s
.1 0 .485 r
.1382 .67783 m .14065 .65771 L .16043 .65118 L p F P
0 0 0 r
s
.1 0 .485 r
.14065 .65771 m .1382 .67783 L .11847 .68427 L p F P
0 0 0 r
s
.125 0 .956 r
.09811 .8018 m .07858 .80772 L .06356 .79675 L p F P
0 0 0 r
s
.125 0 .956 r
.04411 .80271 m .06356 .79675 L .07858 .80772 L p F P
0 0 0 r
s
.511 .78 0 r
.76134 .8018 m .7391 .80772 L .72911 .79675 L p F P
0 0 0 r
s
.1 0 .485 r
.56647 .28535 m .56621 .26771 L .58774 .25957 L p F P
0 0 0 r
s
.511 .78 0 r
.72039 .7991 m .72911 .79675 L .7391 .80772 L p F P
0 0 0 r
s
.1 0 .485 r
.56621 .26771 m .56647 .28535 L .54498 .2934 L p F P
0 0 0 r
s
.195 0 .31 r
.79162 .574 m .78994 .55439 L .79947 .56718 L p F P
0 0 0 r
s
.195 0 .31 r
.79947 .56718 m .80121 .58673 L .79162 .574 L p F P
0 0 0 r
s
.195 0 .31 r
.67471 .20882 m .67376 .19152 L .68418 .20706 L p F P
0 0 0 r
s
.195 0 .31 r
.68418 .20706 m .68518 .22433 L .67471 .20882 L p F P
0 0 0 r
s
.1 0 .485 r
.50222 .34513 m .50237 .3271 L .52364 .31921 L p F P
0 0 0 r
s
.1 0 .485 r
.50237 .3271 m .50222 .34513 L .48099 .35294 L p F P
0 0 0 r
s
.625 .201 0 r
.45686 .80134 m .43585 .80726 L .42355 .79629 L p F P
0 0 0 r
s
.625 .201 0 r
.40261 .80226 m .42355 .79629 L .43585 .80726 L p F P
0 0 0 r
s
.1 0 .485 r
.07382 .73773 m .07667 .71723 L .09619 .71094 L p F P
0 0 0 r
s
.1 0 .485 r
.07667 .71723 m .07382 .73773 L .05434 .74393 L p F P
0 0 0 r
s
.195 0 .31 r
.85008 .75659 m .84802 .73582 L .85712 .74724 L p F P
0 0 0 r
s
.195 0 .31 r
.85712 .74724 m .85922 .76793 L .85008 .75659 L p F P
0 0 0 r
s
.195 0 .31 r
.73316 .39141 m .73185 .37295 L .74183 .38712 L p F P
0 0 0 r
s
.195 0 .31 r
.74183 .38712 m .74319 .40553 L .73316 .39141 L p F P
0 0 0 r
s
.1 0 .485 r
.43793 .40495 m .43849 .38654 L .45951 .37888 L p F P
0 0 0 r
s
.1 0 .485 r
.43849 .38654 m .43793 .40495 L .41695 .41251 L p F P
0 0 0 r
s
0 .78 .12 r
.7972 .80579 m .79335 .80681 L .78376 .79583 L p F P
0 0 0 r
s
0 .78 .12 r
.76171 .8017 m .78376 .79583 L .79335 .80681 L p F P
0 0 0 r
s
0 .647 .956 r
.15218 .80088 m .13242 .80681 L .1178 .79583 L p F P
0 0 0 r
s
0 .647 .956 r
.11456 .79681 m .1178 .79583 L .13242 .80681 L p F P
0 0 0 r
s
0 .647 .956 r
.15994 .8068 m .15218 .80088 L .1684 .79602 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.3736 .4648 m .37456 .44601 L .39533 .4386 L p F P
0 0 0 r
s
.1 0 .485 r
.37456 .44601 m .3736 .4648 L .35288 .47212 L p F P
0 0 0 r
s
.625 0 .573 r
.48993 .80635 m .4826 .79959 L .50655 .79608 L p F P
0 0 0 r
s
.625 0 .573 r
.50655 .79608 m .51117 .80043 L .48993 .80635 L p F P
0 0 0 r
s
.1 0 .485 r
.30923 .52469 m .3106 .50552 L .33111 .49835 L p F P
0 0 0 r
s
.1 0 .485 r
.3106 .50552 m .30923 .52469 L .28877 .53177 L p F P
0 0 0 r
s
0 .78 .71 r
.20631 .79997 m .18632 .8059 L .1721 .79491 L p F P
0 0 0 r
s
0 .78 .71 r
.1684 .79602 m .1721 .79491 L .18632 .8059 L p F P
0 0 0 r
s
0 .647 .956 r
.85076 .80509 m .84767 .8059 L .83849 .79491 L p F P
0 0 0 r
s
0 .647 .956 r
.82055 .79964 m .83849 .79491 L .84767 .8059 L p F P
0 0 0 r
s
0 .78 .12 r
.78376 .79583 m .78786 .79474 L .7972 .80579 L p F P
0 0 0 r
s
0 .78 .71 r
.81583 .80088 m .7972 .80579 L .78786 .79474 L p F P
0 0 0 r
s
.1 0 .485 r
.24482 .58462 m .2466 .56506 L .26685 .55814 L p F P
0 0 0 r
s
.1 0 .485 r
.2466 .56506 m .24482 .58462 L .22462 .59146 L p F P
0 0 0 r
s
.1 0 .485 r
.67284 .17444 m .67376 .19152 L .6518 .19997 L p F P
0 0 0 r
s
.625 0 .573 r
.54408 .80545 m .53258 .79445 L p .56246 .7965 L F P
0 0 0 r
s
.625 0 .573 r
.56246 .7965 m .56555 .79951 L .54408 .80545 L p F P
0 0 0 r
s
.625 0 .573 r
.51117 .80043 m .53258 .79445 L .54408 .80545 L p F P
0 0 0 r
s
.195 0 .31 r
.83879 .72422 m .8368 .70362 L .84599 .7153 L p F P
0 0 0 r
s
.195 0 .31 r
.84599 .7153 m .84802 .73582 L .83879 .72422 L p F P
0 0 0 r
s
.195 0 .31 r
.78025 .54139 m .77864 .52196 L .78827 .53502 L p F P
0 0 0 r
s
.195 0 .31 r
.78827 .53502 m .78994 .55439 L .78025 .54139 L p F P
0 0 0 r
s
.195 0 .31 r
.72172 .35857 m .72048 .34029 L .73055 .35473 L p F P
0 0 0 r
s
.195 0 .31 r
.73055 .35473 m .73185 .37295 L .72172 .35857 L p F P
0 0 0 r
s
0 .647 .956 r
.83849 .79491 m .84177 .79405 L .85076 .80509 L p F P
0 0 0 r
s
.125 0 .956 r
.87038 .79997 m .85076 .80509 L .84177 .79405 L p F P
0 0 0 r
s
.1 0 .485 r
.60945 .25137 m .60893 .2339 L .63067 .22561 L p F P
0 0 0 r
s
.1 0 .485 r
.60893 .2339 m .60945 .25137 L .58774 .25957 L p F P
0 0 0 r
s
0 .78 .12 r
.26052 .79905 m .24029 .80499 L .22647 .79399 L p F P
0 0 0 r
s
.1 0 .485 r
.18037 .64459 m .18255 .62465 L .20254 .61796 L p F P
0 0 0 r
s
0 .78 .12 r
.21671 .79688 m .22647 .79399 L .24029 .80499 L p F P
0 0 0 r
s
.1 0 .485 r
.18255 .62465 m .18037 .64459 L .16043 .65118 L p F P
0 0 0 r
s
.625 .201 0 r
.47803 .79537 m .4826 .79959 L .46058 .80472 L p F P
0 0 0 r
s
.625 .201 0 r
.46058 .80472 m .45686 .80134 L .47803 .79537 L p F P
0 0 0 r
s
.625 0 .573 r
.59835 .80452 m .59829 .80454 L .59823 .80448 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.11588 .7046 m .11847 .68427 L .1382 .67783 L p F P
0 0 0 r
s
.1 0 .485 r
.11847 .68427 m .11588 .7046 L .09619 .71094 L p F P
0 0 0 r
s
.1 0 .485 r
.54509 .31125 m .54498 .2934 L .56647 .28535 L p F P
0 0 0 r
s
.1 0 .485 r
.54498 .2934 m .54509 .31125 L .52364 .31921 L p F P
0 0 0 r
s
.625 .201 0 r
.62 .79859 m .59835 .80452 L .59823 .80448 L p F P
0 0 0 r
s
.625 .201 0 r
.60903 .78749 m .62 .79859 L p .59823 .80448 L F P
0 0 0 r
s
.625 .201 0 r
.59823 .80448 m .5872 .79353 L .60903 .78749 L p F P
0 0 0 r
s
.625 0 .573 r
.56555 .79951 m .57144 .79788 L .59823 .80448 L p F P
0 0 0 r
s
.625 .201 0 r
.57144 .79788 m .5872 .79353 L .59823 .80448 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.4807 .37117 m .48099 .35294 L .50222 .34513 L p F P
0 0 0 r
s
.1 0 .485 r
.48099 .35294 m .4807 .37117 L .45951 .37888 L p F P
0 0 0 r
s
.1 0 .485 r
.05135 .76464 m .05434 .74393 L .07382 .73773 L p F P
0 0 0 r
s
.1 0 .485 r
.05434 .74393 m .05135 .76464 L .03192 .77074 L p F P
0 0 0 r
s
.511 .78 0 r
.31479 .79813 m .29433 .80408 L .28092 .79306 L p F P
0 0 0 r
s
.511 .78 0 r
.26522 .79767 m .28092 .79306 L .29433 .80408 L p F P
0 0 0 r
s
.195 0 .31 r
.76886 .5087 m .76731 .48945 L .77705 .50277 L p F P
0 0 0 r
s
.195 0 .31 r
.77705 .50277 m .77864 .52196 L .76886 .5087 L p F P
0 0 0 r
s
.195 0 .31 r
.71025 .32564 m .70908 .30755 L .71925 .32225 L p F P
0 0 0 r
s
.195 0 .31 r
.71925 .32225 m .72048 .34029 L .71025 .32564 L p F P
0 0 0 r
s
.625 .201 0 r
.6701 .79887 m .65257 .80362 L .64189 .7926 L p F P
0 0 0 r
s
.625 .201 0 r
.62 .79859 m .64189 .7926 L .65257 .80362 L p F P
0 0 0 r
s
.1 0 .485 r
.41626 .43113 m .41695 .41251 L .43793 .40495 L p F P
0 0 0 r
s
.1 0 .485 r
.41695 .41251 m .41626 .43113 L .39533 .4386 L p F P
0 0 0 r
s
.195 0 .31 r
.82746 .69175 m .82555 .67134 L .83484 .68328 L p F P
0 0 0 r
s
.195 0 .31 r
.83484 .68328 m .8368 .70362 L .82746 .69175 L p F P
0 0 0 r
s
.1 0 .485 r
.35178 .49112 m .35288 .47212 L .3736 .4648 L p F P
0 0 0 r
s
.1 0 .485 r
.35288 .47212 m .35178 .49112 L .33111 .49835 L p F P
0 0 0 r
s
.625 .656 0 r
.36914 .79721 m .34844 .80317 L .33543 .79214 L p F P
0 0 0 r
s
.625 .656 0 r
.32123 .79626 m .33543 .79214 L .34844 .80317 L p F P
0 0 0 r
s
0 .78 .71 r
.21013 .80296 m .20631 .79997 L .21671 .79688 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.28726 .55116 m .28877 .53177 L .30923 .52469 L p F P
0 0 0 r
s
.1 0 .485 r
.28877 .53177 m .28726 .55116 L .26685 .55814 L p F P
0 0 0 r
s
.188 0 .528 r
.03192 .77074 m .02877 .79167 L .04411 .80271 L p F P
0 0 0 r
s
.125 0 .956 r
.06356 .79675 m .04411 .80271 L .02877 .79167 L p F P
0 0 0 r
s
.625 .656 0 r
.72039 .7991 m .70692 .80271 L .69665 .79167 L p F P
0 0 0 r
s
.625 .656 0 r
.67452 .79767 m .69665 .79167 L .70692 .80271 L p F P
0 0 0 r
s
.1 0 .485 r
.6526 .21725 m .6518 .19997 L .67376 .19152 L p F P
0 0 0 r
s
.1 0 .485 r
.6518 .19997 m .6526 .21725 L .63067 .22561 L p F P
0 0 0 r
s
.1 0 .485 r
.2227 .61123 m .22462 .59146 L .24482 .58462 L p F P
0 0 0 r
s
.1 0 .485 r
.22462 .59146 m .2227 .61123 L .20254 .61796 L p F P
0 0 0 r
s
.625 .201 0 r
.40261 .80226 m .39255 .79344 L .41195 .78595 L p F P
0 0 0 r
s
.625 .201 0 r
.41195 .78595 m .42355 .79629 L .40261 .80226 L p F P
0 0 0 r
s
.625 .656 0 r
.39001 .79121 m .39255 .79344 L .37458 .80191 L p F P
0 0 0 r
s
.625 .656 0 r
.37458 .80191 m .36914 .79721 L .39001 .79121 L p F P
0 0 0 r
s
.195 0 .31 r
.81611 .65921 m .81427 .63898 L .82366 .65118 L p F P
0 0 0 r
s
.195 0 .31 r
.82366 .65118 m .82555 .67134 L .81611 .65921 L p F P
0 0 0 r
s
.195 0 .31 r
.75743 .47592 m .75596 .45685 L .76579 .47044 L p F P
0 0 0 r
s
.195 0 .31 r
.76579 .47044 m .76731 .48945 L .75743 .47592 L p F P
0 0 0 r
s
.195 0 .31 r
.69875 .29263 m .69765 .27473 L .70793 .28969 L p F P
0 0 0 r
s
.195 0 .31 r
.70793 .28969 m .70908 .30755 L .69875 .29263 L p F P
0 0 0 r
s
.511 .78 0 r
.76171 .8017 m .76134 .8018 L .75147 .79075 L p F P
0 0 0 r
s
.1 0 .485 r
.58813 .27724 m .58774 .25957 L .60945 .25137 L p F P
0 0 0 r
s
.511 .78 0 r
.72911 .79675 m .75147 .79075 L .76134 .8018 L p F P
0 0 0 r
s
.1 0 .485 r
.58774 .25957 m .58813 .27724 L .56647 .28535 L p F P
0 0 0 r
s
.1 0 .485 r
.1581 .67134 m .16043 .65118 L .18037 .64459 L p F P
0 0 0 r
s
.1 0 .485 r
.16043 .65118 m .1581 .67134 L .1382 .67783 L p F P
0 0 0 r
s
.125 0 .956 r
.11456 .79681 m .09811 .8018 L .08317 .79075 L p F P
0 0 0 r
s
.125 0 .956 r
.06356 .79675 m .08317 .79075 L .09811 .8018 L p F P
0 0 0 r
s
.511 .78 0 r
.75147 .79075 m .75151 .79074 L .76171 .8017 L p F P
0 0 0 r
s
0 .78 .12 r
.78376 .79583 m .76171 .8017 L .75151 .79074 L p F P
0 0 0 r
s
.1 0 .485 r
.52363 .33726 m .52364 .31921 L .54509 .31125 L p F P
0 0 0 r
s
.1 0 .485 r
.52364 .31921 m .52363 .33726 L .50222 .34513 L p F P
0 0 0 r
s
.625 .201 0 r
.47803 .79537 m .45686 .80134 L .44466 .79028 L p F P
0 0 0 r
s
.625 .201 0 r
.42355 .79629 m .44466 .79028 L .45686 .80134 L p F P
0 0 0 r
s
.1 0 .485 r
.09346 .73149 m .09619 .71094 L .11588 .7046 L p F P
0 0 0 r
s
.1 0 .485 r
.09619 .71094 m .09346 .73149 L .07382 .73773 L p F P
0 0 0 r
s
.1 0 .485 r
.45908 .39732 m .45951 .37888 L .4807 .37117 L p F P
0 0 0 r
s
.1 0 .485 r
.45951 .37888 m .45908 .39732 L .43793 .40495 L p F P
0 0 0 r
s
0 .647 .956 r
.1684 .79602 m .15218 .80088 L .13765 .78982 L p F P
0 0 0 r
s
0 .647 .956 r
.1178 .79583 m .13765 .78982 L .15218 .80088 L p F P
0 0 0 r
s
.1 0 .485 r
.02877 .79167 m .03192 .77074 L .05135 .76464 L p F P
0 0 0 r
s
0 .78 .71 r
.82055 .79964 m .81583 .80088 L .80637 .78982 L p F P
0 0 0 r
s
0 .78 .71 r
.78786 .79474 m .80637 .78982 L .81583 .80088 L p F P
0 0 0 r
s
.625 0 .573 r
.51117 .80043 m .50655 .79608 L .53255 .79442 L p F P
0 0 0 r
s
.625 0 .573 r
.53255 .79442 m .53258 .79445 L .51117 .80043 L p F P
0 0 0 r
s
.1 0 .485 r
.39449 .45742 m .39533 .4386 L .41626 .43113 L p F P
0 0 0 r
s
.1 0 .485 r
.39533 .4386 m .39449 .45742 L .3736 .4648 L p F P
0 0 0 r
s
0 .78 .12 r
.26188 .80015 m .26052 .79905 L .26522 .79767 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.74598 .44306 m .74458 .42417 L .75451 .43802 L p F P
0 0 0 r
s
.195 0 .31 r
.75451 .43802 m .75596 .45685 L .74598 .44306 L p F P
0 0 0 r
s
.1 0 .485 r
.32986 .51756 m .33111 .49835 L .35178 .49112 L p F P
0 0 0 r
s
.1 0 .485 r
.33111 .49835 m .32986 .51756 L .30923 .52469 L p F P
0 0 0 r
s
.195 0 .31 r
.80473 .62658 m .80296 .60653 L .81244 .619 L p F P
0 0 0 r
s
.195 0 .31 r
.81244 .619 m .81427 .63898 L .80473 .62658 L p F P
0 0 0 r
s
.195 0 .31 r
.68722 .25953 m .68619 .24182 L .69657 .25705 L p F P
0 0 0 r
s
.195 0 .31 r
.69657 .25705 m .69765 .27473 L .68722 .25953 L p F P
0 0 0 r
s
.125 0 .956 r
.84177 .79405 m .86134 .78889 L .87038 .79997 L p F P
0 0 0 r
s
0 .78 .71 r
.21671 .79688 m .20631 .79997 L .19219 .78889 L p F P
0 0 0 r
s
0 .78 .71 r
.1721 .79491 m .19219 .78889 L .20631 .79997 L p F P
0 0 0 r
s
0 .78 .71 r
.80637 .78982 m .81125 .78852 L .82055 .79964 L p F P
0 0 0 r
s
0 .647 .956 r
.83849 .79491 m .82055 .79964 L .81125 .78852 L p F P
0 0 0 r
s
.625 .201 0 r
.49938 .78935 m .50655 .79608 L .4826 .79959 L p F P
0 0 0 r
s
.625 .201 0 r
.4826 .79959 m .47803 .79537 L .49938 .78935 L p F P
0 0 0 r
s
.625 0 .573 r
.57144 .79788 m .56555 .79951 L .56246 .7965 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.26519 .57774 m .26685 .55814 L .28726 .55116 L p F P
0 0 0 r
s
.1 0 .485 r
.26685 .55814 m .26519 .57774 L .24482 .58462 L p F P
0 0 0 r
s
.511 .78 0 r
.31619 .7993 m .31479 .79813 L .32123 .79626 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.69665 .79167 m .70845 .78847 L .72039 .7991 L p F P
0 0 0 r
s
.511 .78 0 r
.72911 .79675 m .72039 .7991 L .70845 .78847 L p F P
0 0 0 r
s
0 .78 .12 r
.26522 .79767 m .26052 .79905 L .2468 .78796 L p F P
0 0 0 r
s
.1 0 .485 r
.20048 .63795 m .20254 .61796 L .2227 .61123 L p F P
0 0 0 r
s
0 .78 .12 r
.22647 .79399 m .2468 .78796 L .26052 .79905 L p F P
0 0 0 r
s
.1 0 .485 r
.20254 .61796 m .20048 .63795 L .18037 .64459 L p F P
0 0 0 r
s
.1 0 .485 r
.63134 .2431 m .63067 .22561 L .6526 .21725 L p F P
0 0 0 r
s
.1 0 .485 r
.63067 .22561 m .63134 .2431 L .60945 .25137 L p F P
0 0 0 r
s
.625 .201 0 r
.64189 .7926 m .65452 .78914 L .6701 .79887 L p F P
0 0 0 r
s
.625 .656 0 r
.67452 .79767 m .6701 .79887 L .65452 .78914 L p F P
0 0 0 r
s
.1 0 .485 r
.56672 .30322 m .56647 .28535 L .58813 .27724 L p F P
0 0 0 r
s
.1 0 .485 r
.56647 .28535 m .56672 .30322 L .54509 .31125 L p F P
0 0 0 r
s
.625 .201 0 r
.64189 .7926 m .62 .79859 L .60903 .78749 L p F P
0 0 0 r
s
.1 0 .485 r
.13573 .6982 m .1382 .67783 L .1581 .67134 L p F P
0 0 0 r
s
.1 0 .485 r
.1382 .67783 m .13573 .6982 L .11588 .7046 L p F P
0 0 0 r
s
.195 0 .31 r
.79333 .59387 m .79162 .574 L .80121 .58673 L p F P
0 0 0 r
s
.195 0 .31 r
.80121 .58673 m .80296 .60653 L .79333 .59387 L p F P
0 0 0 r
s
.195 0 .31 r
.73449 .41011 m .73316 .39141 L .74319 .40553 L p F P
0 0 0 r
s
.195 0 .31 r
.74319 .40553 m .74458 .42417 L .73449 .41011 L p F P
0 0 0 r
s
.195 0 .31 r
.67566 .22635 m .67471 .20882 L .68518 .22433 L p F P
0 0 0 r
s
.195 0 .31 r
.68518 .22433 m .68619 .24182 L .67566 .22635 L p F P
0 0 0 r
s
.1 0 .485 r
.50206 .36339 m .50222 .34513 L .52363 .33726 L p F P
0 0 0 r
s
.1 0 .485 r
.50222 .34513 m .50206 .36339 L .4807 .37117 L p F P
0 0 0 r
s
.511 .78 0 r
.32123 .79626 m .31479 .79813 L .30148 .78702 L p F P
0 0 0 r
s
.511 .78 0 r
.28092 .79306 m .30148 .78702 L .31479 .79813 L p F P
0 0 0 r
s
.1 0 .485 r
.07093 .75849 m .07382 .73773 L .09346 .73149 L p F P
0 0 0 r
s
.1 0 .485 r
.07382 .73773 m .07093 .75849 L .05135 .76464 L p F P
0 0 0 r
s
.195 0 .31 r
.85216 .77764 m .85008 .75659 L .85922 .76793 L p F P
0 0 0 r
s
.195 0 .31 r
.85922 .76793 m .86134 .78889 L .85216 .77764 L p F P
0 0 0 r
s
.625 .201 0 r
.5872 .79353 m .57144 .79788 L .56246 .7965 L p F P
0 0 0 r
s
.625 .656 0 r
.69665 .79167 m .67452 .79767 L .66396 .78656 L p F P
0 0 0 r
s
.625 .656 0 r
.65452 .78914 m .66396 .78656 L .67452 .79767 L p F P
0 0 0 r
s
.1 0 .485 r
.43737 .42359 m .43793 .40495 L .45908 .39732 L p F P
0 0 0 r
s
.1 0 .485 r
.43793 .40495 m .43737 .42359 L .41626 .43113 L p F P
0 0 0 r
s
.511 .78 0 r
.27725 .79005 m .28092 .79306 L .26522 .79767 L closepath p F P
0 0 0 r
s
0 .78 .12 r
.2673 .78188 m .27725 .79005 L .26522 .79767 L p F P
0 0 0 r
s
0 .78 .12 r
.2468 .78796 m .2673 .78188 L p .26522 .79767 L F P
0 0 0 r
s
.1 0 .485 r
.37263 .48383 m .3736 .4648 L .39449 .45742 L p F P
0 0 0 r
s
.1 0 .485 r
.3736 .4648 m .37263 .48383 L .35178 .49112 L p F P
0 0 0 r
s
.625 .656 0 r
.39001 .79121 m .36914 .79721 L .35623 .78609 L p F P
0 0 0 r
s
.625 .656 0 r
.33543 .79214 m .35623 .78609 L .36914 .79721 L p F P
0 0 0 r
s
0 .78 .12 r
.22369 .79177 m .22647 .79399 L .21671 .79688 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.21244 .78281 m .22369 .79177 L .21671 .79688 L p F P
0 0 0 r
s
0 .78 .71 r
.19219 .78889 m .21244 .78281 L p .21671 .79688 L F P
0 0 0 r
s
0 .647 .956 r
.11639 .79478 m .1178 .79583 L .11456 .79681 L closepath p F P
0 0 0 r
s
.125 0 .956 r
.10295 .78469 m .11639 .79478 L .11456 .79681 L p F P
0 0 0 r
s
.125 0 .956 r
.08317 .79075 m .10295 .78469 L p .11456 .79681 L F P
0 0 0 r
s
.1 0 .485 r
.30785 .54412 m .30923 .52469 L .32986 .51756 L p F P
0 0 0 r
s
.1 0 .485 r
.30923 .52469 m .30785 .54412 L .28726 .55116 L p F P
0 0 0 r
s
.125 0 .956 r
.08317 .79075 m .06356 .79675 L .04831 .78562 L p F P
0 0 0 r
s
.125 0 .956 r
.02877 .79167 m .04831 .78562 L .06356 .79675 L p F P
0 0 0 r
s
.511 .78 0 r
.72911 .79675 m .71896 .78562 L p .75118 .79041 L F P
0 0 0 r
s
.511 .78 0 r
.75118 .79041 m .75147 .79075 L .72911 .79675 L p F P
0 0 0 r
s
.511 .78 0 r
.70845 .78847 m .71896 .78562 L .72911 .79675 L p F P
0 0 0 r
s
.625 .201 0 r
.57594 .78235 m .5872 .79353 L p .56246 .7965 L F P
0 0 0 r
s
.625 .201 0 r
.56246 .7965 m .55417 .78842 L .57594 .78235 L p F P
0 0 0 r
s
.625 0 .573 r
.53258 .79445 m .53268 .79442 L .56246 .7965 L p F P
0 0 0 r
s
.625 .201 0 r
.53268 .79442 m .55417 .78842 L .56246 .7965 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.67376 .19152 m .67471 .20882 L .6526 .21725 L p F P
0 0 0 r
s
.1 0 .485 r
.24302 .60443 m .24482 .58462 L .26519 .57774 L p F P
0 0 0 r
s
.1 0 .485 r
.24482 .58462 m .24302 .60443 L .2227 .61123 L p F P
0 0 0 r
s
.195 0 .31 r
.8408 .74508 m .83879 .72422 L .84802 .73582 L p F P
0 0 0 r
s
.195 0 .31 r
.84802 .73582 m .85008 .75659 L .8408 .74508 L p F P
0 0 0 r
s
.195 0 .31 r
.78189 .56108 m .78025 .54139 L .78994 .55439 L p F P
0 0 0 r
s
.195 0 .31 r
.78994 .55439 m .79162 .574 L .78189 .56108 L p F P
0 0 0 r
s
.195 0 .31 r
.72298 .37708 m .72172 .35857 L .73185 .37295 L p F P
0 0 0 r
s
.195 0 .31 r
.73185 .37295 m .73316 .39141 L .72298 .37708 L p F P
0 0 0 r
s
.625 .201 0 r
.42355 .79629 m .41195 .78595 L .43263 .77938 L p F P
0 0 0 r
s
.625 .201 0 r
.43263 .77938 m .44466 .79028 L .42355 .79629 L p F P
0 0 0 r
s
.625 .656 0 r
.3329 .78999 m .33543 .79214 L .32123 .79626 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.32222 .78094 m .3329 .78999 L .32123 .79626 L p F P
0 0 0 r
s
.511 .78 0 r
.30148 .78702 m .32222 .78094 L p .32123 .79626 L F P
0 0 0 r
s
.625 .201 0 r
.52091 .78328 m .53255 .79442 L .50655 .79608 L p F P
0 0 0 r
s
.625 .201 0 r
.50655 .79608 m .49938 .78935 L .52091 .78328 L p F P
0 0 0 r
s
0 .78 .71 r
.17083 .79393 m .1721 .79491 L .1684 .79602 L closepath p F P
0 0 0 r
s
0 .647 .956 r
.15766 .78375 m .17083 .79393 L .1684 .79602 L p F P
0 0 0 r
s
0 .647 .956 r
.13765 .78982 m .15766 .78375 L p .1684 .79602 L F P
0 0 0 r
s
0 .647 .956 r
.1178 .79583 m .11639 .79478 L .13075 .78457 L p F P
0 0 0 r
s
0 .647 .956 r
.13075 .78457 m .13765 .78982 L .1178 .79583 L p F P
0 0 0 r
s
0 .78 .12 r
.78786 .79474 m .78376 .79583 L .77403 .78469 L p F P
0 0 0 r
s
.1 0 .485 r
.60998 .26905 m .60945 .25137 L .63134 .2431 L p F P
0 0 0 r
s
0 .78 .12 r
.75151 .79074 m .77403 .78469 L .78376 .79583 L p F P
0 0 0 r
s
.1 0 .485 r
.60945 .25137 m .60998 .26905 L .58813 .27724 L p F P
0 0 0 r
s
.1 0 .485 r
.17816 .66479 m .18037 .64459 L .20048 .63795 L p F P
0 0 0 r
s
.1 0 .485 r
.18037 .64459 m .17816 .66479 L .1581 .67134 L p F P
0 0 0 r
s
.1 0 .485 r
.54521 .32932 m .54509 .31125 L .56672 .30322 L p F P
0 0 0 r
s
.1 0 .485 r
.54509 .31125 m .54521 .32932 L .52363 .33726 L p F P
0 0 0 r
s
.625 .201 0 r
.49938 .78935 m .47803 .79537 L .46594 .78422 L p F P
0 0 0 r
s
.625 .201 0 r
.44466 .79028 m .46594 .78422 L .47803 .79537 L p F P
0 0 0 r
s
.1 0 .485 r
.11326 .72519 m .11588 .7046 L .13573 .6982 L p F P
0 0 0 r
s
.1 0 .485 r
.11588 .7046 m .11326 .72519 L .09346 .73149 L p F P
0 0 0 r
s
.1 0 .485 r
.48041 .38963 m .4807 .37117 L .50206 .36339 L p F P
0 0 0 r
s
.1 0 .485 r
.4807 .37117 m .48041 .38963 L .45908 .39732 L p F P
0 0 0 r
s
0 .647 .956 r
.84177 .79405 m .83849 .79491 L .82917 .78375 L p F P
0 0 0 r
s
0 .647 .956 r
.81125 .78852 m .82917 .78375 L .83849 .79491 L p F P
0 0 0 r
s
0 .78 .71 r
.1721 .79491 m .17083 .79393 L .18592 .78397 L p F P
0 0 0 r
s
0 .78 .71 r
.18592 .78397 m .19219 .78889 L .1721 .79491 L p F P
0 0 0 r
s
.1 0 .485 r
.04831 .78562 m .05135 .76464 L .07093 .75849 L p F P
0 0 0 r
s
.1 0 .485 r
.05135 .76464 m .04831 .78562 L .02877 .79167 L p F P
0 0 0 r
s
.125 0 .956 r
.12289 .77858 m .13075 .78457 L .11639 .79478 L p F P
0 0 0 r
s
.125 0 .956 r
.11639 .79478 m .10295 .78469 L .12289 .77858 L p F P
0 0 0 r
s
0 .78 .12 r
.77403 .78469 m .77792 .78364 L .78786 .79474 L p F P
0 0 0 r
s
0 .78 .71 r
.80637 .78982 m .78786 .79474 L .77792 .78364 L p F P
0 0 0 r
s
.195 0 .31 r
.77042 .5282 m .76886 .5087 L .77864 .52196 L p F P
0 0 0 r
s
.195 0 .31 r
.77864 .52196 m .78025 .54139 L .77042 .5282 L p F P
0 0 0 r
s
.1 0 .485 r
.41556 .44998 m .41626 .43113 L .43737 .42359 L p F P
0 0 0 r
s
.1 0 .485 r
.41626 .43113 m .41556 .44998 L .39449 .45742 L p F P
0 0 0 r
s
.195 0 .31 r
.8294 .71243 m .82746 .69175 L .8368 .70362 L p F P
0 0 0 r
s
.195 0 .31 r
.8368 .70362 m .83879 .72422 L .8294 .71243 L p F P
0 0 0 r
s
.195 0 .31 r
.71144 .34396 m .71025 .32564 L .72048 .34029 L p F P
0 0 0 r
s
.195 0 .31 r
.72048 .34029 m .72172 .35857 L .71144 .34396 L p F P
0 0 0 r
s
.625 0 .573 r
.53268 .79442 m .53258 .79445 L .53255 .79442 L closepath p F P
0 0 0 r
s
.625 .201 0 r
.55417 .78842 m .53268 .79442 L .53255 .79442 L p F P
0 0 0 r
s
.625 .201 0 r
.54261 .77716 m .55417 .78842 L p .53255 .79442 L F P
0 0 0 r
s
.625 .201 0 r
.53255 .79442 m .52091 .78328 L .54261 .77716 L p F P
0 0 0 r
s
0 .647 .956 r
.82917 .78375 m .83252 .78286 L .84177 .79405 L p F P
0 0 0 r
s
.125 0 .956 r
.86134 .78889 m .84177 .79405 L .83252 .78286 L p F P
0 0 0 r
s
.1 0 .485 r
.35066 .51037 m .35178 .49112 L .37263 .48383 L p F P
0 0 0 r
s
.1 0 .485 r
.35178 .49112 m .35066 .51037 L .32986 .51756 L p F P
0 0 0 r
s
0 .78 .12 r
.22647 .79399 m .22369 .79177 L .23975 .78226 L p F P
0 0 0 r
s
0 .78 .12 r
.23975 .78226 m .2468 .78796 L .22647 .79399 L p F P
0 0 0 r
s
0 .647 .956 r
.17785 .77764 m .18592 .78397 L .17083 .79393 L p F P
0 0 0 r
s
0 .647 .956 r
.17083 .79393 m .15766 .78375 L .17785 .77764 L p F P
0 0 0 r
s
.625 .201 0 r
.60903 .78749 m .5872 .79353 L .57594 .78235 L p F P
0 0 0 r
s
.1 0 .485 r
.28573 .57079 m .28726 .55116 L .30785 .54412 L p F P
0 0 0 r
s
.1 0 .485 r
.28726 .55116 m .28573 .57079 L .26519 .57774 L p F P
0 0 0 r
s
.625 .656 0 r
.41105 .78516 m .41195 .78595 L .39255 .79344 L p F P
0 0 0 r
s
.625 .656 0 r
.39255 .79344 m .39001 .79121 L .41105 .78516 L p F P
0 0 0 r
s
.1 0 .485 r
.65341 .23476 m .6526 .21725 L .67471 .20882 L p F P
0 0 0 r
s
.1 0 .485 r
.6526 .21725 m .65341 .23476 L .63134 .2431 L p F P
0 0 0 r
s
.511 .78 0 r
.28092 .79306 m .27725 .79005 L .29432 .78105 L p F P
0 0 0 r
s
.511 .78 0 r
.29432 .78105 m .30148 .78702 L .28092 .79306 L p F P
0 0 0 r
s
.1 0 .485 r
.22076 .63125 m .2227 .61123 L .24302 .60443 L p F P
0 0 0 r
s
.1 0 .485 r
.2227 .61123 m .22076 .63125 L .20048 .63795 L p F P
0 0 0 r
s
.1 0 .485 r
.58853 .29513 m .58813 .27724 L .60998 .26905 L p F P
0 0 0 r
s
.1 0 .485 r
.58813 .27724 m .58853 .29513 L .56672 .30322 L p F P
0 0 0 r
s
.625 .201 0 r
.65452 .78914 m .64189 .7926 L .63104 .78141 L p F P
0 0 0 r
s
.625 .201 0 r
.60903 .78749 m .63104 .78141 L .64189 .7926 L p F P
0 0 0 r
s
.1 0 .485 r
.15574 .69175 m .1581 .67134 L .17816 .66479 L p F P
0 0 0 r
s
.1 0 .485 r
.1581 .67134 m .15574 .69175 L .13573 .6982 L p F P
0 0 0 r
s
.195 0 .31 r
.81798 .67971 m .81611 .65921 L .82555 .67134 L p F P
0 0 0 r
s
.195 0 .31 r
.82555 .67134 m .82746 .69175 L .81798 .67971 L p F P
0 0 0 r
s
.195 0 .31 r
.75892 .49523 m .75743 .47592 L .76731 .48945 L p F P
0 0 0 r
s
.195 0 .31 r
.76731 .48945 m .76886 .5087 L .75892 .49523 L p F P
0 0 0 r
s
.195 0 .31 r
.69986 .31076 m .69875 .29263 L .70908 .30755 L p F P
0 0 0 r
s
.195 0 .31 r
.70908 .30755 m .71025 .32564 L .69986 .31076 L p F P
0 0 0 r
s
.1 0 .485 r
.52361 .35554 m .52363 .33726 L .54521 .32932 L p F P
0 0 0 r
s
.1 0 .485 r
.52363 .33726 m .52361 .35554 L .50206 .36339 L p F P
0 0 0 r
s
.625 .656 0 r
.33543 .79214 m .3329 .78999 L .35108 .78165 L p F P
0 0 0 r
s
.625 .656 0 r
.35108 .78165 m .35623 .78609 L .33543 .79214 L p F P
0 0 0 r
s
.1 0 .485 r
.09068 .75229 m .09346 .73149 L .11326 .72519 L p F P
0 0 0 r
s
.1 0 .485 r
.09346 .73149 m .09068 .75229 L .07093 .75849 L p F P
0 0 0 r
s
0 .78 .71 r
.23287 .77669 m .23975 .78226 L .22369 .79177 L p F P
0 0 0 r
s
0 .78 .71 r
.22369 .79177 m .21244 .78281 L .23287 .77669 L p F P
0 0 0 r
s
.625 .656 0 r
.70845 .78847 m .69665 .79167 L .68621 .78046 L p F P
0 0 0 r
s
.625 .656 0 r
.66396 .78656 m .68621 .78046 L .69665 .79167 L p F P
0 0 0 r
s
.1 0 .485 r
.45865 .416 m .45908 .39732 L .48041 .38963 L p F P
0 0 0 r
s
.1 0 .485 r
.45908 .39732 m .45865 .416 L .43737 .42359 L p F P
0 0 0 r
s
.1 0 .485 r
.39365 .47649 m .39449 .45742 L .41556 .44998 L p F P
0 0 0 r
s
.1 0 .485 r
.39449 .45742 m .39365 .47649 L .37263 .48383 L p F P
0 0 0 r
s
.625 .656 0 r
.41105 .78516 m .39001 .79121 L .37721 .77999 L p F P
0 0 0 r
s
.625 .656 0 r
.35623 .78609 m .37721 .77999 L .39001 .79121 L p F P
0 0 0 r
s
.195 0 .31 r
.7474 .46218 m .74598 .44306 L .75596 .45685 L p F P
0 0 0 r
s
.195 0 .31 r
.75596 .45685 m .75743 .47592 L .7474 .46218 L p F P
0 0 0 r
s
.195 0 .31 r
.80653 .6469 m .80473 .62658 L .81427 .63898 L p F P
0 0 0 r
s
.195 0 .31 r
.81427 .63898 m .81611 .65921 L .80653 .6469 L p F P
0 0 0 r
s
.195 0 .31 r
.68826 .27747 m .68722 .25953 L .69765 .27473 L p F P
0 0 0 r
s
.195 0 .31 r
.69765 .27473 m .69875 .29263 L .68826 .27747 L p F P
0 0 0 r
s
.511 .78 0 r
.75151 .79074 m .75147 .79075 L .75118 .79041 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.3286 .53702 m .32986 .51756 L .35066 .51037 L p F P
0 0 0 r
s
.1 0 .485 r
.32986 .51756 m .3286 .53702 L .30785 .54412 L p F P
0 0 0 r
s
.125 0 .956 r
.10295 .78469 m .08317 .79075 L .06801 .77952 L p F P
0 0 0 r
s
.125 0 .956 r
.04831 .78562 m .06801 .77952 L .08317 .79075 L p F P
0 0 0 r
s
0 .78 .12 r
.77403 .78469 m .75151 .79074 L .75118 .79041 L p F P
0 0 0 r
s
0 .78 .12 r
.76414 .77337 m .77403 .78469 L p .75118 .79041 L F P
0 0 0 r
s
0 .78 .12 r
.75118 .79041 m .74146 .77952 L .76414 .77337 L p F P
0 0 0 r
s
.511 .78 0 r
.71896 .78562 m .74031 .77983 L .75118 .79041 L p F P
0 0 0 r
s
0 .78 .12 r
.74031 .77983 m .74146 .77952 L .75118 .79041 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.26352 .59758 m .26519 .57774 L .28573 .57079 L p F P
0 0 0 r
s
.1 0 .485 r
.26519 .57774 m .26352 .59758 L .24302 .60443 L p F P
0 0 0 r
s
.625 .201 0 r
.44466 .79028 m .43263 .77938 L .45455 .77371 L p F P
0 0 0 r
s
.625 .201 0 r
.45455 .77371 m .46594 .78422 L .44466 .79028 L p F P
0 0 0 r
s
0 .78 .12 r
.28796 .77574 m .29432 .78105 L .27725 .79005 L p F P
0 0 0 r
s
0 .78 .12 r
.27725 .79005 m .2673 .78188 L .28796 .77574 L p F P
0 0 0 r
s
.511 .78 0 r
.34313 .7748 m .35108 .78165 L .3329 .78999 L p F P
0 0 0 r
s
.511 .78 0 r
.3329 .78999 m .32222 .78094 L .34313 .7748 L p F P
0 0 0 r
s
.1 0 .485 r
.19839 .65819 m .20048 .63795 L .22076 .63125 L p F P
0 0 0 r
s
.1 0 .485 r
.20048 .63795 m .19839 .65819 L .17816 .66479 L p F P
0 0 0 r
s
0 .78 .71 r
.81125 .78852 m .80637 .78982 L .79677 .77858 L p F P
0 0 0 r
s
.1 0 .485 r
.63201 .2608 m .63134 .2431 L .65341 .23476 L p F P
0 0 0 r
s
0 .78 .71 r
.77792 .78364 m .79677 .77858 L .80637 .78982 L p F P
0 0 0 r
s
.1 0 .485 r
.63134 .2431 m .63201 .2608 L .60998 .26905 L p F P
0 0 0 r
s
0 .647 .956 r
.13765 .78982 m .13075 .78457 L .14761 .77598 L p F P
0 0 0 r
s
0 .647 .956 r
.14761 .77598 m .15766 .78375 L .13765 .78982 L p F P
0 0 0 r
s
.1 0 .485 r
.56698 .32132 m .56672 .30322 L .58853 .29513 L p F P
0 0 0 r
s
.1 0 .485 r
.56672 .30322 m .56698 .32132 L .54521 .32932 L p F P
0 0 0 r
s
.625 .201 0 r
.52091 .78328 m .49938 .78935 L .48741 .77811 L p F P
0 0 0 r
s
.625 .201 0 r
.46594 .78422 m .48741 .77811 L .49938 .78935 L p F P
0 0 0 r
s
.1 0 .485 r
.13322 .71884 m .13573 .6982 L .15574 .69175 L p F P
0 0 0 r
s
.1 0 .485 r
.13573 .6982 m .13322 .71884 L .11326 .72519 L p F P
0 0 0 r
s
.625 .201 0 r
.63104 .78141 m .63622 .77997 L .65452 .78914 L p F P
0 0 0 r
s
.625 .656 0 r
.66396 .78656 m .65452 .78914 L .63622 .77997 L p F P
0 0 0 r
s
.195 0 .31 r
.67663 .24409 m .67566 .22635 L .68619 .24182 L p F P
0 0 0 r
s
.195 0 .31 r
.68619 .24182 m .68722 .25953 L .67663 .24409 L p F P
0 0 0 r
s
.1 0 .485 r
.50191 .38188 m .50206 .36339 L .52361 .35554 L p F P
0 0 0 r
s
.1 0 .485 r
.50206 .36339 m .50191 .38188 L .48041 .38963 L p F P
0 0 0 r
s
0 .78 .71 r
.19219 .78889 m .18592 .78397 L .2028 .77514 L p F P
0 0 0 r
s
0 .78 .71 r
.2028 .77514 m .21244 .78281 L .19219 .78889 L p F P
0 0 0 r
s
.1 0 .485 r
.06801 .77952 m .07093 .75849 L .09068 .75229 L p F P
0 0 0 r
s
.1 0 .485 r
.07093 .75849 m .06801 .77952 L .04831 .78562 L p F P
0 0 0 r
s
.195 0 .31 r
.79505 .614 m .79333 .59387 L .80296 .60653 L p F P
0 0 0 r
s
.195 0 .31 r
.80296 .60653 m .80473 .62658 L .79505 .614 L p F P
0 0 0 r
s
.195 0 .31 r
.73584 .42905 m .73449 .41011 L .74458 .42417 L p F P
0 0 0 r
s
.195 0 .31 r
.74458 .42417 m .74598 .44306 L .73584 .42905 L p F P
0 0 0 r
s
.125 0 .956 r
.83252 .78286 m .85216 .77764 L .86134 .78889 L p F P
0 0 0 r
s
0 .78 .71 r
.79677 .77858 m .80155 .7773 L .81125 .78852 L p F P
0 0 0 r
s
0 .647 .956 r
.82917 .78375 m .81125 .78852 L .80155 .7773 L p F P
0 0 0 r
s
.625 .656 0 r
.68621 .78046 m .69505 .77804 L .70845 .78847 L p F P
0 0 0 r
s
.511 .78 0 r
.71896 .78562 m .70845 .78847 L .69505 .77804 L p F P
0 0 0 r
s
.1 0 .485 r
.4368 .44248 m .43737 .42359 L .45865 .416 L p F P
0 0 0 r
s
.1 0 .485 r
.43737 .42359 m .4368 .44248 L .41556 .44998 L p F P
0 0 0 r
s
.625 .201 0 r
.57594 .78235 m .55417 .78842 L .54261 .77716 L p F P
0 0 0 r
s
.1 0 .485 r
.37164 .50311 m .37263 .48383 L .39365 .47649 L p F P
0 0 0 r
s
.1 0 .485 r
.37263 .48383 m .37164 .50311 L .35066 .51037 L p F P
0 0 0 r
s
0 .78 .12 r
.2468 .78796 m .23975 .78226 L .2572 .77358 L p F P
0 0 0 r
s
0 .78 .12 r
.2572 .77358 m .2673 .78188 L .2468 .78796 L p F P
0 0 0 r
s
.625 .201 0 r
.60903 .78749 m .59789 .77622 L p .62555 .77574 L F P
0 0 0 r
s
.625 .201 0 r
.62555 .77574 m .63104 .78141 L .60903 .78749 L p F P
0 0 0 r
s
.625 .201 0 r
.57594 .78235 m .59789 .77622 L .60903 .78749 L p F P
0 0 0 r
s
.1 0 .485 r
.30644 .56379 m .30785 .54412 L .3286 .53702 L p F P
0 0 0 r
s
.1 0 .485 r
.30785 .54412 m .30644 .56379 L .28573 .57079 L p F P
0 0 0 r
s
.195 0 .31 r
.84283 .76621 m .8408 .74508 L .85008 .75659 L p F P
0 0 0 r
s
.195 0 .31 r
.85008 .75659 m .85216 .77764 L .84283 .76621 L p F P
0 0 0 r
s
.195 0 .31 r
.78354 .58102 m .78189 .56108 L .79162 .574 L p F P
0 0 0 r
s
.195 0 .31 r
.79162 .574 m .79333 .59387 L .78354 .58102 L p F P
0 0 0 r
s
.195 0 .31 r
.72425 .39583 m .72298 .37708 L .73316 .39141 L p F P
0 0 0 r
s
.195 0 .31 r
.73316 .39141 m .73449 .41011 L .72425 .39583 L p F P
0 0 0 r
s
.1 0 .485 r
.67471 .20882 m .67566 .22635 L .65341 .23476 L p F P
0 0 0 r
s
.511 .78 0 r
.30148 .78702 m .29432 .78105 L .31255 .77274 L p F P
0 0 0 r
s
.511 .78 0 r
.31255 .77274 m .32222 .78094 L .30148 .78702 L p F P
0 0 0 r
s
.1 0 .485 r
.2412 .6245 m .24302 .60443 L .26352 .59758 L p F P
0 0 0 r
s
.1 0 .485 r
.24302 .60443 m .2412 .6245 L .22076 .63125 L p F P
0 0 0 r
s
.1 0 .485 r
.61052 .28697 m .60998 .26905 L .63201 .2608 L p F P
0 0 0 r
s
.1 0 .485 r
.60998 .26905 m .61052 .28697 L .58853 .29513 L p F P
0 0 0 r
s
.625 .656 0 r
.68621 .78046 m .66396 .78656 L .65324 .77527 L p F P
0 0 0 r
s
.625 .656 0 r
.63622 .77997 m .65324 .77527 L .66396 .78656 L p F P
0 0 0 r
s
.1 0 .485 r
.17592 .68525 m .17816 .66479 L .19839 .65819 L p F P
0 0 0 r
s
.1 0 .485 r
.17816 .66479 m .17592 .68525 L .15574 .69175 L p F P
0 0 0 r
s
.1 0 .485 r
.1106 .74604 m .11326 .72519 L .13322 .71884 L p F P
0 0 0 r
s
.1 0 .485 r
.11326 .72519 m .1106 .74604 L .09068 .75229 L p F P
0 0 0 r
s
.1 0 .485 r
.54534 .34763 m .54521 .32932 L .56698 .32132 L p F P
0 0 0 r
s
.1 0 .485 r
.54521 .32932 m .54534 .34763 L .52361 .35554 L p F P
0 0 0 r
s
.625 .656 0 r
.35623 .78609 m .35108 .78165 L .37034 .77398 L p F P
0 0 0 r
s
.625 .656 0 r
.37034 .77398 m .37721 .77999 L .35623 .78609 L p F P
0 0 0 r
s
.625 .656 0 r
.43227 .77905 m .43263 .77938 L .41195 .78595 L p F P
0 0 0 r
s
.625 .656 0 r
.41195 .78595 m .41105 .78516 L .43227 .77905 L p F P
0 0 0 r
s
.511 .78 0 r
.74031 .77983 m .71896 .78562 L .70865 .77432 L p F P
0 0 0 r
s
.511 .78 0 r
.69505 .77804 m .70865 .77432 L .71896 .78562 L p F P
0 0 0 r
s
.1 0 .485 r
.48011 .40834 m .48041 .38963 L .50191 .38188 L p F P
0 0 0 r
s
.1 0 .485 r
.48041 .38963 m .48011 .40834 L .45865 .416 L p F P
0 0 0 r
s
.195 0 .31 r
.772 .54795 m .77042 .5282 L .78025 .54139 L p F P
0 0 0 r
s
.195 0 .31 r
.78025 .54139 m .78189 .56108 L .772 .54795 L p F P
0 0 0 r
s
.195 0 .31 r
.71264 .36252 m .71144 .34396 L .72172 .35857 L p F P
0 0 0 r
s
.195 0 .31 r
.72172 .35857 m .72298 .37708 L .71264 .36252 L p F P
0 0 0 r
s
.1 0 .485 r
.41484 .46908 m .41556 .44998 L .4368 .44248 L p F P
0 0 0 r
s
.1 0 .485 r
.41556 .44998 m .41484 .46908 L .39365 .47649 L p F P
0 0 0 r
s
.625 .656 0 r
.43227 .77905 m .41105 .78516 L .39837 .77385 L p F P
0 0 0 r
s
.625 .656 0 r
.37721 .77999 m .39837 .77385 L .41105 .78516 L p F P
0 0 0 r
s
.195 0 .31 r
.83137 .73338 m .8294 .71243 L .83879 .72422 L p F P
0 0 0 r
s
.195 0 .31 r
.83879 .72422 m .8408 .74508 L .83137 .73338 L p F P
0 0 0 r
s
.1 0 .485 r
.34953 .52986 m .35066 .51037 L .37164 .50311 L p F P
0 0 0 r
s
.1 0 .485 r
.35066 .51037 m .34953 .52986 L .3286 .53702 L p F P
0 0 0 r
s
0 .78 .12 r
.77792 .78364 m .77403 .78469 L .76414 .77337 L p F P
0 0 0 r
s
.125 0 .956 r
.12289 .77858 m .10295 .78469 L .08788 .77337 L p F P
0 0 0 r
s
.125 0 .956 r
.06801 .77952 m .08788 .77337 L .10295 .78469 L p F P
0 0 0 r
s
.125 0 .956 r
.143 .77242 m .14761 .77598 L .13075 .78457 L p F P
0 0 0 r
s
.125 0 .956 r
.13075 .78457 m .12289 .77858 L .143 .77242 L p F P
0 0 0 r
s
.1 0 .485 r
.28418 .59068 m .28573 .57079 L .30644 .56379 L p F P
0 0 0 r
s
.1 0 .485 r
.28573 .57079 m .28418 .59068 L .26352 .59758 L p F P
0 0 0 r
s
.625 .201 0 r
.46594 .78422 m .45455 .77371 L .47771 .769 L p F P
0 0 0 r
s
.625 .201 0 r
.47771 .769 m .48741 .77811 L .46594 .78422 L p F P
0 0 0 r
s
0 .647 .956 r
.1982 .77147 m .2028 .77514 L .18592 .78397 L p F P
0 0 0 r
s
0 .647 .956 r
.18592 .78397 m .17785 .77764 L .1982 .77147 L p F P
0 0 0 r
s
0 .647 .956 r
.15766 .78375 m .14761 .77598 L .16579 .76818 L p F P
0 0 0 r
s
0 .647 .956 r
.16579 .76818 m .17785 .77764 L .15766 .78375 L p F P
0 0 0 r
s
0 .647 .956 r
.83252 .78286 m .82917 .78375 L .81971 .77242 L p F P
0 0 0 r
s
.1 0 .485 r
.65423 .25248 m .65341 .23476 L .67566 .22635 L p F P
0 0 0 r
s
0 .647 .956 r
.80155 .7773 m .81971 .77242 L .82917 .78375 L p F P
0 0 0 r
s
.1 0 .485 r
.65341 .23476 m .65423 .25248 L .63201 .2608 L p F P
0 0 0 r
s
.1 0 .485 r
.21879 .65154 m .22076 .63125 L .2412 .6245 L p F P
0 0 0 r
s
.1 0 .485 r
.22076 .63125 m .21879 .65154 L .19839 .65819 L p F P
0 0 0 r
s
0 .78 .12 r
.76414 .77337 m .76738 .77249 L .77792 .78364 L p F P
0 0 0 r
s
0 .78 .71 r
.79677 .77858 m .77792 .78364 L .76738 .77249 L p F P
0 0 0 r
s
.195 0 .31 r
.81988 .70047 m .81798 .67971 L .82746 .69175 L p F P
0 0 0 r
s
.195 0 .31 r
.82746 .69175 m .8294 .71243 L .81988 .70047 L p F P
0 0 0 r
s
.195 0 .31 r
.76043 .5148 m .75892 .49523 L .76886 .5087 L p F P
0 0 0 r
s
.195 0 .31 r
.76886 .5087 m .77042 .5282 L .76043 .5148 L p F P
0 0 0 r
s
.195 0 .31 r
.70099 .32912 m .69986 .31076 L .71025 .32564 L p F P
0 0 0 r
s
.195 0 .31 r
.71025 .32564 m .71144 .34396 L .70099 .32912 L p F P
0 0 0 r
s
.1 0 .485 r
.58893 .31325 m .58853 .29513 L .61052 .28697 L p F P
0 0 0 r
s
.1 0 .485 r
.58853 .29513 m .58893 .31325 L .56698 .32132 L p F P
0 0 0 r
s
.625 .201 0 r
.54261 .77716 m .52091 .78328 L .50905 .77194 L p F P
0 0 0 r
s
.625 .201 0 r
.48741 .77811 m .50905 .77194 L .52091 .78328 L p F P
0 0 0 r
s
.1 0 .485 r
.15335 .71243 m .15574 .69175 L .17592 .68525 L p F P
0 0 0 r
s
.1 0 .485 r
.15574 .69175 m .15335 .71243 L .13322 .71884 L p F P
0 0 0 r
s
0 .647 .956 r
.81971 .77242 m .82303 .77153 L .83252 .78286 L p F P
0 0 0 r
s
.125 0 .956 r
.85216 .77764 m .83252 .78286 L .82303 .77153 L p F P
0 0 0 r
s
.1 0 .485 r
.52359 .37406 m .52361 .35554 L .54534 .34763 L p F P
0 0 0 r
s
.1 0 .485 r
.52361 .35554 m .52359 .37406 L .50191 .38188 L p F P
0 0 0 r
s
.1 0 .485 r
.08788 .77337 m .09068 .75229 L .1106 .74604 L p F P
0 0 0 r
s
.1 0 .485 r
.09068 .75229 m .08788 .77337 L .06801 .77952 L p F P
0 0 0 r
s
0 .78 .71 r
.21244 .78281 m .2028 .77514 L .22087 .76699 L p F P
0 0 0 r
s
0 .78 .71 r
.22087 .76699 m .23287 .77669 L .21244 .78281 L p F P
0 0 0 r
s
.1 0 .485 r
.45821 .43491 m .45865 .416 L .48011 .40834 L p F P
0 0 0 r
s
.1 0 .485 r
.45865 .416 m .45821 .43491 L .4368 .44248 L p F P
0 0 0 r
s
.625 .201 0 r
.57594 .78235 m .5645 .77099 L p .58758 .76578 L F P
0 0 0 r
s
.625 .201 0 r
.58758 .76578 m .59789 .77622 L .57594 .78235 L p F P
0 0 0 r
s
.625 .201 0 r
.54261 .77716 m .5645 .77099 L .57594 .78235 L p F P
0 0 0 r
s
0 .78 .71 r
.25347 .77051 m .2572 .77358 L .23975 .78226 L p F P
0 0 0 r
s
0 .78 .71 r
.23975 .78226 m .23287 .77669 L .25347 .77051 L p F P
0 0 0 r
s
.1 0 .485 r
.39279 .4958 m .39365 .47649 L .41484 .46908 L p F P
0 0 0 r
s
.1 0 .485 r
.39365 .47649 m .39279 .4958 L .37164 .50311 L p F P
0 0 0 r
s
0 .78 .12 r
.2673 .78188 m .2572 .77358 L .27568 .76549 L p F P
0 0 0 r
s
0 .78 .12 r
.27568 .76549 m .28796 .77574 L .2673 .78188 L p F P
0 0 0 r
s
.511 .78 0 r
.36422 .7686 m .37034 .77398 L .35108 .78165 L p F P
0 0 0 r
s
.511 .78 0 r
.35108 .78165 m .34313 .7748 L .36422 .7686 L p F P
0 0 0 r
s
.195 0 .31 r
.80836 .66747 m .80653 .6469 L .81611 .65921 L p F P
0 0 0 r
s
.195 0 .31 r
.81611 .65921 m .81798 .67971 L .80836 .66747 L p F P
0 0 0 r
s
.195 0 .31 r
.74883 .48156 m .7474 .46218 L .75743 .47592 L p F P
0 0 0 r
s
.195 0 .31 r
.75743 .47592 m .75892 .49523 L .74883 .48156 L p F P
0 0 0 r
s
.195 0 .31 r
.68931 .29564 m .68826 .27747 L .69875 .29263 L p F P
0 0 0 r
s
.195 0 .31 r
.69875 .29263 m .69986 .31076 L .68931 .29564 L p F P
0 0 0 r
s
.625 .201 0 r
.63622 .77997 m .63104 .78141 L .62555 .77574 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.32733 .55672 m .3286 .53702 L .34953 .52986 L p F P
0 0 0 r
s
.1 0 .485 r
.3286 .53702 m .32733 .55672 L .30644 .56379 L p F P
0 0 0 r
s
0 .78 .12 r
.3088 .76956 m .31255 .77274 L .29432 .78105 L p F P
0 0 0 r
s
0 .78 .12 r
.29432 .78105 m .28796 .77574 L .3088 .76956 L p F P
0 0 0 r
s
.511 .78 0 r
.32222 .78094 m .31255 .77274 L .33172 .76496 L p F P
0 0 0 r
s
.511 .78 0 r
.33172 .76496 m .34313 .7748 L .32222 .78094 L p F P
0 0 0 r
s
.1 0 .485 r
.26182 .61769 m .26352 .59758 L .28418 .59068 L p F P
0 0 0 r
s
.1 0 .485 r
.26352 .59758 m .26182 .61769 L .2412 .6245 L p F P
0 0 0 r
s
.1 0 .485 r
.63269 .27874 m .63201 .2608 L .65423 .25248 L p F P
0 0 0 r
s
.1 0 .485 r
.63201 .2608 m .63269 .27874 L .61052 .28697 L p F P
0 0 0 r
s
.625 .656 0 r
.69505 .77804 m .68621 .78046 L .67562 .76908 L p F P
0 0 0 r
s
.625 .656 0 r
.65324 .77527 m .67562 .76908 L .68621 .78046 L p F P
0 0 0 r
s
.1 0 .485 r
.19627 .67869 m .19839 .65819 L .21879 .65154 L p F P
0 0 0 r
s
.1 0 .485 r
.19839 .65819 m .19627 .67869 L .17592 .68525 L p F P
0 0 0 r
s
.1 0 .485 r
.56724 .33966 m .56698 .32132 L .58893 .31325 L p F P
0 0 0 r
s
.1 0 .485 r
.56698 .32132 m .56724 .33966 L .54534 .34763 L p F P
0 0 0 r
s
.1 0 .485 r
.13068 .73974 m .13322 .71884 L .15335 .71243 L p F P
0 0 0 r
s
.1 0 .485 r
.13322 .71884 m .13068 .73974 L .1106 .74604 L p F P
0 0 0 r
s
.625 .656 0 r
.37721 .77999 m .37034 .77398 L .39055 .76688 L p F P
0 0 0 r
s
.625 .656 0 r
.39055 .76688 m .39837 .77385 L .37721 .77999 L p F P
0 0 0 r
s
.625 .656 0 r
.65324 .77527 m .63622 .77997 L .62555 .77574 L p F P
0 0 0 r
s
.511 .78 0 r
.70865 .77432 m .72806 .76901 L .74031 .77983 L p F P
0 0 0 r
s
0 .78 .12 r
.74146 .77952 m .74031 .77983 L .72806 .76901 L p F P
0 0 0 r
s
.1 0 .485 r
.50175 .40061 m .50191 .38188 L .52359 .37406 L p F P
0 0 0 r
s
.1 0 .485 r
.50191 .38188 m .50175 .40061 L .48011 .40834 L p F P
0 0 0 r
s
.195 0 .31 r
.6776 .26208 m .67663 .24409 L .68722 .25953 L p F P
0 0 0 r
s
.195 0 .31 r
.68722 .25953 m .68826 .27747 L .6776 .26208 L p F P
0 0 0 r
s
.195 0 .31 r
.7968 .63439 m .79505 .614 L .80473 .62658 L p F P
0 0 0 r
s
.195 0 .31 r
.80473 .62658 m .80653 .6469 L .7968 .63439 L p F P
0 0 0 r
s
.195 0 .31 r
.7372 .44823 m .73584 .42905 L .74598 .44306 L p F P
0 0 0 r
s
.195 0 .31 r
.74598 .44306 m .7474 .46218 L .7372 .44823 L p F P
0 0 0 r
s
0 .78 .12 r
.76414 .77337 m .74146 .77952 L .73128 .76813 L p F P
0 0 0 r
s
0 .78 .12 r
.72806 .76901 m .73128 .76813 L .74146 .77952 L p F P
0 0 0 r
s
.625 .656 0 r
.45367 .7729 m .45455 .77371 L .43263 .77938 L p F P
0 0 0 r
s
.625 .656 0 r
.43263 .77938 m .43227 .77905 L .45367 .7729 L p F P
0 0 0 r
s
.1 0 .485 r
.43622 .46161 m .4368 .44248 L .45821 .43491 L p F P
0 0 0 r
s
.1 0 .485 r
.4368 .44248 m .43622 .46161 L .41484 .46908 L p F P
0 0 0 r
s
.625 .656 0 r
.45367 .7729 m .43227 .77905 L .4197 .76765 L p F P
0 0 0 r
s
.625 .656 0 r
.39837 .77385 m .4197 .76765 L .43227 .77905 L p F P
0 0 0 r
s
.1 0 .485 r
.37064 .52264 m .37164 .50311 L .39279 .4958 L p F P
0 0 0 r
s
.1 0 .485 r
.37164 .50311 m .37064 .52264 L .34953 .52986 L p F P
0 0 0 r
s
.125 0 .956 r
.143 .77242 m .12289 .77858 L .10791 .76717 L p F P
0 0 0 r
s
.125 0 .956 r
.08788 .77337 m .10791 .76717 L .12289 .77858 L p F P
0 0 0 r
s
0 .78 .71 r
.80155 .7773 m .79677 .77858 L .78702 .76717 L p F P
0 0 0 r
s
0 .78 .71 r
.76738 .77249 m .78702 .76717 L .79677 .77858 L p F P
0 0 0 r
s
.625 .201 0 r
.48741 .77811 m .47771 .769 L .50217 .76537 L p F P
0 0 0 r
s
.625 .201 0 r
.50217 .76537 m .50905 .77194 L .48741 .77811 L p F P
0 0 0 r
s
.1 0 .485 r
.30502 .58371 m .30644 .56379 L .32733 .55672 L p F P
0 0 0 r
s
.1 0 .485 r
.30644 .56379 m .30502 .58371 L .28418 .59068 L p F P
0 0 0 r
s
.625 .656 0 r
.67562 .76908 m .67996 .76788 L .69505 .77804 L p F P
0 0 0 r
s
.511 .78 0 r
.70865 .77432 m .69505 .77804 L .67996 .76788 L p F P
0 0 0 r
s
.195 0 .31 r
.72554 .41482 m .72425 .39583 L .73449 .41011 L p F P
0 0 0 r
s
.195 0 .31 r
.73449 .41011 m .73584 .42905 L .72554 .41482 L p F P
0 0 0 r
s
.1 0 .485 r
.67566 .22635 m .67663 .24409 L .65423 .25248 L p F P
0 0 0 r
s
.1 0 .485 r
.23936 .64482 m .2412 .6245 L .26182 .61769 L p F P
0 0 0 r
s
.1 0 .485 r
.2412 .6245 m .23936 .64482 L .21879 .65154 L p F P
0 0 0 r
s
0 .647 .956 r
.17785 .77764 m .16579 .76818 L .18479 .76079 L p F P
0 0 0 r
s
0 .647 .956 r
.18479 .76079 m .1982 .77147 L .17785 .77764 L p F P
0 0 0 r
s
.195 0 .31 r
.78522 .60122 m .78354 .58102 L .79333 .59387 L p F P
0 0 0 r
s
.195 0 .31 r
.79333 .59387 m .79505 .614 L .78522 .60122 L p F P
0 0 0 r
s
.125 0 .956 r
.82303 .77153 m .84283 .76621 L .85216 .77764 L p F P
0 0 0 r
s
0 .78 .71 r
.78702 .76717 m .79144 .76597 L .80155 .7773 L p F P
0 0 0 r
s
0 .647 .956 r
.81971 .77242 m .80155 .7773 L .79144 .76597 L p F P
0 0 0 r
s
.625 .201 0 r
.54261 .77716 m .53088 .76573 L p .55627 .76281 L F P
0 0 0 r
s
.625 .201 0 r
.55627 .76281 m .5645 .77099 L .54261 .77716 L p F P
0 0 0 r
s
.625 .201 0 r
.50905 .77194 m .53088 .76573 L .54261 .77716 L p F P
0 0 0 r
s
.1 0 .485 r
.61106 .30512 m .61052 .28697 L .63269 .27874 L p F P
0 0 0 r
s
.1 0 .485 r
.61052 .28697 m .61106 .30512 L .58893 .31325 L p F P
0 0 0 r
s
.1 0 .485 r
.17366 .70598 m .17592 .68525 L .19627 .67869 L p F P
0 0 0 r
s
.1 0 .485 r
.17592 .68525 m .17366 .70598 L .15335 .71243 L p F P
0 0 0 r
s
.1 0 .485 r
.54546 .36618 m .54534 .34763 L .56724 .33966 L p F P
0 0 0 r
s
.1 0 .485 r
.54534 .34763 m .54546 .36618 L .52359 .37406 L p F P
0 0 0 r
s
0 .78 .71 r
.23287 .77669 m .22087 .76699 L .23979 .75929 L p F P
0 0 0 r
s
0 .78 .71 r
.23979 .75929 m .25347 .77051 L .23287 .77669 L p F P
0 0 0 r
s
.1 0 .485 r
.10791 .76717 m .1106 .74604 L .13068 .73974 L p F P
0 0 0 r
s
.1 0 .485 r
.1106 .74604 m .10791 .76717 L .08788 .77337 L p F P
0 0 0 r
s
.1 0 .485 r
.47981 .42728 m .48011 .40834 L .50175 .40061 L p F P
0 0 0 r
s
.1 0 .485 r
.48011 .40834 m .47981 .42728 L .45821 .43491 L p F P
0 0 0 r
s
.625 .201 0 r
.59789 .77622 m .61361 .77183 L .62555 .77574 L p F P
0 0 0 r
s
.625 .201 0 r
.61361 .77183 m .59789 .77622 L .58758 .76578 L closepath p F P
0 0 0 r
s
.125 0 .956 r
.16328 .76621 m .16579 .76818 L .14761 .77598 L p F P
0 0 0 r
s
.125 0 .956 r
.14761 .77598 m .143 .77242 L .16328 .76621 L p F P
0 0 0 r
s
.195 0 .31 r
.77361 .56796 m .772 .54795 L .78189 .56108 L p F P
0 0 0 r
s
.195 0 .31 r
.78189 .56108 m .78354 .58102 L .77361 .56796 L p F P
0 0 0 r
s
.1 0 .485 r
.41412 .48842 m .41484 .46908 L .43622 .46161 L p F P
0 0 0 r
s
.1 0 .485 r
.41484 .46908 m .41412 .48842 L .39279 .4958 L p F P
0 0 0 r
s
.195 0 .31 r
.83336 .7546 m .83137 .73338 L .8408 .74508 L p F P
0 0 0 r
s
.195 0 .31 r
.8408 .74508 m .84283 .76621 L .83336 .7546 L p F P
0 0 0 r
s
.195 0 .31 r
.71385 .38132 m .71264 .36252 L .72298 .37708 L p F P
0 0 0 r
s
.195 0 .31 r
.72298 .37708 m .72425 .39583 L .71385 .38132 L p F P
0 0 0 r
s
0 .78 .12 r
.28796 .77574 m .27568 .76549 L .2923 .75887 L p F P
0 0 0 r
s
0 .78 .12 r
.3088 .76956 m .28796 .77574 L p .2923 .75887 L F P
0 0 0 r
s
.625 .656 0 r
.61361 .77183 m .62002 .77004 L .62555 .77574 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.64235 .76381 m .65324 .77527 L p .62555 .77574 L F P
0 0 0 r
s
.625 .656 0 r
.62555 .77574 m .62002 .77004 L .64235 .76381 L p F P
0 0 0 r
s
.625 .656 0 r
.65324 .77527 m .64235 .76381 L p .66824 .76116 L F P
0 0 0 r
s
.625 .656 0 r
.66824 .76116 m .67562 .76908 L .65324 .77527 L p F P
0 0 0 r
s
.1 0 .485 r
.34839 .5496 m .34953 .52986 L .37064 .52264 L p F P
0 0 0 r
s
.1 0 .485 r
.34953 .52986 m .34839 .5496 L .32733 .55672 L p F P
0 0 0 r
s
0 .647 .956 r
.21872 .76525 m .22087 .76699 L .2028 .77514 L p F P
0 0 0 r
s
0 .647 .956 r
.2028 .77514 m .1982 .77147 L .21872 .76525 L p F P
0 0 0 r
s
.511 .78 0 r
.34313 .7748 m .33172 .76496 L .35169 .75763 L p F P
0 0 0 r
s
.511 .78 0 r
.35169 .75763 m .36422 .7686 L .34313 .7748 L p F P
0 0 0 r
s
.1 0 .485 r
.28261 .61082 m .28418 .59068 L .30502 .58371 L p F P
0 0 0 r
s
.1 0 .485 r
.28418 .59068 m .28261 .61082 L .26182 .61769 L p F P
0 0 0 r
s
.1 0 .485 r
.65505 .27044 m .65423 .25248 L .67663 .24409 L p F P
0 0 0 r
s
.1 0 .485 r
.65423 .25248 m .65505 .27044 L .63269 .27874 L p F P
0 0 0 r
s
.511 .78 0 r
.72806 .76901 m .70865 .77432 L .69819 .76284 L p F P
0 0 0 r
s
.511 .78 0 r
.67996 .76788 m .69819 .76284 L .70865 .77432 L p F P
0 0 0 r
s
.1 0 .485 r
.2168 .67208 m .21879 .65154 L .23936 .64482 L p F P
0 0 0 r
s
.1 0 .485 r
.21879 .65154 m .2168 .67208 L .19627 .67869 L p F P
0 0 0 r
s
.511 .78 0 r
.38548 .76236 m .39055 .76688 L .37034 .77398 L p F P
0 0 0 r
s
.511 .78 0 r
.37034 .77398 m .36422 .7686 L .38548 .76236 L p F P
0 0 0 r
s
.195 0 .31 r
.8218 .7215 m .81988 .70047 L .8294 .71243 L p F P
0 0 0 r
s
.195 0 .31 r
.8294 .71243 m .83137 .73338 L .8218 .7215 L p F P
0 0 0 r
s
.195 0 .31 r
.76196 .53462 m .76043 .5148 L .77042 .5282 L p F P
0 0 0 r
s
.195 0 .31 r
.77042 .5282 m .772 .54795 L .76196 .53462 L p F P
0 0 0 r
s
.195 0 .31 r
.70213 .34773 m .70099 .32912 L .71144 .34396 L p F P
0 0 0 r
s
.195 0 .31 r
.71144 .34396 m .71264 .36252 L .70213 .34773 L p F P
0 0 0 r
s
.1 0 .485 r
.58934 .33161 m .58893 .31325 L .61106 .30512 L p F P
0 0 0 r
s
.1 0 .485 r
.58893 .31325 m .58934 .33161 L .56724 .33966 L p F P
0 0 0 r
s
.1 0 .485 r
.15093 .73338 m .15335 .71243 L .17366 .70598 L p F P
0 0 0 r
s
.1 0 .485 r
.15335 .71243 m .15093 .73338 L .13068 .73974 L p F P
0 0 0 r
s
.625 .656 0 r
.39837 .77385 m .39055 .76688 L .41163 .76033 L p F P
0 0 0 r
s
.625 .656 0 r
.41163 .76033 m .4197 .76765 L .39837 .77385 L p F P
0 0 0 r
s
.625 .656 0 r
.47525 .76669 m .47771 .769 L .45455 .77371 L p F P
0 0 0 r
s
.625 .656 0 r
.45455 .77371 m .45367 .7729 L .47525 .76669 L p F P
0 0 0 r
s
0 .78 .71 r
.27423 .76429 m .27568 .76549 L .2572 .77358 L p F P
0 0 0 r
s
0 .78 .71 r
.2572 .77358 m .25347 .77051 L .27423 .76429 L p F P
0 0 0 r
s
.1 0 .485 r
.52357 .39282 m .52359 .37406 L .54546 .36618 L p F P
0 0 0 r
s
.1 0 .485 r
.52359 .37406 m .52357 .39282 L .50175 .40061 L p F P
0 0 0 r
s
0 .78 .12 r
.76738 .77249 m .76414 .77337 L .75411 .76188 L p F P
0 0 0 r
s
0 .78 .12 r
.73128 .76813 m .75411 .76188 L .76414 .77337 L p F P
0 0 0 r
s
.1 0 .485 r
.45777 .45407 m .45821 .43491 L .47981 .42728 L p F P
0 0 0 r
s
.1 0 .485 r
.45821 .43491 m .45777 .45407 L .43622 .46161 L p F P
0 0 0 r
s
.625 .656 0 r
.47525 .76669 m .45367 .7729 L .44121 .7614 L p F P
0 0 0 r
s
.625 .656 0 r
.4197 .76765 m .44121 .7614 L .45367 .7729 L p F P
0 0 0 r
s
0 .78 .12 r
.32982 .76332 m .33172 .76496 L .31255 .77274 L p F P
0 0 0 r
s
0 .78 .12 r
.31255 .77274 m .3088 .76956 L .32982 .76332 L p F P
0 0 0 r
s
0 .78 .12 r
.75411 .76188 m .75618 .76131 L .76738 .77249 L p F P
0 0 0 r
s
0 .78 .71 r
.78702 .76717 m .76738 .77249 L .75618 .76131 L p F P
0 0 0 r
s
.1 0 .485 r
.39192 .51536 m .39279 .4958 L .41412 .48842 L p F P
0 0 0 r
s
.1 0 .485 r
.39279 .4958 m .39192 .51536 L .37064 .52264 L p F P
0 0 0 r
s
.125 0 .956 r
.16328 .76621 m .143 .77242 L .12811 .76091 L p F P
0 0 0 r
s
.125 0 .956 r
.10791 .76717 m .12811 .76091 L .143 .77242 L p F P
0 0 0 r
s
0 .647 .956 r
.82303 .77153 m .81971 .77242 L .81009 .76091 L p F P
0 0 0 r
s
0 .647 .956 r
.79144 .76597 m .81009 .76091 L .81971 .77242 L p F P
0 0 0 r
s
.195 0 .31 r
.75029 .50119 m .74883 .48156 L .75892 .49523 L p F P
0 0 0 r
s
.195 0 .31 r
.75892 .49523 m .76043 .5148 L .75029 .50119 L p F P
0 0 0 r
s
.1 0 .485 r
.32604 .57669 m .32733 .55672 L .34839 .5496 L p F P
0 0 0 r
s
.1 0 .485 r
.32733 .55672 m .32604 .57669 L .30502 .58371 L p F P
0 0 0 r
s
.195 0 .31 r
.8102 .68832 m .80836 .66747 L .81798 .67971 L p F P
0 0 0 r
s
.195 0 .31 r
.81798 .67971 m .81988 .70047 L .8102 .68832 L p F P
0 0 0 r
s
.195 0 .31 r
.69038 .31406 m .68931 .29564 L .69986 .31076 L p F P
0 0 0 r
s
.195 0 .31 r
.69986 .31076 m .70099 .32912 L .69038 .31406 L p F P
0 0 0 r
s
.625 .201 0 r
.50905 .77194 m .50217 .76537 L .5281 .76302 L p F P
0 0 0 r
s
.625 .201 0 r
.5281 .76302 m .53088 .76573 L .50905 .77194 L p F P
0 0 0 r
s
.625 .656 0 r
.62002 .77004 m .61361 .77183 L .58758 .76578 L p F P
0 0 0 r
s
0 .647 .956 r
.81009 .76091 m .81326 .76005 L .82303 .77153 L p F P
0 0 0 r
s
.125 0 .956 r
.84283 .76621 m .82303 .77153 L .81326 .76005 L p F P
0 0 0 r
s
.1 0 .485 r
.2601 .63806 m .26182 .61769 L .28261 .61082 L p F P
0 0 0 r
s
.1 0 .485 r
.26182 .61769 m .2601 .63806 L .23936 .64482 L p F P
0 0 0 r
s
0 .647 .956 r
.1982 .77147 m .18479 .76079 L .20439 .75366 L p F P
0 0 0 r
s
0 .647 .956 r
.20439 .75366 m .21872 .76525 L .1982 .77147 L p F P
0 0 0 r
s
.1 0 .485 r
.63338 .29691 m .63269 .27874 L .65505 .27044 L p F P
0 0 0 r
s
.1 0 .485 r
.63269 .27874 m .63338 .29691 L .61106 .30512 L p F P
0 0 0 r
s
.625 .201 0 r
.5645 .77099 m .58463 .76532 L .58758 .76578 L p F P
0 0 0 r
s
.625 .201 0 r
.58463 .76532 m .5645 .77099 L .55627 .76281 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.19413 .69946 m .19627 .67869 L .2168 .67208 L p F P
0 0 0 r
s
.1 0 .485 r
.19627 .67869 m .19413 .69946 L .17366 .70598 L p F P
0 0 0 r
s
.1 0 .485 r
.56751 .35823 m .56724 .33966 L .58934 .33161 L p F P
0 0 0 r
s
.1 0 .485 r
.56724 .33966 m .56751 .35823 L .54546 .36618 L p F P
0 0 0 r
s
0 .78 .71 r
.25347 .77051 m .23979 .75929 L .24523 .75722 L p F P
0 0 0 r
s
0 .78 .71 r
.27423 .76429 m .25347 .77051 L p .24523 .75722 L F P
0 0 0 r
s
.1 0 .485 r
.12811 .76091 m .13068 .73974 L .15093 .73338 L p F P
0 0 0 r
s
.1 0 .485 r
.13068 .73974 m .12811 .76091 L .10791 .76717 L p F P
0 0 0 r
s
.195 0 .31 r
.79858 .65504 m .7968 .63439 L .80653 .6469 L p F P
0 0 0 r
s
.195 0 .31 r
.80653 .6469 m .80836 .66747 L .79858 .65504 L p F P
0 0 0 r
s
.195 0 .31 r
.73859 .46767 m .7372 .44823 L .7474 .46218 L p F P
0 0 0 r
s
.195 0 .31 r
.7474 .46218 m .74883 .48156 L .73859 .46767 L p F P
0 0 0 r
s
.195 0 .31 r
.6786 .28029 m .6776 .26208 L .68826 .27747 L p F P
0 0 0 r
s
.195 0 .31 r
.68826 .27747 m .68931 .29564 L .6786 .28029 L p F P
0 0 0 r
s
.1 0 .485 r
.50159 .41959 m .50175 .40061 L .52357 .39282 L p F P
0 0 0 r
s
.1 0 .485 r
.50175 .40061 m .50159 .41959 L .47981 .42728 L p F P
0 0 0 r
s
.625 .656 0 r
.64235 .76381 m .62002 .77004 L .60884 .75849 L p F P
0 0 0 r
s
.625 .656 0 r
.60884 .75849 m .62002 .77004 L p .58758 .76578 L F P
0 0 0 r
s
.1 0 .485 r
.43563 .48098 m .43622 .46161 L .45777 .45407 L p F P
0 0 0 r
s
.1 0 .485 r
.43622 .46161 m .43563 .48098 L .41412 .48842 L p F P
0 0 0 r
s
0 .78 .12 r
.32982 .76332 m .3088 .76956 L .29518 .75801 L p F P
0 0 0 r
s
0 .78 .12 r
.2923 .75887 m .29518 .75801 L .3088 .76956 L p F P
0 0 0 r
s
.1 0 .485 r
.36963 .54242 m .37064 .52264 L .39192 .51536 L p F P
0 0 0 r
s
.1 0 .485 r
.37064 .52264 m .36963 .54242 L .34839 .5496 L p F P
0 0 0 r
s
.625 .656 0 r
.67996 .76788 m .67562 .76908 L .66824 .76116 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.69819 .76284 m .71461 .7583 L .72806 .76901 L p F P
0 0 0 r
s
0 .78 .12 r
.73128 .76813 m .72806 .76901 L .71461 .7583 L p F P
0 0 0 r
s
.625 .656 0 r
.49701 .76043 m .50217 .76537 L .47771 .769 L p F P
0 0 0 r
s
.625 .656 0 r
.47771 .769 m .47525 .76669 L .49701 .76043 L p F P
0 0 0 r
s
.511 .78 0 r
.36422 .7686 m .35169 .75763 L .37175 .75088 L p F P
0 0 0 r
s
.511 .78 0 r
.38548 .76236 m .36422 .7686 L p .37175 .75088 L F P
0 0 0 r
s
.1 0 .485 r
.30358 .6039 m .30502 .58371 L .32604 .57669 L p F P
0 0 0 r
s
.1 0 .485 r
.30502 .58371 m .30358 .6039 L .28261 .61082 L p F P
0 0 0 r
s
.125 0 .956 r
.18373 .75995 m .18479 .76079 L .16579 .76818 L p F P
0 0 0 r
s
.125 0 .956 r
.16579 .76818 m .16328 .76621 L .18373 .75995 L p F P
0 0 0 r
s
.1 0 .485 r
.23749 .66541 m .23936 .64482 L .2601 .63806 L p F P
0 0 0 r
s
.1 0 .485 r
.23936 .64482 m .23749 .66541 L .2168 .67208 L p F P
0 0 0 r
s
.195 0 .31 r
.72685 .43406 m .72554 .41482 L .73584 .42905 L p F P
0 0 0 r
s
.195 0 .31 r
.73584 .42905 m .7372 .44823 L .72685 .43406 L p F P
0 0 0 r
s
.1 0 .485 r
.67663 .24409 m .6776 .26208 L .65505 .27044 L p F P
0 0 0 r
s
0 .78 .12 r
.75411 .76188 m .73128 .76813 L .72095 .75655 L p F P
0 0 0 r
s
0 .78 .12 r
.71461 .7583 m .72095 .75655 L .73128 .76813 L p F P
0 0 0 r
s
.195 0 .31 r
.78692 .62168 m .78522 .60122 L .79505 .614 L p F P
0 0 0 r
s
.195 0 .31 r
.79505 .614 m .7968 .63439 L .78692 .62168 L p F P
0 0 0 r
s
.511 .78 0 r
.69819 .76284 m .67996 .76788 L .66824 .76116 L p F P
0 0 0 r
s
.1 0 .485 r
.61162 .3235 m .61106 .30512 L .63338 .29691 L p F P
0 0 0 r
s
.1 0 .485 r
.61106 .30512 m .61162 .3235 L .58934 .33161 L p F P
0 0 0 r
s
.625 .656 0 r
.4197 .76765 m .41163 .76033 L .43354 .75431 L p F P
0 0 0 r
s
.625 .656 0 r
.43354 .75431 m .44121 .7614 L .4197 .76765 L p F P
0 0 0 r
s
.1 0 .485 r
.17136 .72697 m .17366 .70598 L .19413 .69946 L p F P
0 0 0 r
s
.1 0 .485 r
.17366 .70598 m .17136 .72697 L .15093 .73338 L p F P
0 0 0 r
s
.1 0 .485 r
.54558 .38497 m .54546 .36618 L .56751 .35823 L p F P
0 0 0 r
s
.1 0 .485 r
.54546 .36618 m .54558 .38497 L .52357 .39282 L p F P
0 0 0 r
s
0 .78 .71 r
.79144 .76597 m .78702 .76717 L .77712 .75558 L p F P
0 0 0 r
s
0 .78 .71 r
.75618 .76131 m .77712 .75558 L .78702 .76717 L p F P
0 0 0 r
s
0 .647 .956 r
.23942 .75898 m .23979 .75929 L .22087 .76699 L p F P
0 0 0 r
s
0 .647 .956 r
.22087 .76699 m .21872 .76525 L .23942 .75898 L p F P
0 0 0 r
s
.511 .78 0 r
.40692 .75606 m .41163 .76033 L .39055 .76688 L p F P
0 0 0 r
s
.511 .78 0 r
.39055 .76688 m .38548 .76236 L .40692 .75606 L p F P
0 0 0 r
s
.1 0 .485 r
.47951 .44647 m .47981 .42728 L .50159 .41959 L p F P
0 0 0 r
s
.1 0 .485 r
.47981 .42728 m .47951 .44647 L .45777 .45407 L p F P
0 0 0 r
s
.625 .656 0 r
.49701 .76043 m .47525 .76669 L .4629 .75509 L p F P
0 0 0 r
s
.625 .656 0 r
.44121 .7614 m .4629 .75509 L .47525 .76669 L p F P
0 0 0 r
s
.195 0 .31 r
.77523 .58823 m .77361 .56796 L .78354 .58102 L p F P
0 0 0 r
s
.195 0 .31 r
.78354 .58102 m .78522 .60122 L .77523 .58823 L p F P
0 0 0 r
s
.195 0 .31 r
.71508 .40037 m .71385 .38132 L .72425 .39583 L p F P
0 0 0 r
s
.195 0 .31 r
.72425 .39583 m .72554 .41482 L .71508 .40037 L p F P
0 0 0 r
s
.125 0 .956 r
.81326 .76005 m .83336 .7546 L .84283 .76621 L p F P
0 0 0 r
s
.1 0 .485 r
.41339 .50802 m .41412 .48842 L .43563 .48098 L p F P
0 0 0 r
s
.1 0 .485 r
.41412 .48842 m .41339 .50802 L .39192 .51536 L p F P
0 0 0 r
s
.125 0 .956 r
.18373 .75995 m .16328 .76621 L .14848 .7546 L p F P
0 0 0 r
s
.125 0 .956 r
.12811 .76091 m .14848 .7546 L .16328 .76621 L p F P
0 0 0 r
s
0 .78 .71 r
.77712 .75558 m .78088 .75455 L .79144 .76597 L p F P
0 0 0 r
s
0 .647 .956 r
.81009 .76091 m .79144 .76597 L .78088 .75455 L p F P
0 0 0 r
s
.625 .656 0 r
.58758 .76578 m .58658 .76477 L .60884 .75849 L p F P
0 0 0 r
s
.625 .656 0 r
.58463 .76532 m .58658 .76477 L .58758 .76578 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.34723 .5696 m .34839 .5496 L .36963 .54242 L p F P
0 0 0 r
s
.1 0 .485 r
.34839 .5496 m .34723 .5696 L .32604 .57669 L p F P
0 0 0 r
s
.625 .201 0 r
.53088 .76573 m .54187 .7626 L .55627 .76281 L p F P
0 0 0 r
s
.625 .201 0 r
.54187 .7626 m .53088 .76573 L .5281 .76302 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.27568 .76549 m .27423 .76429 L .2923 .75887 L closepath p F P
0 0 0 r
s
.625 .656 0 r
.51896 .75412 m .5281 .76302 L .50217 .76537 L p F P
0 0 0 r
s
.625 .656 0 r
.50217 .76537 m .49701 .76043 L .51896 .75412 L p F P
0 0 0 r
s
.625 .656 0 r
.58658 .76477 m .58463 .76532 L .55627 .76281 L p F P
0 0 0 r
s
.1 0 .485 r
.28102 .63123 m .28261 .61082 L .30358 .6039 L p F P
0 0 0 r
s
.1 0 .485 r
.28261 .61082 m .28102 .63123 L .2601 .63806 L p F P
0 0 0 r
s
0 .647 .956 r
.21872 .76525 m .20439 .75366 L .20526 .75335 L p F P
0 0 0 r
s
0 .647 .956 r
.23942 .75898 m .21872 .76525 L p .20526 .75335 L F P
0 0 0 r
s
0 .78 .12 r
.35102 .75704 m .35169 .75763 L .33172 .76496 L p F P
0 0 0 r
s
0 .78 .12 r
.33172 .76496 m .32982 .76332 L .35102 .75704 L p F P
0 0 0 r
s
.1 0 .485 r
.65589 .28864 m .65505 .27044 L .6776 .26208 L p F P
0 0 0 r
s
.1 0 .485 r
.65505 .27044 m .65589 .28864 L .63338 .29691 L p F P
0 0 0 r
s
.625 .656 0 r
.60884 .75849 m .58658 .76477 L .57509 .75314 L p F P
0 0 0 r
s
.625 .656 0 r
.57509 .75314 m .58658 .76477 L p .55627 .76281 L F P
0 0 0 r
s
.1 0 .485 r
.21478 .6929 m .2168 .67208 L .23749 .66541 L p F P
0 0 0 r
s
.1 0 .485 r
.2168 .67208 m .21478 .6929 L .19413 .69946 L p F P
0 0 0 r
s
.1 0 .485 r
.14848 .7546 m .15093 .73338 L .17136 .72697 L p F P
0 0 0 r
s
.1 0 .485 r
.15093 .73338 m .14848 .7546 L .12811 .76091 L p F P
0 0 0 r
s
.195 0 .31 r
.82374 .74281 m .8218 .7215 L .83137 .73338 L p F P
0 0 0 r
s
.195 0 .31 r
.83137 .73338 m .83336 .7546 L .82374 .74281 L p F P
0 0 0 r
s
.195 0 .31 r
.76351 .5547 m .76196 .53462 L .772 .54795 L p F P
0 0 0 r
s
.195 0 .31 r
.772 .54795 m .77361 .56796 L .76351 .5547 L p F P
0 0 0 r
s
.195 0 .31 r
.70329 .36658 m .70213 .34773 L .71264 .36252 L p F P
0 0 0 r
s
.195 0 .31 r
.71264 .36252 m .71385 .38132 L .70329 .36658 L p F P
0 0 0 r
s
.1 0 .485 r
.58975 .35021 m .58934 .33161 L .61162 .3235 L p F P
0 0 0 r
s
.1 0 .485 r
.58934 .33161 m .58975 .35021 L .56751 .35823 L p F P
0 0 0 r
s
0 .78 .71 r
.2923 .75887 m .27423 .76429 L .26029 .75265 L p F P
0 0 0 r
s
0 .78 .71 r
.24523 .75722 m .26029 .75265 L .27423 .76429 L p F P
0 0 0 r
s
.1 0 .485 r
.52356 .41183 m .52357 .39282 L .54558 .38497 L p F P
0 0 0 r
s
.1 0 .485 r
.52357 .39282 m .52356 .41183 L .50159 .41959 L p F P
0 0 0 r
s
.625 .656 0 r
.64235 .76381 m .66247 .75819 L .66824 .76116 L p F P
0 0 0 r
s
.625 .656 0 r
.66247 .75819 m .64235 .76381 L .63129 .75216 L p F P
0 0 0 r
s
.625 .656 0 r
.60884 .75849 m .63129 .75216 L .64235 .76381 L p F P
0 0 0 r
s
.1 0 .485 r
.45732 .47348 m .45777 .45407 L .47951 .44647 L p F P
0 0 0 r
s
.1 0 .485 r
.45777 .45407 m .45732 .47348 L .43563 .48098 L p F P
0 0 0 r
s
0 .78 .12 r
.35102 .75704 m .32982 .76332 L .3163 .75167 L p F P
0 0 0 r
s
0 .78 .12 r
.29518 .75801 m .3163 .75167 L .32982 .76332 L p F P
0 0 0 r
s
.625 .656 0 r
.55289 .75946 m .54187 .7626 L .5281 .76302 L p F P
0 0 0 r
s
.625 .656 0 r
.54109 .74775 m .55289 .75946 L p .5281 .76302 L F P
0 0 0 r
s
.625 .656 0 r
.5281 .76302 m .51896 .75412 L .54109 .74775 L p F P
0 0 0 r
s
.1 0 .485 r
.39105 .53518 m .39192 .51536 L .41339 .50802 L p F P
0 0 0 r
s
.1 0 .485 r
.39192 .51536 m .39105 .53518 L .36963 .54242 L p F P
0 0 0 r
s
.511 .78 0 r
.71461 .7583 m .69819 .76284 L .68756 .75118 L p F P
0 0 0 r
s
.511 .78 0 r
.68756 .75118 m .69819 .76284 L p .66824 .76116 L F P
0 0 0 r
s
.625 .656 0 r
.55627 .76281 m .55289 .75946 L .57509 .75314 L p F P
0 0 0 r
s
.625 .656 0 r
.54187 .7626 m .55289 .75946 L .55627 .76281 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.81207 .70944 m .8102 .68832 L .81988 .70047 L p F P
0 0 0 r
s
.195 0 .31 r
.81988 .70047 m .8218 .7215 L .81207 .70944 L p F P
0 0 0 r
s
.195 0 .31 r
.75177 .52107 m .75029 .50119 L .76043 .5148 L p F P
0 0 0 r
s
.195 0 .31 r
.76043 .5148 m .76196 .53462 L .75177 .52107 L p F P
0 0 0 r
s
.195 0 .31 r
.69146 .33271 m .69038 .31406 L .70099 .32912 L p F P
0 0 0 r
s
.195 0 .31 r
.70099 .32912 m .70213 .34773 L .69146 .33271 L p F P
0 0 0 r
s
.511 .78 0 r
.40692 .75606 m .38548 .76236 L .37239 .75069 L p F P
0 0 0 r
s
.1 0 .485 r
.32473 .59691 m .32604 .57669 L .34723 .5696 L p F P
0 0 0 r
s
.511 .78 0 r
.37175 .75088 m .37239 .75069 L .38548 .76236 L p F P
0 0 0 r
s
.1 0 .485 r
.32604 .57669 m .32473 .59691 L .30358 .6039 L p F P
0 0 0 r
s
0 .78 .12 r
.75618 .76131 m .75411 .76188 L .74391 .7502 L p F P
0 0 0 r
s
0 .78 .12 r
.72095 .75655 m .74391 .7502 L .75411 .76188 L p F P
0 0 0 r
s
.1 0 .485 r
.25836 .65869 m .2601 .63806 L .28102 .63123 L p F P
0 0 0 r
s
.1 0 .485 r
.2601 .63806 m .25836 .65869 L .23749 .66541 L p F P
0 0 0 r
s
.1 0 .485 r
.63408 .31532 m .63338 .29691 L .65589 .28864 L p F P
0 0 0 r
s
.1 0 .485 r
.63338 .29691 m .63408 .31532 L .61162 .3235 L p F P
0 0 0 r
s
.625 .656 0 r
.44121 .7614 m .43354 .75431 L .45628 .74887 L p F P
0 0 0 r
s
.625 .656 0 r
.45628 .74887 m .4629 .75509 L .44121 .7614 L p F P
0 0 0 r
s
.1 0 .485 r
.19196 .72051 m .19413 .69946 L .21478 .6929 L p F P
0 0 0 r
s
.1 0 .485 r
.19413 .69946 m .19196 .72051 L .17136 .72697 L p F P
0 0 0 r
s
0 .78 .12 r
.74391 .7502 m .74424 .75011 L .75618 .76131 L p F P
0 0 0 r
s
0 .78 .71 r
.77712 .75558 m .75618 .76131 L .74424 .75011 L p F P
0 0 0 r
s
.511 .78 0 r
.66824 .76116 m .66486 .75752 L .68756 .75118 L p F P
0 0 0 r
s
.511 .78 0 r
.66247 .75819 m .66486 .75752 L .66824 .76116 L closepath p F P
0 0 0 r
s
0 .647 .956 r
.81326 .76005 m .81009 .76091 L .80033 .74922 L p F P
0 0 0 r
s
0 .647 .956 r
.78088 .75455 m .80033 .74922 L .81009 .76091 L p F P
0 0 0 r
s
.1 0 .485 r
.56778 .37704 m .56751 .35823 L .58975 .35021 L p F P
0 0 0 r
s
.1 0 .485 r
.56751 .35823 m .56778 .37704 L .54558 .38497 L p F P
0 0 0 r
s
.125 0 .956 r
.20435 .75363 m .20439 .75366 L .18479 .76079 L p F P
0 0 0 r
s
.125 0 .956 r
.18479 .76079 m .18373 .75995 L .20435 .75363 L p F P
0 0 0 r
s
.1 0 .485 r
.50143 .43881 m .50159 .41959 L .52356 .41183 L p F P
0 0 0 r
s
.1 0 .485 r
.50159 .41959 m .50143 .43881 L .47951 .44647 L p F P
0 0 0 r
s
.625 .656 0 r
.51896 .75412 m .49701 .76043 L .48478 .74873 L p F P
0 0 0 r
s
.625 .656 0 r
.4629 .75509 m .48478 .74873 L .49701 .76043 L p F P
0 0 0 r
s
.195 0 .31 r
.80037 .67597 m .79858 .65504 L .80836 .66747 L p F P
0 0 0 r
s
.195 0 .31 r
.80836 .66747 m .8102 .68832 L .80037 .67597 L p F P
0 0 0 r
s
.195 0 .31 r
.73999 .48736 m .73859 .46767 L .74883 .48156 L p F P
0 0 0 r
s
.195 0 .31 r
.74883 .48156 m .75029 .50119 L .73999 .48736 L p F P
0 0 0 r
s
.195 0 .31 r
.6796 .29875 m .6786 .28029 L .68931 .29564 L p F P
0 0 0 r
s
.195 0 .31 r
.68931 .29564 m .69038 .31406 L .6796 .29875 L p F P
0 0 0 r
s
.511 .78 0 r
.42855 .74971 m .43354 .75431 L .41163 .76033 L p F P
0 0 0 r
s
.511 .78 0 r
.41163 .76033 m .40692 .75606 L .42855 .74971 L p F P
0 0 0 r
s
0 .647 .956 r
.80033 .74922 m .80322 .74843 L .81326 .76005 L p F P
0 0 0 r
s
.125 0 .956 r
.83336 .7546 m .81326 .76005 L .80322 .74843 L p F P
0 0 0 r
s
.1 0 .485 r
.43504 .50061 m .43563 .48098 L .45732 .47348 L p F P
0 0 0 r
s
.1 0 .485 r
.43563 .48098 m .43504 .50061 L .41339 .50802 L p F P
0 0 0 r
s
.125 0 .956 r
.20435 .75363 m .18373 .75995 L .16903 .74824 L p F P
0 0 0 r
s
.125 0 .956 r
.14848 .7546 m .16903 .74824 L .18373 .75995 L p F P
0 0 0 r
s
.1 0 .485 r
.3686 .56246 m .36963 .54242 L .39105 .53518 L p F P
0 0 0 r
s
.1 0 .485 r
.36963 .54242 m .3686 .56246 L .34723 .5696 L p F P
0 0 0 r
s
.625 .656 0 r
.57509 .75314 m .55289 .75946 L .54109 .74775 L p F P
0 0 0 r
s
0 .647 .956 r
.23979 .75929 m .23942 .75898 L .24523 .75722 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.30212 .62435 m .30358 .6039 L .32473 .59691 L p F P
0 0 0 r
s
.1 0 .485 r
.30358 .6039 m .30212 .62435 L .28102 .63123 L p F P
0 0 0 r
s
0 .647 .956 r
.24523 .75722 m .23942 .75898 L .22515 .74726 L p F P
0 0 0 r
s
0 .647 .956 r
.20526 .75335 m .22515 .74726 L .23942 .75898 L p F P
0 0 0 r
s
0 .78 .12 r
.29499 .75784 m .29518 .75801 L .2923 .75887 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.28134 .74627 m .29499 .75784 L .2923 .75887 L p F P
0 0 0 r
s
0 .78 .71 r
.26029 .75265 m .28134 .74627 L p .2923 .75887 L F P
0 0 0 r
s
.195 0 .31 r
.72818 .45356 m .72685 .43406 L .7372 .44823 L p F P
0 0 0 r
s
.195 0 .31 r
.7372 .44823 m .73859 .46767 L .72818 .45356 L p F P
0 0 0 r
s
.1 0 .485 r
.6776 .26208 m .6786 .28029 L .65589 .28864 L p F P
0 0 0 r
s
.625 .656 0 r
.60884 .75849 m .59747 .74676 L p .62316 .7436 L F P
0 0 0 r
s
.625 .656 0 r
.62316 .7436 m .63129 .75216 L .60884 .75849 L p F P
0 0 0 r
s
.625 .656 0 r
.57509 .75314 m .59747 .74676 L .60884 .75849 L p F P
0 0 0 r
s
.1 0 .485 r
.2356 .68627 m .23749 .66541 L .25836 .65869 L p F P
0 0 0 r
s
.1 0 .485 r
.23749 .66541 m .2356 .68627 L .21478 .6929 L p F P
0 0 0 r
s
.195 0 .31 r
.78864 .64242 m .78692 .62168 L .7968 .63439 L p F P
0 0 0 r
s
.195 0 .31 r
.7968 .63439 m .79858 .65504 L .78864 .64242 L p F P
0 0 0 r
s
.511 .78 0 r
.68756 .75118 m .69971 .74779 L .71461 .7583 L p F P
0 0 0 r
s
0 .78 .12 r
.72095 .75655 m .71461 .7583 L .69971 .74779 L p F P
0 0 0 r
s
.625 .656 0 r
.63129 .75216 m .64128 .74934 L .66247 .75819 L p F P
0 0 0 r
s
.511 .78 0 r
.66486 .75752 m .66247 .75819 L .64128 .74934 L p F P
0 0 0 r
s
.1 0 .485 r
.61217 .34213 m .61162 .3235 L .63408 .31532 L p F P
0 0 0 r
s
.1 0 .485 r
.61162 .3235 m .61217 .34213 L .58975 .35021 L p F P
0 0 0 r
s
0 .78 .12 r
.29518 .75801 m .29499 .75784 L .31507 .75061 L p F P
0 0 0 r
s
0 .78 .12 r
.31507 .75061 m .3163 .75167 L .29518 .75801 L p F P
0 0 0 r
s
.1 0 .485 r
.16903 .74824 m .17136 .72697 L .19196 .72051 L p F P
0 0 0 r
s
.1 0 .485 r
.17136 .72697 m .16903 .74824 L .14848 .7546 L p F P
0 0 0 r
s
0 .78 .71 r
.30257 .73984 m .31507 .75061 L .29499 .75784 L p F P
0 0 0 r
s
0 .78 .71 r
.29499 .75784 m .28134 .74627 L .30257 .73984 L p F P
0 0 0 r
s
0 .78 .12 r
.35169 .75763 m .35102 .75704 L .37175 .75088 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.54571 .404 m .54558 .38497 L .56778 .37704 L p F P
0 0 0 r
s
.1 0 .485 r
.54558 .38497 m .54571 .404 L .52356 .41183 L p F P
0 0 0 r
s
.511 .78 0 r
.68756 .75118 m .66486 .75752 L .65393 .74578 L p F P
0 0 0 r
s
.511 .78 0 r
.64128 .74934 m .65393 .74578 L .66486 .75752 L p F P
0 0 0 r
s
0 .78 .71 r
.25947 .75197 m .26029 .75265 L .24523 .75722 L closepath p F P
0 0 0 r
s
0 .647 .956 r
.24613 .74083 m .25947 .75197 L .24523 .75722 L p F P
0 0 0 r
s
0 .647 .956 r
.22515 .74726 m .24613 .74083 L p .24523 .75722 L F P
0 0 0 r
s
.1 0 .485 r
.4792 .46592 m .47951 .44647 L .50143 .43881 L p F P
0 0 0 r
s
.1 0 .485 r
.47951 .44647 m .4792 .46592 L .45732 .47348 L p F P
0 0 0 r
s
0 .78 .12 r
.37175 .75088 m .35102 .75704 L .33761 .74529 L p F P
0 0 0 r
s
0 .78 .12 r
.3163 .75167 m .33761 .74529 L .35102 .75704 L p F P
0 0 0 r
s
.1 0 .485 r
.41265 .52787 m .41339 .50802 L .43504 .50061 L p F P
0 0 0 r
s
.1 0 .485 r
.41339 .50802 m .41265 .52787 L .39105 .53518 L p F P
0 0 0 r
s
.195 0 .31 r
.77688 .60878 m .77523 .58823 L .78522 .60122 L p F P
0 0 0 r
s
.195 0 .31 r
.78522 .60122 m .78692 .62168 L .77688 .60878 L p F P
0 0 0 r
s
.195 0 .31 r
.71633 .41967 m .71508 .40037 L .72554 .41482 L p F P
0 0 0 r
s
.195 0 .31 r
.72554 .41482 m .72685 .43406 L .71633 .41967 L p F P
0 0 0 r
s
0 .78 .12 r
.72095 .75655 m .71046 .74479 L p .7425 .74859 L F P
0 0 0 r
s
0 .78 .12 r
.7425 .74859 m .74391 .7502 L .72095 .75655 L p F P
0 0 0 r
s
0 .78 .12 r
.69971 .74779 m .71046 .74479 L .72095 .75655 L p F P
0 0 0 r
s
.511 .78 0 r
.42855 .74971 m .40692 .75606 L .39395 .7443 L p F P
0 0 0 r
s
.1 0 .485 r
.34605 .58987 m .34723 .5696 L .3686 .56246 L p F P
0 0 0 r
s
.511 .78 0 r
.37239 .75069 m .39395 .7443 L .40692 .75606 L p F P
0 0 0 r
s
.1 0 .485 r
.34723 .5696 m .34605 .58987 L .32473 .59691 L p F P
0 0 0 r
s
0 .78 .71 r
.78088 .75455 m .77712 .75558 L .76706 .7438 L p F P
0 0 0 r
s
0 .78 .71 r
.74424 .75011 m .76706 .7438 L .77712 .75558 L p F P
0 0 0 r
s
.1 0 .485 r
.27941 .65191 m .28102 .63123 L .30212 .62435 L p F P
0 0 0 r
s
.1 0 .485 r
.28102 .63123 m .27941 .65191 L .25836 .65869 L p F P
0 0 0 r
s
.1 0 .485 r
.65675 .30707 m .65589 .28864 L .6786 .28029 L p F P
0 0 0 r
s
.1 0 .485 r
.65589 .28864 m .65675 .30707 L .63408 .31532 L p F P
0 0 0 r
s
.625 .656 0 r
.4629 .75509 m .45628 .74887 L .4799 .74406 L p F P
0 0 0 r
s
.625 .656 0 r
.4799 .74406 m .48478 .74873 L .4629 .75509 L p F P
0 0 0 r
s
.1 0 .485 r
.21273 .71398 m .21478 .6929 L .2356 .68627 L p F P
0 0 0 r
s
.1 0 .485 r
.21478 .6929 m .21273 .71398 L .19196 .72051 L p F P
0 0 0 r
s
.195 0 .31 r
.70446 .38568 m .70329 .36658 L .71385 .38132 L p F P
0 0 0 r
s
.195 0 .31 r
.71385 .38132 m .71508 .40037 L .70446 .38568 L p F P
0 0 0 r
s
.125 0 .956 r
.80322 .74843 m .82374 .74281 L .83336 .7546 L p F P
0 0 0 r
s
.1 0 .485 r
.59016 .36905 m .58975 .35021 L .61217 .34213 L p F P
0 0 0 r
s
.1 0 .485 r
.58975 .35021 m .59016 .36905 L .56778 .37704 L p F P
0 0 0 r
s
.195 0 .31 r
.76509 .57505 m .76351 .5547 L .77361 .56796 L p F P
0 0 0 r
s
.195 0 .31 r
.77361 .56796 m .77523 .58823 L .76509 .57505 L p F P
0 0 0 r
s
0 .78 .71 r
.76706 .7438 m .76983 .74304 L .78088 .75455 L p F P
0 0 0 r
s
0 .647 .956 r
.80033 .74922 m .78088 .75455 L .76983 .74304 L p F P
0 0 0 r
s
.511 .78 0 r
.45036 .74331 m .45628 .74887 L .43354 .75431 L p F P
0 0 0 r
s
.511 .78 0 r
.43354 .75431 m .42855 .74971 L .45036 .74331 L p F P
0 0 0 r
s
.1 0 .485 r
.52354 .43108 m .52356 .41183 L .54571 .404 L p F P
0 0 0 r
s
.1 0 .485 r
.52356 .41183 m .52354 .43108 L .50143 .43881 L p F P
0 0 0 r
s
.625 .656 0 r
.51896 .75412 m .50685 .74232 L p .53038 .73712 L F P
0 0 0 r
s
.625 .656 0 r
.53038 .73712 m .54109 .74775 L .51896 .75412 L p F P
0 0 0 r
s
.625 .656 0 r
.48478 .74873 m .50685 .74232 L .51896 .75412 L p F P
0 0 0 r
s
.125 0 .956 r
.20439 .75366 m .20435 .75363 L .20526 .75335 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.45687 .49315 m .45732 .47348 L .4792 .46592 L p F P
0 0 0 r
s
.1 0 .485 r
.45732 .47348 m .45687 .49315 L .43504 .50061 L p F P
0 0 0 r
s
.125 0 .956 r
.20526 .75335 m .20435 .75363 L .18975 .74182 L p F P
0 0 0 r
s
.125 0 .956 r
.16903 .74824 m .18975 .74182 L .20435 .75363 L p F P
0 0 0 r
s
0 .647 .956 r
.22451 .74673 m .22515 .74726 L .20526 .75335 L closepath p F P
0 0 0 r
s
.125 0 .956 r
.21066 .73535 m .22451 .74673 L .20526 .75335 L p F P
0 0 0 r
s
.125 0 .956 r
.18975 .74182 m .21066 .73535 L p .20526 .75335 L F P
0 0 0 r
s
.1 0 .485 r
.39016 .55526 m .39105 .53518 L .41265 .52787 L p F P
0 0 0 r
s
.1 0 .485 r
.39105 .53518 m .39016 .55526 L .3686 .56246 L p F P
0 0 0 r
s
.625 .656 0 r
.57509 .75314 m .56341 .74133 L p .58837 .73738 L F P
0 0 0 r
s
.625 .656 0 r
.58837 .73738 m .59747 .74676 L .57509 .75314 L p F P
0 0 0 r
s
.625 .656 0 r
.54109 .74775 m .56341 .74133 L .57509 .75314 L p F P
0 0 0 r
s
.195 0 .31 r
.75326 .54122 m .75177 .52107 L .76196 .53462 L p F P
0 0 0 r
s
.195 0 .31 r
.76196 .53462 m .76351 .5547 L .75326 .54122 L p F P
0 0 0 r
s
0 .78 .71 r
.26029 .75265 m .25947 .75197 L .27968 .74486 L p F P
0 0 0 r
s
0 .78 .71 r
.27968 .74486 m .28134 .74627 L .26029 .75265 L p F P
0 0 0 r
s
.195 0 .31 r
.81397 .73084 m .81207 .70944 L .8218 .7215 L p F P
0 0 0 r
s
.195 0 .31 r
.8218 .7215 m .82374 .74281 L .81397 .73084 L p F P
0 0 0 r
s
.195 0 .31 r
.69256 .35161 m .69146 .33271 L .70213 .34773 L p F P
0 0 0 r
s
.195 0 .31 r
.70213 .34773 m .70329 .36658 L .69256 .35161 L p F P
0 0 0 r
s
.1 0 .485 r
.3234 .6174 m .32473 .59691 L .34605 .58987 L p F P
0 0 0 r
s
.1 0 .485 r
.32473 .59691 m .3234 .6174 L .30212 .62435 L p F P
0 0 0 r
s
.625 .656 0 r
.64128 .74934 m .63129 .75216 L .62316 .7436 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.2566 .67959 m .25836 .65869 L .27941 .65191 L p F P
0 0 0 r
s
.1 0 .485 r
.25836 .65869 m .2566 .67959 L .2356 .68627 L p F P
0 0 0 r
s
0 .647 .956 r
.26728 .73435 m .27968 .74486 L .25947 .75197 L p F P
0 0 0 r
s
0 .647 .956 r
.25947 .75197 m .24613 .74083 L .26728 .73435 L p F P
0 0 0 r
s
.1 0 .485 r
.63479 .33397 m .63408 .31532 L .65675 .30707 L p F P
0 0 0 r
s
.1 0 .485 r
.63408 .31532 m .63479 .33397 L .61217 .34213 L p F P
0 0 0 r
s
.1 0 .485 r
.18975 .74182 m .19196 .72051 L .21273 .71398 L p F P
0 0 0 r
s
.1 0 .485 r
.19196 .72051 m .18975 .74182 L .16903 .74824 L p F P
0 0 0 r
s
0 .78 .12 r
.3163 .75167 m .31507 .75061 L .33569 .7436 L p F P
0 0 0 r
s
0 .78 .12 r
.33569 .7436 m .33761 .74529 L .3163 .75167 L p F P
0 0 0 r
s
.511 .78 0 r
.69971 .74779 m .68756 .75118 L .67676 .73934 L p F P
0 0 0 r
s
.1 0 .485 r
.56805 .39611 m .56778 .37704 L .59016 .36905 L p F P
0 0 0 r
s
.511 .78 0 r
.65393 .74578 m .67676 .73934 L .68756 .75118 L p F P
0 0 0 r
s
.1 0 .485 r
.56778 .37704 m .56805 .39611 L .54571 .404 L p F P
0 0 0 r
s
.511 .78 0 r
.37237 .75068 m .37239 .75069 L .37175 .75088 L closepath p F P
0 0 0 r
s
0 .78 .12 r
.3591 .73884 m .37237 .75068 L .37175 .75088 L p F P
0 0 0 r
s
0 .78 .12 r
.33761 .74529 m .3591 .73884 L p .37175 .75088 L F P
0 0 0 r
s
.195 0 .31 r
.80219 .69718 m .80037 .67597 L .8102 .68832 L p F P
0 0 0 r
s
.195 0 .31 r
.8102 .68832 m .81207 .70944 L .80219 .69718 L p F P
0 0 0 r
s
.195 0 .31 r
.74141 .50731 m .73999 .48736 L .75029 .50119 L p F P
0 0 0 r
s
.195 0 .31 r
.75029 .50119 m .75177 .52107 L .74141 .50731 L p F P
0 0 0 r
s
.195 0 .31 r
.68062 .31745 m .6796 .29875 L .69038 .31406 L p F P
0 0 0 r
s
.195 0 .31 r
.69038 .31406 m .69146 .33271 L .68062 .31745 L p F P
0 0 0 r
s
.1 0 .485 r
.50127 .45829 m .50143 .43881 L .52354 .43108 L p F P
0 0 0 r
s
.1 0 .485 r
.50143 .43881 m .50127 .45829 L .4792 .46592 L p F P
0 0 0 r
s
.511 .78 0 r
.37239 .75069 m .37237 .75068 L .39373 .7441 L p F P
0 0 0 r
s
.511 .78 0 r
.39373 .7441 m .39395 .7443 L .37239 .75069 L p F P
0 0 0 r
s
0 .78 .12 r
.38077 .73235 m .39373 .7441 L .37237 .75068 L p F P
0 0 0 r
s
0 .78 .12 r
.37237 .75068 m .3591 .73884 L .38077 .73235 L p F P
0 0 0 r
s
0 .78 .71 r
.32399 .73335 m .33569 .7436 L .31507 .75061 L p F P
0 0 0 r
s
0 .78 .71 r
.31507 .75061 m .30257 .73984 L .32399 .73335 L p F P
0 0 0 r
s
0 .78 .12 r
.74424 .75011 m .74391 .7502 L .7425 .74859 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.43444 .5205 m .43504 .50061 L .45687 .49315 L p F P
0 0 0 r
s
.1 0 .485 r
.43504 .50061 m .43444 .5205 L .41265 .52787 L p F P
0 0 0 r
s
0 .78 .71 r
.76706 .7438 m .74424 .75011 L .7425 .74859 L p F P
0 0 0 r
s
.511 .78 0 r
.42855 .74971 m .41569 .73785 L p .43827 .73195 L F P
0 0 0 r
s
.511 .78 0 r
.43827 .73195 m .45036 .74331 L .42855 .74971 L p F P
0 0 0 r
s
.1 0 .485 r
.36756 .58276 m .3686 .56246 L .39016 .55526 L p F P
0 0 0 r
s
.511 .78 0 r
.39395 .7443 m .41569 .73785 L .42855 .74971 L p F P
0 0 0 r
s
.1 0 .485 r
.3686 .56246 m .36756 .58276 L .34605 .58987 L p F P
0 0 0 r
s
.511 .78 0 r
.65393 .74578 m .64128 .74934 L .62316 .7436 L p F P
0 0 0 r
s
0 .647 .956 r
.80322 .74843 m .80033 .74922 L .79041 .73735 L p F P
0 0 0 r
s
0 .647 .956 r
.76983 .74304 m .79041 .73735 L .80033 .74922 L p F P
0 0 0 r
s
.1 0 .485 r
.30064 .64507 m .30212 .62435 L .3234 .6174 L p F P
0 0 0 r
s
.1 0 .485 r
.30212 .62435 m .30064 .64507 L .27941 .65191 L p F P
0 0 0 r
s
.511 .78 0 r
.47236 .73685 m .4799 .74406 L .45628 .74887 L p F P
0 0 0 r
s
.511 .78 0 r
.45628 .74887 m .45036 .74331 L .47236 .73685 L p F P
0 0 0 r
s
.1 0 .485 r
.23368 .70741 m .2356 .68627 L .2566 .67959 L p F P
0 0 0 r
s
.1 0 .485 r
.2356 .68627 m .23368 .70741 L .21273 .71398 L p F P
0 0 0 r
s
.195 0 .31 r
.79038 .66343 m .78864 .64242 L .79858 .65504 L p F P
0 0 0 r
s
.195 0 .31 r
.79858 .65504 m .80037 .67597 L .79038 .66343 L p F P
0 0 0 r
s
.195 0 .31 r
.72952 .47331 m .72818 .45356 L .73859 .46767 L p F P
0 0 0 r
s
.195 0 .31 r
.73859 .46767 m .73999 .48736 L .72952 .47331 L p F P
0 0 0 r
s
.1 0 .485 r
.6786 .28029 m .6796 .29875 L .65675 .30707 L p F P
0 0 0 r
s
.625 .656 0 r
.48478 .74873 m .4799 .74406 L .50449 .74002 L p F P
0 0 0 r
s
.625 .656 0 r
.50449 .74002 m .50685 .74232 L .48478 .74873 L p F P
0 0 0 r
s
0 .78 .71 r
.75684 .73184 m .76706 .7438 L p .7425 .74859 L F P
0 0 0 r
s
0 .78 .71 r
.7425 .74859 m .73355 .73835 L .75684 .73184 L p F P
0 0 0 r
s
0 .78 .12 r
.71046 .74479 m .73113 .73902 L .7425 .74859 L p F P
0 0 0 r
s
0 .78 .71 r
.73113 .73902 m .73355 .73835 L .7425 .74859 L closepath p F P
0 0 0 r
s
0 .647 .956 r
.79041 .73735 m .79288 .73667 L .80322 .74843 L p F P
0 0 0 r
s
.125 0 .956 r
.82374 .74281 m .80322 .74843 L .79288 .73667 L p F P
0 0 0 r
s
.1 0 .485 r
.61274 .361 m .61217 .34213 L .63479 .33397 L p F P
0 0 0 r
s
.1 0 .485 r
.61217 .34213 m .61274 .361 L .59016 .36905 L p F P
0 0 0 r
s
.511 .78 0 r
.67676 .73934 m .68297 .73759 L .69971 .74779 L p F P
0 0 0 r
s
0 .78 .12 r
.71046 .74479 m .69971 .74779 L .68297 .73759 L p F P
0 0 0 r
s
.1 0 .485 r
.54584 .42329 m .54571 .404 L .56805 .39611 L p F P
0 0 0 r
s
.1 0 .485 r
.54571 .404 m .54584 .42329 L .52354 .43108 L p F P
0 0 0 r
s
.625 .656 0 r
.54109 .74775 m .53038 .73712 L .55819 .73604 L p F P
0 0 0 r
s
.625 .656 0 r
.55819 .73604 m .56341 .74133 L .54109 .74775 L p F P
0 0 0 r
s
.1 0 .485 r
.47889 .48562 m .4792 .46592 L .50127 .45829 L p F P
0 0 0 r
s
.1 0 .485 r
.4792 .46592 m .47889 .48562 L .45687 .49315 L p F P
0 0 0 r
s
0 .647 .956 r
.22515 .74726 m .22451 .74673 L .245 .73989 L p F P
0 0 0 r
s
0 .647 .956 r
.245 .73989 m .24613 .74083 L .22515 .74726 L p F P
0 0 0 r
s
.195 0 .31 r
.77855 .62959 m .77688 .60878 L .78692 .62168 L p F P
0 0 0 r
s
.195 0 .31 r
.78692 .62168 m .78864 .64242 L .77855 .62959 L p F P
0 0 0 r
s
.195 0 .31 r
.7176 .43922 m .71633 .41967 L .72685 .43406 L p F P
0 0 0 r
s
.195 0 .31 r
.72685 .43406 m .72818 .45356 L .7176 .43922 L p F P
0 0 0 r
s
.625 .656 0 r
.59747 .74676 m .61528 .74169 L .62316 .7436 L p F P
0 0 0 r
s
.625 .656 0 r
.61528 .74169 m .59747 .74676 L .58837 .73738 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.4119 .54799 m .41265 .52787 L .43444 .5205 L p F P
0 0 0 r
s
.1 0 .485 r
.41265 .52787 m .4119 .54799 L .39016 .55526 L p F P
0 0 0 r
s
.125 0 .956 r
.23174 .72882 m .245 .73989 L .22451 .74673 L p F P
0 0 0 r
s
.125 0 .956 r
.22451 .74673 m .21066 .73535 L .23174 .72882 L p F P
0 0 0 r
s
.1 0 .485 r
.34486 .6104 m .34605 .58987 L .36756 .58276 L p F P
0 0 0 r
s
.1 0 .485 r
.34605 .58987 m .34486 .6104 L .3234 .6174 L p F P
0 0 0 r
s
0 .78 .71 r
.28134 .74627 m .27968 .74486 L .30032 .7379 L p F P
0 0 0 r
s
0 .78 .71 r
.30032 .7379 m .30257 .73984 L .28134 .74627 L p F P
0 0 0 r
s
.511 .78 0 r
.65393 .74578 m .64283 .73385 L p .66834 .73011 L F P
0 0 0 r
s
.511 .78 0 r
.66834 .73011 m .67676 .73934 L .65393 .74578 L p F P
0 0 0 r
s
.511 .78 0 r
.64283 .73385 m .65393 .74578 L p .62316 .7436 L F P
0 0 0 r
s
.1 0 .485 r
.27778 .67286 m .27941 .65191 L .30064 .64507 L p F P
0 0 0 r
s
.1 0 .485 r
.27941 .65191 m .27778 .67286 L .2566 .67959 L p F P
0 0 0 r
s
.1 0 .485 r
.65761 .32575 m .65675 .30707 L .6796 .29875 L p F P
0 0 0 r
s
.1 0 .485 r
.65675 .30707 m .65761 .32575 L .63479 .33397 L p F P
0 0 0 r
s
0 .78 .12 r
.33761 .74529 m .33569 .7436 L .35679 .73679 L p F P
0 0 0 r
s
0 .78 .12 r
.35679 .73679 m .3591 .73884 L .33761 .74529 L p F P
0 0 0 r
s
.1 0 .485 r
.21066 .73535 m .21273 .71398 L .23368 .70741 L p F P
0 0 0 r
s
.1 0 .485 r
.21273 .71398 m .21066 .73535 L .18975 .74182 L p F P
0 0 0 r
s
0 .647 .956 r
.28862 .72781 m .30032 .7379 L .27968 .74486 L p F P
0 0 0 r
s
0 .647 .956 r
.27968 .74486 m .26728 .73435 L .28862 .72781 L p F P
0 0 0 r
s
.1 0 .485 r
.59059 .38815 m .59016 .36905 L .61274 .361 L p F P
0 0 0 r
s
.1 0 .485 r
.59016 .36905 m .59059 .38815 L .56805 .39611 L p F P
0 0 0 r
s
.195 0 .31 r
.70565 .40504 m .70446 .38568 L .71508 .40037 L p F P
0 0 0 r
s
.195 0 .31 r
.71508 .40037 m .71633 .41967 L .70565 .40504 L p F P
0 0 0 r
s
.195 0 .31 r
.76668 .59566 m .76509 .57505 L .77523 .58823 L p F P
0 0 0 r
s
.195 0 .31 r
.77523 .58823 m .77688 .60878 L .76668 .59566 L p F P
0 0 0 r
s
0 .78 .12 r
.73113 .73902 m .71046 .74479 L .6998 .73285 L p F P
0 0 0 r
s
0 .78 .12 r
.68297 .73759 m .6998 .73285 L .71046 .74479 L p F P
0 0 0 r
s
.1 0 .485 r
.52352 .45059 m .52354 .43108 L .54584 .42329 L p F P
0 0 0 r
s
.1 0 .485 r
.52354 .43108 m .52352 .45059 L .50127 .45829 L p F P
0 0 0 r
s
.511 .78 0 r
.39395 .7443 m .39373 .7441 L .41567 .73783 L p F P
0 0 0 r
s
.511 .78 0 r
.41567 .73783 m .41569 .73785 L .39395 .7443 L p F P
0 0 0 r
s
0 .78 .12 r
.40263 .72579 m .41567 .73783 L .39373 .7441 L p F P
0 0 0 r
s
0 .78 .12 r
.39373 .7441 m .38077 .73235 L .40263 .72579 L p F P
0 0 0 r
s
.511 .78 0 r
.49455 .73033 m .50449 .74002 L .4799 .74406 L p F P
0 0 0 r
s
.511 .78 0 r
.4799 .74406 m .47236 .73685 L .49455 .73033 L p F P
0 0 0 r
s
0 .78 .71 r
.76983 .74304 m .76706 .7438 L .75684 .73184 L p F P
0 0 0 r
s
.1 0 .485 r
.45641 .51307 m .45687 .49315 L .47889 .48562 L p F P
0 0 0 r
s
.1 0 .485 r
.45687 .49315 m .45641 .51307 L .43444 .5205 L p F P
0 0 0 r
s
.511 .78 0 r
.62316 .7436 m .62005 .74034 L .64283 .73385 L p F P
0 0 0 r
s
.511 .78 0 r
.61528 .74169 m .62005 .74034 L .62316 .7436 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.34559 .7268 m .35679 .73679 L .33569 .7436 L p F P
0 0 0 r
s
0 .78 .71 r
.33569 .7436 m .32399 .73335 L .34559 .7268 L p F P
0 0 0 r
s
.511 .78 0 r
.45036 .74331 m .43827 .73195 L .46154 .7265 L p F P
0 0 0 r
s
.511 .78 0 r
.46154 .7265 m .47236 .73685 L .45036 .74331 L p F P
0 0 0 r
s
.1 0 .485 r
.38926 .5756 m .39016 .55526 L .4119 .54799 L p F P
0 0 0 r
s
.1 0 .485 r
.39016 .55526 m .38926 .5756 L .36756 .58276 L p F P
0 0 0 r
s
0 .78 .71 r
.75684 .73184 m .75821 .73146 L .76983 .74304 L p F P
0 0 0 r
s
0 .647 .956 r
.79041 .73735 m .76983 .74304 L .75821 .73146 L p F P
0 0 0 r
s
.195 0 .31 r
.75478 .56165 m .75326 .54122 L .76351 .5547 L p F P
0 0 0 r
s
.195 0 .31 r
.76351 .5547 m .76509 .57505 L .75478 .56165 L p F P
0 0 0 r
s
.195 0 .31 r
.69367 .37077 m .69256 .35161 L .70329 .36658 L p F P
0 0 0 r
s
.195 0 .31 r
.70329 .36658 m .70446 .38568 L .69367 .37077 L p F P
0 0 0 r
s
.125 0 .956 r
.79288 .73667 m .81397 .73084 L .82374 .74281 L p F P
0 0 0 r
s
.1 0 .485 r
.32206 .63817 m .3234 .6174 L .34486 .6104 L p F P
0 0 0 r
s
.1 0 .485 r
.3234 .6174 m .32206 .63817 L .30064 .64507 L p F P
0 0 0 r
s
.1 0 .485 r
.25481 .70077 m .2566 .67959 L .27778 .67286 L p F P
0 0 0 r
s
.1 0 .485 r
.2566 .67959 m .25481 .70077 L .23368 .70741 L p F P
0 0 0 r
s
.625 .656 0 r
.50685 .74232 m .52212 .73788 L .53038 .73712 L p F P
0 0 0 r
s
.625 .656 0 r
.52212 .73788 m .50685 .74232 L .50449 .74002 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.63551 .35287 m .63479 .33397 L .65761 .32575 L p F P
0 0 0 r
s
.1 0 .485 r
.63479 .33397 m .63551 .35287 L .61274 .361 L p F P
0 0 0 r
s
.511 .78 0 r
.62005 .74034 m .61528 .74169 L .58837 .73738 L p F P
0 0 0 r
s
.1 0 .485 r
.56833 .41542 m .56805 .39611 L .59059 .38815 L p F P
0 0 0 r
s
.1 0 .485 r
.56805 .39611 m .56833 .41542 L .54584 .42329 L p F P
0 0 0 r
s
.625 .656 0 r
.56341 .74133 m .57973 .73664 L .58837 .73738 L p F P
0 0 0 r
s
.625 .656 0 r
.57973 .73664 m .56341 .74133 L .55819 .73604 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.5011 .47802 m .50127 .45829 L .52352 .45059 L p F P
0 0 0 r
s
.1 0 .485 r
.50127 .45829 m .5011 .47802 L .47889 .48562 L p F P
0 0 0 r
s
0 .647 .956 r
.24613 .74083 m .245 .73989 L .26579 .73309 L p F P
0 0 0 r
s
0 .647 .956 r
.26579 .73309 m .26728 .73435 L .24613 .74083 L p F P
0 0 0 r
s
.195 0 .31 r
.68165 .3364 m .68062 .31745 L .69146 .33271 L p F P
0 0 0 r
s
.195 0 .31 r
.69146 .33271 m .69256 .35161 L .68165 .3364 L p F P
0 0 0 r
s
.195 0 .31 r
.80404 .71867 m .80219 .69718 L .81207 .70944 L p F P
0 0 0 r
s
.195 0 .31 r
.81207 .70944 m .81397 .73084 L .80404 .71867 L p F P
0 0 0 r
s
.195 0 .31 r
.74284 .52754 m .74141 .50731 L .75177 .52107 L p F P
0 0 0 r
s
.195 0 .31 r
.75177 .52107 m .75326 .54122 L .74284 .52754 L p F P
0 0 0 r
s
.1 0 .485 r
.43383 .54066 m .43444 .5205 L .45641 .51307 L p F P
0 0 0 r
s
.1 0 .485 r
.43444 .5205 m .43383 .54066 L .4119 .54799 L p F P
0 0 0 r
s
.511 .78 0 r
.64283 .73385 m .62005 .74034 L .60864 .72832 L p F P
0 0 0 r
s
.511 .78 0 r
.60864 .72832 m .62005 .74034 L p .58837 .73738 L F P
0 0 0 r
s
.511 .78 0 r
.52911 .73585 m .52212 .73788 L .50449 .74002 L p F P
0 0 0 r
s
.511 .78 0 r
.51693 .72376 m .52911 .73585 L p .50449 .74002 L F P
0 0 0 r
s
.511 .78 0 r
.50449 .74002 m .49455 .73033 L .51693 .72376 L p F P
0 0 0 r
s
.125 0 .956 r
.253 .72224 m .26579 .73309 L .245 .73989 L p F P
0 0 0 r
s
.125 0 .956 r
.245 .73989 m .23174 .72882 L .253 .72224 L p F P
0 0 0 r
s
.1 0 .485 r
.36651 .60334 m .36756 .58276 L .38926 .5756 L p F P
0 0 0 r
s
.1 0 .485 r
.36756 .58276 m .36651 .60334 L .34486 .6104 L p F P
0 0 0 r
s
0 .78 .71 r
.30257 .73984 m .30032 .7379 L .32135 .73103 L p F P
0 0 0 r
s
0 .78 .71 r
.32135 .73103 m .32399 .73335 L .30257 .73984 L p F P
0 0 0 r
s
.511 .78 0 r
.68297 .73759 m .67676 .73934 L .66834 .73011 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.29914 .66606 m .30064 .64507 L .32206 .63817 L p F P
0 0 0 r
s
.1 0 .485 r
.30064 .64507 m .29914 .66606 L .27778 .67286 L p F P
0 0 0 r
s
0 .78 .12 r
.6998 .73285 m .71677 .72806 L .73113 .73902 L p F P
0 0 0 r
s
0 .78 .71 r
.73355 .73835 m .73113 .73902 L .71677 .72806 L p F P
0 0 0 r
s
.195 0 .31 r
.73088 .49333 m .72952 .47331 L .73999 .48736 L p F P
0 0 0 r
s
.195 0 .31 r
.73999 .48736 m .74141 .50731 L .73088 .49333 L p F P
0 0 0 r
s
.1 0 .485 r
.6796 .29875 m .68062 .31745 L .65761 .32575 L p F P
0 0 0 r
s
0 .78 .12 r
.3591 .73884 m .35679 .73679 L .37835 .73015 L p F P
0 0 0 r
s
0 .78 .12 r
.37835 .73015 m .38077 .73235 L .3591 .73884 L p F P
0 0 0 r
s
.1 0 .485 r
.23174 .72882 m .23368 .70741 L .25481 .70077 L p F P
0 0 0 r
s
.1 0 .485 r
.23368 .70741 m .23174 .72882 L .21066 .73535 L p F P
0 0 0 r
s
.195 0 .31 r
.79215 .68472 m .79038 .66343 L .80037 .67597 L p F P
0 0 0 r
s
.195 0 .31 r
.80037 .67597 m .80219 .69718 L .79215 .68472 L p F P
0 0 0 r
s
.1 0 .485 r
.61332 .38012 m .61274 .361 L .63551 .35287 L p F P
0 0 0 r
s
.1 0 .485 r
.61274 .361 m .61332 .38012 L .59059 .38815 L p F P
0 0 0 r
s
0 .78 .71 r
.73355 .73835 m .72303 .7263 L p .74938 .7231 L F P
0 0 0 r
s
0 .78 .71 r
.74938 .7231 m .75684 .73184 L .73355 .73835 L p F P
0 0 0 r
s
0 .78 .71 r
.71677 .72806 m .72303 .7263 L .73355 .73835 L p F P
0 0 0 r
s
0 .647 .956 r
.31015 .72122 m .32135 .73103 L .30032 .7379 L p F P
0 0 0 r
s
0 .647 .956 r
.30032 .7379 m .28862 .72781 L .31015 .72122 L p F P
0 0 0 r
s
.511 .78 0 r
.52212 .73788 m .52911 .73585 L .53038 .73712 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.54597 .44283 m .54584 .42329 L .56833 .41542 L p F P
0 0 0 r
s
.1 0 .485 r
.54584 .42329 m .54597 .44283 L .52352 .45059 L p F P
0 0 0 r
s
.511 .78 0 r
.41569 .73785 m .41634 .73765 L .43827 .73195 L p F P
0 0 0 r
s
.511 .78 0 r
.41634 .73765 m .41569 .73785 L .41567 .73783 L closepath p F P
0 0 0 r
s
0 .78 .12 r
.43762 .73134 m .41634 .73765 L .41567 .73783 L p F P
0 0 0 r
s
0 .78 .12 r
.42468 .71918 m .43762 .73134 L p .41567 .73783 L F P
0 0 0 r
s
0 .78 .12 r
.41567 .73783 m .40263 .72579 L .42468 .71918 L p F P
0 0 0 r
s
0 .78 .12 r
.41634 .73765 m .43762 .73134 L .43827 .73195 L closepath p F P
0 0 0 r
s
0 .78 .12 r
.6998 .73285 m .68297 .73759 L .66834 .73011 L p F P
0 0 0 r
s
.511 .78 0 r
.58837 .73738 m .58593 .73485 L .60864 .72832 L p F P
0 0 0 r
s
.511 .78 0 r
.57973 .73664 m .58593 .73485 L .58837 .73738 L closepath p F P
0 0 0 r
s
0 .647 .956 r
.79288 .73667 m .79041 .73735 L .78034 .72528 L p F P
0 0 0 r
s
0 .647 .956 r
.75821 .73146 m .78034 .72528 L .79041 .73735 L p F P
0 0 0 r
s
.1 0 .485 r
.47857 .50558 m .47889 .48562 L .5011 .47802 L p F P
0 0 0 r
s
.1 0 .485 r
.47889 .48562 m .47857 .50558 L .45641 .51307 L p F P
0 0 0 r
s
.511 .78 0 r
.55156 .72933 m .55819 .73604 L .53038 .73712 L p F P
0 0 0 r
s
.511 .78 0 r
.53038 .73712 m .52911 .73585 L .55156 .72933 L p F P
0 0 0 r
s
.195 0 .31 r
.78024 .65069 m .77855 .62959 L .78864 .64242 L p F P
0 0 0 r
s
.195 0 .31 r
.78864 .64242 m .79038 .66343 L .78024 .65069 L p F P
0 0 0 r
s
.195 0 .31 r
.71888 .45904 m .7176 .43922 L .72818 .45356 L p F P
0 0 0 r
s
.195 0 .31 r
.72818 .45356 m .72952 .47331 L .71888 .45904 L p F P
0 0 0 r
s
.511 .78 0 r
.47236 .73685 m .46154 .7265 L .48554 .72156 L p F P
0 0 0 r
s
.511 .78 0 r
.48554 .72156 m .49455 .73033 L .47236 .73685 L p F P
0 0 0 r
s
.1 0 .485 r
.41114 .56837 m .4119 .54799 L .43383 .54066 L p F P
0 0 0 r
s
.1 0 .485 r
.4119 .54799 m .41114 .56837 L .38926 .5756 L p F P
0 0 0 r
s
0 .78 .71 r
.36737 .7202 m .37835 .73015 L .35679 .73679 L p F P
0 0 0 r
s
0 .78 .71 r
.35679 .73679 m .34559 .7268 L .36737 .7202 L p F P
0 0 0 r
s
0 .647 .956 r
.78034 .72528 m .78221 .72476 L .79288 .73667 L p F P
0 0 0 r
s
.125 0 .956 r
.81397 .73084 m .79288 .73667 L .78221 .72476 L p F P
0 0 0 r
s
.511 .78 0 r
.58593 .73485 m .57973 .73664 L .55819 .73604 L p F P
0 0 0 r
s
.1 0 .485 r
.34365 .63121 m .34486 .6104 L .36651 .60334 L p F P
0 0 0 r
s
.1 0 .485 r
.34486 .6104 m .34365 .63121 L .32206 .63817 L p F P
0 0 0 r
s
.511 .78 0 r
.5742 .72275 m .58593 .73485 L p .55819 .73604 L F P
0 0 0 r
s
.511 .78 0 r
.55819 .73604 m .55156 .72933 L .5742 .72275 L p F P
0 0 0 r
s
.511 .78 0 r
.55156 .72933 m .52911 .73585 L .51693 .72376 L p F P
0 0 0 r
s
.1 0 .485 r
.27613 .69408 m .27778 .67286 L .29914 .66606 L p F P
0 0 0 r
s
.1 0 .485 r
.27778 .67286 m .27613 .69408 L .25481 .70077 L p F P
0 0 0 r
s
.1 0 .485 r
.65848 .34467 m .65761 .32575 L .68062 .31745 L p F P
0 0 0 r
s
.1 0 .485 r
.65761 .32575 m .65848 .34467 L .63551 .35287 L p F P
0 0 0 r
s
.511 .78 0 r
.60864 .72832 m .58593 .73485 L .5742 .72275 L p F P
0 0 0 r
s
.195 0 .31 r
.70685 .42466 m .70565 .40504 L .71633 .41967 L p F P
0 0 0 r
s
.195 0 .31 r
.71633 .41967 m .7176 .43922 L .70685 .42466 L p F P
0 0 0 r
s
.1 0 .485 r
.59101 .40749 m .59059 .38815 L .61332 .38012 L p F P
0 0 0 r
s
.1 0 .485 r
.59059 .38815 m .59101 .40749 L .56833 .41542 L p F P
0 0 0 r
s
.195 0 .31 r
.76829 .61656 m .76668 .59566 L .77688 .60878 L p F P
0 0 0 r
s
.195 0 .31 r
.77688 .60878 m .77855 .62959 L .76829 .61656 L p F P
0 0 0 r
s
.1 0 .485 r
.5235 .47036 m .52352 .45059 L .54597 .44283 L p F P
0 0 0 r
s
.1 0 .485 r
.52352 .45059 m .5235 .47036 L .5011 .47802 L p F P
0 0 0 r
s
0 .647 .956 r
.26728 .73435 m .26579 .73309 L .28688 .72631 L p F P
0 0 0 r
s
0 .647 .956 r
.28688 .72631 m .28862 .72781 L .26728 .73435 L p F P
0 0 0 r
s
.1 0 .485 r
.45594 .53327 m .45641 .51307 L .47857 .50558 L p F P
0 0 0 r
s
.1 0 .485 r
.45641 .51307 m .45594 .53327 L .43383 .54066 L p F P
0 0 0 r
s
.511 .78 0 r
.64283 .73385 m .6635 .72796 L .66834 .73011 L p F P
0 0 0 r
s
.511 .78 0 r
.6635 .72796 m .64283 .73385 L .63154 .72173 L p F P
0 0 0 r
s
.511 .78 0 r
.60864 .72832 m .63154 .72173 L .64283 .73385 L p F P
0 0 0 r
s
.1 0 .485 r
.38834 .59621 m .38926 .5756 L .41114 .56837 L p F P
0 0 0 r
s
.1 0 .485 r
.38926 .5756 m .38834 .59621 L .36651 .60334 L p F P
0 0 0 r
s
0 .78 .71 r
.32399 .73335 m .32135 .73103 L .34274 .72426 L p F P
0 0 0 r
s
0 .78 .71 r
.34274 .72426 m .34559 .7268 L .32399 .73335 L p F P
0 0 0 r
s
.125 0 .956 r
.27445 .7156 m .28688 .72631 L .26579 .73309 L p F P
0 0 0 r
s
.125 0 .956 r
.26579 .73309 m .253 .72224 L .27445 .7156 L p F P
0 0 0 r
s
.195 0 .31 r
.75631 .58234 m .75478 .56165 L .76509 .57505 L p F P
0 0 0 r
s
.195 0 .31 r
.76509 .57505 m .76668 .59566 L .75631 .58234 L p F P
0 0 0 r
s
.195 0 .31 r
.69479 .39018 m .69367 .37077 L .70446 .38568 L p F P
0 0 0 r
s
.195 0 .31 r
.70446 .38568 m .70565 .40504 L .69479 .39018 L p F P
0 0 0 r
s
0 .78 .12 r
.71677 .72806 m .6998 .73285 L .68896 .72071 L p F P
0 0 0 r
s
0 .78 .12 r
.68896 .72071 m .6998 .73285 L p .66834 .73011 L F P
0 0 0 r
s
.1 0 .485 r
.32069 .65921 m .32206 .63817 L .34365 .63121 L p F P
0 0 0 r
s
.1 0 .485 r
.32206 .63817 m .32069 .65921 L .29914 .66606 L p F P
0 0 0 r
s
0 .78 .12 r
.38077 .73235 m .37835 .73015 L .40036 .7237 L p F P
0 0 0 r
s
0 .78 .12 r
.40036 .7237 m .40263 .72579 L .38077 .73235 L p F P
0 0 0 r
s
.1 0 .485 r
.253 .72224 m .25481 .70077 L .27613 .69408 L p F P
0 0 0 r
s
.1 0 .485 r
.25481 .70077 m .253 .72224 L .23174 .72882 L p F P
0 0 0 r
s
0 .78 .12 r
.45974 .72478 m .46154 .7265 L .43827 .73195 L p F P
0 0 0 r
s
0 .78 .12 r
.43827 .73195 m .43762 .73134 L .45974 .72478 L p F P
0 0 0 r
s
.1 0 .485 r
.63624 .37202 m .63551 .35287 L .65848 .34467 L p F P
0 0 0 r
s
.1 0 .485 r
.63551 .35287 m .63624 .37202 L .61332 .38012 L p F P
0 0 0 r
s
0 .78 .71 r
.75821 .73146 m .75684 .73184 L .74938 .7231 L closepath p F P
0 0 0 r
s
0 .647 .956 r
.78034 .72528 m .75821 .73146 L .74938 .7231 L p F P
0 0 0 r
s
.1 0 .485 r
.56861 .435 m .56833 .41542 L .59101 .40749 L p F P
0 0 0 r
s
.1 0 .485 r
.56833 .41542 m .56861 .435 L .54597 .44283 L p F P
0 0 0 r
s
0 .78 .12 r
.45974 .72478 m .43762 .73134 L .42468 .71918 L p F P
0 0 0 r
s
0 .647 .956 r
.33186 .71457 m .34274 .72426 L .32135 .73103 L p F P
0 0 0 r
s
0 .647 .956 r
.32135 .73103 m .31015 .72122 L .33186 .71457 L p F P
0 0 0 r
s
.1 0 .485 r
.50093 .49802 m .5011 .47802 L .5235 .47036 L p F P
0 0 0 r
s
.1 0 .485 r
.5011 .47802 m .50093 .49802 L .47857 .50558 L p F P
0 0 0 r
s
.195 0 .31 r
.6827 .35561 m .68165 .3364 L .69256 .35161 L p F P
0 0 0 r
s
.195 0 .31 r
.69256 .35161 m .69367 .37077 L .6827 .35561 L p F P
0 0 0 r
s
.125 0 .956 r
.78221 .72476 m .80404 .71867 L .81397 .73084 L p F P
0 0 0 r
s
.195 0 .31 r
.7443 .54803 m .74284 .52754 L .75326 .54122 L p F P
0 0 0 r
s
.195 0 .31 r
.75326 .54122 m .75478 .56165 L .7443 .54803 L p F P
0 0 0 r
s
.511 .78 0 r
.49455 .73033 m .48554 .72156 L .51038 .71726 L p F P
0 0 0 r
s
.511 .78 0 r
.51038 .71726 m .51693 .72376 L .49455 .73033 L p F P
0 0 0 r
s
.1 0 .485 r
.43321 .56108 m .43383 .54066 L .45594 .53327 L p F P
0 0 0 r
s
.1 0 .485 r
.43383 .54066 m .43321 .56108 L .41114 .56837 L p F P
0 0 0 r
s
0 .78 .71 r
.38935 .71354 m .40036 .7237 L .37835 .73015 L p F P
0 0 0 r
s
0 .78 .71 r
.37835 .73015 m .36737 .7202 L .38935 .71354 L p F P
0 0 0 r
s
0 .78 .12 r
.66834 .73011 m .6658 .72731 L .68896 .72071 L p F P
0 0 0 r
s
0 .78 .12 r
.6635 .72796 m .6658 .72731 L .66834 .73011 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.36544 .62419 m .36651 .60334 L .38834 .59621 L p F P
0 0 0 r
s
.1 0 .485 r
.36651 .60334 m .36544 .62419 L .34365 .63121 L p F P
0 0 0 r
s
.511 .78 0 r
.55156 .72933 m .53951 .71713 L p .56348 .71168 L F P
0 0 0 r
s
.511 .78 0 r
.56348 .71168 m .5742 .72275 L .55156 .72933 L p F P
0 0 0 r
s
.511 .78 0 r
.51693 .72376 m .53951 .71713 L .55156 .72933 L p F P
0 0 0 r
s
.1 0 .485 r
.29763 .68734 m .29914 .66606 L .32069 .65921 L p F P
0 0 0 r
s
.1 0 .485 r
.29914 .66606 m .29763 .68734 L .27613 .69408 L p F P
0 0 0 r
s
.195 0 .31 r
.73226 .51362 m .73088 .49333 L .74141 .50731 L p F P
0 0 0 r
s
.195 0 .31 r
.74141 .50731 m .74284 .52754 L .73226 .51362 L p F P
0 0 0 r
s
.1 0 .485 r
.68062 .31745 m .68165 .3364 L .65848 .34467 L p F P
0 0 0 r
s
.195 0 .31 r
.79394 .7063 m .79215 .68472 L .80219 .69718 L p F P
0 0 0 r
s
.195 0 .31 r
.80219 .69718 m .80404 .71867 L .79394 .7063 L p F P
0 0 0 r
s
.511 .78 0 r
.60864 .72832 m .59704 .71611 L p .62666 .71648 L F P
0 0 0 r
s
.511 .78 0 r
.62666 .71648 m .63154 .72173 L .60864 .72832 L p F P
0 0 0 r
s
.511 .78 0 r
.5742 .72275 m .59704 .71611 L .60864 .72832 L p F P
0 0 0 r
s
.1 0 .485 r
.6139 .39949 m .61332 .38012 L .63624 .37202 L p F P
0 0 0 r
s
.1 0 .485 r
.61332 .38012 m .6139 .39949 L .59101 .40749 L p F P
0 0 0 r
s
0 .78 .12 r
.68896 .72071 m .70081 .71734 L .71677 .72806 L p F P
0 0 0 r
s
0 .78 .71 r
.72303 .7263 m .71677 .72806 L .70081 .71734 L p F P
0 0 0 r
s
.511 .78 0 r
.63154 .72173 m .63912 .71955 L .6635 .72796 L p F P
0 0 0 r
s
0 .78 .12 r
.6658 .72731 m .6635 .72796 L .63912 .71955 L p F P
0 0 0 r
s
.1 0 .485 r
.5461 .46263 m .54597 .44283 L .56861 .435 L p F P
0 0 0 r
s
.1 0 .485 r
.54597 .44283 m .5461 .46263 L .5235 .47036 L p F P
0 0 0 r
s
0 .647 .956 r
.28862 .72781 m .28688 .72631 L .30824 .71955 L p F P
0 0 0 r
s
0 .647 .956 r
.30824 .71955 m .31015 .72122 L .28862 .72781 L p F P
0 0 0 r
s
.1 0 .485 r
.47826 .52581 m .47857 .50558 L .50093 .49802 L p F P
0 0 0 r
s
.1 0 .485 r
.47857 .50558 m .47826 .52581 L .45594 .53327 L p F P
0 0 0 r
s
0 .78 .12 r
.68896 .72071 m .6658 .72731 L .65465 .71508 L p F P
0 0 0 r
s
0 .78 .12 r
.63912 .71955 m .65465 .71508 L .6658 .72731 L p F P
0 0 0 r
s
.195 0 .31 r
.78195 .67207 m .78024 .65069 L .79038 .66343 L p F P
0 0 0 r
s
.195 0 .31 r
.79038 .66343 m .79215 .68472 L .78195 .67207 L p F P
0 0 0 r
s
.195 0 .31 r
.72018 .47913 m .71888 .45904 L .72952 .47331 L p F P
0 0 0 r
s
.195 0 .31 r
.72952 .47331 m .73088 .49333 L .72018 .47913 L p F P
0 0 0 r
s
.1 0 .485 r
.41037 .58903 m .41114 .56837 L .43321 .56108 L p F P
0 0 0 r
s
.1 0 .485 r
.41114 .56837 m .41037 .58903 L .38834 .59621 L p F P
0 0 0 r
s
0 .78 .71 r
.34559 .7268 m .34274 .72426 L .36447 .71757 L p F P
0 0 0 r
s
0 .78 .71 r
.36447 .71757 m .36737 .7202 L .34559 .7268 L p F P
0 0 0 r
s
0 .78 .12 r
.48205 .71816 m .48554 .72156 L .46154 .7265 L p F P
0 0 0 r
s
0 .78 .12 r
.46154 .7265 m .45974 .72478 L .48205 .71816 L p F P
0 0 0 r
s
.125 0 .956 r
.29609 .7089 m .30824 .71955 L .28688 .72631 L p F P
0 0 0 r
s
.125 0 .956 r
.28688 .72631 m .27445 .7156 L .29609 .7089 L p F P
0 0 0 r
s
0 .78 .71 r
.72303 .7263 m .74584 .71987 L .74938 .7231 L p F P
0 0 0 r
s
0 .78 .71 r
.74584 .71987 m .72303 .7263 L .71234 .71406 L p F P
0 0 0 r
s
0 .78 .71 r
.70081 .71734 m .71234 .71406 L .72303 .7263 L p F P
0 0 0 r
s
.1 0 .485 r
.34243 .65229 m .34365 .63121 L .36544 .62419 L p F P
0 0 0 r
s
.1 0 .485 r
.34365 .63121 m .34243 .65229 L .32069 .65921 L p F P
0 0 0 r
s
0 .78 .12 r
.40263 .72579 m .40036 .7237 L .42282 .71744 L p F P
0 0 0 r
s
0 .78 .12 r
.42282 .71744 m .42468 .71918 L .40263 .72579 L p F P
0 0 0 r
s
.1 0 .485 r
.27445 .7156 m .27613 .69408 L .29763 .68734 L p F P
0 0 0 r
s
.1 0 .485 r
.27613 .69408 m .27445 .7156 L .253 .72224 L p F P
0 0 0 r
s
.1 0 .485 r
.65937 .36385 m .65848 .34467 L .68165 .3364 L p F P
0 0 0 r
s
.1 0 .485 r
.65848 .34467 m .65937 .36385 L .63624 .37202 L p F P
0 0 0 r
s
0 .647 .956 r
.78221 .72476 m .78034 .72528 L .7701 .71303 L p F P
0 0 0 r
s
0 .647 .956 r
.7701 .71303 m .78034 .72528 L p .74938 .7231 L F P
0 0 0 r
s
.195 0 .31 r
.70807 .44454 m .70685 .42466 L .7176 .43922 L p F P
0 0 0 r
s
.195 0 .31 r
.7176 .43922 m .71888 .45904 L .70807 .44454 L p F P
0 0 0 r
s
.1 0 .485 r
.59145 .4271 m .59101 .40749 L .6139 .39949 L p F P
0 0 0 r
s
.1 0 .485 r
.59101 .40749 m .59145 .4271 L .56861 .435 L p F P
0 0 0 r
s
0 .78 .12 r
.48205 .71816 m .45974 .72478 L .44692 .71251 L p F P
0 0 0 r
s
0 .78 .12 r
.42468 .71918 m .44692 .71251 L .45974 .72478 L p F P
0 0 0 r
s
.195 0 .31 r
.76993 .63774 m .76829 .61656 L .77855 .62959 L p F P
0 0 0 r
s
.195 0 .31 r
.77855 .62959 m .78024 .65069 L .76993 .63774 L p F P
0 0 0 r
s
0 .647 .956 r
.7701 .71303 m .77115 .71273 L .78221 .72476 L p F P
0 0 0 r
s
.125 0 .956 r
.80404 .71867 m .78221 .72476 L .77115 .71273 L p F P
0 0 0 r
s
.1 0 .485 r
.52348 .49039 m .5235 .47036 L .5461 .46263 L p F P
0 0 0 r
s
.1 0 .485 r
.5235 .47036 m .52348 .49039 L .50093 .49802 L p F P
0 0 0 r
s
0 .647 .956 r
.35377 .70786 m .36447 .71757 L .34274 .72426 L p F P
0 0 0 r
s
0 .647 .956 r
.34274 .72426 m .33186 .71457 L .35377 .70786 L p F P
0 0 0 r
s
.511 .78 0 r
.51693 .72376 m .51038 .71726 L .53622 .7138 L p F P
0 0 0 r
s
.511 .78 0 r
.53622 .7138 m .53951 .71713 L .51693 .72376 L p F P
0 0 0 r
s
.1 0 .485 r
.45547 .55373 m .45594 .53327 L .47826 .52581 L p F P
0 0 0 r
s
.1 0 .485 r
.45594 .53327 m .45547 .55373 L .43321 .56108 L p F P
0 0 0 r
s
0 .78 .71 r
.41152 .70682 m .42282 .71744 L .40036 .7237 L p F P
0 0 0 r
s
0 .78 .71 r
.40036 .7237 m .38935 .71354 L .41152 .70682 L p F P
0 0 0 r
s
.1 0 .485 r
.38742 .61711 m .38834 .59621 L .41037 .58903 L p F P
0 0 0 r
s
.1 0 .485 r
.38834 .59621 m .38742 .61711 L .36544 .62419 L p F P
0 0 0 r
s
0 .647 .956 r
.74938 .7231 m .74646 .71969 L .7701 .71303 L p F P
0 0 0 r
s
0 .647 .956 r
.74584 .71987 m .74646 .71969 L .74938 .7231 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.75787 .60331 m .75631 .58234 L .76668 .59566 L p F P
0 0 0 r
s
.195 0 .31 r
.76668 .59566 m .76829 .61656 L .75787 .60331 L p F P
0 0 0 r
s
.195 0 .31 r
.69593 .40985 m .69479 .39018 L .70565 .40504 L p F P
0 0 0 r
s
.195 0 .31 r
.70565 .40504 m .70685 .42466 L .69593 .40985 L p F P
0 0 0 r
s
.511 .78 0 r
.5742 .72275 m .56348 .71168 L .59318 .71205 L p F P
0 0 0 r
s
.511 .78 0 r
.59318 .71205 m .59704 .71611 L .5742 .72275 L p F P
0 0 0 r
s
.1 0 .485 r
.31931 .68053 m .32069 .65921 L .34243 .65229 L p F P
0 0 0 r
s
.1 0 .485 r
.32069 .65921 m .31931 .68053 L .29763 .68734 L p F P
0 0 0 r
s
.1 0 .485 r
.63698 .39143 m .63624 .37202 L .65937 .36385 L p F P
0 0 0 r
s
.1 0 .485 r
.63624 .37202 m .63698 .39143 L .6139 .39949 L p F P
0 0 0 r
s
.511 .78 0 r
.63912 .71955 m .63154 .72173 L .62666 .71648 L closepath p F P
0 0 0 r
s
0 .78 .12 r
.50456 .71148 m .51038 .71726 L .48554 .72156 L p F P
0 0 0 r
s
0 .78 .12 r
.48554 .72156 m .48205 .71816 L .50456 .71148 L p F P
0 0 0 r
s
.1 0 .485 r
.56889 .45483 m .56861 .435 L .59145 .4271 L p F P
0 0 0 r
s
.1 0 .485 r
.56861 .435 m .56889 .45483 L .5461 .46263 L p F P
0 0 0 r
s
0 .647 .956 r
.31015 .72122 m .30824 .71955 L .32987 .71279 L p F P
0 0 0 r
s
0 .647 .956 r
.32987 .71279 m .33186 .71457 L .31015 .72122 L p F P
0 0 0 r
s
.1 0 .485 r
.50076 .51829 m .50093 .49802 L .52348 .49039 L p F P
0 0 0 r
s
.1 0 .485 r
.50093 .49802 m .50076 .51829 L .47826 .52581 L p F P
0 0 0 r
s
.195 0 .31 r
.68376 .37507 m .6827 .35561 L .69367 .37077 L p F P
0 0 0 r
s
.195 0 .31 r
.69367 .37077 m .69479 .39018 L .68376 .37507 L p F P
0 0 0 r
s
.195 0 .31 r
.74578 .5688 m .7443 .54803 L .75478 .56165 L p F P
0 0 0 r
s
.195 0 .31 r
.75478 .56165 m .75631 .58234 L .74578 .5688 L p F P
0 0 0 r
s
0 .78 .12 r
.70081 .71734 m .68896 .72071 L .67796 .70838 L p F P
0 0 0 r
s
0 .78 .12 r
.65465 .71508 m .67796 .70838 L .68896 .72071 L p F P
0 0 0 r
s
.1 0 .485 r
.43258 .58178 m .43321 .56108 L .45547 .55373 L p F P
0 0 0 r
s
.1 0 .485 r
.43321 .56108 m .43258 .58178 L .41037 .58903 L p F P
0 0 0 r
s
0 .78 .71 r
.36737 .7202 m .36447 .71757 L .38655 .71095 L p F P
0 0 0 r
s
0 .78 .71 r
.38655 .71095 m .38935 .71354 L .36737 .7202 L p F P
0 0 0 r
s
0 .78 .71 r
.71234 .71406 m .73234 .70836 L .74584 .71987 L p F P
0 0 0 r
s
0 .647 .956 r
.74646 .71969 m .74584 .71987 L .73234 .70836 L p F P
0 0 0 r
s
0 .647 .956 r
.74646 .71969 m .73591 .70734 L p .76015 .70112 L F P
0 0 0 r
s
0 .647 .956 r
.76015 .70112 m .7701 .71303 L .74646 .71969 L p F P
0 0 0 r
s
0 .647 .956 r
.73234 .70836 m .73591 .70734 L .74646 .71969 L p F P
0 0 0 r
s
.1 0 .485 r
.36436 .64532 m .36544 .62419 L .38742 .61711 L p F P
0 0 0 r
s
.1 0 .485 r
.36544 .62419 m .36436 .64532 L .34243 .65229 L p F P
0 0 0 r
s
0 .78 .12 r
.65465 .71508 m .63912 .71955 L .62666 .71648 L p F P
0 0 0 r
s
.125 0 .956 r
.31792 .70214 m .32987 .71279 L .30824 .71955 L p F P
0 0 0 r
s
.125 0 .956 r
.30824 .71955 m .29609 .7089 L .31792 .70214 L p F P
0 0 0 r
s
.1 0 .485 r
.29609 .7089 m .29763 .68734 L .31931 .68053 L p F P
0 0 0 r
s
.1 0 .485 r
.29763 .68734 m .29609 .7089 L .27445 .7156 L p F P
0 0 0 r
s
0 .78 .12 r
.42468 .71918 m .42282 .71744 L .44575 .71139 L p F P
0 0 0 r
s
0 .78 .12 r
.44575 .71139 m .44692 .71251 L .42468 .71918 L p F P
0 0 0 r
s
.195 0 .31 r
.73365 .53419 m .73226 .51362 L .74284 .52754 L p F P
0 0 0 r
s
.195 0 .31 r
.74284 .52754 m .7443 .54803 L .73365 .53419 L p F P
0 0 0 r
s
.1 0 .485 r
.68165 .3364 m .6827 .35561 L .65937 .36385 L p F P
0 0 0 r
s
.125 0 .956 r
.77115 .71273 m .79394 .7063 L .80404 .71867 L p F P
0 0 0 r
s
.1 0 .485 r
.61449 .41913 m .6139 .39949 L .63698 .39143 L p F P
0 0 0 r
s
.1 0 .485 r
.6139 .39949 m .61449 .41913 L .59145 .4271 L p F P
0 0 0 r
s
0 .78 .12 r
.48205 .71816 m .46935 .70578 L p .49331 .70031 L F P
0 0 0 r
s
0 .78 .12 r
.49331 .70031 m .50456 .71148 L .48205 .71816 L p F P
0 0 0 r
s
0 .78 .12 r
.44692 .71251 m .46935 .70578 L .48205 .71816 L p F P
0 0 0 r
s
.1 0 .485 r
.54623 .4827 m .5461 .46263 L .56889 .45483 L p F P
0 0 0 r
s
.1 0 .485 r
.5461 .46263 m .54623 .4827 L .52348 .49039 L p F P
0 0 0 r
s
0 .647 .956 r
.37586 .70109 m .38655 .71095 L .36447 .71757 L p F P
0 0 0 r
s
0 .647 .956 r
.36447 .71757 m .35377 .70786 L .37586 .70109 L p F P
0 0 0 r
s
0 .78 .71 r
.43389 .70005 m .44575 .71139 L .42282 .71744 L p F P
0 0 0 r
s
0 .78 .71 r
.42282 .71744 m .41152 .70682 L .43389 .70005 L p F P
0 0 0 r
s
0 .78 .12 r
.67796 .70838 m .68264 .70703 L .70081 .71734 L p F P
0 0 0 r
s
0 .78 .71 r
.71234 .71406 m .70081 .71734 L .68264 .70703 L p F P
0 0 0 r
s
0 .78 .12 r
.52727 .70474 m .53622 .7138 L .51038 .71726 L p F P
0 0 0 r
s
0 .78 .12 r
.51038 .71726 m .50456 .71148 L .52727 .70474 L p F P
0 0 0 r
s
.511 .78 0 r
.53951 .71713 m .557 .712 L .56348 .71168 L p F P
0 0 0 r
s
.511 .78 0 r
.557 .712 m .53951 .71713 L .53622 .7138 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.47793 .54631 m .47826 .52581 L .50076 .51829 L p F P
0 0 0 r
s
.1 0 .485 r
.47826 .52581 m .47793 .54631 L .45547 .55373 L p F P
0 0 0 r
s
.195 0 .31 r
.78369 .69374 m .78195 .67207 L .79215 .68472 L p F P
0 0 0 r
s
.195 0 .31 r
.79215 .68472 m .79394 .7063 L .78369 .69374 L p F P
0 0 0 r
s
.195 0 .31 r
.7215 .49949 m .72018 .47913 L .73088 .49333 L p F P
0 0 0 r
s
.195 0 .31 r
.73088 .49333 m .73226 .51362 L .7215 .49949 L p F P
0 0 0 r
s
.1 0 .485 r
.40958 .60996 m .41037 .58903 L .43258 .58178 L p F P
0 0 0 r
s
.1 0 .485 r
.41037 .58903 m .40958 .60996 L .38742 .61711 L p F P
0 0 0 r
s
0 .78 .12 r
.64332 .70266 m .65465 .71508 L p .62666 .71648 L F P
0 0 0 r
s
0 .78 .12 r
.62666 .71648 m .62008 .70941 L .64332 .70266 L p F P
0 0 0 r
s
.511 .78 0 r
.59704 .71611 m .60689 .71325 L .62666 .71648 L p F P
0 0 0 r
s
0 .78 .12 r
.60689 .71325 m .62008 .70941 L .62666 .71648 L closepath p F P
0 0 0 r
s
.511 .78 0 r
.60689 .71325 m .59704 .71611 L .59318 .71205 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.34119 .67366 m .34243 .65229 L .36436 .64532 L p F P
0 0 0 r
s
.1 0 .485 r
.34243 .65229 m .34119 .67366 L .31931 .68053 L p F P
0 0 0 r
s
.1 0 .485 r
.66027 .38329 m .65937 .36385 L .6827 .35561 L p F P
0 0 0 r
s
.1 0 .485 r
.65937 .36385 m .66027 .38329 L .63698 .39143 L p F P
0 0 0 r
s
0 .78 .12 r
.65465 .71508 m .64332 .70266 L p .67258 .70235 L F P
0 0 0 r
s
0 .78 .12 r
.67258 .70235 m .67796 .70838 L .65465 .71508 L p F P
0 0 0 r
s
.195 0 .31 r
.77158 .6592 m .76993 .63774 L .78024 .65069 L p F P
0 0 0 r
s
.195 0 .31 r
.78024 .65069 m .78195 .67207 L .77158 .6592 L p F P
0 0 0 r
s
.195 0 .31 r
.70931 .46469 m .70807 .44454 L .71888 .45904 L p F P
0 0 0 r
s
.195 0 .31 r
.71888 .45904 m .72018 .47913 L .70931 .46469 L p F P
0 0 0 r
s
.1 0 .485 r
.59189 .44697 m .59145 .4271 L .61449 .41913 L p F P
0 0 0 r
s
.1 0 .485 r
.59145 .4271 m .59189 .44697 L .56889 .45483 L p F P
0 0 0 r
s
0 .647 .956 r
.33186 .71457 m .32987 .71279 L .35175 .70604 L p F P
0 0 0 r
s
0 .647 .956 r
.35175 .70604 m .35377 .70786 L .33186 .71457 L p F P
0 0 0 r
s
.1 0 .485 r
.52346 .5107 m .52348 .49039 L .54623 .4827 L p F P
0 0 0 r
s
.1 0 .485 r
.52348 .49039 m .52346 .5107 L .50076 .51829 L p F P
0 0 0 r
s
0 .78 .71 r
.73234 .70836 m .71234 .71406 L .70147 .70162 L p F P
0 0 0 r
s
0 .78 .71 r
.68264 .70703 m .70147 .70162 L .71234 .71406 L p F P
0 0 0 r
s
0 .78 .12 r
.56228 .71045 m .557 .712 L .53622 .7138 L p F P
0 0 0 r
s
0 .78 .12 r
.55017 .69795 m .56228 .71045 L p .53622 .7138 L F P
0 0 0 r
s
0 .78 .12 r
.53622 .7138 m .52727 .70474 L .55017 .69795 L p F P
0 0 0 r
s
.1 0 .485 r
.45499 .57447 m .45547 .55373 L .47793 .54631 L p F P
0 0 0 r
s
.1 0 .485 r
.45547 .55373 m .45499 .57447 L .43258 .58178 L p F P
0 0 0 r
s
0 .78 .71 r
.38935 .71354 m .38655 .71095 L .40897 .70443 L p F P
0 0 0 r
s
0 .78 .71 r
.40897 .70443 m .41152 .70682 L .38935 .71354 L p F P
0 0 0 r
s
0 .78 .12 r
.62008 .70941 m .60689 .71325 L .59318 .71205 L p F P
0 0 0 r
s
0 .647 .956 r
.77115 .71273 m .7701 .71303 L .76015 .70112 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.38648 .63828 m .38742 .61711 L .40958 .60996 L p F P
0 0 0 r
s
.1 0 .485 r
.38742 .61711 m .38648 .63828 L .36436 .64532 L p F P
0 0 0 r
s
.125 0 .956 r
.33993 .69532 m .35175 .70604 L .32987 .71279 L p F P
0 0 0 r
s
.125 0 .956 r
.32987 .71279 m .31792 .70214 L .33993 .69532 L p F P
0 0 0 r
s
.125 0 .956 r
.79394 .7063 m .77115 .71273 L .76015 .70112 L p F P
0 0 0 r
s
.195 0 .31 r
.75945 .62458 m .75787 .60331 L .76829 .61656 L p F P
0 0 0 r
s
.195 0 .31 r
.76829 .61656 m .76993 .63774 L .75945 .62458 L p F P
0 0 0 r
s
.195 0 .31 r
.69709 .4298 m .69593 .40985 L .70685 .42466 L p F P
0 0 0 r
s
.195 0 .31 r
.70685 .42466 m .70807 .44454 L .69709 .4298 L p F P
0 0 0 r
s
0 .78 .12 r
.44692 .71251 m .44575 .71139 L .46917 .70561 L p F P
0 0 0 r
s
0 .78 .12 r
.46917 .70561 m .46935 .70578 L .44692 .71251 L p F P
0 0 0 r
s
.1 0 .485 r
.31792 .70214 m .31931 .68053 L .34119 .67366 L p F P
0 0 0 r
s
.1 0 .485 r
.31931 .68053 m .31792 .70214 L .29609 .7089 L p F P
0 0 0 r
s
0 .78 .12 r
.60843 .6969 m .62008 .70941 L p .59318 .71205 L F P
0 0 0 r
s
0 .78 .12 r
.59318 .71205 m .58526 .7037 L .60843 .6969 L p F P
0 0 0 r
s
0 .78 .12 r
.58526 .7037 m .59318 .71205 L .56348 .71168 L p F P
0 0 0 r
s
0 .78 .12 r
.557 .712 m .56228 .71045 L .56348 .71168 L closepath p F P
0 0 0 r
s
0 .78 .12 r
.56348 .71168 m .56228 .71045 L .58526 .7037 L p F P
0 0 0 r
s
.1 0 .485 r
.63773 .4111 m .63698 .39143 L .66027 .38329 L p F P
0 0 0 r
s
.1 0 .485 r
.63698 .39143 m .63773 .4111 L .61449 .41913 L p F P
0 0 0 r
s
0 .78 .12 r
.50456 .71148 m .49331 .70031 L .51818 .69555 L p F P
0 0 0 r
s
0 .78 .12 r
.51818 .69555 m .52727 .70474 L .50456 .71148 L p F P
0 0 0 r
s
0 .78 .71 r
.45645 .69321 m .46917 .70561 L .44575 .71139 L p F P
0 0 0 r
s
0 .78 .71 r
.44575 .71139 m .43389 .70005 L .45645 .69321 L p F P
0 0 0 r
s
.1 0 .485 r
.56918 .47494 m .56889 .45483 L .59189 .44697 L p F P
0 0 0 r
s
.1 0 .485 r
.56889 .45483 m .56918 .47494 L .54623 .4827 L p F P
0 0 0 r
s
0 .647 .956 r
.39815 .69426 m .40897 .70443 L .38655 .71095 L p F P
0 0 0 r
s
0 .647 .956 r
.38655 .71095 m .37586 .70109 L .39815 .69426 L p F P
0 0 0 r
s
.195 0 .31 r
.74727 .58985 m .74578 .5688 L .75631 .58234 L p F P
0 0 0 r
s
.195 0 .31 r
.75631 .58234 m .75787 .60331 L .74727 .58985 L p F P
0 0 0 r
s
.195 0 .31 r
.68483 .39481 m .68376 .37507 L .69479 .39018 L p F P
0 0 0 r
s
.195 0 .31 r
.69479 .39018 m .69593 .40985 L .68483 .39481 L p F P
0 0 0 r
s
0 .78 .12 r
.58526 .7037 m .56228 .71045 L .55017 .69795 L p F P
0 0 0 r
s
.1 0 .485 r
.50059 .53883 m .50076 .51829 L .52346 .5107 L p F P
0 0 0 r
s
.1 0 .485 r
.50076 .51829 m .50059 .53883 L .47793 .54631 L p F P
0 0 0 r
s
.1 0 .485 r
.43195 .60276 m .43258 .58178 L .45499 .57447 L p F P
0 0 0 r
s
.1 0 .485 r
.43258 .58178 m .43195 .60276 L .40958 .60996 L p F P
0 0 0 r
s
0 .78 .12 r
.62008 .70941 m .60843 .6969 L p .63214 .69039 L F P
0 0 0 r
s
0 .78 .12 r
.63214 .69039 m .64332 .70266 L .62008 .70941 L p F P
0 0 0 r
s
.1 0 .485 r
.36326 .66673 m .36436 .64532 L .38648 .63828 L p F P
0 0 0 r
s
.1 0 .485 r
.36436 .64532 m .36326 .66673 L .34119 .67366 L p F P
0 0 0 r
s
.1 0 .485 r
.6827 .35561 m .68376 .37507 L .66027 .38329 L p F P
0 0 0 r
s
0 .78 .12 r
.68264 .70703 m .67796 .70838 L .67258 .70235 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.73507 .55504 m .73365 .53419 L .7443 .54803 L p F P
0 0 0 r
s
.195 0 .31 r
.7443 .54803 m .74578 .5688 L .73507 .55504 L p F P
0 0 0 r
s
0 .78 .71 r
.70147 .70162 m .71754 .69699 L .73234 .70836 L p F P
0 0 0 r
s
0 .647 .956 r
.73591 .70734 m .73234 .70836 L .71754 .69699 L p F P
0 0 0 r
s
.1 0 .485 r
.61508 .43904 m .61449 .41913 L .63773 .4111 L p F P
0 0 0 r
s
.1 0 .485 r
.61449 .41913 m .61508 .43904 L .59189 .44697 L p F P
0 0 0 r
s
0 .647 .956 r
.35377 .70786 m .35175 .70604 L .3739 .69928 L p F P
0 0 0 r
s
0 .647 .956 r
.3739 .69928 m .37586 .70109 L .35377 .70786 L p F P
0 0 0 r
s
.1 0 .485 r
.54637 .50304 m .54623 .4827 L .56918 .47494 L p F P
0 0 0 r
s
.1 0 .485 r
.54623 .4827 m .54637 .50304 L .52346 .5107 L p F P
0 0 0 r
s
0 .647 .956 r
.73591 .70734 m .75964 .70059 L .76015 .70112 L p F P
0 0 0 r
s
0 .647 .956 r
.75964 .70059 m .73591 .70734 L .72519 .69479 L p F P
0 0 0 r
s
0 .647 .956 r
.71754 .69699 m .72519 .69479 L .73591 .70734 L p F P
0 0 0 r
s
0 .78 .71 r
.70147 .70162 m .68264 .70703 L .67258 .70235 L p F P
0 0 0 r
s
.1 0 .485 r
.4776 .56709 m .47793 .54631 L .50059 .53883 L p F P
0 0 0 r
s
.1 0 .485 r
.47793 .54631 m .4776 .56709 L .45499 .57447 L p F P
0 0 0 r
s
0 .78 .71 r
.41152 .70682 m .40897 .70443 L .43175 .698 L p F P
0 0 0 r
s
0 .78 .71 r
.43175 .698 m .43389 .70005 L .41152 .70682 L p F P
0 0 0 r
s
.195 0 .31 r
.72283 .52012 m .7215 .49949 L .73226 .51362 L p F P
0 0 0 r
s
.195 0 .31 r
.73226 .51362 m .73365 .53419 L .72283 .52012 L p F P
0 0 0 r
s
.125 0 .956 r
.78369 .69374 m .79394 .7063 L p .76015 .70112 L F P
0 0 0 r
s
.1 0 .485 r
.40879 .63118 m .40958 .60996 L .43195 .60276 L p F P
0 0 0 r
s
.1 0 .485 r
.40958 .60996 m .40879 .63118 L .38648 .63828 L p F P
0 0 0 r
s
.125 0 .956 r
.36215 .68844 m .3739 .69928 L .35175 .70604 L p F P
0 0 0 r
s
.125 0 .956 r
.35175 .70604 m .33993 .69532 L .36215 .68844 L p F P
0 0 0 r
s
0 .78 .12 r
.46935 .70578 m .47245 .70486 L .49331 .70031 L p F P
0 0 0 r
s
0 .78 .12 r
.47245 .70486 m .46935 .70578 L .46917 .70561 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.33993 .69532 m .34119 .67366 L .36326 .66673 L p F P
0 0 0 r
s
.1 0 .485 r
.34119 .67366 m .33993 .69532 L .31792 .70214 L p F P
0 0 0 r
s
0 .78 .71 r
.49199 .699 m .47245 .70486 L .46917 .70561 L p F P
0 0 0 r
s
0 .78 .71 r
.47921 .68631 m .49199 .699 L p .46917 .70561 L F P
0 0 0 r
s
0 .78 .71 r
.46917 .70561 m .45645 .69321 L .47921 .68631 L p F P
0 0 0 r
s
0 .78 .71 r
.47245 .70486 m .49199 .699 L .49331 .70031 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.66117 .40299 m .66027 .38329 L .68376 .37507 L p F P
0 0 0 r
s
.1 0 .485 r
.66027 .38329 m .66117 .40299 L .63773 .4111 L p F P
0 0 0 r
s
0 .78 .12 r
.52727 .70474 m .51818 .69555 L .54394 .69152 L p F P
0 0 0 r
s
0 .78 .12 r
.54394 .69152 m .55017 .69795 L .52727 .70474 L p F P
0 0 0 r
s
0 .647 .956 r
.42064 .68738 m .43175 .698 L .40897 .70443 L p F P
0 0 0 r
s
0 .647 .956 r
.40897 .70443 m .39815 .69426 L .42064 .68738 L p F P
0 0 0 r
s
.195 0 .31 r
.71056 .48512 m .70931 .46469 L .72018 .47913 L p F P
0 0 0 r
s
.195 0 .31 r
.72018 .47913 m .7215 .49949 L .71056 .48512 L p F P
0 0 0 r
s
.1 0 .485 r
.59233 .46711 m .59189 .44697 L .61508 .43904 L p F P
0 0 0 r
s
.1 0 .485 r
.59189 .44697 m .59233 .46711 L .56918 .47494 L p F P
0 0 0 r
s
.195 0 .31 r
.77326 .68096 m .77158 .6592 L .78195 .67207 L p F P
0 0 0 r
s
.195 0 .31 r
.78195 .67207 m .78369 .69374 L .77326 .68096 L p F P
0 0 0 r
s
0 .78 .12 r
.58526 .7037 m .57328 .69109 L p .59984 .68767 L F P
0 0 0 r
s
0 .78 .12 r
.59984 .68767 m .60843 .6969 L .58526 .7037 L p F P
0 0 0 r
s
.1 0 .485 r
.52344 .53128 m .52346 .5107 L .54637 .50304 L p F P
0 0 0 r
s
0 .78 .12 r
.55017 .69795 m .57328 .69109 L .58526 .7037 L p F P
0 0 0 r
s
.1 0 .485 r
.52346 .5107 m .52344 .53128 L .50059 .53883 L p F P
0 0 0 r
s
.1 0 .485 r
.45451 .59549 m .45499 .57447 L .4776 .56709 L p F P
0 0 0 r
s
.1 0 .485 r
.45499 .57447 m .45451 .59549 L .43195 .60276 L p F P
0 0 0 r
s
.1 0 .485 r
.38553 .65974 m .38648 .63828 L .40879 .63118 L p F P
0 0 0 r
s
.1 0 .485 r
.38648 .63828 m .38553 .65974 L .36326 .66673 L p F P
0 0 0 r
s
0 .78 .12 r
.64332 .70266 m .66035 .69771 L .67258 .70235 L p F P
0 0 0 r
s
0 .78 .12 r
.66035 .69771 m .64332 .70266 L .63214 .69039 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.69043 .68897 m .70147 .70162 L p .67258 .70235 L F P
0 0 0 r
s
0 .78 .71 r
.67258 .70235 m .66677 .69585 L .69043 .68897 L p F P
0 0 0 r
s
0 .78 .71 r
.66035 .69771 m .66677 .69585 L .67258 .70235 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.76104 .64613 m .75945 .62458 L .76993 .63774 L p F P
0 0 0 r
s
.195 0 .31 r
.76993 .63774 m .77158 .6592 L .76104 .64613 L p F P
0 0 0 r
s
.195 0 .31 r
.69826 .45001 m .69709 .4298 L .70807 .44454 L p F P
0 0 0 r
s
.195 0 .31 r
.70807 .44454 m .70931 .46469 L .69826 .45001 L p F P
0 0 0 r
s
0 .78 .71 r
.71754 .69699 m .70147 .70162 L .69043 .68897 L p F P
0 0 0 r
s
.125 0 .956 r
.76015 .70112 m .75969 .70057 L .78369 .69374 L p F P
0 0 0 r
s
.125 0 .956 r
.75964 .70059 m .75969 .70057 L .76015 .70112 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.63849 .43103 m .63773 .4111 L .66117 .40299 L p F P
0 0 0 r
s
.1 0 .485 r
.63773 .4111 m .63849 .43103 L .61508 .43904 L p F P
0 0 0 r
s
0 .647 .956 r
.37586 .70109 m .3739 .69928 L .39631 .69253 L p F P
0 0 0 r
s
0 .647 .956 r
.39631 .69253 m .39815 .69426 L .37586 .70109 L p F P
0 0 0 r
s
0 .647 .956 r
.72519 .69479 m .74736 .68841 L .75964 .70059 L p F P
0 0 0 r
s
.125 0 .956 r
.75969 .70057 m .75964 .70059 L .74736 .68841 L p F P
0 0 0 r
s
.1 0 .485 r
.56947 .49532 m .56918 .47494 L .59233 .46711 L p F P
0 0 0 r
s
.1 0 .485 r
.56918 .47494 m .56947 .49532 L .54637 .50304 L p F P
0 0 0 r
s
.125 0 .956 r
.78369 .69374 m .75969 .70057 L .74912 .68791 L p F P
0 0 0 r
s
.125 0 .956 r
.74736 .68841 m .74912 .68791 L .75969 .70057 L p F P
0 0 0 r
s
0 .78 .71 r
.51482 .69215 m .51818 .69555 L .49331 .70031 L p F P
0 0 0 r
s
0 .78 .71 r
.49331 .70031 m .49199 .699 L .51482 .69215 L p F P
0 0 0 r
s
.195 0 .31 r
.68592 .41481 m .68483 .39481 L .69593 .40985 L p F P
0 0 0 r
s
.195 0 .31 r
.69593 .40985 m .69709 .4298 L .68592 .41481 L p F P
0 0 0 r
s
.1 0 .485 r
.50041 .55965 m .50059 .53883 L .52344 .53128 L p F P
0 0 0 r
s
.1 0 .485 r
.50059 .53883 m .50041 .55965 L .4776 .56709 L p F P
0 0 0 r
s
0 .78 .71 r
.43389 .70005 m .43175 .698 L .4549 .6917 L p F P
0 0 0 r
s
0 .78 .71 r
.4549 .6917 m .45645 .69321 L .43389 .70005 L p F P
0 0 0 r
s
.195 0 .31 r
.74879 .6112 m .74727 .58985 L .75787 .60331 L p F P
0 0 0 r
s
.195 0 .31 r
.75787 .60331 m .75945 .62458 L .74879 .6112 L p F P
0 0 0 r
s
.1 0 .485 r
.4313 .62402 m .43195 .60276 L .45451 .59549 L p F P
0 0 0 r
s
.1 0 .485 r
.43195 .60276 m .4313 .62402 L .40879 .63118 L p F P
0 0 0 r
s
.125 0 .956 r
.38456 .6815 m .39631 .69253 L .3739 .69928 L p F P
0 0 0 r
s
.125 0 .956 r
.3739 .69928 m .36215 .68844 L .38456 .6815 L p F P
0 0 0 r
s
0 .78 .71 r
.49199 .699 m .47921 .68631 L p .50251 .67969 L F P
0 0 0 r
s
0 .78 .71 r
.50251 .67969 m .51482 .69215 L .49199 .699 L p F P
0 0 0 r
s
.1 0 .485 r
.36215 .68844 m .36326 .66673 L .38553 .65974 L p F P
0 0 0 r
s
.1 0 .485 r
.36326 .66673 m .36215 .68844 L .33993 .69532 L p F P
0 0 0 r
s
0 .647 .956 r
.44333 .68043 m .4549 .6917 L .43175 .698 L p F P
0 0 0 r
s
0 .647 .956 r
.43175 .698 m .42064 .68738 L .44333 .68043 L p F P
0 0 0 r
s
.195 0 .31 r
.73651 .57617 m .73507 .55504 L .74578 .5688 L p F P
0 0 0 r
s
.195 0 .31 r
.74578 .5688 m .74727 .58985 L .73651 .57617 L p F P
0 0 0 r
s
.1 0 .485 r
.68376 .37507 m .68483 .39481 L .66117 .40299 L p F P
0 0 0 r
s
0 .78 .12 r
.55017 .69795 m .54394 .69152 L .57086 .68855 L p F P
0 0 0 r
s
0 .78 .12 r
.57086 .68855 m .57328 .69109 L .55017 .69795 L p F P
0 0 0 r
s
0 .78 .71 r
.66677 .69585 m .66035 .69771 L .63214 .69039 L p F P
0 0 0 r
s
.1 0 .485 r
.61569 .45921 m .61508 .43904 L .63849 .43103 L p F P
0 0 0 r
s
.1 0 .485 r
.61508 .43904 m .61569 .45921 L .59233 .46711 L p F P
0 0 0 r
s
0 .78 .71 r
.69043 .68897 m .70088 .68593 L .71754 .69699 L p F P
0 0 0 r
s
0 .647 .956 r
.72519 .69479 m .71754 .69699 L .70088 .68593 L p F P
0 0 0 r
s
0 .78 .12 r
.60843 .6969 m .63115 .69023 L .63214 .69039 L p F P
0 0 0 r
s
0 .78 .12 r
.63115 .69023 m .60843 .6969 L .59984 .68767 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.5465 .52366 m .54637 .50304 L .56947 .49532 L p F P
0 0 0 r
s
.1 0 .485 r
.54637 .50304 m .5465 .52366 L .52344 .53128 L p F P
0 0 0 r
s
.1 0 .485 r
.47727 .58815 m .4776 .56709 L .50041 .55965 L p F P
0 0 0 r
s
.1 0 .485 r
.4776 .56709 m .47727 .58815 L .45451 .59549 L p F P
0 0 0 r
s
.1 0 .485 r
.40799 .65269 m .40879 .63118 L .4313 .62402 L p F P
0 0 0 r
s
.1 0 .485 r
.40879 .63118 m .40799 .65269 L .38553 .65974 L p F P
0 0 0 r
s
.195 0 .31 r
.72419 .54105 m .72283 .52012 L .73365 .53419 L p F P
0 0 0 r
s
.195 0 .31 r
.73365 .53419 m .73507 .55504 L .72419 .54105 L p F P
0 0 0 r
s
0 .78 .71 r
.69043 .68897 m .66677 .69585 L .6554 .68311 L p F P
0 0 0 r
s
0 .78 .71 r
.6554 .68311 m .66677 .69585 L p .63214 .69039 L F P
0 0 0 r
s
0 .78 .71 r
.53786 .68524 m .54394 .69152 L .51818 .69555 L p F P
0 0 0 r
s
0 .78 .71 r
.51818 .69555 m .51482 .69215 L .53786 .68524 L p F P
0 0 0 r
s
0 .647 .956 r
.74736 .68841 m .72519 .69479 L .71429 .68204 L p F P
0 0 0 r
s
0 .647 .956 r
.70088 .68593 m .71429 .68204 L .72519 .69479 L p F P
0 0 0 r
s
.1 0 .485 r
.6621 .42296 m .66117 .40299 L .68483 .39481 L p F P
0 0 0 r
s
.1 0 .485 r
.66117 .40299 m .6621 .42296 L .63849 .43103 L p F P
0 0 0 r
s
0 .647 .956 r
.39815 .69426 m .39631 .69253 L .41898 .68579 L p F P
0 0 0 r
s
0 .647 .956 r
.41898 .68579 m .42064 .68738 L .39815 .69426 L p F P
0 0 0 r
s
.1 0 .485 r
.59278 .48753 m .59233 .46711 L .61569 .45921 L p F P
0 0 0 r
s
.1 0 .485 r
.59233 .46711 m .59278 .48753 L .56947 .49532 L p F P
0 0 0 r
s
.195 0 .31 r
.71183 .50582 m .71056 .48512 L .7215 .49949 L p F P
0 0 0 r
s
.195 0 .31 r
.7215 .49949 m .72283 .52012 L .71183 .50582 L p F P
0 0 0 r
s
.125 0 .956 r
.74912 .68791 m .77326 .68096 L .78369 .69374 L p F P
0 0 0 r
s
.1 0 .485 r
.52342 .55214 m .52344 .53128 L .5465 .52366 L p F P
0 0 0 r
s
.1 0 .485 r
.52344 .53128 m .52342 .55214 L .50041 .55965 L p F P
0 0 0 r
s
0 .78 .71 r
.45645 .69321 m .4549 .6917 L .47846 .68556 L p F P
0 0 0 r
s
0 .78 .71 r
.47846 .68556 m .47921 .68631 L .45645 .69321 L p F P
0 0 0 r
s
.1 0 .485 r
.45402 .6168 m .45451 .59549 L .47727 .58815 L p F P
0 0 0 r
s
.1 0 .485 r
.45451 .59549 m .45402 .6168 L .4313 .62402 L p F P
0 0 0 r
s
.125 0 .956 r
.40718 .6745 m .41898 .68579 L .39631 .69253 L p F P
0 0 0 r
s
.125 0 .956 r
.39631 .69253 m .38456 .6815 L .40718 .6745 L p F P
0 0 0 r
s
0 .78 .71 r
.51482 .69215 m .50251 .67969 L .52725 .67429 L p F P
0 0 0 r
s
0 .78 .71 r
.52725 .67429 m .53786 .68524 L .51482 .69215 L p F P
0 0 0 r
s
.1 0 .485 r
.38456 .6815 m .38553 .65974 L .40799 .65269 L p F P
0 0 0 r
s
.1 0 .485 r
.38553 .65974 m .38456 .6815 L .36215 .68844 L p F P
0 0 0 r
s
0 .647 .956 r
.46622 .67341 m .47846 .68556 L .4549 .6917 L p F P
0 0 0 r
s
0 .647 .956 r
.4549 .6917 m .44333 .68043 L .46622 .67341 L p F P
0 0 0 r
s
.195 0 .31 r
.76267 .66798 m .76104 .64613 L .77158 .6592 L p F P
0 0 0 r
s
.195 0 .31 r
.77158 .6592 m .77326 .68096 L .76267 .66798 L p F P
0 0 0 r
s
.195 0 .31 r
.69944 .47051 m .69826 .45001 L .70931 .46469 L p F P
0 0 0 r
s
.195 0 .31 r
.70931 .46469 m .71056 .48512 L .69944 .47051 L p F P
0 0 0 r
s
0 .78 .71 r
.5611 .67828 m .57086 .68855 L .54394 .69152 L p F P
0 0 0 r
s
0 .78 .71 r
.54394 .69152 m .53786 .68524 L .5611 .67828 L p F P
0 0 0 r
s
0 .78 .12 r
.57328 .69109 m .58451 .68776 L .59984 .68767 L p F P
0 0 0 r
s
0 .78 .12 r
.58451 .68776 m .57328 .69109 L .57086 .68855 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.63926 .45124 m .63849 .43103 L .6621 .42296 L p F P
0 0 0 r
s
.1 0 .485 r
.63849 .43103 m .63926 .45124 L .61569 .45921 L p F P
0 0 0 r
s
0 .78 .71 r
.63214 .69039 m .63181 .69003 L .6554 .68311 L p F P
0 0 0 r
s
0 .78 .71 r
.63115 .69023 m .63181 .69003 L .63214 .69039 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.63181 .69003 m .63115 .69023 L .59984 .68767 L p F P
0 0 0 r
s
0 .78 .71 r
.6554 .68311 m .63181 .69003 L .62011 .6772 L p F P
0 0 0 r
s
.1 0 .485 r
.56977 .51598 m .56947 .49532 L .59278 .48753 L p F P
0 0 0 r
s
0 .78 .71 r
.62011 .6772 m .63181 .69003 L p .59984 .68767 L F P
0 0 0 r
s
.1 0 .485 r
.56947 .49532 m .56977 .51598 L .5465 .52366 L p F P
0 0 0 r
s
.195 0 .31 r
.68702 .43509 m .68592 .41481 L .69709 .4298 L p F P
0 0 0 r
s
.195 0 .31 r
.69709 .4298 m .69826 .45001 L .68702 .43509 L p F P
0 0 0 r
s
.195 0 .31 r
.75033 .63283 m .74879 .6112 L .75945 .62458 L p F P
0 0 0 r
s
.195 0 .31 r
.75945 .62458 m .76104 .64613 L .75033 .63283 L p F P
0 0 0 r
s
.1 0 .485 r
.50023 .58076 m .50041 .55965 L .52342 .55214 L p F P
0 0 0 r
s
.1 0 .485 r
.50041 .55965 m .50023 .58076 L .47727 .58815 L p F P
0 0 0 r
s
.1 0 .485 r
.43065 .64558 m .4313 .62402 L .45402 .6168 L p F P
0 0 0 r
s
.1 0 .485 r
.4313 .62402 m .43065 .64558 L .40799 .65269 L p F P
0 0 0 r
s
0 .78 .71 r
.70088 .68593 m .69043 .68897 L .6792 .67612 L p F P
0 0 0 r
s
0 .78 .71 r
.6554 .68311 m .6792 .67612 L .69043 .68897 L p F P
0 0 0 r
s
0 .78 .71 r
.59659 .68418 m .58451 .68776 L .57086 .68855 L p F P
0 0 0 r
s
0 .78 .71 r
.58455 .67124 m .59659 .68418 L p .57086 .68855 L F P
0 0 0 r
s
0 .78 .71 r
.57086 .68855 m .5611 .67828 L .58455 .67124 L p F P
0 0 0 r
s
0 .647 .956 r
.71429 .68204 m .73423 .67624 L .74736 .68841 L p F P
0 0 0 r
s
.125 0 .956 r
.74912 .68791 m .74736 .68841 L .73423 .67624 L p F P
0 0 0 r
s
.125 0 .956 r
.77326 .68096 m .74912 .68791 L .73837 .67504 L p F P
0 0 0 r
s
.125 0 .956 r
.73423 .67624 m .73837 .67504 L .74912 .68791 L p F P
0 0 0 r
s
0 .78 .71 r
.58451 .68776 m .59659 .68418 L .59984 .68767 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.59984 .68767 m .59659 .68418 L .62011 .6772 L p F P
0 0 0 r
s
.1 0 .485 r
.68483 .39481 m .68592 .41481 L .6621 .42296 L p F P
0 0 0 r
s
0 .647 .956 r
.42064 .68738 m .41898 .68579 L .44194 .67907 L p F P
0 0 0 r
s
0 .647 .956 r
.44194 .67907 m .44333 .68043 L .42064 .68738 L p F P
0 0 0 r
s
.195 0 .31 r
.73796 .5976 m .73651 .57617 L .74727 .58985 L p F P
0 0 0 r
s
.195 0 .31 r
.74727 .58985 m .74879 .6112 L .73796 .5976 L p F P
0 0 0 r
s
.1 0 .485 r
.6163 .47967 m .61569 .45921 L .63926 .45124 L p F P
0 0 0 r
s
.1 0 .485 r
.61569 .45921 m .6163 .47967 L .59278 .48753 L p F P
0 0 0 r
s
.1 0 .485 r
.54664 .54456 m .5465 .52366 L .56977 .51598 L p F P
0 0 0 r
s
.1 0 .485 r
.5465 .52366 m .54664 .54456 L .52342 .55214 L p F P
0 0 0 r
s
0 .78 .71 r
.47921 .68631 m .49575 .6813 L .50251 .67969 L p F P
0 0 0 r
s
0 .78 .71 r
.49575 .6813 m .47921 .68631 L .47846 .68556 L closepath p F P
0 0 0 r
s
0 .78 .71 r
.6792 .67612 m .68132 .67549 L .70088 .68593 L p F P
0 0 0 r
s
0 .647 .956 r
.71429 .68204 m .70088 .68593 L .68132 .67549 L p F P
0 0 0 r
s
.125 0 .956 r
.42999 .66743 m .44194 .67907 L .41898 .68579 L p F P
0 0 0 r
s
.125 0 .956 r
.41898 .68579 m .40718 .6745 L .42999 .66743 L p F P
0 0 0 r
s
.1 0 .485 r
.47693 .60951 m .47727 .58815 L .50023 .58076 L p F P
0 0 0 r
s
.1 0 .485 r
.47727 .58815 m .47693 .60951 L .45402 .6168 L p F P
0 0 0 r
s
0 .647 .956 r
.50218 .67935 m .49575 .6813 L .47846 .68556 L p F P
0 0 0 r
s
0 .647 .956 r
.48932 .66634 m .50218 .67935 L p .47846 .68556 L F P
0 0 0 r
s
0 .647 .956 r
.47846 .68556 m .46622 .67341 L .48932 .66634 L p F P
0 0 0 r
s
.195 0 .31 r
.72556 .56226 m .72419 .54105 L .73507 .55504 L p F P
0 0 0 r
s
.195 0 .31 r
.73507 .55504 m .73651 .57617 L .72556 .56226 L p F P
0 0 0 r
s
0 .78 .71 r
.53786 .68524 m .52725 .67429 L .55273 .66946 L p F P
0 0 0 r
s
0 .78 .71 r
.55273 .66946 m .5611 .67828 L .53786 .68524 L p F P
0 0 0 r
s
.1 0 .485 r
.40718 .6745 m .40799 .65269 L .43065 .64558 L p F P
0 0 0 r
s
.1 0 .485 r
.40799 .65269 m .40718 .6745 L .38456 .6815 L p F P
0 0 0 r
s
0 .78 .71 r
.62011 .6772 m .59659 .68418 L .58455 .67124 L p F P
0 0 0 r
s
.1 0 .485 r
.66303 .4432 m .6621 .42296 L .68592 .41481 L p F P
0 0 0 r
s
.1 0 .485 r
.6621 .42296 m .66303 .4432 L .63926 .45124 L p F P
0 0 0 r
s
.1 0 .485 r
.59324 .50822 m .59278 .48753 L .6163 .47967 L p F P
0 0 0 r
s
.1 0 .485 r
.59278 .48753 m .59324 .50822 L .56977 .51598 L p F P
0 0 0 r
s
.195 0 .31 r
.71312 .52682 m .71183 .50582 L .72283 .52012 L p F P
0 0 0 r
s
.195 0 .31 r
.72283 .52012 m .72419 .54105 L .71312 .52682 L p F P
0 0 0 r
s
0 .78 .71 r
.6554 .68311 m .64384 .67016 L p .6771 .67372 L F P
0 0 0 r
s
0 .78 .71 r
.6771 .67372 m .6792 .67612 L .6554 .68311 L p F P
0 0 0 r
s
0 .78 .71 r
.62011 .6772 m .64384 .67016 L .6554 .68311 L p F P
0 0 0 r
s
.1 0 .485 r
.5234 .57329 m .52342 .55214 L .54664 .54456 L p F P
0 0 0 r
s
.1 0 .485 r
.52342 .55214 m .5234 .57329 L .50023 .58076 L p F P
0 0 0 r
s
0 .647 .956 r
.73423 .67624 m .71429 .68204 L .70321 .66907 L p F P
0 0 0 r
s
0 .647 .956 r
.68132 .67549 m .70321 .66907 L .71429 .68204 L p F P
0 0 0 r
s
.1 0 .485 r
.45352 .6384 m .45402 .6168 L .47693 .60951 L p F P
0 0 0 r
s
.1 0 .485 r
.45402 .6168 m .45352 .6384 L .43065 .64558 L p F P
0 0 0 r
s
0 .647 .956 r
.49575 .6813 m .50218 .67935 L .50251 .67969 L closepath p F P
0 0 0 r
s
.125 0 .956 r
.73837 .67504 m .76267 .66798 L .77326 .68096 L p F P
0 0 0 r
s
.195 0 .31 r
.70065 .49129 m .69944 .47051 L .71056 .48512 L p F P
0 0 0 r
s
.195 0 .31 r
.71056 .48512 m .71183 .50582 L .70065 .49129 L p F P
0 0 0 r
s
0 .647 .956 r
.44333 .68043 m .44194 .67907 L .46518 .67238 L p F P
0 0 0 r
s
0 .647 .956 r
.46518 .67238 m .46622 .67341 L .44333 .68043 L p F P
0 0 0 r
s
.1 0 .485 r
.64004 .47173 m .63926 .45124 L .66303 .4432 L p F P
0 0 0 r
s
.1 0 .485 r
.63926 .45124 m .64004 .47173 L .6163 .47967 L p F P
0 0 0 r
s
0 .647 .956 r
.52535 .67233 m .52725 .67429 L .50251 .67969 L p F P
0 0 0 r
s
0 .647 .956 r
.50251 .67969 m .50218 .67935 L .52535 .67233 L p F P
0 0 0 r
s
.1 0 .485 r
.57007 .53692 m .56977 .51598 L .59324 .50822 L p F P
0 0 0 r
s
.1 0 .485 r
.56977 .51598 m .57007 .53692 L .54664 .54456 L p F P
0 0 0 r
s
0 .647 .956 r
.50218 .67935 m .48932 .66634 L p .51265 .65923 L F P
0 0 0 r
s
0 .647 .956 r
.51265 .65923 m .52535 .67233 L .50218 .67935 L p F P
0 0 0 r
s
.125 0 .956 r
.45301 .6603 m .46518 .67238 L .44194 .67907 L p F P
0 0 0 r
s
.125 0 .956 r
.44194 .67907 m .42999 .66743 L .45301 .6603 L p F P
0 0 0 r
s
.195 0 .31 r
.75189 .65477 m .75033 .63283 L .76104 .64613 L p F P
0 0 0 r
s
.195 0 .31 r
.76104 .64613 m .76267 .66798 L .75189 .65477 L p F P
0 0 0 r
s
.195 0 .31 r
.68814 .45565 m .68702 .43509 L .69826 .45001 L p F P
0 0 0 r
s
.195 0 .31 r
.69826 .45001 m .69944 .47051 L .68814 .45565 L p F P
0 0 0 r
s
.1 0 .485 r
.50005 .60215 m .50023 .58076 L .5234 .57329 L p F P
0 0 0 r
s
.1 0 .485 r
.50023 .58076 m .50005 .60215 L .47693 .60951 L p F P
0 0 0 r
s
0 .78 .71 r
.5611 .67828 m .55273 .66946 L .5792 .6655 L p F P
0 0 0 r
s
0 .78 .71 r
.5792 .6655 m .58455 .67124 L .5611 .67828 L p F P
0 0 0 r
s
.1 0 .485 r
.42999 .66743 m .43065 .64558 L .45352 .6384 L p F P
0 0 0 r
s
.1 0 .485 r
.43065 .64558 m .42999 .66743 L .40718 .6745 L p F P
0 0 0 r
s
0 .78 .71 r
.62011 .6772 m .60821 .66415 L p .63847 .66414 L F P
0 0 0 r
s
0 .78 .71 r
.63847 .66414 m .64384 .67016 L .62011 .6772 L p F P
0 0 0 r
s
0 .78 .71 r
.58455 .67124 m .60821 .66415 L .62011 .6772 L p F P
0 0 0 r
s
.1 0 .485 r
.68592 .41481 m .68702 .43509 L .66303 .4432 L p F P
0 0 0 r
s
.195 0 .31 r
.73944 .61932 m .73796 .5976 L .74879 .6112 L p F P
0 0 0 r
s
.195 0 .31 r
.74879 .6112 m .75033 .63283 L .73944 .61932 L p F P
0 0 0 r
s
0 .647 .956 r
.70321 .66907 m .71984 .66419 L .73423 .67624 L p F P
0 0 0 r
s
.125 0 .956 r
.73837 .67504 m .73423 .67624 L .71984 .66419 L p F P
0 0 0 r
s
0 .78 .71 r
.68132 .67549 m .6792 .67612 L .6771 .67372 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.61693 .5004 m .6163 .47967 L .64004 .47173 L p F P
0 0 0 r
s
.1 0 .485 r
.6163 .47967 m .61693 .5004 L .59324 .50822 L p F P
0 0 0 r
s
.1 0 .485 r
.54678 .56576 m .54664 .54456 L .57007 .53692 L p F P
0 0 0 r
s
.1 0 .485 r
.54664 .54456 m .54678 .56576 L .5234 .57329 L p F P
0 0 0 r
s
0 .647 .956 r
.70321 .66907 m .68132 .67549 L .6771 .67372 L p F P
0 0 0 r
s
.125 0 .956 r
.76267 .66798 m .73837 .67504 L .72744 .66195 L p F P
0 0 0 r
s
.125 0 .956 r
.71984 .66419 m .72744 .66195 L .73837 .67504 L p F P
0 0 0 r
s
.1 0 .485 r
.47659 .63116 m .47693 .60951 L .50005 .60215 L p F P
0 0 0 r
s
.1 0 .485 r
.47693 .60951 m .47659 .63116 L .45352 .6384 L p F P
0 0 0 r
s
.195 0 .31 r
.72695 .58377 m .72556 .56226 L .73651 .57617 L p F P
0 0 0 r
s
.195 0 .31 r
.73651 .57617 m .73796 .5976 L .72695 .58377 L p F P
0 0 0 r
s
0 .647 .956 r
.54873 .66524 m .55273 .66946 L .52725 .67429 L p F P
0 0 0 r
s
0 .647 .956 r
.52725 .67429 m .52535 .67233 L .54873 .66524 L p F P
0 0 0 r
s
0 .647 .956 r
.69195 .65588 m .70321 .66907 L p .6771 .67372 L F P
0 0 0 r
s
0 .647 .956 r
.6771 .67372 m .66779 .66305 L .69195 .65588 L p F P
0 0 0 r
s
0 .78 .71 r
.64384 .67016 m .65481 .6669 L .6771 .67372 L p F P
0 0 0 r
s
0 .647 .956 r
.65481 .6669 m .66779 .66305 L .6771 .67372 L closepath p F P
0 0 0 r
s
0 .647 .956 r
.46622 .67341 m .46518 .67238 L .48874 .66576 L p F P
0 0 0 r
s
0 .647 .956 r
.48874 .66576 m .48932 .66634 L .46622 .67341 L p F P
0 0 0 r
s
.1 0 .485 r
.66398 .46373 m .66303 .4432 L .68702 .43509 L p F P
0 0 0 r
s
.1 0 .485 r
.66303 .4432 m .66398 .46373 L .64004 .47173 L p F P
0 0 0 r
s
.125 0 .956 r
.47624 .65311 m .48874 .66576 L .46518 .67238 L p F P
0 0 0 r
s
.125 0 .956 r
.46518 .67238 m .45301 .6603 L .47624 .65311 L p F P
0 0 0 r
s
0 .647 .956 r
.52535 .67233 m .51265 .65923 L .53707 .65297 L p F P
0 0 0 r
s
0 .647 .956 r
.53707 .65297 m .54873 .66524 L .52535 .67233 L p F P
0 0 0 r
s
.195 0 .31 r
.71443 .54811 m .71312 .52682 L .72419 .54105 L p F P
0 0 0 r
s
.195 0 .31 r
.72419 .54105 m .72556 .56226 L .71443 .54811 L p F P
0 0 0 r
s
.1 0 .485 r
.59371 .52921 m .59324 .50822 L .61693 .5004 L p F P
0 0 0 r
s
.1 0 .485 r
.59324 .50822 m .59371 .52921 L .57007 .53692 L p F P
0 0 0 r
s
.1 0 .485 r
.52338 .59473 m .5234 .57329 L .54678 .56576 L p F P
0 0 0 r
s
.1 0 .485 r
.5234 .57329 m .52338 .59473 L .50005 .60215 L p F P
0 0 0 r
s
.1 0 .485 r
.45301 .6603 m .45352 .6384 L .47659 .63116 L p F P
0 0 0 r
s
.1 0 .485 r
.45352 .6384 m .45301 .6603 L .42999 .66743 L p F P
0 0 0 r
s
0 .78 .71 r
.58455 .67124 m .5792 .6655 L .60715 .66298 L p F P
0 0 0 r
s
0 .78 .71 r
.60715 .66298 m .60821 .66415 L .58455 .67124 L p F P
0 0 0 r
s
.195 0 .31 r
.70187 .51236 m .70065 .49129 L .71183 .50582 L p F P
0 0 0 r
s
.195 0 .31 r
.71183 .50582 m .71312 .52682 L .70187 .51236 L p F P
0 0 0 r
s
0 .78 .71 r
.65481 .6669 m .64384 .67016 L .63847 .66414 L closepath p F P
0 0 0 r
s
0 .647 .956 r
.57232 .6581 m .5792 .6655 L .55273 .66946 L p F P
0 0 0 r
s
0 .647 .956 r
.55273 .66946 m .54873 .66524 L .57232 .6581 L p F P
0 0 0 r
s
0 .647 .956 r
.71984 .66419 m .70321 .66907 L .69195 .65588 L p F P
0 0 0 r
s
.1 0 .485 r
.64083 .49251 m .64004 .47173 L .66398 .46373 L p F P
0 0 0 r
s
.1 0 .485 r
.64004 .47173 m .64083 .49251 L .61693 .5004 L p F P
0 0 0 r
s
.1 0 .485 r
.57037 .55816 m .57007 .53692 L .59371 .52921 L p F P
0 0 0 r
s
.1 0 .485 r
.57007 .53692 m .57037 .55816 L .54678 .56576 L p F P
0 0 0 r
s
.1 0 .485 r
.49987 .62385 m .50005 .60215 L .52338 .59473 L p F P
0 0 0 r
s
.1 0 .485 r
.50005 .60215 m .49987 .62385 L .47659 .63116 L p F P
0 0 0 r
s
.195 0 .31 r
.68928 .47651 m .68814 .45565 L .69944 .47051 L p F P
0 0 0 r
s
.195 0 .31 r
.69944 .47051 m .70065 .49129 L .68928 .47651 L p F P
0 0 0 r
s
.125 0 .956 r
.72744 .66195 m .75189 .65477 L .76267 .66798 L p F P
0 0 0 r
s
0 .647 .956 r
.66779 .66305 m .65481 .6669 L .63847 .66414 L p F P
0 0 0 r
s
0 .647 .956 r
.48932 .66634 m .5116 .65952 L .51265 .65923 L p F P
0 0 0 r
s
0 .647 .956 r
.5116 .65952 m .48932 .66634 L .48874 .66576 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.74093 .64135 m .73944 .61932 L .75033 .63283 L p F P
0 0 0 r
s
.195 0 .31 r
.75033 .63283 m .75189 .65477 L .74093 .64135 L p F P
0 0 0 r
s
.1 0 .485 r
.68702 .43509 m .68814 .45565 L .66398 .46373 L p F P
0 0 0 r
s
.125 0 .956 r
.51262 .6592 m .5116 .65952 L .48874 .66576 L p F P
0 0 0 r
s
.125 0 .956 r
.49969 .64585 m .51262 .6592 L p .48874 .66576 L F P
0 0 0 r
s
.125 0 .956 r
.48874 .66576 m .47624 .65311 L .49969 .64585 L p F P
0 0 0 r
s
0 .647 .956 r
.59612 .65088 m .60715 .66298 L .5792 .6655 L p F P
0 0 0 r
s
0 .647 .956 r
.5792 .6655 m .57232 .6581 L .59612 .65088 L p F P
0 0 0 r
s
.1 0 .485 r
.61756 .52143 m .61693 .5004 L .64083 .49251 L p F P
0 0 0 r
s
.1 0 .485 r
.61693 .5004 m .61756 .52143 L .59371 .52921 L p F P
0 0 0 r
s
0 .647 .956 r
.54873 .66524 m .53707 .65297 L .56202 .64703 L p F P
0 0 0 r
s
0 .647 .956 r
.56202 .64703 m .57232 .6581 L .54873 .66524 L p F P
0 0 0 r
s
.1 0 .485 r
.54693 .58724 m .54678 .56576 L .57037 .55816 L p F P
0 0 0 r
s
.1 0 .485 r
.54678 .56576 m .54693 .58724 L .52338 .59473 L p F P
0 0 0 r
s
0 .647 .956 r
.69195 .65588 m .70336 .6525 L .71984 .66419 L p F P
0 0 0 r
s
.125 0 .956 r
.72744 .66195 m .71984 .66419 L .70336 .6525 L p F P
0 0 0 r
s
0 .78 .71 r
.60821 .66415 m .61262 .66283 L .63847 .66414 L p F P
0 0 0 r
s
0 .78 .71 r
.61262 .66283 m .60821 .66415 L .60715 .66298 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.47624 .65311 m .47659 .63116 L .49987 .62385 L p F P
0 0 0 r
s
.1 0 .485 r
.47659 .63116 m .47624 .65311 L .45301 .6603 L p F P
0 0 0 r
s
0 .647 .956 r
.65618 .64977 m .66779 .66305 L p .63847 .66414 L F P
0 0 0 r
s
0 .647 .956 r
.63847 .66414 m .63209 .65699 L .65618 .64977 L p F P
0 0 0 r
s
0 .647 .956 r
.61262 .66283 m .63209 .65699 L .63847 .66414 L closepath p F P
0 0 0 r
s
.195 0 .31 r
.72836 .60558 m .72695 .58377 L .73796 .5976 L p F P
0 0 0 r
s
.195 0 .31 r
.73796 .5976 m .73944 .61932 L .72836 .60558 L p F P
0 0 0 r
s
0 .647 .956 r
.69195 .65588 m .66779 .66305 L .65618 .64977 L p F P
0 0 0 r
s
0 .647 .956 r
.63209 .65699 m .61262 .66283 L .60715 .66298 L p F P
0 0 0 r
s
0 .647 .956 r
.62014 .6436 m .63209 .65699 L p .60715 .66298 L F P
0 0 0 r
s
0 .647 .956 r
.60715 .66298 m .59612 .65088 L .62014 .6436 L p F P
0 0 0 r
s
.125 0 .956 r
.75189 .65477 m .72744 .66195 L .71633 .64865 L p F P
0 0 0 r
s
.1 0 .485 r
.66494 .48454 m .66398 .46373 L .68814 .45565 L p F P
0 0 0 r
s
.125 0 .956 r
.70336 .6525 m .71633 .64865 L .72744 .66195 L p F P
0 0 0 r
s
.1 0 .485 r
.66398 .46373 m .66494 .48454 L .64083 .49251 L p F P
0 0 0 r
s
.195 0 .31 r
.71575 .5697 m .71443 .54811 L .72556 .56226 L p F P
0 0 0 r
s
.195 0 .31 r
.72556 .56226 m .72695 .58377 L .71575 .5697 L p F P
0 0 0 r
s
.1 0 .485 r
.59418 .55049 m .59371 .52921 L .61756 .52143 L p F P
0 0 0 r
s
.1 0 .485 r
.59371 .52921 m .59418 .55049 L .57037 .55816 L p F P
0 0 0 r
s
.1 0 .485 r
.52336 .61648 m .52338 .59473 L .54693 .58724 L p F P
0 0 0 r
s
.1 0 .485 r
.52338 .59473 m .52336 .61648 L .49987 .62385 L p F P
0 0 0 r
s
.125 0 .956 r
.5116 .65952 m .51262 .6592 L .51265 .65923 L closepath p F P
0 0 0 r
s
.125 0 .956 r
.53614 .652 m .53707 .65297 L .51265 .65923 L p F P
0 0 0 r
s
.125 0 .956 r
.51265 .65923 m .51262 .6592 L .53614 .652 L p F P
0 0 0 r
s
.125 0 .956 r
.53614 .652 m .51262 .6592 L .49969 .64585 L p F P
0 0 0 r
s
.195 0 .31 r
.70311 .53373 m .70187 .51236 L .71312 .52682 L p F P
0 0 0 r
s
.195 0 .31 r
.71312 .52682 m .71443 .54811 L .70311 .53373 L p F P
0 0 0 r
s
.1 0 .485 r
.64163 .51357 m .64083 .49251 L .66494 .48454 L p F P
0 0 0 r
s
.1 0 .485 r
.64083 .49251 m .64163 .51357 L .61756 .52143 L p F P
0 0 0 r
s
0 .647 .956 r
.57232 .6581 m .56202 .64703 L .58769 .64164 L p F P
0 0 0 r
s
0 .647 .956 r
.58769 .64164 m .59612 .65088 L .57232 .6581 L p F P
0 0 0 r
s
.1 0 .485 r
.57068 .57969 m .57037 .55816 L .59418 .55049 L p F P
0 0 0 r
s
.1 0 .485 r
.57037 .55816 m .57068 .57969 L .54693 .58724 L p F P
0 0 0 r
s
.195 0 .31 r
.69043 .49765 m .68928 .47651 L .70065 .49129 L p F P
0 0 0 r
s
.195 0 .31 r
.70065 .49129 m .70187 .51236 L .69043 .49765 L p F P
0 0 0 r
s
0 .647 .956 r
.65618 .64977 m .63209 .65699 L .62014 .6436 L p F P
0 0 0 r
s
.1 0 .485 r
.49969 .64585 m .49987 .62385 L .52336 .61648 L p F P
0 0 0 r
s
.1 0 .485 r
.49987 .62385 m .49969 .64585 L .47624 .65311 L p F P
0 0 0 r
s
0 .647 .956 r
.70336 .6525 m .69195 .65588 L .6805 .64248 L p F P
0 0 0 r
s
0 .647 .956 r
.65618 .64977 m .6805 .64248 L .69195 .65588 L p F P
0 0 0 r
s
.125 0 .956 r
.71633 .64865 m .74093 .64135 L .75189 .65477 L p F P
0 0 0 r
s
.1 0 .485 r
.68814 .45565 m .68928 .47651 L .66494 .48454 L p F P
0 0 0 r
s
.1 0 .485 r
.6182 .54275 m .61756 .52143 L .64163 .51357 L p F P
0 0 0 r
s
.1 0 .485 r
.61756 .52143 m .6182 .54275 L .59418 .55049 L p F P
0 0 0 r
s
.1 0 .485 r
.54707 .60903 m .54693 .58724 L .57068 .57969 L p F P
0 0 0 r
s
.1 0 .485 r
.54693 .58724 m .54707 .60903 L .52336 .61648 L p F P
0 0 0 r
s
.125 0 .956 r
.55987 .64473 m .56202 .64703 L .53707 .65297 L p F P
0 0 0 r
s
.125 0 .956 r
.53707 .65297 m .53614 .652 L .55987 .64473 L p F P
0 0 0 r
s
.195 0 .31 r
.72979 .6277 m .72836 .60558 L .73944 .61932 L p F P
0 0 0 r
s
.195 0 .31 r
.73944 .61932 m .74093 .64135 L .72979 .6277 L p F P
0 0 0 r
s
0 .647 .956 r
.6805 .64248 m .68283 .64178 L .70336 .6525 L p F P
0 0 0 r
s
.125 0 .956 r
.71633 .64865 m .70336 .6525 L .68283 .64178 L p F P
0 0 0 r
s
.125 0 .956 r
.55987 .64473 m .53614 .652 L .52334 .63852 L p F P
0 0 0 r
s
.125 0 .956 r
.49969 .64585 m .52334 .63852 L .53614 .652 L p F P
0 0 0 r
s
.1 0 .485 r
.66592 .50565 m .66494 .48454 L .68928 .47651 L p F P
0 0 0 r
s
.1 0 .485 r
.66494 .48454 m .66592 .50565 L .64163 .51357 L p F P
0 0 0 r
s
0 .647 .956 r
.59612 .65088 m .58769 .64164 L .61447 .63725 L p F P
0 0 0 r
s
0 .647 .956 r
.61447 .63725 m .62014 .6436 L .59612 .65088 L p F P
0 0 0 r
s
.195 0 .31 r
.7171 .5916 m .71575 .5697 L .72695 .58377 L p F P
0 0 0 r
s
.195 0 .31 r
.72695 .58377 m .72836 .60558 L .7171 .5916 L p F P
0 0 0 r
s
.1 0 .485 r
.59465 .57206 m .59418 .55049 L .6182 .54275 L p F P
0 0 0 r
s
.1 0 .485 r
.59418 .55049 m .59465 .57206 L .57068 .57969 L p F P
0 0 0 r
s
0 .647 .956 r
.65618 .64977 m .64438 .63626 L p .6786 .64026 L F P
0 0 0 r
s
0 .647 .956 r
.6786 .64026 m .6805 .64248 L .65618 .64977 L p F P
0 0 0 r
s
0 .647 .956 r
.62014 .6436 m .64438 .63626 L .65618 .64977 L p F P
0 0 0 r
s
.1 0 .485 r
.52334 .63852 m .52336 .61648 L .54707 .60903 L p F P
0 0 0 r
s
.1 0 .485 r
.52336 .61648 m .52334 .63852 L .49969 .64585 L p F P
0 0 0 r
s
.125 0 .956 r
.74093 .64135 m .71633 .64865 L .70503 .63512 L p F P
0 0 0 r
s
.125 0 .956 r
.68283 .64178 m .70503 .63512 L .71633 .64865 L p F P
0 0 0 r
s
.195 0 .31 r
.70436 .5554 m .70311 .53373 L .71443 .54811 L p F P
0 0 0 r
s
.195 0 .31 r
.71443 .54811 m .71575 .5697 L .70436 .5554 L p F P
0 0 0 r
s
.125 0 .956 r
.58382 .63739 m .58769 .64164 L .56202 .64703 L p F P
0 0 0 r
s
.125 0 .956 r
.56202 .64703 m .55987 .64473 L .58382 .63739 L p F P
0 0 0 r
s
.1 0 .485 r
.64244 .53494 m .64163 .51357 L .66592 .50565 L p F P
0 0 0 r
s
.1 0 .485 r
.64163 .51357 m .64244 .53494 L .6182 .54275 L p F P
0 0 0 r
s
.1 0 .485 r
.57099 .60152 m .57068 .57969 L .59465 .57206 L p F P
0 0 0 r
s
.1 0 .485 r
.57068 .57969 m .57099 .60152 L .54707 .60903 L p F P
0 0 0 r
s
.195 0 .31 r
.69159 .5191 m .69043 .49765 L .70187 .51236 L p F P
0 0 0 r
s
.195 0 .31 r
.70187 .51236 m .70311 .53373 L .69159 .5191 L p F P
0 0 0 r
s
.125 0 .956 r
.58382 .63739 m .55987 .64473 L .54722 .63113 L p F P
0 0 0 r
s
.125 0 .956 r
.52334 .63852 m .54722 .63113 L .55987 .64473 L p F P
0 0 0 r
s
.1 0 .485 r
.68928 .47651 m .69043 .49765 L .66592 .50565 L p F P
0 0 0 r
s
0 .647 .956 r
.62014 .6436 m .61447 .63725 L .64325 .63496 L p F P
0 0 0 r
s
0 .647 .956 r
.64325 .63496 m .64438 .63626 L .62014 .6436 L p F P
0 0 0 r
s
.1 0 .485 r
.61885 .56437 m .6182 .54275 L .64244 .53494 L p F P
0 0 0 r
s
.1 0 .485 r
.6182 .54275 m .61885 .56437 L .59465 .57206 L p F P
0 0 0 r
s
0 .647 .956 r
.68283 .64178 m .6805 .64248 L .6786 .64026 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.54722 .63113 m .54707 .60903 L .57099 .60152 L p F P
0 0 0 r
s
.1 0 .485 r
.54707 .60903 m .54722 .63113 L .52334 .63852 L p F P
0 0 0 r
s
.125 0 .956 r
.70503 .63512 m .68283 .64178 L .6786 .64026 L p F P
0 0 0 r
s
.125 0 .956 r
.60799 .62999 m .61447 .63725 L .58769 .64164 L p F P
0 0 0 r
s
.125 0 .956 r
.58769 .64164 m .58382 .63739 L .60799 .62999 L p F P
0 0 0 r
s
.125 0 .956 r
.70503 .63512 m .72979 .6277 L .74093 .64135 L p F P
0 0 0 r
s
.125 0 .956 r
.69354 .62136 m .70503 .63512 L p .6786 .64026 L F P
0 0 0 r
s
.125 0 .956 r
.6786 .64026 m .66885 .62884 L .69354 .62136 L p F P
0 0 0 r
s
0 .647 .956 r
.64438 .63626 m .64837 .63505 L .6786 .64026 L p F P
0 0 0 r
s
.125 0 .956 r
.64837 .63505 m .66885 .62884 L .6786 .64026 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.6669 .52705 m .66592 .50565 L .69043 .49765 L p F P
0 0 0 r
s
.1 0 .485 r
.66592 .50565 m .6669 .52705 L .64244 .53494 L p F P
0 0 0 r
s
.195 0 .31 r
.71846 .61381 m .7171 .5916 L .72836 .60558 L p F P
0 0 0 r
s
.195 0 .31 r
.72836 .60558 m .72979 .6277 L .71846 .61381 L p F P
0 0 0 r
s
.1 0 .485 r
.59514 .59395 m .59465 .57206 L .61885 .56437 L p F P
0 0 0 r
s
.1 0 .485 r
.59465 .57206 m .59514 .59395 L .57099 .60152 L p F P
0 0 0 r
s
.125 0 .956 r
.60799 .62999 m .58382 .63739 L .57131 .62367 L p F P
0 0 0 r
s
.125 0 .956 r
.54722 .63113 m .57131 .62367 L .58382 .63739 L p F P
0 0 0 r
s
.125 0 .956 r
.63238 .62252 m .64325 .63496 L .61447 .63725 L p F P
0 0 0 r
s
.125 0 .956 r
.61447 .63725 m .60799 .62999 L .63238 .62252 L p F P
0 0 0 r
s
.195 0 .31 r
.70564 .57738 m .70436 .5554 L .71575 .5697 L p F P
0 0 0 r
s
.195 0 .31 r
.71575 .5697 m .7171 .5916 L .70564 .57738 L p F P
0 0 0 r
s
0 .647 .956 r
.64837 .63505 m .64438 .63626 L .64325 .63496 L closepath p F P
0 0 0 r
s
.1 0 .485 r
.64326 .5566 m .64244 .53494 L .6669 .52705 L p F P
0 0 0 r
s
.1 0 .485 r
.64244 .53494 m .64326 .5566 L .61885 .56437 L p F P
0 0 0 r
s
.125 0 .956 r
.72979 .6277 m .70503 .63512 L .69354 .62136 L p F P
0 0 0 r
s
.1 0 .485 r
.57131 .62367 m .57099 .60152 L .59514 .59395 L p F P
0 0 0 r
s
.1 0 .485 r
.57099 .60152 m .57131 .62367 L .54722 .63113 L p F P
0 0 0 r
s
.125 0 .956 r
.66885 .62884 m .64837 .63505 L .64325 .63496 L p F P
0 0 0 r
s
.125 0 .956 r
.657 .61498 m .66885 .62884 L p .64325 .63496 L F P
0 0 0 r
s
.125 0 .956 r
.64325 .63496 m .63238 .62252 L .657 .61498 L p F P
0 0 0 r
s
.195 0 .31 r
.69278 .54085 m .69159 .5191 L .70311 .53373 L p F P
0 0 0 r
s
.195 0 .31 r
.70311 .53373 m .70436 .5554 L .69278 .54085 L p F P
0 0 0 r
s
.1 0 .485 r
.69043 .49765 m .69159 .5191 L .6669 .52705 L p F P
0 0 0 r
s
.1 0 .485 r
.61951 .5863 m .61885 .56437 L .64326 .5566 L p F P
0 0 0 r
s
.1 0 .485 r
.61885 .56437 m .61951 .5863 L .59514 .59395 L p F P
0 0 0 r
s
.125 0 .956 r
.63238 .62252 m .60799 .62999 L .59563 .61614 L p F P
0 0 0 r
s
.125 0 .956 r
.57131 .62367 m .59563 .61614 L .60799 .62999 L p F P
0 0 0 r
s
.125 0 .956 r
.69354 .62136 m .66885 .62884 L .657 .61498 L p F P
0 0 0 r
s
.1 0 .485 r
.66791 .54876 m .6669 .52705 L .69159 .5191 L p F P
0 0 0 r
s
.1 0 .485 r
.6669 .52705 m .66791 .54876 L .64326 .5566 L p F P
0 0 0 r
s
.125 0 .956 r
.69354 .62136 m .71846 .61381 L .72979 .6277 L p F P
0 0 0 r
s
.1 0 .485 r
.59563 .61614 m .59514 .59395 L .61951 .5863 L p F P
0 0 0 r
s
.1 0 .485 r
.59514 .59395 m .59563 .61614 L .57131 .62367 L p F P
0 0 0 r
s
.195 0 .31 r
.70693 .59968 m .70564 .57738 L .7171 .5916 L p F P
0 0 0 r
s
.195 0 .31 r
.7171 .5916 m .71846 .61381 L .70693 .59968 L p F P
0 0 0 r
s
.1 0 .485 r
.6441 .57858 m .64326 .5566 L .66791 .54876 L p F P
0 0 0 r
s
.1 0 .485 r
.64326 .5566 m .6441 .57858 L .61951 .5863 L p F P
0 0 0 r
s
.195 0 .31 r
.69398 .56292 m .69278 .54085 L .70436 .5554 L p F P
0 0 0 r
s
.195 0 .31 r
.70436 .5554 m .70564 .57738 L .69398 .56292 L p F P
0 0 0 r
s
.125 0 .956 r
.657 .61498 m .63238 .62252 L .62017 .60854 L p F P
0 0 0 r
s
.125 0 .956 r
.59563 .61614 m .62017 .60854 L .63238 .62252 L p F P
0 0 0 r
s
.125 0 .956 r
.71846 .61381 m .69354 .62136 L .68185 .60736 L p F P
0 0 0 r
s
.125 0 .956 r
.657 .61498 m .68185 .60736 L .69354 .62136 L p F P
0 0 0 r
s
.1 0 .485 r
.69159 .5191 m .69278 .54085 L .66791 .54876 L p F P
0 0 0 r
s
.1 0 .485 r
.62017 .60854 m .61951 .5863 L .6441 .57858 L p F P
0 0 0 r
s
.1 0 .485 r
.61951 .5863 m .62017 .60854 L .59563 .61614 L p F P
0 0 0 r
s
.1 0 .485 r
.66892 .57078 m .66791 .54876 L .69278 .54085 L p F P
0 0 0 r
s
.1 0 .485 r
.66791 .54876 m .66892 .57078 L .6441 .57858 L p F P
0 0 0 r
s
.125 0 .956 r
.68185 .60736 m .657 .61498 L .64495 .60087 L p F P
0 0 0 r
s
.125 0 .956 r
.62017 .60854 m .64495 .60087 L .657 .61498 L p F P
0 0 0 r
s
.125 0 .956 r
.68185 .60736 m .70693 .59968 L .71846 .61381 L p F P
0 0 0 r
s
.1 0 .485 r
.64495 .60087 m .6441 .57858 L .66892 .57078 L p F P
0 0 0 r
s
.1 0 .485 r
.6441 .57858 m .64495 .60087 L .62017 .60854 L p F P
0 0 0 r
s
.195 0 .31 r
.6952 .58531 m .69398 .56292 L .70564 .57738 L p F P
0 0 0 r
s
.195 0 .31 r
.70564 .57738 m .70693 .59968 L .6952 .58531 L p F P
0 0 0 r
s
.1 0 .485 r
.69278 .54085 m .69398 .56292 L .66892 .57078 L p F P
0 0 0 r
s
.125 0 .956 r
.70693 .59968 m .68185 .60736 L .66996 .59312 L p F P
0 0 0 r
s
.125 0 .956 r
.64495 .60087 m .66996 .59312 L .68185 .60736 L p F P
0 0 0 r
s
.1 0 .485 r
.66996 .59312 m .66892 .57078 L .69398 .56292 L p F P
0 0 0 r
s
.1 0 .485 r
.66892 .57078 m .66996 .59312 L .64495 .60087 L p F P
0 0 0 r
s
.125 0 .956 r
.66996 .59312 m .6952 .58531 L .70693 .59968 L p F P
0 0 0 r
s
.1 0 .485 r
.69398 .56292 m .6952 .58531 L .66996 .59312 L p F P
0 0 0 r
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.773587 0.020347 0.97619 0.834227 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 4.0171 [
[ 0 0 0 0 ]
[ 1 4.0171 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 4.0171 L
0 4.0171 L
closepath
clip
newpath
0 g
gsave
0 .40171 -61 -19.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.188 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.773 0.102 0.004 setrgbcolor
0.000 0.000 rmoveto
63.188 15.188 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.773 0.102 0.004 setrgbcolor
(AceFEM) show
108.000 15.188 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.773 0.102 0.004 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
0 .68291 -61 -15.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
68.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
0 .9641 -61 -15.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Min) show
77.313 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
79.813 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
0 1.2453 -61 -15.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6190) show
90.500 13.000 moveto
(e2) show
100.500 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
0 1.5265 -61 -15.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Max) show
79.625 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
82.125 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.2 0 1 r
0 1.60684 m
0 1.85791 L
.1 1.85791 L
.1 1.60684 L
F
0 .829 1 r
0 1.85791 m
0 2.10898 L
.1 2.10898 L
.1 1.85791 L
F
0 1 .743 r
0 2.10898 m
0 2.36005 L
.1 2.36005 L
.1 2.10898 L
F
0 1 .126 r
0 2.36005 m
0 2.61111 L
.1 2.61111 L
.1 2.36005 L
F
.817 1 0 r
0 2.61111 m
0 2.86218 L
.1 2.86218 L
.1 2.61111 L
F
1 .84 0 r
0 2.86218 m
0 3.11325 L
.1 3.11325 L
.1 2.86218 L
F
1 .257 0 r
0 3.11325 m
0 3.36432 L
.1 3.36432 L
.1 3.11325 L
F
1 0 .6 r
0 3.36432 m
0 3.61539 L
.1 3.61539 L
.1 3.36432 L
F
0 g
gsave
.1 1.85791 -61 -9.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.773) show
85.500 13.000 moveto
(e1) show
95.500 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.1 2.10898 -61 -9.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.154) show
85.500 13.000 moveto
(e2) show
95.500 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.1 2.36005 -61 -9.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.232) show
85.500 13.000 moveto
(e2) show
95.500 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.1 2.61111 -61 -9.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.309) show
85.500 13.000 moveto
(e2) show
95.500 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.1 2.86218 -61 -9.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.386) show
85.500 13.000 moveto
(e2) show
95.500 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.1 3.11325 -61 -9.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.464) show
85.500 13.000 moveto
(e2) show
95.500 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.1 3.36432 -61 -9.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.541) show
85.500 13.000 moveto
(e2) show
95.500 13.000 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[176]:=",
  ImageSize->{288, 246.063},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000mR000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00U@3oool00`000000oooo0?ooo`280?ooo`00T`3o
ool4000008T0oooo002@0?ooo`<000000`0I07`2000008P0oooo002<0?ooo`@0000000<06@1l0000
000I07`00P0I07`2000000030340C`000000oooo08H0oooo002:0?ooo`80000000<06@1l0000000I
07`00P0I07`01@0000006@1l0000000000006@1l00@00000QP3oool008P0oooo0P00000301T0O004
0000000I07`06@1l01T0O08000000`0I07`4000008H0oooo00260?ooo`<00000100I07`00`000000
6@1l00000002000000<06@1l0P000000100a04l000000340C`0000250?ooo`00Q03oool200000080
6@1l00@0000001T0O00I07`06@1l0`00000201T0O00:0000000I07`000000000000I07`000000340
C`000000<@1?000004@0oooo10356P400`3oool0aAX10<DJ0@020<DJ0@030?ooo`356P40aAX10080
aAX10`3oool40<DJ0@030?ooo`356P40aAX100<0aAX10P3oool;0<DJ0@040?ooo`356P40aAX10<DJ
0AD0oooo00220?ooo`<000000`0I07`01P0000006@1l0000000000006@1l000000<06@1l0P000003
01T0O0H00000A03oool20<DJ0@<0oooo0P356P400`3oool0aAX10<DJ0@030?ooo`040<DJ0@3oool0
aAX10<DJ0@<0oooo00@0aAX10?ooo`356P40aAX11@3oool20<DJ0@<0oooo00@0aAX10?ooo`356P40
aAX10P3oool20<DJ0AH0oooo001o0?ooo`<000000P0I07`00`0000006@1l01T0O003000000<06@1l
00<0000001T0O00000000P00000401T0O0H00000A@3oool60<DJ0@030?ooo`356P40aAX100D0oooo
0P356P450?ooo`80aAX11@3oool20<DJ0@D0oooo0P356P420?ooo`80aAX15P3oool007d0oooo0P00
00000`0I07`0000001T0O00201T0O0<0000000<06@1l0000000I07`00P0I07`3000000806@1l00@0
000001T0O00I07`06@1l0P0000001P0a04l000000340C`000000<@1?000004@0oooo0P356P420?oo
o`80aAX100<0oooo0<DJ0@356P401@3oool60<DJ0@80oooo0P356P40103oool0aAX10?ooo`3oool2
0<DJ0@80oooo00<0aAX10?ooo`3oool00P356P40103oool0aAX10?ooo`356P4F0?ooo`00NP3oool3
000000<06@1l00<0000001T0O00000000P00000301T0O0060000000I07`000000000000I07`00000
0`0I07`01@0000006@1l0000000000006@1l00P00000A03oool20<DJ0@030?ooo`356P40aAX10080
oooo0P356P420?ooo`040<DJ0@3oool0oooo0<DJ0@80oooo0P356P420?ooo`@0aAX10`3oool40<DJ
0@<0oooo00@0aAX10?ooo`356P40oooo0P356P4E0?ooo`00M`3oool30000000301T0O00000006@1l
00806@1l0`00000201T0O0040000000I07`06@1l01T0O08000000`0I07`00`0000006@1l01T0O003
000000<06@1l200000140?ooo`80aAX100<0oooo0<DJ0@356P400`3oool40<DJ0@<0oooo0`356P43
0?ooo`80aAX100<0oooo0<DJ0@3oool00P3oool20<DJ0@030?ooo`356P40oooo0080oooo0P356P40
103oool0aAX10<DJ0@356P4E0?ooo`00M@3oool3000000<06@1l00H0000001T0O0000000000001T0
O000000301T0O0030000000I07`0000000800000100I07`30000000301T0O00000006@1l00<06@1l
00T000000340C`000000<@1?0000000a04l000000340C`000000A03oool30<DJ0A40oooo0P356P43
0?ooo`040<DJ0@3oool0aAX10<DJ0@<0oooo00D0aAX10?ooo`356P40aAX10?ooo`030<DJ0AD0oooo
001c0?ooo`8000000P0I07`0100000006@1l01T0O00I07`2000000<06@1l00<0000001T0O00I07`0
0`00000301T0O0030000000I07`0000000800000100I07`00`0000006@1l00000002000000030340
C`000000000000H00000@P3oool40<DJ0A00oooo4@356P420?ooo`<0aAX1503oool00740oooo0`00
000301T0O0030000000I07`00000008000000`0I07`40000000301T0O00000006@1l00806@1l0`00
000201T0O0040000000I07`06@1l01T0O0<000000P0I07`:00000800oooo001_0?ooo`8000000P0I
07`00`0000006@1l01T0O003000000806@1l00H0000001T0O0000000000001T0O000000301T0O006
0000000I07`000000000000I07`000000`0I07`01P0000006@1l0000000000006@1l000000<06@1l
0`000000200a04l000000340C`000000<@1?0000000a04l00000O`3oool006d0oooo00<0000001T0
O00000000`0I07`30000000301T0O00000006@1l00806@1l0P00000301T0O0040000000I07`06@1l
01T0O08000000`0I07`0100000006@1l01T0O00I07`2000000<06@1l00<0000001T0O00I07`00P00
00001`0a04l000000340C`000000<@1?0000000a04l01000001n0?ooo`00J@3oool4000000806@1l
00<0000001T0O00000000P00000301T0O0030000000I07`0000000800000100I07`00`0000006@1l
00000002000000@06@1l00<0000001T0O00000000P00000301T0O0@0000000<06@1l000000000000
2P00001n0?ooo`00IP3oool3000000806@1l00<0000001T0O00I07`00`00000201T0O0040000000I
07`06@1l01T0O08000000P0I07`0100000006@1l01T0O00I07`3000000806@1l00<0000001T0O00I
07`01000000201T0O0060000000I07`000000000000I07`00000100I07`8000000040340C`000000
<@1?000007d0oooo001T0?ooo`<000000`0I07`01P0000006@1l0000000000006@1l000000<06@1l
00<0000001T0O00000000P00000301T0O0060000000I07`000000000000I07`000000`0I07`30000
00806@1l00@0000001T0O00I07`06@1l0P00000301T0O0040000000I07`06@1l01T0O080000000X0
<@1?000000000000<@1?0000000a04l000000340C`000000<@1?0P00001l0?ooo`00HP3oool20000
00806@1l00@0000001T0O00I07`06@1l0P00000301T0O0030000000I07`06@1l00<000000P0I07`0
0`0000006@1l01T0O003000000<06@1l00<0000001T0O00000000P00000401T0O0030000000I07`0
000000800000100I07`01@0000006@1l0000000000006@1l00d00000O03oool00600oooo0`000003
01T0O0030000000I07`00000008000000`0I07`40000000301T0O00000006@1l00806@1l0`000000
0`0I07`0000001T0O00201T0O0<000000P0I07`0100000006@1l01T0O00I07`3000000806@1l00@0
000001T0O00I07`06@1l0`00000301T0O0`0000000<0<@1?0000003oool0NP3oool005d0oooo0`00
000201T0O0030000000I07`06@1l00<000000P0I07`01P0000006@1l0000000000006@1l000000<0
6@1l00<0000001T0O00000000P00000301T0O0060000000I07`000000000000I07`000000`0I07`0
1P0000006@1l0000000000006@1l000000<06@1l00H0000001T0O0000000000001T0O000000401T0
O0060000000a04l000000340C`000000<@1?0P0000001P0a04l000000340C`000000<@1?000007/0
oooo001J0?ooo`<0000000<06@1l0000000I07`00P0I07`30000000301T0O00000006@1l00806@1l
0P00000301T0O0040000000I07`06@1l01T0O08000000P0I07`0100000006@1l01T0O00I07`20000
00<06@1l00@0000001T0O00I07`06@1l0P00000301T0O0040000000I07`06@1l01T0O08000000`0I
07`00`0000006@1l01T0O003000000050340C`000000<@1?0000000a04l02@00001j0?ooo`00F03o
ool3000000<06@1l00<0000001T0O00000000P00000301T0O0030000000I07`0000000800000100I
07`01@0000006@1l0000000I07`0000000<06@1l00<0000001T0O00000000P00000401T0O0030000
000I07`0000000800000100I07`00`0000006@1l00000002000000<06@1l1000000201T0O0l00000
>@3oool3000003h0oooo001F0?ooo`8000000P0I07`0100000006@1l01T0O00I07`2000000806@1l
00@0000001T0O00I07`06@1l0P00000201T0O0030000000I07`06@1l00@000000P0I07`00`000000
6@1l01T0O003000000806@1l00<0000001T0O00I07`01000000201T0O0030000000I07`06@1l00@0
00000P0I07`01P0000006@1l0000000000006@1l000000@06@1l1`0000002@0a04l000000000000a
04l000000340C`000000<@1?0000000h0?ooo`040000003oool0oooo000003d0oooo001D0?ooo`<0
00000`0I07`00`0000006@1l00000002000000<06@1l00<0000001T0O00000000P00000301T0O0<0
00000P0I07`00`0000006@1l01T0O0040000000301T0O00000006@1l00806@1l0`00000201T0O004
0000000I07`06@1l01T0O0<000000P0I07`0100000006@1l01T0O00I07`2000000<06@1l00@00000
01T0O00I07`06@1l0P0000001`0a04l000000340C`000000<@1?0000000a04l02000000h0?ooo`04
0000003oool0oooo000003d0oooo001A0?ooo`<000000P0I07`00`0000006@1l01T0O00300000080
6@1l00<0000001T0O00I07`00`00000201T0O0030000000I07`00000008000000`0I07`01P000000
6@1l0000000000006@1l000000<06@1l00<0000001T0O00000000P00000401T0O0030000000I07`0
000000800000100I07`00`0000006@1l00000002000000@06@1l00L0000001T0O0000000000001T0
O0000000<@1?00l00000=`3oool010000000oooo0?ooo`00000m0?ooo`00CP3oool30000000301T0
O00000006@1l00806@1l0`0000000`0I07`0000001T0O00201T0O0<0000000<06@1l0000000I07`0
0P0I07`2000000806@1l00@0000001T0O00I07`06@1l0P00000301T0O0040000000I07`06@1l01T0
O08000000P0I07`0100000006@1l01T0O00I07`3000000806@1l00@0000001T0O00I07`06@1l0`00
000201T0O0030000000I07`06@1l00806@1l0P00000301T0O0`0000000<0<@1?0000000a04l00P00
000g0?ooo`040000003oool0oooo000003d0oooo001<0?ooo`<000000`0I07`00`0000006@1l0000
0002000000<06@1l00<0000001T0O00000000P00000301T0O0030000000I07`00000008000000`0I
07`00`0000006@1l00000002000000@06@1l00<0000001T0O00000000P00000301T0O0060000000I
07`000000000000I07`000000`0I07`01P0000006@1l0000000000006@1l000000@06@1l00<00000
01T0O00000000P00000401T0O0<0000000L0<@1?0000000a04l000000340C`000000<@1?00P00000
=P3oool010000000oooo0?ooo`00000m0?ooo`00BP3oool2000000806@1l00<0000001T0O00I07`0
0`00000201T0O0030000000I07`06@1l00<000000P0I07`0100000006@1l01T0O00I07`200000080
6@1l00@0000001T0O00I07`06@1l0P00000201T0O0040000000I07`06@1l01T0O0<000000P0I07`0
100000006@1l01T0O00I07`2000000<06@1l00@0000001T0O00I07`06@1l0P00000301T0O0040000
000I07`06@1l01T0O0<000000P0I07`0100000006@1l01T0O00I07`2000000050340C`000000<@1?
0000000a04l03000000g0?ooo`800000?P3oool004L0oooo0`000000100I07`0000001T0O00I07`3
0000000301T0O00000006@1l00806@1l0`0000000`0I07`0000001T0O00201T0O0030000000I07`0
0000008000000`0I07`00`0000006@1l00000002000000<06@1l00H0000001T0O0000000000001T0
O000000301T0O0030000000I07`0000000800000100I07`00`0000006@1l00000002000000@06@1l
00H0000001T0O0000000000001T0O000000301T0O0050000000I07`000000000000I07`03P000000
0`0a04l000000340C`02000007H0oooo00150?ooo`030000000I07`0000000806@1l00<0000001T0
O00000000P00000301T0O0030000000I07`00000008000000`0I07`00`0000006@1l01T0O0030000
00806@1l00<0000001T0O00I07`00`00000201T0O0030000000I07`06@1l00<000000`0I07`00`00
00006@1l01T0O003000000806@1l00<0000001T0O00I07`01000000201T0O0030000000I07`06@1l
00@000000`0I07`00`0000006@1l01T0O003000000<06@1l1`0000001@0a04l000000340C`000000
<@1?00P00000M@3oool004<0oooo0P0000000`0I07`0000001T0O00201T0O08000000P0I07`01000
00006@1l01T0O00I07`2000000806@1l00@0000001T0O00I07`06@1l0`0000000`0I07`0000001T0
O00201T0O0<0000000<06@1l0000000I07`00P0I07`30000000301T0O00000006@1l00806@1l1000
00000`0I07`0000001T0O00201T0O0<000000P0I07`0100000006@1l01T0O00I07`3000000806@1l
00@0000001T0O00I07`06@1l100000000`0I07`0000001T0O00301T0O0080000000a04l000000340
C`000000<@1?0000000a04l<000007D0oooo00110?ooo`<000000P0I07`00`0000006@1l00000002
000000<06@1l00<0000001T0O00000000P00000301T0O0030000000I07`00000008000000`0I07`0
0`0000006@1l00000002000000<06@1l00<0000001T0O00000000P00000301T0O0060000000I07`0
00000000000I07`000000`0I07`00`0000006@1l00000002000000@06@1l00<0000001T0O0000000
0P00000401T0O0060000000I07`000000000000I07`00000100I07`00`0000006@1l0000000A0000
00030340C`000000<@1?00800000M03oool003h0oooo0`000000100I07`0000001T0O00I07`30000
00806@1l00<0000001T0O00I07`00`00000201T0O0030000000I07`06@1l00<000000P0I07`01000
00006@1l01T0O00I07`2000000806@1l00@0000001T0O00I07`06@1l0P00000201T0O0040000000I
07`06@1l01T0O08000000`0I07`0100000006@1l01T0O00I07`2000000806@1l00@0000001T0O00I
07`06@1l0`00000201T0O0030000000I07`06@1l00806@1l0P00000301T0O0040000000I07`06@1l
01T0O0<000000P0I07`3000000030340C`000000000000<0000000D0<@1?0000000a04l000000340
C`08000007<0oooo000k0?ooo`<0000000@06@1l0000000I07`06@1l0`0000000`0I07`0000001T0
O00201T0O0<0000000<06@1l0000000I07`00P0I07`30000000301T0O00000006@1l00806@1l00D0
000001T0O00000006@1l0000000301T0O0030000000I07`00000008000000`0I07`00`0000006@1l
00000002000000@06@1l00<0000001T0O00000000P00000301T0O0060000000I07`000000000000I
07`00000100I07`00`0000006@1l00000002000000@06@1l00H0000001T0O0000000000001T0O000
000401T0O0<0000000P0<@1?000000000000<@1?0000000a04l000000340C`T0000000<0<@1?0000
003oool0L@3oool003T0oooo0`00000301T0O0@000000`0I07`00`0000006@1l00000002000000<0
6@1l00D0000001T0O00000006@1l0000000301T0O0030000000I07`06@1l00<000000P0I07`00`00
00006@1l01T0O003000000806@1l00<0000001T0O00I07`00`00000201T0O0040000000I07`06@1l
01T0O0<000000P0I07`0100000006@1l01T0O00I07`2000000<06@1l00@0000001T0O00I07`06@1l
0`00000201T0O0040000000I07`06@1l01T0O0<000000`0I07`0100000006@1l01T0O00I07`20000
00030340C`000000<@1?00d0000000@0<@1?000000000000<@1?0P00001a0?ooo`00=P3oool30000
00806@1l00<0000001T0O00I07`00P00000201T0O0040000000I07`06@1l01T0O08000000P0I07`0
100000006@1l01T0O00I07`20000000301T0O00000006@1l00806@1l10000000100I07`0000001T0
O00I07`40000000301T0O00000006@1l00806@1l0`0000000`0I07`0000001T0O00201T0O0060000
000I07`000000000000I07`000000`0I07`00`0000006@1l00000002000000@06@1l00H0000001T0
O0000000000001T0O000000301T0O0060000000I07`000000000000I07`00000100I07`01`000000
6@1l0000000000006@1l0000000a04l0100000000`0a04l0000000000003000000030340C`000000
<@1?00P00000L@3oool003@0oooo0P0000000`0I07`0000001T0O00201T0O0<0000000H06@1l0000
000I07`06@1l0000000I07`3000000<06@1l00D0000001T0O00000006@1l0000000201T0O0060000
000I07`000000000000I07`000000P0I07`01P0000006@1l0000000000006@1l000000<06@1l00<0
000001T0O00000000P00000301T0O0030000000I07`06@1l00<000000`0I07`00`0000006@1l01T0
O003000000806@1l00<0000001T0O00I07`00P0I07`2000000<06@1l00@0000001T0O00I07`06@1l
0P00000301T0O0040000000I07`06@1l01T0O0<000000`0I07`7000000060340C`00000000000340
C`000000<@1?2@0000000`0a04l000000?ooo`1_0?ooo`00<P3oool3000000806@1l00<0000001T0
O00000000P00000201T0O0030000000I07`06@1l00<000000P0I07`00`0000006@1l01T0O0030000
000401T0O00000006@1l01T0O0<000000P0I07`0100000006@1l01T0O00I07`2000000806@1l00@0
000001T0O00I07`06@1l0`00000201T0O0040000000I07`06@1l01T0O0<0000000<06@1l0000000I
07`00P0I07`40000000301T0O00000006@1l00<06@1l00<0000001T0O00000000P00000401T0O003
0000000I07`0000000800000100I07`01P0000006@1l0000000000006@1l000000@06@1l0`000000
1@0a04l000000340C`000000<@1?00/0000000@0<@1?000000000000<@1?0P00000^0?ooo`040000
003oool0oooo00000080oooo0P0000001@3oool000000?ooo`3oool0000000<0oooo00<000000?oo
o`3oool0;P3oool002l0oooo0`0000000`0I07`0000001T0O00201T0O08000000P0I07`00`000000
6@1l01T0O0030000000301T0O00000006@1l00806@1l0`000000100I07`0000001T0O00I07`30000
000301T0O00000006@1l00806@1l00<0000001T0O00000000P00000301T0O0060000000I07`00000
0000000I07`000000`0I07`00`0000006@1l00000002000000<06@1l00H0000001T0O00000000000
01T0O000000301T0O0030000000I07`06@1l00@000000P0I07`00`0000006@1l01T0O00400000080
6@1l00@0000001T0O00I07`06@1l0`00000301T0O0040000000I07`06@1l01T0O080000000<0<@1?
0000000a04l02P0000000`0a04l000000340C`08000002h0oooo00H000000?ooo`000000oooo0000
003oool2000000050?ooo`000000oooo0?ooo`000000=03oool002`0oooo0`0000001P0I07`00000
01T0O00I07`0000001T0O0<000000`0I07`4000000<06@1l00<0000001T0O00000000P00000201T0
O0030000000I07`00000008000000`0I07`00`0000006@1l01T0O003000000806@1l00<0000001T0
O00I07`00`00000201T0O0040000000I07`06@1l01T0O0<000000P0I07`0100000006@1l01T0O00I
07`2000000<06@1l00@0000001T0O00I07`06@1l0`00000201T0O0040000000I07`06@1l01T0O0<0
00000P0I07`01P0000006@1l01T0O00I07`0000001T0O080000000<06@1l0000000I07`00`0I07`0
1@0000006@1l0000000000006@1l00T0000000H0<@1?000000000000<@1?0000000a04l900000003
0340C`000000oooo02`0oooo00H000000?ooo`000000oooo0000003oool2000000050?ooo`000000
oooo0?ooo`000000=03oool002X0oooo0`00000301T0O0030000000I07`00000008000000P0I07`0
0`0000006@1l01T0O002000000806@1l00<0000001T0O00I07`00`00000201T0O0030000000I07`0
6@1l008000000P0I07`0100000006@1l01T0O00I07`30000000301T0O00000006@1l00806@1l0`00
00000`0I07`0000001T0O00201T0O0060000000I07`000000000000I07`000000`0I07`00`000000
6@1l00000002000000@06@1l00<0000001T0O00000000P00000401T0O0030000000I07`000000080
0000100I07`00`0000006@1l01T0O003000000<06@1l00@0000001T0O00I07`06@1l0`00000301T0
O0D0000000D0<@1?0000000a04l000000340C`09000000030340C`000000<@1?0080000000<0<@1?
0000003oool0;03oool01P000000oooo0000003oool000000?ooo`80000000D0oooo0000003oool0
oooo0000000d0?ooo`00:03oool2000000806@1l00@0000001T0O00I07`06@1l0P0000000`0I07`0
000001T0O00201T0O0<0000000@06@1l0000000I07`06@1l0`0000000`0I07`0000001T0O00201T0
O0@000000`0I07`00`0000006@1l00000002000000<06@1l00<0000001T0O00000000P00000301T0
O0030000000I07`06@1l00<000000`0I07`00`0000006@1l01T0O003000000806@1l00@0000001T0
O00I07`06@1l0`00000201T0O0040000000I07`06@1l01T0O0<000000P0I07`0100000006@1l01T0
O00I07`40000000301T0O00000006@1l00<06@1l00H0000001T0O0000000000001T0O000000401T0
O0080000000a04l000000340C`000000<@1?0000000a04l8000000040340C`00000000000340C`L0
0000;03oool2000000<0oooo0`000000103oool0000000000000000e0?ooo`009@3oool300000009
01T0O00000006@1l01T0O00000006@1l0000000I07`0000000806@1l00<0000001T0O00000000P00
000201T0O0030000000I07`00000008000000`0I07`00`0000006@1l01T0O002000000806@1l00<0
000001T0O00I07`00`00000201T0O0040000000I07`06@1l01T0O08000000P0I07`0100000006@1l
01T0O00I07`30000000301T0O00000006@1l00806@1l100000000`0I07`0000001T0O00201T0O006
0000000I07`000000000000I07`000000`0I07`01P0000006@1l0000000000006@1l000000<06@1l
00H0000001T0O0000000000001T0O000000301T0O0030000000I07`06@1l00@000000`0I07`01000
00006@1l01T0O00I07`2000000030340C`000000<@1?00X0000000<0<@1?0000000a04l01`000000
0`0a04l000000000000/0?ooo`8000000`3oool2000003X0oooo000S0?ooo`<000000P0I07`00`00
00006@1l01T0O0030000000401T0O00000006@1l01T0O0<0000000<06@1l0000000I07`00P0I07`2
000000806@1l00@0000001T0O00I07`06@1l0`000000100I07`0000001T0O00I07`30000000301T0
O00000006@1l00806@1l00<0000001T0O00000000P00000301T0O0030000000I07`0000000800000
0`0I07`01P0000006@1l0000000000006@1l000000<06@1l00<0000001T0O00I07`00`00000301T0
O0040000000I07`06@1l01T0O08000000`0I07`0100000006@1l01T0O00I07`2000000<06@1l00@0
000001T0O00I07`06@1l0`00000201T0O0030000000I07`06@1l00806@1l00D0000001T0O0000000
000001T0O009000000030340C`000000<@1?00T0000000@0<@1?000000000000<@1?0`00000[0?oo
o`030000003oool0oooo00<0oooo0P00000i0?ooo`00803oool3000000806@1l00<0000001T0O00I
07`00`000000100I07`0000001T0O00I07`30000000601T0O00000006@1l01T0O00000006@1l0`00
000301T0O0050000000I07`0000001T0O00000000P0I07`00`0000006@1l00000002000000<06@1l
00<0000001T0O00I07`00`00000201T0O0040000000I07`06@1l01T0O08000000P0I07`010000000
6@1l01T0O00I07`2000000<06@1l00@0000001T0O00I07`06@1l0`0000000`0I07`0000001T0O003
01T0O0030000000I07`0000000800000100I07`00`0000006@1l00000002000000@06@1l00<00000
01T0O00000000P00000401T0O0030000000I07`06@1l00@000000`0I07`5000000050340C`000000
<@1?0000000a04l020000000100a04l000000000000a04l6000006`0oooo000N0?ooo`80000000<0
6@1l0000000I07`00P0I07`4000000806@1l00<0000001T0O00000000P00000301T0O0030000000I
07`00000008000000P0I07`00`0000006@1l01T0O0030000000301T0O00000006@1l00806@1l0P00
000201T0O0040000000I07`06@1l01T0O0<0000000<06@1l0000000I07`00P0I07`00`0000006@1l
00000002000000<06@1l00<0000001T0O00000000P00000401T0O0030000000I07`0000000800000
0`0I07`00`0000006@1l01T0O004000000806@1l00@0000001T0O00I07`06@1l0`00000201T0O004
0000000I07`06@1l01T0O0<000000P0I07`00`0000006@1l01T0O00201T0O0<000000P0I07`00`00
00006@1l01T0O00201T0O0060000000a04l000000340C`000000<@1?2P0000000`0a04l000000340
C`07000000030340C`000000000006/0oooo000N0?ooo`040000000I07`06@1l000000806@1l0P00
000201T0O0030000000I07`00000008000000P0I07`0100000006@1l01T0O00I07`20000000301T0
O00000006@1l00806@1l0`0000001P0I07`0000001T0O00I07`0000001T0O0<000000`0I07`00`00
00006@1l00000002000000<06@1l00<0000001T0O00I07`00`00000201T0O0030000000I07`06@1l
00<000000P0I07`0100000006@1l01T0O00I07`3000000806@1l00@0000001T0O00I07`06@1l0`00
000201T0O0060000000I07`06@1l01T0O00000006@1l0P0000000`0I07`0000001T0O00201T0O006
0000000I07`000000000000I07`00000100I07`00`0000006@1l00000002000000@06@1l00<00000
01T0O00I07`00`0000000`0a04l0000000000007000000030340C`000000<@1?00T0000000@0<@1?
000000000000<@1?0`00001Z0?ooo`007@3oool0100000006@1l01T0O00I07`30000000401T0O000
00006@1l01T0O080000000<06@1l0000000I07`00P0I07`01@0000006@1l0000000I07`000000080
6@1l00<0000001T0O00000000P00000201T0O0030000000I07`06@1l00<000000P0I07`00`000000
6@1l01T0O003000000806@1l00@0000001T0O00I07`06@1l0`0000000`0I07`0000001T0O00201T0
O0<0000000<06@1l0000000I07`00P0I07`01P0000006@1l0000000000006@1l000000<06@1l00<0
000001T0O00000000P00000401T0O0030000000I07`06@1l00<000000`0I07`0100000006@1l01T0
O00I07`2000000<06@1l00@0000001T0O00I07`06@1l0`00000201T0O0040000000I07`06@1l01T0
O0@000000P0I07`7000000050340C`000000<@1?0000000a04l020000000100a04l000000000000a
04l5000000030340C`000000oooo06P0oooo000M0?ooo`030000000I07`00000008000000P0I07`0
0`0000006@1l00000002000000806@1l00<0000001T0O00I07`00`000000100I07`0000001T0O00I
07`30000000301T0O00000006@1l00806@1l0`0000000`0I07`0000001T0O00201T0O0<0000000<0
6@1l0000000I07`00P0I07`01@0000006@1l0000000I07`0000000<06@1l00<0000001T0O0000000
0P00000301T0O0030000000I07`06@1l00<000000P0I07`0100000006@1l01T0O00I07`300000080
6@1l00@0000001T0O00I07`06@1l100000000`0I07`0000001T0O00301T0O0030000000I07`00000
00800000100I07`01P0000006@1l0000000000006@1l000000<06@1l00H0000001T0O00000000000
01T0O000000401T0O0<0000000D0<@1?0000000a04l000000340C`0:000000030340C`000000<@1?
00P0000000<0<@1?0000003oool0J03oool001d0oooo0P000000100I07`0000001T0O00I07`30000
000301T0O00000006@1l00806@1l0`000000100I07`0000001T0O00I07`30000000601T0O0000000
6@1l01T0O00000006@1l0`00000301T0O0030000000I07`00000008000000`0I07`00`0000006@1l
01T0O003000000806@1l00@0000001T0O00I07`06@1l0P00000201T0O0040000000I07`06@1l01T0
O0<0000000<06@1l0000000I07`00P0I07`01P0000006@1l0000000000006@1l000000<06@1l00H0
000001T0O0000000000001T0O000000301T0O0030000000I07`06@1l00@000000P0I07`010000000
6@1l01T0O00I07`3000000<06@1l00@0000001T0O00I07`06@1l0P00000301T0O0030000000I07`0
6@1l00806@1l00@000000340C`000000<@1?2@0000000`0a04l000000340C`09000000030340C`00
0000000000@00000J03oool001d0oooo00<0000001T0O00I07`00`0000001P0I07`0000001T0O00I
07`0000001T0O0<000000P0I07`00`0000006@1l00000002000000<06@1l00<0000001T0O0000000
0P00000201T0O0040000000I07`06@1l01T0O08000000P0I07`0100000006@1l01T0O00I07`30000
000301T0O00000006@1l00806@1l00D0000001T0O00000006@1l0000000301T0O0030000000I07`0
0000008000000`0I07`00`0000006@1l01T0O003000000<06@1l00@0000001T0O00I07`06@1l0P00
000301T0O0040000000I07`06@1l01T0O0<000000P0I07`01P0000006@1l01T0O00I07`0000001T0
O080000000<06@1l0000000I07`00`0I07`00`0000006@1l00000002000000@06@1l00<0000001T0
O00I07`00`0000000`0a04l0000000000003000000070340C`00000000000000000a04l000000340
C`08000000030340C`000000000000L00000J03oool001d0oooo1000000301T0O0030000000I07`0
0000008000000P0I07`00`0000006@1l01T0O002000000806@1l00@0000001T0O00I07`06@1l0P00
00000`0I07`0000001T0O00201T0O0030000000I07`00000008000000`0I07`01@0000006@1l0000
000I07`0000000806@1l00<0000001T0O00I07`01000000201T0O0040000000I07`06@1l01T0O080
00000P0I07`0100000006@1l01T0O00I07`30000000301T0O00000006@1l00<06@1l00<0000001T0
O00000000P00000401T0O0030000000I07`0000000800000100I07`00`0000006@1l01T0O0030000
00<06@1l00@0000001T0O00I07`06@1l0`00000201T0O0030000000I07`06@1l00806@1l0`000002
01T0O0<0000000<0<@1?0000000000000P0000000`0a04l0000000000009000000030340C`000000
<@1?00D0000000<0<@1?0000000000000P00001W0?ooo`007@3oool0100000006@1l01T0O0000003
01T0O080000000<06@1l0000000I07`00P0I07`4000000<06@1l00D0000001T0O00000006@1l0000
000201T0O0030000000I07`06@1l00<000000P0I07`0100000006@1l01T0O00I07`20000000301T0
O00000006@1l00806@1l0`00000201T0O0090000000I07`06@1l01T0O00000006@1l0000000I07`0
000000<06@1l00<0000001T0O00000000P00000301T0O0030000000I07`06@1l00@000000P0I07`0
100000006@1l01T0O00I07`3000000806@1l00@0000001T0O00I07`06@1l100000000`0I07`00000
01T0O00301T0O0060000000I07`000000000000I07`00000100I07`00`0000006@1l000000020000
00@06@1l00T000000340C`00000000000340C`000000<@1?0000000a04l00P0000001`0a04l00000
000000000000<@1?0000000a04l01`000000100a04l000000000000a04l4000006L0oooo000M0?oo
o`080000000I07`06@1l0000000I07`0000001T0O000000201T0O0030000000I07`06@1l00800000
0P0I07`00`0000006@1l01T0O0030000000301T0O00000006@1l00806@1l0`0000000`0I07`00000
01T0O00201T0O0050000000I07`0000001T0O00000000P0I07`00`0000006@1l00000002000000<0
6@1l00<0000001T0O00I07`01000000201T0O0040000000I07`06@1l01T0O08000000P0I07`01000
00006@1l01T0O00I07`3000000806@1l00H0000001T0O00I07`06@1l0000000I07`20000000301T0
O00000006@1l00806@1l00H0000001T0O0000000000001T0O000000301T0O0040000000I07`06@1l
01T0O0<000000`0I07`0100000006@1l01T0O00I07`3000000806@1l00<0000001T0O00I07`00`0I
07`010000000<@1?0000000a04l7000000040340C`00000000000340C`H0000000@0<@1?00000000
0000<@1?1@0000000`0a04l000000000001V0?ooo`00703oool00`0000006@1l01T0O00300000003
01T0O00000006@1l00806@1l0`000000100I07`0000001T0O00I07`30000000601T0O00000006@1l
01T0O00000006@1l0`00000301T0O0030000000I07`06@1l00<0000000@06@1l0000000I07`06@1l
0`00000201T0O0040000000I07`06@1l01T0O0<000000P0I07`02@0000006@1l01T0O00I07`00000
01T0O00000006@1l0000000301T0O0030000000I07`0000000800000100I07`00`0000006@1l01T0
O003000000806@1l00@0000001T0O00I07`06@1l0`00000301T0O0060000000I07`06@1l01T0O000
00006@1l0P0000000`0I07`0000001T0O00301T0O0060000000I07`000000000000I07`00000100I
07`00`0000006@1l01T0O003000000030340C`000000000000D0000000<0<@1?0000000a04l02@00
00000`0a04l0000000000006000000040340C`0000000000000002@0oooo0`0000030?ooo`030000
003oool0oooo00800000103oool010000000oooo0?ooo`3oool200000080oooo0`0000030?ooo`<0
000000<0oooo0000000000000P00000L0?ooo`00703oool30000000601T0O00000006@1l01T0O000
00006@1l0`00000201T0O0030000000I07`00000008000000P0I07`00`0000006@1l01T0O0030000
00806@1l00@0000001T0O00I07`06@1l0`000000100I07`0000001T0O00I07`30000000301T0O000
00006@1l00806@1l00<0000001T0O00000000P00000301T0O0030000000I07`06@1l00@000000P0I
07`0100000006@1l01T0O00I07`2000000806@1l00@0000001T0O00I07`06@1l100000000`0I07`0
000001T0O00201T0O0060000000I07`000000000000I07`00000100I07`00`0000006@1l01T0O003
000000<06@1l00@0000001T0O00I07`06@1l0`00000301T0O0040000000I07`06@1l01T0O0@00000
0P0I07`5000000050340C`000000<@1?0000000a04l01P0000000`0a04l000000340C`0700000003
0340C`000000000000@0000000<0<@1?0000003oool08P3oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0000
00020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0703oool001`0oooo00@00000
01T0O00I07`000000P0I07`30000000401T0O00000006@1l01T0O0<000000P0I07`00`0000006@1l
01T0O0030000000301T0O00000006@1l00806@1l00D0000001T0O00000006@1l0000000201T0O003
0000000I07`00000008000000`0I07`00`0000006@1l01T0O003000000806@1l00@0000001T0O00I
07`06@1l0`00000201T0O0090000000I07`06@1l01T0O00000006@1l0000000I07`0000000<06@1l
00H0000001T0O0000000000001T0O000000301T0O0030000000I07`06@1l00<000000`0I07`01000
00006@1l01T0O00I07`40000000301T0O00000006@1l00<06@1l00H0000001T0O0000000000001T0
O000000401T0O0060000000I07`000000000000I07`00000100I07`3000000050340C`000000<@1?
0000000a04l0200000000`0a04l0000000000004000000040340C`00000000000340C`H0000000<0
<@1?0000003oool08P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000<0
oooo00@000000?ooo`3oool0oooo0`0000001P3oool000000?ooo`3oool000000?ooo`@000000`3o
ool00`000000oooo0?ooo`0K0?ooo`00703oool00`0000006@1l000000030000000401T0O0000000
6@1l01T0O0<0000000<06@1l0000000I07`00P0I07`4000000<06@1l00<0000001T0O00I07`00`00
00000`0I07`0000001T0O00201T0O08000000P0I07`0100000006@1l01T0O00I07`30000000301T0
O00000006@1l00806@1l00<0000001T0O00000000P00000301T0O0030000000I07`06@1l00@00000
0P0I07`0100000006@1l01T0O00I07`2000000<06@1l00@0000001T0O00I07`06@1l0`0000000`0I
07`0000001T0O00301T0O0060000000I07`000000000000I07`000000`0I07`00`0000006@1l01T0
O004000000<06@1l00@0000001T0O00I07`06@1l0`00000301T0O0030000000I07`06@1l00806@1l
00@000000340C`000000<@1?1`0000000`0a04l000000340C`09000000030340C`000000000000<0
000000<0<@1?0000000000001000000R0?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool000000080oooo00<0
00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001d0oooo000L0?ooo`80000000<0
6@1l0000000I07`00P0I07`4000000<06@1l00<0000001T0O00I07`00P00000201T0O0040000000I
07`06@1l01T0O0<0000000H06@1l0000000I07`06@1l0000000I07`3000000<06@1l00<0000001T0
O00000000P00000301T0O0030000000I07`06@1l00<000000P0I07`0100000006@1l01T0O00I07`3
000000806@1l00H0000001T0O00I07`06@1l0000000I07`3000000@06@1l00<0000001T0O0000000
0P00000301T0O0040000000I07`06@1l01T0O0<000000`0I07`0100000006@1l01T0O00I07`30000
00806@1l00<0000001T0O00I07`00P0I07`01P0000006@1l0000000000006@1l000000@06@1l00<0
000001T0O00I07`00`0000000`0a04l0000000000005000000030340C`000000<@1?00H0000000<0
<@1?0000000a04l01@000000100a04l000000000000a04l600000280oooo00@000000?ooo`3oool0
0000103oool3000000@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000020?oo
o`030000003oool0oooo008000001@3oool00`000000oooo0?ooo`0J0?ooo`00703oool010000000
6@1l01T0O000000201T0O08000000P0I07`0100000006@1l01T0O00I07`30000000601T0O0000000
6@1l01T0O00000006@1l0`00000201T0O0030000000I07`06@1l00<000000P0I07`0100000006@1l
01T0O00I07`2000000806@1l00@0000001T0O00I07`06@1l0`0000000`0I07`0000001T0O00201T0
O0030000000I07`00000008000000`0I07`00`0000006@1l01T0O004000000806@1l00@0000001T0
O00I07`06@1l0`00000201T0O0060000000I07`06@1l01T0O00000006@1l0P0000000`0I07`00000
01T0O00301T0O0030000000I07`0000000800000100I07`0100000006@1l01T0O00I07`3000000<0
6@1l00@0000001T0O00I07`06@1l1000000201T0O0D0000000D0<@1?0000000a04l000000340C`08
000000030340C`000000000000D0000000<0<@1?0000000000000`0000000`0a04l0000000000002
00000240oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000020?ooo`800000
0P3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`00000L0?ooo`006`3oool0100000006@1l01T0O00I07`30000000601T0O0000000
6@1l01T0O00000006@1l0`00000201T0O0030000000I07`06@1l00<0000000<06@1l0000000I07`0
0P0I07`30000000301T0O00000006@1l00806@1l00<0000001T0O00000000P00000301T0O0030000
000I07`00000008000000`0I07`0100000006@1l01T0O00I07`2000000806@1l00@0000001T0O00I
07`06@1l0`00000201T0O0060000000I07`06@1l01T0O00000006@1l0P0000000`0I07`0000001T0
O00201T0O0030000000I07`06@1l00<000000`0I07`0100000006@1l01T0O00I07`3000000806@1l
00<0000001T0O00I07`00P0I07`01P0000006@1l0000000000006@1l000000@06@1l00H0000001T0
O0000000000001T0O000000401T0O0<0000000<0<@1?0000000a04l01`0000000`0a04l000000340
C`07000000030340C`000000000000H0000000<0<@1?0000000000000P00000R0?ooo`8000001P3o
ool2000000@0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`800000203oool2000001d0oooo
000K0?ooo`030000000I07`00000008000000P0I07`00`0000006@1l01T0O0030000000301T0O000
00006@1l00806@1l0`0000001P0I07`0000001T0O00I07`0000001T0O0<000000`0I07`00`000000
6@1l01T0O003000000806@1l00@0000001T0O00I07`06@1l0P00000201T0O0060000000I07`06@1l
01T0O00000006@1l0`00000301T0O0030000000I07`0000000800000100I07`00`0000006@1l01T0
O003000000806@1l00@0000001T0O00I07`06@1l100000000`0I07`0000001T0O00301T0O0060000
000I07`000000000000I07`000000`0I07`00`0000006@1l01T0O004000000<06@1l00@0000001T0
O00I07`06@1l0`00000301T0O0030000000I07`06@1l00806@1l00@000000340C`000000<@1?1`00
00000`0a04l000000340C`06000000030340C`000000000000D0000000<0<@1?0000000000001000
00000`0a04l000000000001Q0?ooo`006`3oool20000000301T0O00000006@1l00806@1l0`000000
1P0I07`0000001T0O00I07`0000001T0O0<000000`0I07`00`0000006@1l00000002000000806@1l
00@0000001T0O00I07`06@1l0`0000000`0I07`0000001T0O00201T0O0050000000I07`0000001T0
O00000000`0I07`00`0000006@1l01T0O003000000806@1l00@0000001T0O00I07`06@1l0P000002
01T0O0040000000I07`06@1l01T0O0@0000000<06@1l0000000I07`00P0I07`01P0000006@1l0000
000000006@1l000000<06@1l00@0000001T0O00I07`06@1l0`00000301T0O0040000000I07`06@1l
01T0O0<000000P0I07`00`0000006@1l01T0O00201T0O0060000000I07`000000000000I07`00000
100I07`00`0000006@1l01T0O003000000030340C`000000000000<0000000D0<@1?0000000a04l0
00000340C`05000000040340C`00000000000340C`L0000000<0<@1?00000000000010000000100a
04l0000000000000001P0?ooo`006`3oool01@0000006@1l01T0O00000006@1l00<000000`0I07`0
0`0000006@1l00000002000000806@1l00@0000001T0O00I07`06@1l0P0000000`0I07`0000001T0
O00201T0O0030000000I07`00000008000000`0I07`00`0000006@1l01T0O003000000806@1l00@0
000001T0O00I07`06@1l0`0000000`0I07`0000001T0O00201T0O0030000000I07`0000000800000
0`0I07`01P0000006@1l0000000000006@1l000000<06@1l00@0000001T0O00I07`06@1l0P000003
01T0O0060000000I07`06@1l01T0O00000006@1l0P0000000`0I07`0000001T0O00301T0O0030000
000I07`0000000800000100I07`0100000006@1l01T0O00I07`3000000<06@1l00@0000001T0O00I
07`06@1l1000000201T0O0D0000000<0<@1?0000000a04l01`0000000`0a04l000000340C`070000
00030340C`000000000000<0000000<0<@1?000000000000100000000`0a04l000000?ooo`1N0?oo
o`006`3oool00`0000006@1l00000002000000806@1l00@0000001T0O00I07`06@1l0P0000000`0I
07`0000001T0O00201T0O0050000000I07`0000001T0O00000000P0I07`00`0000006@1l01T0O003
000000806@1l00@0000001T0O00I07`06@1l0`0000000`0I07`0000001T0O00201T0O0050000000I
07`0000001T0O00000000`0I07`00`0000006@1l01T0O003000000806@1l00@0000001T0O00I07`0
6@1l0P00000301T0O0060000000I07`06@1l01T0O00000006@1l0`00000401T0O0030000000I07`0
6@1l00<000000`0I07`0100000006@1l01T0O00I07`3000000806@1l00<0000001T0O00I07`00P0I
07`01P0000006@1l0000000000006@1l000000@06@1l00H0000001T0O0000000000001T0O0000004
01T0O0<0000000<0<@1?0000000a04l01`0000000`0a04l000000340C`06000000030340C`000000
000000H0000000<0<@1?000000000000100000000`0a04l000000?ooo`1N0?ooo`006`3oool20000
000301T0O00000006@1l00806@1l00D0000001T0O00000006@1l0000000201T0O0030000000I07`0
6@1l00<0000000<06@1l0000000I07`00P0I07`30000000301T0O00000006@1l00806@1l00D00000
01T0O00000006@1l0000000201T0O0030000000I07`06@1l00@0000000<06@1l0000000I07`00P0I
07`40000000301T0O00000006@1l00806@1l00<0000001T0O00000000P00000401T0O0030000000I
07`06@1l00<000000P0I07`0100000006@1l01T0O00I07`40000000301T0O00000006@1l00<06@1l
00H0000001T0O0000000000001T0O000000301T0O0030000000I07`06@1l00@000000`0I07`01000
00006@1l01T0O00I07`3000000<06@1l00<0000001T0O00I07`00P0I07`010000000<@1?0000000a
04l3000000030340C`000000000000<0000000<0<@1?0000000000000`000000100a04l000000000
000a04l4000000030340C`000000000000/00000GP3oool001/0oooo00@0000001T0O00I07`00000
0P0I07`30000000301T0O00000006@1l00806@1l0`0000001P0I07`0000001T0O00I07`0000001T0
O0<000000`0I07`00`0000006@1l01T0O0030000000301T0O00000006@1l00806@1l0`00000201T0
O0050000000I07`06@1l0000000I07`00P0000000`0I07`0000001T0O00201T0O0030000000I07`0
6@1l00<000000P0I07`0100000006@1l01T0O00I07`40000000301T0O00000006@1l00806@1l00H0
000001T0O0000000000001T0O000000301T0O0030000000I07`06@1l00@000000`0I07`010000000
6@1l01T0O00I07`3000000806@1l00<0000001T0O00I07`00P0I07`01P0000006@1l000000000000
6@1l000000@06@1l00@0000001T0O00I07`06@1l0P0000001@0a04l00000000000000000<@1?0080
000000<0<@1?0000000a04l01P0000000`0a04l000000340C`07000000030340C`000000000000<0
000000<0<@1?0000000000001@00001N0?ooo`006P3oool0100000006@1l01T0O00I07`300000006
01T0O00000006@1l01T0O00000006@1l0`00000201T0O0030000000I07`06@1l00<000000P0I07`0
100000006@1l01T0O00I07`30000000601T0O00000006@1l01T0O00000006@1l0`00000301T0O003
0000000I07`06@1l00<000000P0I07`0100000006@1l01T0O00I07`40000000301T0O00000006@1l
00806@1l00H0000001T0O0000000000001T0O000000301T0O0040000000I07`06@1l01T0O0800000
0`0I07`0100000006@1l01T0O00I07`3000000806@1l00<0000001T0O00I07`00P0I07`00`000000
6@1l00000002000000@06@1l00@0000001T0O00I07`06@1l0`00000301T0O0030000000I07`06@1l
00806@1l00D0000001T0O0000000000001T0O003000000060340C`00000000000340C`000000<@1?
1P0000000`0a04l000000340C`06000000030340C`000000000000<0000000@0<@1?000000000000
<@1?0`0000000`0a04l0000000000002000005d0oooo000J0?ooo`030000000I07`0000000800000
0P0I07`00`0000006@1l01T0O0030000000301T0O00000006@1l00806@1l0`0000000`0I07`00000
01T0O00201T0O0050000000I07`0000001T0O00000000P0I07`00`0000006@1l01T0O00300000080
6@1l00@0000001T0O00I07`06@1l0`0000000`0I07`0000001T0O00201T0O0060000000I07`00000
0000000I07`000000`0I07`0100000006@1l01T0O00I07`2000000806@1l00<0000001T0O00I07`0
0P0I07`00`0000006@1l00000002000000@06@1l00<0000001T0O00000000P00000401T0O0040000
000I07`06@1l01T0O0<000000P0I07`00`0000006@1l01T0O00201T0O0060000000I07`000000000
000I07`00000100I07`00`0000006@1l01T0O004000000<06@1l00L000000340C`00000000000340
C`000000<@1?00P0000000<0<@1?0000000000000`0000000`0a04l0000000000006000000030340
C`000000000000@0000000<0<@1?0000000000000`00001L0?ooo`006P3oool20000000301T0O000
00006@1l00806@1l0`0000001P0I07`0000001T0O00I07`0000001T0O0<000000`0I07`00`000000
6@1l01T0O0030000000301T0O00000006@1l00806@1l0`0000000`0I07`0000001T0O00201T0O003
0000000I07`00000008000000`0I07`0100000006@1l01T0O00I07`2000000806@1l00<0000001T0
O00I07`00P0I07`00`0000006@1l00000002000000<06@1l00<0000001T0O00I07`01000000201T0
O0040000000I07`06@1l01T0O0<000000P0I07`00`0000006@1l01T0O00201T0O0060000000I07`0
00000000000I07`00000100I07`00`0000006@1l01T0O003000000<06@1l00@0000001T0O00I07`0
6@1l1000000201T0O0030000000I07`06@1l00806@1l00D000000340C`0a04l000000340C`050000
00030340C`000000<@1?00H0000000<0<@1?0000000a04l01@0000000`0a04l000000000000:0000
00030340C`000000000005`0oooo000J0?ooo`050000000I07`06@1l0000000I07`00`00000301T0
O0030000000I07`00000008000000P0I07`0100000006@1l01T0O00I07`30000000601T0O0000000
6@1l01T0O00000006@1l0`00000301T0O0030000000I07`06@1l00<000000P0I07`01P0000006@1l
01T0O00I07`0000001T0O0<000000`0I07`00`0000006@1l01T0O004000000806@1l00@0000001T0
O00I07`06@1l0`00000201T0O0060000000I07`06@1l01T0O00000006@1l0P0000000`0I07`00000
01T0O00201T0O0030000000I07`06@1l00@000000`0I07`0100000006@1l01T0O00I07`400000003
01T0O00000006@1l00<06@1l00H0000001T0O0000000000001T0O000000401T0O0040000000I07`0
6@1l01T0O08000000P0a04l5000000050340C`000000<@1?0000000a04l00P0000001@0a04l00000
000000000000<@1?00@0000000@0<@1?000000000000<@1?100000000`0a04l00000000000050000
00040340C`0000000000000001X0oooo00@000000?ooo`3oool000000P3oool5000000050?ooo`00
0000oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0/0?ooo`006P3oool00`0000006@1l0000
0002000000806@1l00@0000001T0O00I07`06@1l0P0000000`0I07`0000001T0O00201T0O0050000
000I07`0000001T0O00000000P0I07`00`0000006@1l01T0O003000000806@1l00@0000001T0O00I
07`06@1l0`0000000`0I07`0000001T0O00201T0O0030000000I07`06@1l00<000000P0I07`01000
00006@1l01T0O00I07`3000000806@1l00H0000001T0O00I07`06@1l0000000I07`3000000@06@1l
00<0000001T0O00I07`00`00000301T0O0040000000I07`06@1l01T0O0<000000P0I07`00`000000
6@1l01T0O00201T0O0060000000I07`000000000000I07`000000`0I07`0100000006@1l01T0O00I
07`3000000<06@1l00<0000001T0O00I07`00P0I07`01@0000006@1l0000000000006@1l00800000
00L0<@1?00000000000000000340C`000000<@1?00L0000000<0<@1?0000000000001@0000000`0a
04l0000000000002000000040340C`00000000000340C`/000006P3oool01P000000oooo0000003o
ool000000?ooo`8000000P3oool00`000000oooo0?ooo`0200000380oooo000J0?ooo`80000000<0
6@1l0000000I07`00P0I07`01@0000006@1l0000000I07`0000000806@1l00<0000001T0O00I07`0
0`0000000`0I07`0000001T0O00201T0O0<0000000<06@1l0000000I07`00P0I07`00`0000006@1l
00000002000000<06@1l00@0000001T0O00I07`06@1l0`0000000`0I07`0000001T0O00201T0O003
0000000I07`0000000800000100I07`00`0000006@1l01T0O003000000806@1l00@0000001T0O00I
07`06@1l100000000`0I07`0000001T0O00301T0O0030000000I07`0000000800000100I07`01000
00006@1l01T0O00I07`3000000<06@1l00H0000001T0O00I07`06@1l0000000I07`20000000301T0
O00000006@1l00<06@1l00<0000001T0O00I07`01000000301T0O0070000000a04l000000000000a
04l000000340C`07000000030340C`000000<@1?00@0000000<0<@1?0000000000001@0000000`0a
04l0000000000003000000030340C`000000000000L000006@3oool020000000oooo0000003oool0
00000?ooo`000000oooo0`0000020?ooo`800000<P3oool001X0oooo00@0000001T0O00I07`00000
0P0I07`30000000301T0O00000006@1l00806@1l0`0000001P0I07`0000001T0O00I07`0000001T0
O0<000000`0I07`0100000006@1l01T0O00I07`2000000806@1l00H0000001T0O00I07`06@1l0000
000I07`3000000<06@1l00<0000001T0O00I07`00`00000201T0O0040000000I07`06@1l01T0O0@0
000000<06@1l0000000I07`00P0I07`01P0000006@1l0000000000006@1l000000<06@1l00@00000
01T0O00I07`06@1l0`00000201T0O0030000000I07`06@1l00806@1l00H0000001T0O00000000000
01T0O000000401T0O0030000000I07`06@1l00<000000`0I07`0100000006@1l01T0O00I07`40000
00806@1l00<0000001T0O00I07`00`0I07`010000000<@1?0000000a04l5000000050340C`000000
<@1?0000000a04l01P0000000`0a04l0000000000002000000030340C`000000000000H0000000D0
<@1?00000000000000000340C`06000001P0oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool00P00000b0?ooo`006@3oool0100000006@1l01T0O00I07`30000
000601T0O00000006@1l01T0O00000006@1l0`00000201T0O0030000000I07`06@1l00<000000P0I
07`01P0000006@1l01T0O00I07`0000001T0O0<000000`0I07`00`0000006@1l01T0O00300000080
6@1l00@0000001T0O00I07`06@1l0`0000000`0I07`0000001T0O00201T0O0060000000I07`00000
0000000I07`000000`0I07`0100000006@1l01T0O00I07`2000000<06@1l00H0000001T0O00I07`0
6@1l0000000I07`20000000301T0O00000006@1l00806@1l00<0000001T0O00I07`01000000301T0
O0040000000I07`06@1l01T0O0@0000000<06@1l0000000I07`00`0I07`01P0000006@1l00000000
00006@1l000000@06@1l00<0000001T0O00I07`00P0I07`2000000030340C`000000000000<00000
00<0<@1?0000000a04l01`0000000`0a04l0000000000005000000030340C`000000000000800000
00<0<@1?0000000000001@0000001@0a04l00000000000000000<@1?00800000603oool2000000<0
oooo1P0000001@3oool000000?ooo`3oool000000340oooo000I0?ooo`030000000I07`000000080
00000P0I07`00`0000006@1l01T0O0030000000301T0O00000006@1l00806@1l0`0000000`0I07`0
000001T0O00201T0O0030000000I07`06@1l00<000000P0I07`0100000006@1l01T0O00I07`30000
000301T0O00000006@1l00806@1l00<0000001T0O00000000P00000301T0O0040000000I07`06@1l
01T0O08000000P0I07`00`0000006@1l01T0O00201T0O0030000000I07`0000000800000100I07`0
0`0000006@1l01T0O003000000<06@1l00@0000001T0O00I07`06@1l0`00000201T0O0030000000I
07`06@1l00806@1l00H0000001T0O0000000000001T0O000000301T0O0030000000I07`06@1l0080
6@1l0P00000301T0O0030000000I07`06@1l00<06@1l00D0000001T0O0000000000001T0O0050000
00030340C`000000<@1?00L0000000<0<@1?0000000a04l0100000000`0a04l00000000000050000
00030340C`000000000000d000005`3oool2000000<0oooo0P00000j0?ooo`006@3oool200000003
01T0O00000006@1l00806@1l0`0000001P0I07`0000001T0O00I07`0000001T0O0<000000`0I07`0
100000006@1l01T0O00I07`30000000301T0O00000006@1l00806@1l00<0000001T0O00000000P00
000301T0O0030000000I07`06@1l00<000000P0I07`01P0000006@1l01T0O00I07`0000001T0O0<0
00000`0I07`00`0000006@1l01T0O004000000806@1l00@0000001T0O00I07`06@1l100000000`0I
07`0000001T0O00301T0O0030000000I07`0000000800000100I07`0100000006@1l01T0O00I07`3
000000<06@1l00<0000001T0O00I07`00P0I07`00`0000006@1l00000002000000D06@1l00@00000
01T0O00I07`06@1l0`00000301T0O0<0000000<0<@1?0000000a04l01@0000001@0a04l000000340
C`000000<@1?00H0000000<0<@1?0000000000000P0000000`0a04l0000000000003000000030340
C`000000000000/000005P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03P0oooo
000I0?ooo`050000000I07`06@1l0000000I07`00`00000301T0O0030000000I07`0000000800000
0P0I07`02@0000006@1l01T0O00I07`0000001T0O00000006@1l0000000301T0O0030000000I07`0
6@1l00<0000000<06@1l0000000I07`00P0I07`40000000301T0O00000006@1l00806@1l00<00000
01T0O00I07`00`00000201T0O0040000000I07`06@1l01T0O0<000000P0I07`01P0000006@1l01T0
O00I07`0000001T0O080000000<06@1l0000000I07`00P0I07`0100000006@1l01T0O00I07`30000
00806@1l00<0000001T0O00I07`00P0I07`01P0000006@1l0000000000006@1l000000@06@1l00@0
000001T0O00I07`06@1l0`00000201T0O0030000000I07`06@1l00<06@1l00H0000001T0O0000000
000001T0O000000401T0O0060000000a04l000000340C`000000<@1?0`0000000`0a04l000000340
C`07000000030340C`000000000000D0000000<0<@1?0000000000000`0000000`0a04l000000000
000;000005L0oooo000I0?ooo`030000000I07`00000008000000P0I07`0100000006@1l01T0O00I
07`20000000301T0O00000006@1l00806@1l00<0000001T0O00I07`00`0000000`0I07`0000001T0
O00201T0O0@0000000H06@1l0000000I07`06@1l0000000I07`20000000501T0O00000006@1l01T0
O00000000`0I07`40000000301T0O00000006@1l00806@1l00<0000001T0O00000000P00000401T0
O0040000000I07`06@1l01T0O08000000P0I07`00`0000006@1l01T0O00201T0O0060000000I07`0
00000000000I07`000000`0I07`0100000006@1l01T0O00I07`3000000<06@1l00<0000001T0O00I
07`00P0I07`01P0000006@1l0000000000006@1l000000@06@1l00<0000001T0O00I07`010000003
01T0O0040000000I07`06@1l01T0O080000000<0<@1?0000000a04l00`0000000`0a04l000000340
C`05000000050340C`000000<@1?0000000a04l0100000000`0a04l0000000000003000000030340
C`000000000000<0000000<0<@1?0000000000002@00001F0?ooo`006@3oool20000000301T0O000
00006@1l00806@1l00D0000001T0O00000006@1l0000000201T0O0040000000I07`06@1l01T0O0<0
000000H06@1l0000000I07`06@1l0000000I07`20000000501T0O00000006@1l01T0O00000000`0I
07`2000000806@1l00H0000001T0O00I07`06@1l0000000I07`20000000301T0O00000006@1l0080
6@1l00<0000001T0O00I07`00`00000201T0O0030000000I07`06@1l00806@1l00<0000001T0O000
00000P00000301T0O0030000000I07`06@1l00@000000`0I07`01P0000006@1l01T0O00I07`00000
01T0O080000000<06@1l0000000I07`00`0I07`00`0000006@1l01T0O004000000<06@1l00@00000
01T0O00I07`06@1l1000000201T0O0030000000I07`06@1l00806@1l00L0000001T0O00000000000
01T0O0000000<@1?00D0000000<0<@1?0000000000000P000000100a04l000000000000a04l50000
00030340C`00000000000100000000D0<@1?00000000000000000340C`03000005H0oooo000I0?oo
o`040000000I07`06@1l000000806@1l0`0000000`0I07`0000001T0O00201T0O0030000000I07`0
0000008000000P0I07`00`0000006@1l01T0O003000000806@1l00H0000001T0O00I07`06@1l0000
000I07`3000000<06@1l00<0000001T0O00I07`00`00000201T0O0040000000I07`06@1l01T0O0@0
000000<06@1l0000000I07`00P0I07`00`0000006@1l01T0O004000000806@1l00@0000001T0O00I
07`06@1l0`00000201T0O0030000000I07`06@1l00806@1l00<0000001T0O00I07`00`00000301T0
O0040000000I07`06@1l01T0O0@000000P0I07`00`0000006@1l01T0O00201T0O0060000000I07`0
00000000000I07`00000100I07`0100000006@1l01T0O00I07`3000000<06@1l1@0000000`0a04l0
00000340C`02000000030340C`000000000000H0000000<0<@1?0000000a04l0100000000`0a04l0
000000000003000000030340C`000000000000T0000000<0<@1?0000000000000P00001E0?ooo`00
603oool0100000006@1l01T0O00I07`30000000501T0O00000006@1l01T0O00000000P0I07`30000
00806@1l00<0000001T0O00I07`00`0000000`0I07`0000001T0O00201T0O0030000000I07`06@1l
00<000000P0I07`0100000006@1l01T0O00I07`30000000301T0O00000006@1l00806@1l00H00000
01T0O0000000000001T0O000000301T0O0040000000I07`06@1l01T0O0<000000P0I07`01P000000
6@1l01T0O00I07`0000001T0O0<00000100I07`0100000006@1l01T0O00I07`40000000301T0O000
00006@1l00<06@1l00H0000001T0O0000000000001T0O000000401T0O0040000000I07`06@1l01T0
O0<000000`0I07`00`0000006@1l01T0O00201T0O0060000000I07`000000000000I07`00000100I
07`3000000030340C`000000<@1?0080000000D0<@1?00000000000000000340C`04000000030340
C`000000<@1?00@0000000<0<@1?0000000a04l01@0000000`0a04l000000000000>000005D0oooo
000H0?ooo`030000000I07`00000008000000P0I07`00`0000006@1l01T0O0040000000301T0O000
00006@1l00806@1l1000000301T0O0040000000I07`06@1l01T0O0<0000000<06@1l0000000I07`0
0P0I07`00`0000006@1l00000002000000<06@1l00@0000001T0O00I07`06@1l0P00000201T0O003
0000000I07`06@1l00806@1l00<0000001T0O00000000P00000301T0O0040000000I07`06@1l01T0
O0<000000P0I07`00`0000006@1l01T0O00201T0O0060000000I07`000000000000I07`000000`0I
07`0100000006@1l01T0O00I07`3000000<06@1l00<0000001T0O00I07`00P0I07`01P0000006@1l
0000000000006@1l000000@06@1l00@0000001T0O00I07`06@1l0`00000301T0O0030000000I07`0
6@1l00806@1l00@000000340C`000000<@1?0`0000001P0a04l000000000000a04l000000340C`@0
000000<0<@1?000000000000100000000`0a04l0000000000002000000030340C`000000000000<0
000000<0<@1?0000000000003000001D0?ooo`00603oool20000000301T0O00000006@1l00806@1l
0`0000000`0I07`0000001T0O00201T0O0030000000I07`06@1l008000000P0I07`01P0000006@1l
01T0O00I07`0000001T0O0<000000`0I07`00`0000006@1l01T0O003000000806@1l00H0000001T0
O00I07`06@1l0000000I07`3000000<06@1l00<0000001T0O00I07`01000000201T0O0060000000I
07`06@1l01T0O00000006@1l0P0000000`0I07`0000001T0O00201T0O0030000000I07`06@1l00@0
00000`0I07`01P0000006@1l01T0O00I07`0000001T0O080000000<06@1l0000000I07`00`0I07`0
100000006@1l01T0O00I07`3000000<06@1l00<0000001T0O00I07`00P0I07`01P0000006@1l0000
000000006@1l000000@06@1l00@0000001T0O00I07`06@1l0P0000001@0a04l00000000000000000
<@1?0080000000<0<@1?0000000a04l00`0000000`0a04l0000000000004000000030340C`000000
000000D0000000<0<@1?0000000000000`0000000`0a04l000000000000:000000030340C`000000
oooo05<0oooo000H0?ooo`050000000I07`06@1l0000000I07`00`00000301T0O0040000000I07`0
6@1l01T0O0<0000000D06@1l0000000I07`06@1l0000000201T0O0<000000P0I07`0100000006@1l
01T0O00I07`30000000301T0O00000006@1l00806@1l00<0000001T0O00I07`00`00000201T0O004
0000000I07`06@1l01T0O0<000000P0I07`01@0000006@1l01T0O00I07`0000000806@1l0`000003
01T0O0040000000I07`06@1l01T0O0<000000P0I07`00`0000006@1l01T0O00201T0O0030000000I
07`06@1l00<000000`0I07`00`0000006@1l01T0O00201T0O0060000000I07`000000000000I07`0
0000100I07`00`0000006@1l01T0O004000000<06@1l00<0000001T0O00I07`00P0I07`01@000000
6@1l0000000000006@1l00<0000000H0<@1?000000000000<@1?0000000a04l5000000040340C`00
000000000340C`<0000000<0<@1?0000000000000P0000000`0a04l0000000000009000000050340
C`00000000000000000a04l01@0000000`0a04l000000?ooo`0@0?ooo`H0<`3o?@3oool001P0oooo
00<0000001T0O00000000P00000201T0O0090000000I07`06@1l01T0O00000006@1l0000000I07`0
000000806@1l00@0000001T0O00I07`06@1l0`0000000`0I07`0000001T0O00201T0O0030000000I
07`00000008000000`0I07`0100000006@1l01T0O00I07`30000000301T0O00000006@1l00806@1l
00<0000001T0O00000000P00000401T0O0040000000I07`06@1l01T0O0<0000000<06@1l0000000I
07`00`0I07`00`0000006@1l00000002000000@06@1l00@0000001T0O00I07`06@1l100000000`0I
07`0000001T0O00301T0O0030000000I07`06@1l00@000000`0I07`0100000006@1l01T0O00I07`4
000000806@1l00<0000001T0O00I07`00P0I07`00`0000006@1l01T0O004000000<06@1l00L00000
0340C`00000000000340C`000000<@1?00D0000000<0<@1?0000000a04l00`0000000`0a04l00000
00000005000000030340C`00000000000080000000<0<@1?000000000000200000000`0a04l00000
0000000500000140oooo1P0c0?lm0?ooo`00603oool20000000301T0O00000006@1l00806@1l00<0
000001T0O00I07`00`0000000`0I07`0000001T0O00201T0O0030000000I07`00000008000000`0I
07`00`0000006@1l01T0O0030000000301T0O00000006@1l00<06@1l00<0000001T0O00000000P00
000301T0O0030000000I07`06@1l00<000000P0I07`00`0000006@1l01T0O00201T0O0030000000I
07`00000008000000`0I07`0100000006@1l01T0O00I07`3000000806@1l00<0000001T0O00I07`0
0P0I07`01P0000006@1l0000000000006@1l000000<06@1l00@0000001T0O00I07`06@1l10000002
01T0O0030000000I07`06@1l00806@1l00H0000001T0O0000000000001T0O000000401T0O0040000
000I07`06@1l01T0O0@000000P0I07`00`0000006@1l01T0O00201T0O0050000000a04l0<@1?0000
000a04l01@0000000`0a04l000000340C`03000000030340C`000000<@1?00@0000000<0<@1?0000
000000001@000000100a04l000000000000a04l?00000140oooo1P0c0?lm0?ooo`00603oool01000
00006@1l01T0O000000301T0O0<0000000D06@1l0000000I07`06@1l0000000201T0O0<000000P0I
07`0100000006@1l01T0O00I07`30000000501T0O00000006@1l01T0O00000000P0I07`400000080
6@1l00@0000001T0O00I07`06@1l0`0000000`0I07`0000001T0O00201T0O0030000000I07`06@1l
00@000000P0I07`01P0000006@1l01T0O00I07`0000001T0O080000000<06@1l0000000I07`00P0I
07`0100000006@1l01T0O00I07`3000000806@1l00<0000001T0O00I07`00P0I07`01P0000006@1l
0000000000006@1l000000@06@1l00@0000001T0O00I07`06@1l0`00000301T0O0030000000I07`0
6@1l00806@1l00H0000001T0O0000000000001T0O000000401T0O0040000000I07`06@1l01T0O080
00000P0a04l5000000030340C`000000<@1?00D0000000<0<@1?000000000000100000000`0a04l0
000000000002000000030340C`000000000000<0000000<0<@1?0000000000003@00000A0?ooo`H0
<`3o?@3oool001L0oooo00T0000001T0O00I07`06@1l0000000I07`0000001T0O00000000P0I07`0
0`0000006@1l01T0O0040000000301T0O00000006@1l00806@1l00<0000001T0O00000000P000002
01T0O0040000000I07`06@1l01T0O0<000000P0I07`01P0000006@1l01T0O00I07`0000001T0O0<0
00000`0I07`0100000006@1l01T0O00I07`3000000806@1l00D0000001T0O00I07`06@1l00000002
01T0O0<000000`0I07`01P0000006@1l01T0O00I07`0000001T0O080000000<06@1l0000000I07`0
0P0I07`00`0000006@1l01T0O004000000<06@1l00<0000001T0O00I07`00P0I07`01P0000006@1l
0000000000006@1l000000@06@1l00@0000001T0O00I07`06@1l0`00000301T0O0030000000I07`0
6@1l00806@1l00D0000001T0O0000000000001T0O002000000070340C`00000000000000000a04l0
00000340C`05000000030340C`000000<@1?00<0000000<0<@1?0000000000001@0000000`0a04l0
000000000006000000030340C`000000000000X000004@3oool603<0ocd0oooo000G0?ooo`030000
000I07`06@1l00<0000000<06@1l0000000I07`00P0I07`30000000301T0O00000006@1l00806@1l
00<0000001T0O00I07`00`0000000`0I07`0000001T0O00201T0O0030000000I07`0000000800000
0`0I07`0100000006@1l01T0O00I07`30000000301T0O00000006@1l00<06@1l00<0000001T0O000
00000P00000301T0O0040000000I07`06@1l01T0O0@0000000<06@1l0000000I07`00`0I07`00`00
00006@1l01T0O003000000<06@1l00@0000001T0O00I07`06@1l0`00000201T0O0030000000I07`0
6@1l00806@1l00<0000001T0O00I07`01000000301T0O0030000000I07`06@1l00806@1l00H00000
01T0O0000000000001T0O000000401T0O0040000000I07`06@1l01T0O0<000000`0I07`01`000000
<@1?000000000000<@1?0000000a04l01@0000000`0a04l000000340C`03000000030340C`000000
<@1?00@0000000<0<@1?0000000000000P0000000`0a04l0000000000004000000040340C`000000
00000340C`T000004@3oool603<0ocd0oooo000G0?ooo`<0000000H06@1l0000000I07`06@1l0000
000I07`3000000<06@1l00@0000001T0O00I07`06@1l0`0000001@0I07`0000001T0O00I07`00000
00806@1l0`00000201T0O0060000000I07`06@1l01T0O00000006@1l0P0000001@0I07`0000001T0
O00I07`0000000806@1l1000000201T0O0060000000I07`06@1l01T0O00000006@1l0P0000000`0I
07`0000001T0O00201T0O0040000000I07`06@1l01T0O0@0000000<06@1l0000000I07`00`0I07`0
0`0000006@1l00000002000000@06@1l00@0000001T0O00I07`06@1l1000000201T0O0030000000I
07`06@1l00806@1l00<0000001T0O00I07`01000000301T0O0030000000I07`06@1l00806@1l00H0
000001T0O0000000000001T0O000000501T0O0040000000a04l000000340C`D0000000<0<@1?0000
000a04l00`0000000`0a04l000000340C`06000000060340C`00000000000340C`000000<@1?2@00
00001@0a04l00000000000000000<@1?00D000004@3oool603<0ocd0oooo000G0?ooo`040000000I
07`06@1l000000806@1l0`00000201T0O0060000000I07`06@1l01T0O00000006@1l0`00000201T0
O0040000000I07`06@1l01T0O0<0000000<06@1l0000000I07`00P0I07`00`0000006@1l01T0O003
000000806@1l00@0000001T0O00I07`06@1l0`00000201T0O0050000000I07`06@1l01T0O0000000
0P0I07`3000000<06@1l00H0000001T0O00I07`06@1l0000000I07`20000000301T0O00000006@1l
00806@1l00@0000001T0O00I07`06@1l0`00000201T0O0030000000I07`06@1l00806@1l00H00000
01T0O0000000000001T0O000000401T0O0040000000I07`06@1l01T0O0@000000P0I07`00`000000
6@1l01T0O00201T0O0030000000I07`06@1l00@000000`0I07`00`0000006@1l01T0O00301T0O004
0000000a04l000000340C`<0000000<0<@1?0000000a04l01@0000000`0a04l00000000000030000
00030340C`000000000000P0000000<0<@1?000000000000200000000`0a04l00000000000030000
0140oooo1P0c0?lm0?ooo`005`3oool00`0000006@1l01T0O0030000000301T0O00000006@1l0080
6@1l00<0000001T0O00I07`00`0000000`0I07`0000001T0O00201T0O0030000000I07`000000080
00000`0I07`0100000006@1l01T0O00I07`30000000301T0O00000006@1l00806@1l00<0000001T0
O00000000P00000401T0O0040000000I07`06@1l01T0O0<0000000<06@1l0000000I07`00`0I07`0
0`0000006@1l01T0O003000000806@1l00<0000001T0O00I07`00P0I07`01P0000006@1l00000000
00006@1l000000<06@1l00@0000001T0O00I07`06@1l0`00000301T0O0030000000I07`06@1l0080
6@1l00H0000001T0O0000000000001T0O000000401T0O0040000000I07`06@1l01T0O0@000000P0I
07`00`0000006@1l01T0O00201T0O0040000000I07`06@1l01T0O0<0000000L0<@1?000000000000
00000340C`000000<@1?00D0000000<0<@1?0000000a04l00`0000000`0a04l000000340C`040000
00030340C`000000000000<0000000@0<@1?000000000000<@1?3P00000@0?ooo`H0<`3o?@3oool0
01L0oooo1000000301T0O0040000000I07`06@1l01T0O0<0000000D06@1l0000000I07`06@1l0000
000201T0O0<000000P0I07`01P0000006@1l01T0O00I07`0000001T0O0<000000`0I07`00`000000
6@1l01T0O003000000806@1l00<0000001T0O00I07`00P0I07`00`0000006@1l00000002000000<0
6@1l00@0000001T0O00I07`06@1l100000000`0I07`0000001T0O00201T0O0030000000I07`06@1l
00@000000`0I07`01P0000006@1l01T0O00I07`0000001T0O080000000<06@1l0000000I07`00`0I
07`0100000006@1l01T0O00I07`3000000<06@1l00<0000001T0O00I07`00P0I07`01P0000006@1l
0000000000006@1l000000@06@1l00@0000001T0O00I07`06@1l1@00000201T0O0D0000000D0<@1?
00000000000000000340C`03000000070340C`00000000000000000a04l000000340C`0600000004
0340C`00000000000340Ca@00000403oool603<0ocd0oooo000G0?ooo`040000000I07`06@1l0000
00<06@1l00D0000001T0O00000006@1l0000000201T0O0040000000I07`06@1l01T0O0<0000000<0
6@1l0000000I07`00P0I07`00`0000006@1l01T0O003000000806@1l00@0000001T0O00I07`06@1l
0`0000000`0I07`0000001T0O00201T0O0030000000I07`06@1l00@000000P0I07`01P0000006@1l
01T0O00I07`0000001T0O080000000<06@1l0000000I07`00P0I07`0100000006@1l01T0O00I07`3
000000806@1l00<0000001T0O00I07`00P0I07`00`0000006@1l01T0O003000000<06@1l00<00000
01T0O00I07`00P0I07`01P0000006@1l0000000000006@1l000000@06@1l00@0000001T0O00I07`0
6@1l0`00000301T0O0030000000I07`06@1l00806@1l00H0000001T0O0000000000001T0O0000005
01T0O0<0000000D0<@1?0000000a04l000000340C`02000000030340C`000000000000@0000000<0
<@1?0000000000000`0000000`0a04l0000000000003000000030340C`00000000000080000000<0
<@1?0000000000003@00000@0?ooo`H0<`3o?@3oool001L0oooo00@0000001T0O00I07`000000P0I
07`30000000301T0O00000006@1l00806@1l00<0000001T0O00000000P00000301T0O0040000000I
07`06@1l01T0O0<0000000<06@1l0000000I07`00P0I07`00`0000006@1l00000002000000<06@1l
00@0000001T0O00I07`06@1l0`00000201T0O0050000000I07`06@1l01T0O00000000P0I07`30000
00806@1l00<0000001T0O00I07`00P0I07`00`0000006@1l00000002000000@06@1l00@0000001T0
O00I07`06@1l100000000`0I07`0000001T0O00301T0O0030000000I07`06@1l00@000000`0I07`0
0`0000006@1l01T0O00201T0O0060000000I07`000000000000I07`00000100I07`0100000006@1l
01T0O00I07`3000000<06@1l00<0000001T0O00I07`00`0I07`010000000<@1?0000000a04l20000
00050340C`000000<@1?0000000a04l00P0000001@0a04l00000000000000000<@1?00<0000000<0
<@1?0000000a04l00P0000000`0a04l0000000000005000000040340C`00000000000340C`<00000
00<0<@1?0000000000001P00000@0?ooo`H0<`3o0P3oool3000000<0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`020?ooo`8000000`3oool3000000<0oooo00<000000?ooo`3o
ool06P3oool001H0oooo00@0000001T0O00I07`06@1l0`0000001@0I07`0000001T0O00I07`00000
00806@1l0`00000201T0O0090000000I07`06@1l01T0O00000006@1l0000000I07`0000000<06@1l
00<0000001T0O00I07`00`00000201T0O0060000000I07`06@1l01T0O00000006@1l0`00000301T0
O0040000000I07`06@1l01T0O0@0000000<06@1l0000000I07`00P0I07`00`0000006@1l01T0O004
000000806@1l00<0000001T0O00I07`00P0I07`01P0000006@1l0000000000006@1l000000<06@1l
00@0000001T0O00I07`06@1l1000000201T0O0030000000I07`06@1l00806@1l00<0000001T0O00I
07`01000000301T0O0030000000I07`06@1l00806@1l00H0000001T0O0000000000001T0O0000005
01T0O0040000000I07`06@1l01T0O080000000D0<@1?00000000000000000340C`02000000030340
C`000000000000<0000000<0<@1?000000000000100000000`0a04l0000000000002000000030340
C`00000000000080000000<0<@1?0000000000000`0000001@0a04l00000000000000000<@1?00<0
000000<0<@1?0000000000000P00000@0?ooo`H0<`3o0P3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
000000H0oooo00<000000?ooo`3oool06P3oool001H0oooo00D0000001T0O00000006@1l00000002
01T0O0030000000I07`06@1l00@0000000<06@1l0000000I07`00P0I07`00`0000006@1l01T0O003
0000000301T0O00000006@1l00806@1l100000000`0I07`0000001T0O00201T0O0030000000I07`0
6@1l00<000000P0I07`01P0000006@1l01T0O00I07`0000001T0O080000000<06@1l0000000I07`0
0P0I07`0100000006@1l01T0O00I07`3000000806@1l00D0000001T0O00I07`06@1l0000000301T0
O0<000000`0I07`01P0000006@1l01T0O00I07`0000001T0O080000000<06@1l0000000I07`00`0I
07`0100000006@1l01T0O00I07`4000000806@1l00<0000001T0O00I07`00P0I07`0100000006@1l
01T0O00I07`3000000<06@1l00<0000001T0O00I07`00`0I07`01@0000006@1l0000000000006@1l
00D000000P0a04l00`000000<@1?00000002000000030340C`000000<@1?008000000P0a04l70000
00030340C`00000000000080000000<0<@1?0000000000002`0000000`0a04l00000000000020000
0100oooo1P0c0?l20?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0000000<000000`3oool00`000000oooo0?ooo`0J
0?ooo`005P3oool20000000301T0O00000006@1l00806@1l0`0000000`0I07`0000001T0O00201T0
O0030000000I07`06@1l00@0000000H06@1l0000000I07`06@1l0000000I07`20000000501T0O000
00006@1l01T0O00000000`0I07`40000000301T0O00000006@1l00806@1l00@0000001T0O00I07`0
6@1l0P00000301T0O0060000000I07`06@1l01T0O00000006@1l0`00000401T0O0060000000I07`0
6@1l01T0O00000006@1l0P0000000`0I07`0000001T0O00301T0O0040000000I07`06@1l01T0O080
00000`0I07`00`0000006@1l01T0O00201T0O0060000000I07`000000000000I07`00000100I07`0
0`0000006@1l01T0O00201T0O0060000000I07`000000000000I07`00000100I07`00`0000006@1l
01T0O00201T0O0<000000`0I07`3000000040340C`000000<@1?0340C`<0000000<0<@1?0000000a
04l01@0000000`0a04l0000000000002000000030340C`00000000000080000000<0<@1?00000000
00000P0000000`0a04l000000000000?000000l0oooo1P00e?l20?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00D000000?ooo`3oool0oooo0000000L0?ooo`005P3oool01@0000006@1l01T0O000
00006@1l00<000000`0I07`0100000006@1l01T0O00I07`30000000501T0O00000006@1l01T0O000
00000P0I07`3000000806@1l00H0000001T0O00I07`06@1l0000000I07`20000000301T0O0000000
6@1l00806@1l00H0000001T0O00I07`06@1l0000000I07`3000000<06@1l00@0000001T0O00I07`0
6@1l0`00000201T0O0030000000I07`06@1l00806@1l00<0000001T0O00I07`00`00000301T0O003
0000000I07`06@1l00806@1l00<0000001T0O00000000P00000401T0O0040000000I07`06@1l01T0
O0<000000`0I07`00`0000006@1l01T0O00201T0O0030000000I07`06@1l00@000000`0I07`00`00
00006@1l01T0O00201T0O0030000000I07`000000080000000<06@1l0000000I07`00`0I07`01000
0000<@1?0000000a04l2000000050340C`00000000000000000a04l01@0000000`0a04l000000340
C`04000000030340C`00000000000080000000H0<@1?000000000000<@1?0000000a04lA000000l0
oooo1P00e?l20?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00800000103oool00`000000oooo0?ooo`0J0?oo
o`005@3oool00`0000006@1l01T0O003000000806@1l00H0000001T0O00I07`06@1l0000000I07`3
000000806@1l00@0000001T0O00I07`06@1l0`0000000`0I07`0000001T0O00201T0O0030000000I
07`06@1l00<000000`0I07`01@0000006@1l01T0O00I07`0000000806@1l0`00000201T0O0060000
000I07`06@1l01T0O00000006@1l0P0000000`0I07`0000001T0O00201T0O0040000000I07`06@1l
01T0O0@0000000<06@1l0000000I07`00`0I07`00`0000006@1l01T0O004000000806@1l00<00000
01T0O00I07`00P0I07`01P0000006@1l0000000000006@1l000000@06@1l00@0000001T0O00I07`0
6@1l1000000201T0O0030000000I07`06@1l00806@1l00<0000001T0O00I07`01000000401T0O003
0000000I07`06@1l00806@1l00<000000340C`0000000P0000001P0a04l000000000000a04l00000
0340C`<0000000<0<@1?0000000a04l00`0000000`0a04l0000000000002000000030340C`000000
000000P0000000<0<@1?0000000000003000000?0?ooo`H00=Co0P3oool010000000oooo0?ooo`00
00070?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`050?ooo`800000703oool001D0oooo0`0000000`0I07`0000001T0O00201T0O0030000000I07`0
6@1l00<0000000<06@1l0000000I07`00P0I07`00`0000006@1l00000002000000<06@1l00@00000
01T0O00I07`06@1l0`0000000`0I07`0000001T0O00201T0O0040000000I07`06@1l01T0O0@00000
00<06@1l0000000I07`00P0I07`00`0000006@1l01T0O003000000<06@1l00H0000001T0O00I07`0
6@1l0000000I07`20000000301T0O00000006@1l00806@1l00@0000001T0O00I07`06@1l10000002
01T0O0050000000I07`06@1l01T0O00000000P0I07`4000000<06@1l00<0000001T0O00I07`00P0I
07`01P0000006@1l0000000000006@1l000000@06@1l00@0000001T0O00I07`06@1l1000000201T0
O0030000000I07`06@1l00<06@1l00@0000001T0O00I07`06@1l0P000000200a04l000000000000a
04l000000340C`000000<@1?0`0000000`0a04l000000340C`05000000030340C`00000000000080
000000<0<@1?0000000000000P0000000`0a04l0000000000003000000040340C`00000000000340
C`<0000000D0<@1?00000000000000000340C`03000000l0oooo1P00e?l30?ooo`8000001@3oool4
000000030?ooo`0000000000008000000P3oool2000000T0oooo00<000000?ooo`3oool06P3oool0
01D0oooo00D0000001T0O00I07`06@1l0000000301T0O0<0000000D06@1l0000000I07`06@1l0000
000201T0O0<000000P0I07`01P0000006@1l01T0O00I07`0000001T0O0<000000`0I07`01P000000
6@1l01T0O00I07`0000001T0O080000000<06@1l0000000I07`00P0I07`0100000006@1l01T0O00I
07`30000000301T0O00000006@1l00<06@1l00<0000001T0O00I07`00`00000301T0O0060000000I
07`06@1l01T0O00000006@1l0P0000000`0I07`0000001T0O00201T0O0040000000I07`06@1l01T0
O0@000000P0I07`00`0000006@1l01T0O00201T0O0040000000I07`06@1l01T0O0<000000`0I07`0
0`0000006@1l01T0O00201T0O0060000000I07`000000000000I07`00000100I07`00`0000006@1l
01T0O00301T0O0050000000I07`000000000000I07`00P0000001@0a04l00000000000000000<@1?
00D0000000<0<@1?0000000000000`0000000`0a04l000000340C`04000000030340C`0000000000
0080000000<0<@1?0000000000001P0000001@0a04l00000000000000000<@1?00<0000000@0<@1?
00000000000000003`3oool6003Docd0oooo000E0?ooo`060000000I07`06@1l01T0O00000006@1l
0`00000201T0O0040000000I07`06@1l01T0O0<0000000<06@1l0000000I07`00P0I07`00`000000
6@1l01T0O003000000806@1l00D0000001T0O00I07`06@1l0000000201T0O0<000000P0I07`00`00
00006@1l01T0O00201T0O0030000000I07`00000008000000`0I07`0100000006@1l01T0O00I07`4
0000000301T0O00000006@1l00<06@1l00<0000001T0O00I07`00`00000301T0O0060000000I07`0
6@1l01T0O00000006@1l0P0000000`0I07`0000001T0O00301T0O0030000000I07`06@1l00806@1l
00H0000001T0O0000000000001T0O000000401T0O0040000000I07`06@1l01T0O0<000000`0I07`0
0`0000006@1l01T0O00301T0O0030000000I07`06@1l00@000000`0I07`01`000000<@1?00000000
0000<@1?0000000a04l00`0000000`0a04l000000340C`03000000030340C`000000<@1?00<00000
00<0<@1?0000000000000P0000000`0a04l0000000000002000000050340C`00000000000000000a
04l03P00000?0?ooo`H00=Co?@3oool001D0oooo00<0000001T0O00I07`00`0000000`0I07`00000
01T0O00201T0O0030000000I07`00000008000000`0I07`0100000006@1l01T0O00I07`300000003
01T0O00000006@1l00806@1l00@0000001T0O00I07`06@1l0`0000000`0I07`0000001T0O00201T0
O0030000000I07`06@1l00@000000P0I07`01P0000006@1l01T0O00I07`0000001T0O080000000<0
6@1l0000000I07`00P0I07`0100000006@1l01T0O00I07`40000000301T0O00000006@1l00<06@1l
00@0000001T0O00I07`06@1l0P00000301T0O0030000000I07`06@1l00806@1l00<0000001T0O00I
07`01000000301T0O0030000000I07`06@1l00806@1l00H0000001T0O0000000000001T0O0000004
01T0O0030000000I07`06@1l00806@1l1000000201T0O0030000000I07`06@1l00806@1l00D00000
0340C`0a04l000000340C`03000000030340C`000000<@1?00<0000000<0<@1?0000000a04l00`00
00000`0a04l000000340C`02000000030340C`000000<@1?0080000000<0<@1?0000000a04l04P00
000?0?ooo`H00=Co?@3oool001D0oooo0`0000001@0I07`0000001T0O00I07`0000000806@1l0`00
000201T0O0060000000I07`06@1l01T0O00000006@1l0`00000301T0O0060000000I07`06@1l01T0
O00000006@1l0`00000301T0O0040000000I07`06@1l01T0O0<000000P0I07`01@0000006@1l01T0
O00I07`0000000806@1l0`00000201T0O0030000000I07`06@1l00806@1l00H0000001T0O0000000
000001T0O000000301T0O0030000000I07`06@1l00806@1l00<0000001T0O00000000P00000401T0
O0040000000I07`06@1l01T0O0@000000P0I07`00`0000006@1l01T0O00201T0O0030000000I07`0
6@1l00@000000`0I07`00`0000006@1l01T0O00201T0O0030000000I07`000000080000000<06@1l
0000000I07`00`0I07`00`0000006@1l01T0O00201T0O0030000000a04l0<@1?00D0000000<0<@1?
0000000000000`0000000`0a04l0000000000003000000030340C`000000000000`0000000<0<@1?
0000000000003P00000>0?ooo`H00=Co?@3oool001D0oooo00@0000001T0O00I07`000000`0I07`3
0000000301T0O00000006@1l00806@1l00<0000001T0O00I07`00`0000000`0I07`0000001T0O003
01T0O0030000000I07`06@1l00<000000P0I07`01P0000006@1l01T0O00I07`0000001T0O0<00000
0`0I07`0100000006@1l01T0O00I07`40000000301T0O00000006@1l00806@1l00<0000001T0O00I
07`01000000301T0O0050000000I07`06@1l01T0O00000000P0I07`4000000806@1l00<0000001T0
O00I07`00P0I07`01P0000006@1l0000000000006@1l000000@06@1l00@0000001T0O00I07`06@1l
1000000201T0O0030000000I07`06@1l00806@1l00@0000001T0O00I07`06@1l0`00000401T0O003
0000000I07`06@1l00806@1l00<0000001T0O00I07`00`0000020340C`<0000000<0<@1?0000000a
04l00`0000000`0a04l000000340C`03000000030340C`000000<@1?00<0000000<0<@1?00000000
00000P0000000`0a04l0000000000003000000040340C`00000000000340C`/0000000<0<@1?0000
003oool03@3oool6003Docd0oooo000D0?ooo`060000000I07`06@1l01T0O00000006@1l0`000003
01T0O0040000000I07`06@1l01T0O0<0000000D06@1l0000000I07`06@1l0000000201T0O0D00000
00<06@1l0000000I07`00P0I07`00`0000006@1l01T0O003000000806@1l00H0000001T0O00I07`0
6@1l0000000I07`20000000301T0O00000006@1l00806@1l00@0000001T0O00I07`06@1l0`000002
01T0O0050000000I07`06@1l01T0O00000000`0I07`4000000806@1l00D0000001T0O00I07`06@1l
0000000201T0O0@000000`0I07`00`0000006@1l01T0O00201T0O0060000000I07`000000000000I
07`00000100I07`00`0000006@1l01T0O00201T0O0060000000I07`000000000000I07`000001@0I
07`0100000006@1l01T0O00I07`4000000806@1l0P0000001@0a04l000000340C`000000<@1?00<0
000000<0<@1?0000000a04l00P000000100a04l000000000000a04l3000000030340C`000000<@1?
00@0000000<0<@1?0000000000001P000000100a04l000000000000a04l8000000030340C`000000
oooo00d0oooo1P00e?lm0?ooo`00503oool00`0000006@1l01T0O003000000806@1l00H0000001T0
O00I07`06@1l0000000I07`3000000806@1l00@0000001T0O00I07`06@1l0`00000201T0O0040000
000I07`06@1l000000<06@1l100000000`0I07`0000001T0O00201T0O0030000000I07`06@1l00<0
00000`0I07`01P0000006@1l01T0O00I07`0000001T0O0<00000100I07`01P0000006@1l01T0O00I
07`0000001T0O080000000<06@1l0000000I07`00`0I07`0100000006@1l01T0O00I07`300000080
6@1l00<0000001T0O00I07`00P0I07`0100000006@1l01T0O00I07`3000000<06@1l00<0000001T0
O00I07`00P0I07`00`0000006@1l01T0O004000000<06@1l00<0000001T0O00I07`00`0I07`01P00
00006@1l0000000000006@1l000000@06@1l00D000000340C`00000000000340C`05000000050340
C`00000000000000000a04l01`0000001@0a04l00000000000000000<@1?00@0000000D0<@1?0000
0000000000000340C`05000000040340C`00000000000340C`L000003P3oool6003Docd0oooo000D
0?ooo`<0000000<06@1l0000000I07`00P0I07`00`0000006@1l01T0O0030000000301T0O0000000
6@1l00806@1l00<0000001T0O00000000P00000301T0O0060000000I07`06@1l01T0O00000006@1l
0P0000001@0I07`0000001T0O00I07`0000000<06@1l100000000`0I07`0000001T0O00201T0O004
0000000I07`06@1l01T0O0<000000P0I07`00`0000006@1l01T0O00201T0O0030000000I07`06@1l
00<000000`0I07`00`0000006@1l01T0O00201T0O0030000000I07`0000000800000100I07`00`00
00006@1l01T0O00201T0O0060000000I07`000000000000I07`00000100I07`0100000006@1l01T0
O00I07`4000000806@1l00<0000001T0O00I07`00P0I07`00`0000006@1l01T0O00201T0O0<00000
0`0I07`00`0000006@1l01T0O00301T0O0040000000a04l000000340C`<0000000D0<@1?0000000a
04l000000340C`02000000040340C`00000000000340C`<0000000D0<@1?00000000000000000340
C`04000000030340C`000000000000X0000000<0<@1?0000000000001@00000>0?ooo`H00=Co?@3o
ool001@0oooo00D0000001T0O00I07`06@1l0000000301T0O0<0000000D06@1l0000000I07`06@1l
0000000201T0O0<000000P0I07`01@0000006@1l01T0O00I07`0000000806@1l0`00000201T0O006
0000000I07`06@1l01T0O00000006@1l0P0000000`0I07`0000001T0O00201T0O0060000000I07`0
6@1l01T0O00000006@1l0P0000000`0I07`0000001T0O00201T0O0040000000I07`06@1l01T0O0@0
000000<06@1l0000000I07`00`0I07`0100000006@1l01T0O00I07`3000000806@1l00<0000001T0
O00I07`00P0I07`00`0000006@1l01T0O004000000<06@1l00<0000001T0O00I07`00P0I07`01P00
00006@1l0000000000006@1l000000@06@1l00<0000001T0O00I07`00P0I07`00`0000006@1l0000
00020000000301T0O00000006@1l00<06@1l00<0000001T0O00I07`00P0I07`2000000070340C`00
000000000000000a04l000000340C`02000000050340C`000000<@1?0000000a04l00`0000000`0a
04l0000000000002000000030340C`000000<@1?00@0000000@0<@1?000000000000<@1?3P000000
0`0a04l000000000000>0?ooo`H00=Co0P3oool3000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`8000001@3oool00`000000oooo0?ooo`03000000030?ooo`0000000000008000006`3o
ool001@0oooo00H0000001T0O00I07`06@1l0000000I07`3000000806@1l00@0000001T0O00I07`0
6@1l0`0000000`0I07`0000001T0O00201T0O0040000000I07`06@1l01T0O0<0000000<06@1l0000
000I07`00P0I07`00`0000006@1l01T0O003000000<06@1l00D0000001T0O00I07`06@1l00000002
01T0O0<000000`0I07`01P0000006@1l01T0O00I07`0000001T0O080000000<06@1l0000000I07`0
0P0I07`00`0000006@1l01T0O00201T0O0060000000I07`000000000000I07`000000`0I07`01000
00006@1l01T0O00I07`4000000806@1l00<0000001T0O00I07`00P0I07`0100000006@1l01T0O00I
07`3000000<06@1l00<0000001T0O00I07`00P0I07`00`0000006@1l01T0O004000000@06@1l00<0
000001T0O00I07`00P0I07`00`0000006@1l000000020000000301T0O0000000000000<0000000D0
<@1?00000000000000000340C`02000000070340C`00000000000000000a04l000000340C`020000
00030340C`000000<@1?00<0000000<0<@1?0000000000000`0000000`0a04l000000000000?0000
00h0oooo1P00e?l20?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool06`3o
ool001@0oooo00<0000001T0O00I07`00`0000000`0I07`0000001T0O00201T0O0030000000I07`0
0000008000000`0I07`01P0000006@1l01T0O00I07`0000001T0O0<000000`0I07`0100000006@1l
01T0O00I07`30000000301T0O00000006@1l00806@1l00@0000001T0O00I07`06@1l100000000`0I
07`0000001T0O00301T0O0030000000I07`06@1l00<000000`0I07`01@0000006@1l01T0O00I07`0
000000806@1l1000000201T0O0030000000I07`06@1l00806@1l00H0000001T0O0000000000001T0
O000000401T0O0030000000I07`06@1l00806@1l00H0000001T0O0000000000001T0O000000401T0
O0040000000I07`06@1l01T0O0@000000P0I07`00`0000006@1l01T0O00301T0O0040000000I07`0
6@1l01T0O0<00000100I07`3000000050340C`000000<@1?0000000a04l00P0000000`0a04l00000
0340C`03000000030340C`000000000000P0000000@0<@1?000000000000<@1?100000000`0a04l0
00000000000=000000h0oooo1P00e?l20?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo00000008000000<0oooo00<000000?ooo`3oool06P3oool001@0
oooo0`0000001@0I07`0000001T0O00I07`0000000806@1l0`00000201T0O0050000000I07`06@1l
01T0O00000000P0I07`3000000806@1l00H0000001T0O00I07`06@1l0000000I07`3000000<06@1l
00H0000001T0O00I07`06@1l0000000I07`20000000301T0O00000006@1l00806@1l00@0000001T0
O00I07`06@1l100000000`0I07`0000001T0O00201T0O0040000000I07`06@1l01T0O0@000000P0I
07`01@0000006@1l01T0O00I07`0000000806@1l1000000301T0O0030000000I07`06@1l00806@1l
00<0000001T0O00I07`01000000301T0O0030000000I07`06@1l00806@1l00H0000001T0O0000000
000001T0O000000401T0O0030000000I07`06@1l00<06@1l00H0000001T0O0000000000001T0O000
000501T0O0040000000a04l000000340C`80000000D0<@1?0000000a04l000000340C`0300000003
0340C`000000<@1?00<0000000<0<@1?0000000000000P0000000`0a04l000000340C`0200000006
0340C`00000000000340C`000000<@1?0P0000000`0a04l000000000000:000000h0oooo1P00okh2
0?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
000000020?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo0000000L0?ooo`00
503oool0100000006@1l01T0O000000301T0O0<0000000<06@1l0000000I07`00P0I07`00`000000
6@1l01T0O0040000000301T0O00000006@1l00806@1l00<0000001T0O00I07`00`00000201T0O005
0000000I07`06@1l01T0O00000000P0I07`3000000<06@1l00H0000001T0O00I07`06@1l0000000I
07`20000000301T0O00000006@1l00806@1l00H0000001T0O00I07`06@1l0000000I07`200000003
01T0O00000006@1l00<06@1l00@0000001T0O00I07`06@1l0`00000201T0O0030000000I07`06@1l
00806@1l00@0000001T0O00I07`06@1l1000000201T0O0030000000I07`06@1l00806@1l00@00000
01T0O00I07`06@1l0`00000301T0O0030000000I07`06@1l00<06@1l00<0000001T0O00I07`01000
000301T0O0030000000I07`06@1l00<06@1l00<000000340C`0000000P000000100a04l000000000
000a04l5000000070340C`00000000000000000a04l000000340C`04000000030340C`0000000000
0080000000<0<@1?0000000000001@000000100a04l000000000000a04l3000000030340C`000000
000000<000003P3oool6003o_P80oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`03000000<0oooo00<000000?ooo`0000000P3oool2000000D0oooo00<000000?ooo`3oool06@3o
ool001<0oooo00H0000001T0O00I07`06@1l0000000I07`3000000<06@1l00@0000001T0O00I07`0
6@1l0`0000001@0I07`0000001T0O00I07`0000000<06@1l100000000`0I07`0000001T0O00201T0
O0030000000I07`06@1l00@0000000<06@1l0000000I07`00`0I07`00`0000006@1l01T0O0030000
00<06@1l00D0000001T0O00I07`06@1l0000000201T0O0<000000`0I07`00`0000006@1l01T0O002
01T0O0030000000I07`0000000800000100I07`00`0000006@1l01T0O00201T0O0060000000I07`0
00000000000I07`00000100I07`00`0000006@1l01T0O00201T0O0060000000I07`000000000000I
07`00000100I07`00`0000006@1l01T0O00201T0O0@000000P0I07`00`0000006@1l01T0O00201T0
O0030000000I07`06@1l00806@1l0P000000200a04l000000000000a04l000000340C`000000<@1?
0`0000000`0a04l000000340C`03000000050340C`00000000000000000a04l0100000000`0a04l0
000000000002000000030340C`000000000000<0000000@0<@1?000000000000<@1?0`0000000`0a
04l0000000000004000000d0oooo1P00okh20?ooo`040000003oool0oooo000000D0oooo0P000003
0?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`040000003oool0oooo000001/0oooo000C
0?ooo`030000000I07`06@1l00<0000000<06@1l0000000I07`00`0I07`00`0000006@1l00000002
000000806@1l00H0000001T0O00I07`06@1l0000000I07`20000000501T0O00000006@1l01T0O000
00000`0I07`40000000301T0O00000006@1l00806@1l00@0000001T0O00I07`06@1l100000000`0I
07`0000001T0O00201T0O0040000000I07`06@1l01T0O0@0000000<06@1l0000000I07`00`0I07`0
0`0000006@1l01T0O004000000806@1l00<0000001T0O00I07`00P0I07`00`0000006@1l01T0O004
000000<06@1l00<0000001T0O00I07`00P0I07`00`0000006@1l01T0O004000000<06@1l00<00000
01T0O00I07`00P0I07`00`0000006@1l000000020000000301T0O00000006@1l00<06@1l00<00000
01T0O00I07`00P0I07`00`0000006@1l00000002000000807`3d0P000000100a04l000000000000a
04l3000000030340C`000000<@1?00<0000000<0<@1?0000000a04l00`0000000`0a04l000000000
0002000000060340C`00000000000340C`000000<@1?200000000`0a04l0000000000008000000d0
oooo1P00okh30?ooo`8000001`3oool010000000oooo0?ooo`3oool3000000@0oooo00<000000?oo
o`3oool01@3oool2000001`0oooo000C0?ooo`<0000000D06@1l0000000I07`06@1l0000000201T0
O0@0000000<06@1l0000000I07`00P0I07`00`0000006@1l01T0O003000000806@1l00H0000001T0
O00I07`06@1l0000000I07`20000000301T0O00000006@1l00806@1l00H0000001T0O00I07`06@1l
0000000I07`20000000301T0O00000006@1l00806@1l00H0000001T0O00I07`06@1l0000000I07`2
0000000301T0O00000006@1l00806@1l00@0000001T0O00I07`06@1l1000000201T0O0050000000I
07`06@1l01T0O00000000`0I07`4000000806@1l00<0000001T0O00I07`00P0I07`0100000006@1l
01T0O00I07`4000000806@1l00<0000001T0O00I07`00P0I07`0100000006@1l01T0O00I07`30000
00@06@1l00<0000001T0O00I07`00P0I07`00`0000006@1l01T0O004000000D07`3d0P0000020340
C`030000000a04l000000080000000L0<@1?00000000000000000340C`000000<@1?00<0000000<0
<@1?0000000a04l0100000000`0a04l0000000000004000000030340C`000000000000`0000000<0
<@1?0000000000003@3oool6003o_Sd0oooo000C0?ooo`040000000I07`06@1l000000<06@1l0`00
000201T0O0040000000I07`06@1l000000806@1l100000000`0I07`0000001T0O00201T0O0030000
000I07`06@1l00<000000`0I07`01@0000006@1l01T0O00I07`0000000806@1l0`00000301T0O005
0000000I07`06@1l01T0O00000000P0I07`3000000<06@1l00H0000001T0O00I07`06@1l0000000I
07`20000000301T0O00000006@1l00806@1l00<0000001T0O00I07`00P0I07`01P0000006@1l0000
000000006@1l000000@06@1l00<0000001T0O00I07`00P0I07`01P0000006@1l0000000000006@1l
000000@06@1l00<0000001T0O00I07`00P0I07`01P0000006@1l0000000000006@1l000000D06@1l
00@0000001T0O00I07`06@1l1000000301l0m0030000000O0?@07`3d00<07`3d0P0000020340C`<0
000000<0<@1?0000000a04l00`0000000`0a04l0000000000003000000050340C`00000000000000
000a04l0100000000`0a04l0000000000002000000040340C`00000000000340C`h000003@3oool6
003o_Sd0oooo000B0?ooo`060000000I07`06@1l01T0O00000006@1l0`00000301T0O0040000000I
07`06@1l01T0O0<0000000<06@1l0000000I07`00P0I07`0100000006@1l01T0O00I07`300000003
01T0O00000006@1l00806@1l00@0000001T0O00I07`06@1l100000000`0I07`0000001T0O00201T0
O0040000000I07`06@1l01T0O0@0000000<06@1l0000000I07`00`0I07`0100000006@1l01T0O00I
07`2000000<06@1l00D0000001T0O00I07`06@1l0000000201T0O0@000000`0I07`00`0000006@1l
01T0O00201T0O0030000000I07`06@1l00@000000`0I07`00`0000006@1l01T0O00201T0O0030000
000I07`06@1l00@000000`0I07`00`0000006@1l01T0O00301T0O0040000000I07`0000000000080
7`3d00<0000001l0m00O0?@00`0O0?@00`0000007`3d01l0m002000000807`3d00<000000340C`00
00000P0000001`0a04l00000000000000000<@1?0000000a04l00`0000000`0a04l000000340C`03
000000060340C`00000000000340C`000000<@1?10000000100a04l000000000000a04l200000003
0340C`000000000000T000003@3oool6003o_Sd0oooo000B0?ooo`030000000I07`06@1l00<00000
0P0I07`01P0000006@1l01T0O00I07`0000001T0O0<000000`0I07`01P0000006@1l01T0O00I07`0
000001T0O0<000000`0I07`01P0000006@1l01T0O00I07`0000001T0O080000000<06@1l0000000I
07`00P0I07`01P0000006@1l01T0O00I07`0000001T0O080000000<06@1l0000000I07`00P0I07`0
0`0000006@1l01T0O00201T0O0030000000I07`0000000800000100I07`0100000006@1l01T0O00I
07`3000000806@1l00<0000001T0O00I07`00P0I07`0100000006@1l01T0O00I07`4000000806@1l
00<0000001T0O00I07`00P0I07`0100000006@1l01T0O00I07`4000000806@1l00<0000001T0O00I
07`00P0I07`00`0000006@1l01T0O00201T0O0<00000100O0?@00`0000007`3d01l0m00301l0m0<0
00001@0O0?@2000000030340C`000000<@1?00<0000000@0<@1?000000000000<@1?0P0000001`0a
04l00000000000000000<@1?0000000a04l01P0000000`0a04l0000000000003000000040340C`00
000000000340C`80000000D0<@1?00000000000000000340C`04000000d0oooo1P00okhm0?ooo`00
4P3oool30000000301T0O00000006@1l00806@1l00<0000001T0O00I07`00`00000201T0O0050000
000I07`06@1l01T0O00000000P0I07`3000000806@1l00D0000001T0O00I07`06@1l0000000201T0
O0<000000`0I07`01@0000006@1l01T0O00I07`0000000806@1l0`00000301T0O0050000000I07`0
6@1l01T0O00000000P0I07`4000000806@1l00<0000001T0O00I07`00P0I07`00`0000006@1l0000
0002000000@06@1l00<0000001T0O00I07`00P0I07`01P0000006@1l0000000000006@1l000000@0
6@1l00<0000001T0O00I07`00P0I07`01P0000006@1l0000000000006@1l000000@06@1l00<00000
01T0O00I07`00P0I07`00`0000006@1l00000002000000807`3d00<0000001l0m00O0?@00`0O0?@0
0`0000007`3d01l0m002000000807`3d00<0000001l0m00O0?@00`0O0?@2000000090340C`000000
00000000000a04l000000340C`000000<@1?00D0000000<0<@1?0000000a04l00`0000000`0a04l0
000000000002000000040340C`00000000000340C`D0000000@0<@1?000000000000<@1?0`000000
0`0a04l0000000000002000000d0oooo1P00okhm0?ooo`004P3oool01@0000006@1l01T0O00I07`0
000000<06@1l0`0000000`0I07`0000001T0O00201T0O0040000000I07`06@1l01T0O0<0000000<0
6@1l0000000I07`00P0I07`0100000006@1l01T0O00I07`30000000301T0O00000006@1l00806@1l
00@0000001T0O00I07`06@1l100000000`0I07`0000001T0O00201T0O0040000000I07`06@1l01T0
O0@000000P0I07`01@0000006@1l01T0O00I07`0000000<06@1l0`00000201T0O0030000000I07`0
6@1l00806@1l00<0000001T0O00I07`01000000301T0O0030000000I07`06@1l00806@1l00<00000
01T0O00I07`01000000301T0O0030000000I07`06@1l00806@1l00<0000001T0O00I07`010000005
01l0m0030000000O0?@07`3d00807`3d1000000501l0m0030000000O0?@07`3d008000000P0O0?@2
000000030340C`000000<@1?0080000000<0<@1?0000000a04l00P0000000`0a04l0000000000003
000000030340C`000000<@1?00@0000000<0<@1?0000000000000`0000000`0a04l0000000000003
000000030340C`000000000000L00000303oool6003o_Sd0oooo000B0?ooo`060000000I07`06@1l
01T0O00000006@1l0`00000201T0O0030000000I07`06@1l00806@1l00<0000001T0O00000000P00
000201T0O0030000000I07`06@1l00806@1l00<0000001T0O00000000P00000301T0O0060000000I
07`06@1l01T0O00000006@1l0P0000000`0I07`0000001T0O00201T0O0060000000I07`06@1l01T0
O00000006@1l0P0000000`0I07`0000001T0O00201T0O0030000000I07`06@1l00806@1l00H00000
01T0O0000000000001T0O000000301T0O0040000000I07`06@1l01T0O0@000000P0I07`00`000000
6@1l01T0O00201T0O0040000000I07`06@1l01T0O0@000000P0I07`00`0000006@1l01T0O00201T0
O0040000000I07`06@1l01T0O0@000000`0O0?@00`0000007`3d01l0m00301l0m0D000000`0O0?@0
0`0000007`3d01l0m00301l0m0<00000100O0?@2000000050340C`00000000000000000a04l00P00
00001@0a04l00000000000000000<@1?00@0000000D0<@1?00000000000000000340C`0400000003
0340C`000000000000@0000000<0<@1?000000000000200000000`0a04l000000?ooo`0;0?ooo`H0
0?nn?@3oool00180oooo00<0000001T0O00I07`00`0000000`0I07`0000001T0O00201T0O0030000
000I07`06@1l00@0000000<06@1l0000000I07`00P0I07`00`0000006@1l01T0O004000000806@1l
00D0000001T0O00I07`06@1l0000000201T0O0<000000P0I07`00`0000006@1l01T0O00201T0O003
0000000I07`06@1l00<000000`0I07`01@0000006@1l01T0O00I07`0000000806@1l1000000301T0
O0060000000I07`06@1l01T0O00000006@1l0P0000000`0I07`0000001T0O00301T0O0030000000I
07`06@1l00806@1l00H0000001T0O0000000000001T0O000000401T0O0030000000I07`06@1l0080
6@1l00@0000001T0O000000000000P0O0?@00`0000007`3d01l0m00301l0m0030000000O0?@07`3d
008000000P0O0?@00`0000007`3d01l0m00301l0m0030000000O0?@07`3d00<000000P0O0?@00`00
00007`3d01l0m00201l0m080000000<0<@1?0000000a04l00P0000000`0a04l000000340C`030000
00030340C`00000000000080000000D0<@1?00000000000000000340C`02000000030340C`000000
<@1?0080000000<0<@1?000000000000100000000`0a04l0000000000007000000`0oooo1P00okh2
0?ooo`<000000`3oool00`000000oooo0000000300000080oooo0P0000020?ooo`@000000P3oool3
000000030?ooo`0000000000008000006`3oool00180oooo0`0000001@0I07`0000001T0O00I07`0
000000806@1l1000000201T0O0040000000I07`06@1l000000806@1l1000000201T0O0050000000I
07`06@1l01T0O00000000P0I07`40000000301T0O00000006@1l00806@1l00<0000001T0O00I07`0
1@0000000`0I07`0000001T0O00301T0O0040000000I07`06@1l01T0O0<000000P0I07`00`000000
6@1l01T0O00201T0O0040000000I07`06@1l01T0O08000000`0I07`00`0000006@1l01T0O00201T0
O0040000000I07`06@1l01T0O0<000000`0I07`00`0000006@1l01T0O00201T0O0040000000I07`0
6@1l01T0O0<000001@0O0?@0100000007`3d01l0m00O0?@4000000D07`3d00<0000001l0m00O0?@0
0`0O0?@2000000D07`3d00<0000001l0m00O0?@00P00000201l0m0060000000a04l000000340C`00
0000<@1?0`0000000`0a04l000000340C`05000000040340C`00000000000340C`L0000000<0<@1?
0000000000001`0000000`0a04l0000000000004000000`0oooo1P00okh20?ooo`040000003oool0
oooo000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0K0?ooo`004P3oool0100000006@1l
01T0O000000301T0O0<0000000<06@1l0000000I07`00P0I07`0100000006@1l01T0O00I07`30000
000301T0O00000006@1l00806@1l00@0000001T0O00I07`06@1l100000000`0I07`0000001T0O002
01T0O0040000000I07`06@1l01T0O0<000000P0I07`01@0000006@1l01T0O00I07`0000000@06@1l
00<0000001T0O00000000P00000401T0O0030000000I07`06@1l00806@1l00<0000001T0O0000000
0P00000401T0O0030000000I07`06@1l00806@1l00H0000001T0O0000000000001T0O000000401T0
O0030000000I07`06@1l00806@1l00@0000001T0O000000000000P0O0?@00`0000007`3d01l0m003
01l0m0@000000P0O0?@<000000807`3d00<0000001l0m00O0?@0100O0?@2000000D07`3d0P000000
1`0a04l00000000000000000<@1?0000000a04l00`000000100a04l000000000000a04l500000003
0340C`000000000000D0000000<0<@1?0000000000003000000<0?ooo`H00?nn0P3oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`@000000`3oool00`000000oooo0?ooo`0J0?ooo`004@3oool01P0000006@1l01T0O00I07`0
000001T0O0<000000`0I07`01P0000006@1l01T0O00I07`0000001T0O0<000000`0I07`01P000000
6@1l01T0O00I07`0000001T0O080000000D06@1l0000000I07`06@1l0000000401T0O0030000000I
07`0000000800000100I07`01@0000006@1l01T0O00I07`0000000806@1l1000000201T0O0030000
000I07`06@1l00806@1l00<0000001T0O00I07`01000000201T0O0030000000I07`06@1l00806@1l
00<0000001T0O00I07`01000000301T0O0030000000I07`06@1l00806@1l00<0000001T0O00I07`0
1000000501l0m0030000000O0?@07`3d00P000000P00YO@00`0000000:Gd002Um002000000800:Gd
00<00000002Um000YO@01`00000301l0m0030000000O0?@07`3d00<07`3d0P0000001@0a04l00000
000000000000<@1?00<0000000<0<@1?0000000a04l00`0000000`0a04l000000000000200000003
0340C`000000000000D0000000@0<@1?000000000000<@1?1P0000000`0a04l00000000000020000
00`0oooo1P00ob020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo
0000000L0?ooo`004@3oool00`0000006@1l01T0O003000000806@1l00D0000001T0O00I07`06@1l
0000000201T0O0<000000P0I07`01@0000006@1l01T0O00I07`0000000806@1l0`00000301T0O004
0000000I07`06@1l000000806@1l1000000201T0O0030000000I07`06@1l00806@1l00<0000001T0
O00I07`01000000201T0O0050000000I07`06@1l01T0O00000000`0I07`4000000806@1l00D00000
01T0O00I07`06@1l0000000301T0O0@000000P0I07`00`0000006@1l01T0O00201T0O0040000000I
07`06@1l01T0O0@000000`0O0?@2000000<07`3d1P000003002Um00400000000YO@00:Gd002Um0@0
00001@00YO@00`0000000:Gd002Um002000000800:Gd0P00000301l0m0030000000O0?@07`3d00<0
00000P0O0?@2000000030340C`000000<@1?00<0000000L0<@1?00000000000000000340C`000000
<@1?00@0000000<0<@1?0000000000001@000000100a04l000000000000a04l2000000050340C`00
000000000000000a04l01000000<0?ooo`H00?lP0P3oool010000000oooo0?ooo`0000070?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000D0
oooo00<000000?ooo`3oool06@3oool00140oooo0`0000000`0I07`0000001T0O00201T0O0040000
000I07`06@1l01T0O0<0000000<06@1l0000000I07`00P0I07`0100000006@1l01T0O00I07`30000
000301T0O00000006@1l00806@1l00@0000001T0O00I07`06@1l0`00000201T0O0050000000I07`0
6@1l01T0O00000000`0I07`40000000301T0O00000006@1l00806@1l00<0000001T0O00I07`00P0I
07`01P0000006@1l0000000000006@1l000000<06@1l00<0000001T0O00I07`00P0I07`01P000000
6@1l0000000000006@1l000000@06@1l00<0000001T0O00I07`00P0I07`0100000006@1l00000000
000201l0m0030000000O0?@07`3d00<07`3d1@000002002Um00300000000YO@00:Gd00<00:Gd1000
0003002Um00300000000YO@00:Gd00<00:Gd0`000004002Um00400000000YO@00000000000807`3d
0P00000501l0m080000000L0<@1?00000000000000000340C`000000<@1?00<0000000D0<@1?0000
0000000000000340C`04000000040340C`00000000000340C`D0000000@0<@1?000000000000<@1?
0`0000000`0a04l0000000000003000000/0oooo1P00ob020?ooo`040000003oool0oooo000000@0
oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool000000080oooo00<00000
0?ooo`3oool0103oool010000000oooo0?ooo`00000K0?ooo`004@3oool01@0000006@1l01T0O00I
07`0000000<06@1l00<0000001T0O00000000P00000201T0O0030000000I07`06@1l00806@1l00<0
000001T0O00000000P00000301T0O0060000000I07`06@1l01T0O00000006@1l0`00000401T0O006
0000000I07`06@1l01T0O00000006@1l0P0000000`0I07`0000001T0O00201T0O0050000000I07`0
6@1l01T0O00000000P0I07`4000000<06@1l00D0000001T0O00I07`06@1l0000000201T0O0@00000
0`0I07`00`0000006@1l01T0O00201T0O0030000000I07`06@1l00@000001@0O0?@00`0000007`3d
01l0m005000000@00:Gd00<00000002Um000YO@00`000002002Um00300000000YO@00:Gd00800:Gd
00<00000002Um000YO@00`000002002Um00300000000YO@00:Gd00800:Gd1P0000000`0O0?@00000
01l0m00401l0m080000000D0<@1?00000000000000000340C`03000000030340C`000000<@1?00<0
000000H0<@1?000000000000<@1?0000000a04l2000000040340C`00000000000340C`d0000000<0
<@1?0000003oool02P3oool6003o80<0oooo0P0000060?ooo`8000000`3oool2000000<0oooo0P00
00080?ooo`800000703oool00140oooo00D0000001T0O00I07`06@1l0000000201T0O0<0000000<0
6@1l0000000I07`00P0I07`00`0000006@1l01T0O004000000806@1l00D0000001T0O00I07`06@1l
0000000201T0O0<000000P0I07`00`0000006@1l01T0O00201T0O0030000000I07`06@1l00<00000
0`0I07`01@0000006@1l01T0O00I07`0000000<06@1l0`00000201T0O0030000000I07`06@1l0080
6@1l00@0000001T0O00I07`06@1l0`00000201T0O0030000000I07`06@1l00806@1l00@0000001T0
O00I07`06@1l1000000301l0m0800000100O0?@4000000<00:Gd00@00000002Um000YO@00:Gd1000
0005002Um00300000000YO@00:Gd00<00:Gd0P000005002Um00300000000YO@00:Gd008000000P00
YO@00`0000000:Gd002Um0020000000401l0m00000007`3d01l0m08000000P0O0?@2000000030340
C`000000<@1?00<0000000L0<@1?00000000000000000340C`000000<@1?00L0000000<0<@1?0000
000000000`0000000`0a04l0000000000004000000030340C`000000000000<000002`3oool6003o
83d0oooo000A0?ooo`030000000I07`06@1l00@0000000D06@1l0000000I07`06@1l0000000201T0
O0@000000P0I07`0100000006@1l01T0O000000301T0O0@0000000<06@1l0000000I07`00P0I07`0
100000006@1l01T0O00I07`40000000301T0O00000006@1l00806@1l00<0000001T0O00I07`00P0I
07`00`0000006@1l00000002000000@06@1l00<0000001T0O00I07`00P0I07`00`0000006@1l0000
0002000000@06@1l00<0000001T0O00I07`00P0I07`0100000006@1l00000000000201l0m0030000
000O0?@07`3d00<07`3d1@000002002Um00300000000YO@00:Gd00800:Gd10000002002Um1000000
1@00YO@2000000D00:Gd00<00000002Um000YO@01@00000401l0m080000000@0<@1?000000000000
<@1?0P0000001@0a04l00000000000000000<@1?00<0000000<0<@1?0000000000001@0000000`0a
04l000000000000>000000/0oooo1P00ob0m0?ooo`004@3oool30000000501T0O00000006@1l01T0
O00000000`0I07`30000000301T0O00000006@1l00806@1l00H0000001T0O00I07`06@1l0000000I
07`20000000301T0O00000006@1l00806@1l00H0000001T0O00I07`06@1l0000000I07`200000003
01T0O00000006@1l00806@1l00D0000001T0O00I07`06@1l0000000201T0O0@000000P0I07`00`00
00006@1l01T0O00201T0O0030000000I07`06@1l00@000000P0I07`00`0000006@1l01T0O00201T0
O0030000000I07`06@1l00@00000100O0?@00`0000007`3d01l0m006000000@00:Gd00<00000002U
m000YO@0200000020037]@0300000000akD00<Ne008000000P00akD00`0000000<Ne0037]@030037
]@H0000000<00:Gd00000000YO@01@00YO@2000000800:Gd00<0000001l0m00000000`0O0?@30000
00030340C`000000<@1?00@0000000@0<@1?000000000000<@1?0`000000100a04l000000000000a
04l4000000040340C`00000000000340C`80000000<0<@1?00000000000010000000100a04l00000
00000000000;0?ooo`H00?lP?@3oool00140oooo00@0000001T0O00I07`000000`0I07`00`000000
6@1l00000002000000<06@1l00D0000001T0O00I07`06@1l0000000201T0O0<000000`0I07`01@00
00006@1l01T0O00I07`0000000806@1l0`00000301T0O0050000000I07`06@1l01T0O00000000P0I
07`4000000806@1l00D0000001T0O00I07`06@1l0000000301T0O0@000000P0I07`01@0000006@1l
01T0O00I07`0000000<06@1l1000000301l0m0040000000O0?@07`3d01l0m0H000000`00YO@01000
00000:Gd002Um000YO@6000000<00<Ne00@000000037]@00akD00<Ne100000050037]@0300000000
akD00<Ne008000000P00akD0100000000<Ne0037]@00akD3000000800:Gd0P000002002Um0060000
0000YO@00:Gd002Um00000007`3d0`00000301l0m0040000000a04l000000340C`80000000<0<@1?
0000000000000`0000000`0a04l000000340C`02000000030340C`00000000000080000000@0<@1?
000000000000<@1?1@0000001@0a04l00000000000000000<@1?00<000002`3oool6003o83d0oooo
000A0?ooo`040000000I07`06@1l000000806@1l0`00000201T0O0050000000I07`06@1l01T0O000
00000P0I07`40000000301T0O00000006@1l00806@1l00@0000001T0O00I07`06@1l100000000`0I
07`0000001T0O00201T0O0040000000I07`06@1l01T0O0@0000000<06@1l0000000I07`00P0I07`0
0`0000006@1l01T0O00201T0O0060000000I07`000000000000I07`000000`0I07`00`0000006@1l
01T0O00201T0O0040000000I07`00000000000807`3d00<0000001l0m00O0?@00`0O0?@500000080
0:Gd00<00000002Um000YO@00`00YO@4000000<00<Ne00<000000037]@00akD00P00akD4000000<0
0<Ne0P0000030037]@@000001000akD0100000000<Ne0037]@00akD5000000@00:Gd00@00000002U
m000YO@00:Gd0P0000000`0O0?@0000001l0m00401l0m080000000D0<@1?00000000000000000340
C`02000000030340C`000000<@1?00H0000000<0<@1?0000000000001@0000001@0a04l000000000
00000000<@1?00<0000000@0<@1?00000000000000002`3oool6003o83d0oooo000@0?ooo`040000
000I07`06@1l01T0O0<0000000<06@1l0000000I07`00P0I07`0100000006@1l01T0O00I07`30000
000301T0O00000006@1l00806@1l00H0000001T0O00I07`06@1l0000000I07`20000000301T0O000
00006@1l00806@1l00H0000001T0O00I07`06@1l0000000I07`20000000301T0O00000006@1l0080
6@1l00D0000001T0O00I07`06@1l0000000201T0O0@000000`0I07`01@0000006@1l01T0O00I07`0
000000806@1l1000000501l0m0030000000O0?@07`3d00D000001000YO@0100000000:Gd002Um000
YO@2000000030037]@0000000<Ne00@00<Ne00<000000037]@00akD00P0000020037]@0300000000
akD00<Ne00<00<Ne100000030037]@0300000000akD00<Ne00800<Ne100000030037]@<000000`00
YO@4000000800:Gd0P00000401l0m0<0000000D0<@1?00000000000000000340C`06000000030340
C`00000000000080000000@0<@1?000000000000<@1?100000001@0a04l00000000000000000<@1?
00L000002`3oool6003o83d0oooo000@0?ooo`030000000I07`00000008000000`0I07`01P000000
6@1l01T0O00I07`0000001T0O0<000000`0I07`01@0000006@1l01T0O00I07`0000000806@1l0`00
000301T0O0050000000I07`06@1l01T0O00000000P0I07`3000000<06@1l00D0000001T0O00I07`0
6@1l0000000301T0O0<000000P0I07`00`0000006@1l01T0O00201T0O0040000000I07`06@1l01T0
O0<000000`0O0?@2000000<07`3d1@000003002Um00400000000YO@00:Gd002Um0D000001000akD0
100000000<Ne0037]@00akD4000000<00<Ne2@0000050037]@0300000000akD00<Ne008000000P00
akD00`0000000<Ne0037]@030037]@D000000P00YO@00`0000000:Gd002Um002002Um0D000000`0O
0?@2000000050340C`000000<@1?0000000a04l0100000000`0a04l0000000000002000000030340
C`000000000000D0000000<0<@1?0000000000001@0000000`0a04l0000000000002000000X0oooo
1P00ob0m0?ooo`00403oool2000000806@1l00D0000001T0O00I07`06@1l0000000201T0O0<00000
0P0I07`01@0000006@1l01T0O00I07`0000000806@1l100000000`0I07`0000001T0O00201T0O004
0000000I07`06@1l01T0O0@0000000<06@1l0000000I07`00P0I07`00`0000006@1l01T0O00201T0
O0030000000I07`0000000800000100I07`00`0000006@1l01T0O00201T0O0060000000I07`00000
0000000O0?@000001@0O0?@5000000800:Gd00@00000002Um000YO@00:Gd1P0000020037]@030000
0000akD00<Ne00<00<Ne100000000`00akD00000000000040000000300377P000000000000800000
1000aah00`0000000<LN00377P05000000D00<Ne00<000000037]@00akD00P0000020037]@060000
0000akD0000000000000YO@000000P00YO@2000000800:Gd00<0000001l0m00O0?@00`0O0?@20000
00050340C`00000000000000000a04l0100000000`0a04l0000000000004000000040340C`000000
00000340C`H0000000<0<@1?0000000000001P00000:0?ooo`H00?lP?@3oool00100oooo00@00000
01T0O00I07`000000`0I07`40000000501T0O00000006@1l01T0O00000000`0I07`40000000301T0
O00000006@1l00806@1l00H0000001T0O00I07`06@1l0000000I07`20000000301T0O00000006@1l
00806@1l00D0000001T0O00I07`06@1l0000000201T0O0@000000P0I07`00`0000006@1l01T0O002
01T0O0030000000I07`06@1l00@00000100O0?@00`0000007`3d01l0m005000000@00:Gd1P000002
0037]@0300000000akD00<Ne00800<Ne00<000000037]@00akD01`00000300377P@000000`00aah0
0`0000000<LN00377P0200377P@000000`00aah9000000@00<Ne00@000000037]@00akD00<Ne1000
0005002Um0030000000O0?@07`3d008000000P0O0?@2000000030340C`000000<@1?00H0000000H0
<@1?000000000000<@1?0000000a04l5000000030340C`000000000000L0000000<0<@1?00000000
00002P3oool6003o8080oooo0`0000030?ooo`030000003oool0oooo008000000P3oool3000000<0
oooo0P0000030?ooo`<0000000<0oooo0000000000000P00000K0?ooo`003`3oool01P0000006@1l
01T0O00I07`0000001T0O080000000D06@1l0000000I07`06@1l0000000301T0O0060000000I07`0
00000000000I07`000000P0I07`00`0000006@1l01T0O00201T0O0030000000I07`06@1l00<00000
0`0I07`01@0000006@1l01T0O00I07`0000000806@1l1000000201T0O0050000000I07`06@1l01T0
O00000000`0I07`4000000<07`3d00@0000001l0m00O0?@07`3d1@000003002Um00300000000YO@0
0:Gd00H000001000akD00`0000000<Ne0037]@020037]@D000000`00aah00`0000000<LN00377P02
000000800<LN00<0000000377P00aah00P00aah00`0000000<LN00377P02000000800<LN00<00000
00377P00aah00`00aah3000000<00<LN0P0000050037]@<000000P00akD3000000<00:Gd10000004
01l0m080000000D0<@1?00000000000000000340C`04000000030340C`000000000000@0000000<0
<@1?0000000000001`0000000`0a04l0000000000004000000X0oooo1P00ob020?ooo`040000003o
ool0oooo000000@0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool00000
0080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0K0?ooo`003`3oool00`000000
6@1l01T0O003000000<06@1l00@0000001T0O00I07`000000P0I07`3000000<06@1l00@0000001T0
O00I07`000000P0I07`50000000301T0O00000006@1l00806@1l00@0000001T0O00I07`06@1l1000
00000`0I07`0000001T0O00201T0O0030000000I07`06@1l00806@1l00@0000001T0O00000000000
0P0O0?@00`0000007`3d01l0m00201l0m0D000000P00YO@2000000<00:Gd1@0000030037]@040000
0000akD00<Ne0037]@H000000`00aah0100000000<LN00377P00aah4000000@00<LN00@000000037
7P00aah00<LN1000000500377P0300000000aah00<LN008000000P00aah00`0000000<LN00377P02
00377PD000000P00akD00`0000000<Ne0037]@020037]@0300000000YO@00000008000000`00YO@0
0`0000007`3d01l0m00201l0m080000000D0<@1?00000000000000000340C`04000000030340C`00
0000<@1?00@0000000@0<@1?000000000000<@1?0P0000000`0a04l0000000000004000000040340
C`0000000000000000X0oooo1P00ob020?ooo`040000003oool0oooo000000L0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`03000000030?ooo`0000000000008000000`3oool00`00
0000oooo0?ooo`0J0?ooo`003`3oool30000000301T0O00000006@1l00806@1l00@0000001T0O00I
07`06@1l0`0000000`0I07`0000001T0O00201T0O0040000000I07`06@1l01T0O0<000000P0I07`0
1@0000006@1l01T0O00I07`0000000<06@1l00H0000001T0O0000000000001T0O000000301T0O005
0000000I07`06@1l01T0O00000000P0I07`4000000@07`3d00<0000001l0m00O0?@00`000002002U
m00300000000YO@00:Gd00800:Gd1@0000020037]@0300000000akD00<Ne00800<Ne1@0000020037
7P0300000000aah00<LN00<00<LN1000000300377P0300000000aah00<LN00800<LN2@0000050037
7P8000001000aah0100000000<LN00377P00aah30000000300377P0000000<Ne00<00<Ne00@00000
0037]@00akD00<Ne0P0000000`00YO@00000002Um003002Um0030000000O0?@07`3d008000000P0O
0?@2000000050340C`000000<@1?0000000a04l0100000000`0a04l0000000000002000000040340
C`00000000000340C`80000000@0<@1?000000000000<@1?0`000000100a04l0000000000000000:
0?ooo`H0dOl00P3oool010000000oooo0?ooo`0000060?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
0000703oool000l0oooo00D0000001T0O00I07`06@1l0000000301T0O0030000000I07`000000080
00000`0I07`01P0000006@1l01T0O00I07`0000001T0O0<00000100I07`01@0000006@1l01T0O00I
07`0000000806@1l0`00000301T0O0050000000I07`06@1l01T0O00000000`0I07`3000000<07`3d
0P00000301l0m0@000001000YO@00`0000000:Gd002Um005000000@00<Ne00<000000037]@00akD0
0`00000200377P0300000000aah00<LN00800<LN00<0000000377P00aah00P0000000`00aah00000
00377P0300377PD000001022a`000`000000P/L008;7000208;700P000001@00aah3000000<00<LN
100000020037]@@000000P00akD2000000<00:Gd1000000401l0m080000000D0<@1?000000000000
00000340C`02000000030340C`000000<@1?00X0000000@0<@1?000000000000<@1?1`00000:0?oo
o`H0dOl00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool000000080oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`02000000D0oooo00<000000?ooo`3oool06@3oool0
00l0oooo00D0000001T0O00I07`06@1l0000000201T0O0<000000P0I07`01@0000006@1l01T0O00I
07`0000000806@1l0`00000201T0O0050000000I07`06@1l01T0O00000000`0I07`40000000301T0
O00000006@1l00806@1l00<0000001T0O00I07`00P0I07`01@0000006@1l0000000000007`3d0080
00000`0O0?@5000000<00:Gd00@00000002Um000YO@00:Gd1@0000030037]@8000000`00akD40000
00@00<LN00@0000000377P00aah00<LN3P0000000`22a`00000008;7000408;7000300000022a`00
P/L0008000000P22a`000`000000P/L008;7000208;700D000000P00aah00`0000000<LN00377P03
00377PD000000P00akD0100000000<Ne0037]@00akD5000000<00:Gd0P00000301l0m080000000D0
<@1?0000000a04l000000340C`06000000040340C`00000000000340C`P0000000<0<@1?00000000
00001P0000090?ooo`H0dOl00P3oool010000000oooo0?ooo`0000040?ooo`060000003oool0oooo
0000003oool000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool000006`3oool000l0oooo00<0000001T0O00I07`0100000000`0I07`0000001T0
O00201T0O0040000000I07`06@1l01T0O0<0000000<06@1l0000000I07`00P0I07`01P0000006@1l
01T0O00I07`0000001T0O080000000<06@1l0000000I07`00P0I07`01@0000006@1l01T0O00I07`0
000000806@1l1000000501l0m0@000000P00YO@2000000<00:Gd1P0000000`00akD0000000000003
0037]@D000000`00aah00`0000000<LN00377P0300377PD000000P22a`0010000000P/L008;70022
a`04000000@0P/L000@0000008;70022a`00P/L01000000408;7000300000022a`00P/L000800000
0P22a`0010000000P/L008;70000000200377P0300000000aah00<LN008000000P00aah010000000
0<LN0000000000020037]@<000000`00akD00`0000000:Gd002Um003002Um0@000000P0O0?@20000
00050340C`00000000000000000a04l0100000000`0a04l0000000000006000000030340C`000000
000000L0000000<0<@1?0000003oool0203oool60=7o00<0oooo0P0000060?ooo`8000000`3oool2
000000<0oooo0P0000080?ooo`800000703oool000l0oooo0`0000001@0I07`0000001T0O00I07`0
000000@06@1l00<0000001T0O00000000P00000301T0O0050000000I07`06@1l01T0O00000000P0I
07`3000000<06@1l00D0000001T0O00I07`06@1l0000000201T0O0@000000`0O0?@2000000807`3d
10000005002Um0P000001000akD5000000800<LN00<0000000377P00aah00`00aah00`0000000<LN
00377P05000000@0P/L01000000308;7000300000022a`00P/L00080P/L01000000308;700040000
0022a`00P/L008;700@000001@22a`0010000000P/L008;70022a`04000000@00<LN00@000000037
7P00aah00<LN0P0000000`00akD000000037]@030037]@0300000000YO@00:Gd008000000`00YO@0
0`0000007`3d01l0m00201l0m0030000000a04l000000080000000<0<@1?0000000000000P000000
0`0a04l000000340C`09000000040340C`00000000000340C`D000002@3oool60=7o03d0oooo000?
0?ooo`040000000I07`06@1l000000<06@1l00<0000001T0O00I07`01000000201T0O0050000000I
07`06@1l01T0O00000000P0I07`40000000301T0O00000006@1l00806@1l00@0000001T0O00I07`0
6@1l1000000201l0m08000000`0O0?@5000000800:Gd0P000002002Um0H000000`00akD00`000000
0<Ne0037]@05000000D00<LN00@0000000377P00aah00<LN1@00000308;7000300000022a`00P/L0
008000000P22a`000`000000P/L008;7000208;7000300000022a`00P/L00080000000<0P/L00000
0022a`001@22a`03000000<0P/L00P00000308;700D000000`22a`02000000<00<LN100000020037
7P8000000`00akD4000000@00:Gd0P00000201l0m080000000<07`3d0000000a04l00P0000000`0a
04l0000000000004000000040340C`00000000000340C`80000000<0<@1?0000000000001`000000
0`0a04l00000000000090?ooo`H0dOl0?@3oool000l0oooo00@0000001T0O00I07`000000P0I07`4
000000806@1l00@0000001T0O00I07`000000`0I07`40000000301T0O00000006@1l00806@1l00H0
000001T0O00I07`06@1l0000000I07`2000000807`3d00<0000001l0m00O0?@00`0O0?@400000080
0:Gd0P000003002Um0@000000`00akD2000000<00<Ne1@00000200377P8000000`00aah5000000<0
P/L000@0000008;70022a`00P/L01000000308;700<000000`22a`0?000000H0P/L00`00000308;7
000300000022a`00P/L00080P/L01@00000200377P0400000000aah00<LN00377PD000000`00akD2
000000<00:Gd1000000401l0m0D0000000H0<@1?000000000000<@1?0000000a04l2000000030340
C`000000000000H0000000D0<@1?00000000000000000340C`02000000T0oooo1P3Ao`0m0?ooo`00
3P3oool0100000006@1l01T0O00I07`30000000301T0O00000006@1l00806@1l00H0000001T0O00I
07`06@1l0000000I07`20000000301T0O00000006@1l00806@1l00D0000001T0O00I07`06@1l0000
000201T0O0<000001@0O0?@00`0000007`3d01l0m004000000D00:Gd1@0000000`00akD000000037
]@040037]@D000000P00aah00`0000000<LN00377P0300377P<000000`22a`02000000<0P/L01000
000208;700D0000000<0WjL00000000000000P00000309nW008000000`2OY`04000000@0WjL000<0
000009nW000000001000000508;7000300000022a`00P/L0008000000P22a`03000000<00<LN0`00
000300377P0300000000akD00<Ne00<00<Ne10000002002Um08000000`0O0?@4000000030340C`00
0000<@1?00T0000000@0<@1?000000000000<@1?2P0000090?ooo`H0dOl0?@3oool000h0oooo00<0
000001T0O00000000P00000301T0O0050000000I07`06@1l01T0O00000000P0I07`3000000<06@1l
00@0000001T0O00I07`000000`0I07`4000000807`3d00<0000001l0m00O0?@00`0O0?@400000080
0:Gd0P000002002Um0D000001000akD00`0000000<Ne0037]@05000000D00<LN00<0000000377P00
aah00P0000000`22a`00000008;7000408;700@0000000<0P/L00000000000000`00000209nW00@0
00000P2OY`02000000<0WjL01@00000309nW00040000002OY`00WjL009nW00D000000`2OY`080000
00@0P/L000<0000008;70022a`000`0000000`00aah0000000377P0400377P0400000000akD00000
000000<00<Ne00<00000002Um000YO@00P00YO@4000000<07`3d1@000000100a04l000000000000a
04l4000000040340C`00000000000340C`80000000<0<@1?0000000000001@0000090?ooo`H0dOl0
?@3oool000h0oooo0P00000201T0O0050000000I07`06@1l01T0O00000000P0I07`40000000301T0
O00000006@1l00806@1l00H0000001T0O00I07`06@1l0000000I07`2000000807`3d00<0000001l0
m00O0?@00`0O0?@4000000800:Gd00<00000002Um000YO@00P00YO@4000000<00<Ne0P0000030037
]@@000000`00aah2000000<00<LN1000000408;7000300000022a`00P/L00080000000<0P/L00000
000000000P00000209nW00030000002OY`00WjL0008000000P2OY`000`000000WjL009nW000209nW
00@000000`2OY`000`000000WjL009nW000209nW00@000000`2OY`0010000000WjL009nW002OY`04
00000080WjL000<0000008;7000000000`22a`0400000080P/L000<0000000377P0000000`00aah4
000000D00<Ne00<00000002Um000YO@00P000002002Um0030000000O0?@07`3d00807`3d1@000000
0`0a04l0000000000005000000040340C`00000000000340C`80000000<0<@1?0000000000001@00
00090?ooo`H0dOl0?@3oool000h0oooo00@0000001T0O00I07`000000`0I07`40000000301T0O000
00006@1l00806@1l00D0000001T0O00I07`06@1l0000000201T0O0<000001@0O0?@00`0000007`3d
01l0m00200000003002Um00000000:Gd00@00:Gd100000020037]@0300000000akD00<Ne00<00<Ne
1000000200377P8000000`00aah5000000<0P/L000@0000008;70022a`00P/L0100000001@22a`00
00000000002OY`00000000<0WjL01000000409nW00030000002OY`00WjL0008000000P2OY`000`00
0000WjL009nW000209nW00030000002OY`00WjL0008000000P2OY`000`000000WjL009nW000309nW
00<000000`2OY`000`000000WjL009nW000209nW00@000000`22a`0200000080P/L01@0000030037
7P8000000`00akD4000000@00:Gd00@0000001l0m00O0?@07`3d0`0000001P0a04l000000000000a
04l000000340C`/0000000D0<@1?00000000000000000340C`04000000P0oooo1P3Ao`0m0?ooo`00
3@3oool01P0000006@1l01T0O00I07`0000001T0O080000000<06@1l0000000I07`00P0I07`01@00
00006@1l01T0O00I07`0000000806@1l1000000201l0m0800000100O0?@3000000@00:Gd00<00000
002Um000YO@0100000050037]@0300000000akD00<Ne008000000P00aah00`0000000<LN00377P03
00377PD0000000<0P/L000000022a`001022a`030000000308;7000000000000008000000`2OY`04
000000<0WjL00P00000309nW00<000000`2OY`0300000080WjL01000000509nW00030000002OY`00
WjL00080000000<0WjL00000002OY`00102OY`000`000000WjL009nW00020000000309nW00000000
P/L000D0P/L00P00000208;700<000000`00aah5000000<00<Ne0P000003002Um0@000000`0O0?@5
000000030340C`000000000000<0000000<0<@1?0000000000002P0000000`0a04l000000?ooo`07
0?ooo`H0dOl00P3oool3000000<0oooo00<000000?ooo`3oool00P0000030?ooo`8000000`3oool2
000000<0oooo0`0000000`3oool0000000000002000001/0oooo000=0?ooo`030000000I07`06@1l
00<000000`0I07`0100000006@1l01T0O000000301T0O0@000000P0O0?@2000000<07`3d1@000002
002Um08000000`00YO@5000000800<Ne0P0000030037]@<000001@00aah00`0000000<LN00377P05
000000@0P/L000<0000008;70022a`000P0000001022a`00000000000000000309nW00@000000P2O
Y`02000000<0WjL02`0000000`2O<`00000000000002000000@0Wc<000<0000009lc000000001@00
000409nW00040000002OY`00WjL009nW00@00000102OY`0500000080P/L000H0000008;70022a`00
P/L000000000aah3000000<00<LN00@000000037]@00akD00<Ne1P000002002Um0040000000O0?@0
7`3d01l0m0@0000000<0<@1?0000000a04l02`000000100a04l000000000000a04l5000000P0oooo
1P3Ao`020?ooo`040000003oool0oooo000000@0oooo00H000000?ooo`3oool000000?ooo`000002
0?ooo`030000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0K
0?ooo`003@3oool30000000301T0O00000006@1l00806@1l00H0000001T0O00I07`06@1l0000000I
07`2000000807`3d00<0000001l0m00O0?@00`0O0?@500000003002Um0000000000000<00:Gd1P00
00000`00akD00000000000030037]@H0000000<00<LN00000000aah00P00aah600000080P/L000@0
000008;70022a`00P/L0100000001@22a`0000000000002OY`0000000080WjL00P00000209nW0003
0000002OY`00WjL00080WjL02@00000309lc00@000000`2O<`0010000000Wc<009lc002O<`050000
00<0Wc<000<0000009lc000000001P00000309nW00040000002OY`00WjL009nW00<0000000<0WjL0
00000022a`000P22a`0010000000P/L008;70022a`020000000300377P0000000<LN00<00<LN1000
00030037]@8000000`00YO@4000000<07`3d1@000000100a04l000000000000a04l2000000030340
C`000000000000L0000000<0<@1?000000000000203oool60=7o0080oooo00@000000?ooo`3oool0
00001`3oool00`000000oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`00
00000`0000030?ooo`030000003oool0oooo01X0oooo000=0?ooo`050000000I07`06@1l01T0O000
00000`0I07`00`0000006@1l01T0O003000000D07`3d00<0000001l0m00O0?@00P0000000`0O0?@0
000000000004002Um0@000000P00YO@2000000@00<Ne100000001000akD000000000000000030037
7P@0000000D00<LN000000000000P/L00000000308;700@000000P22a`03000000<0WjL00`000004
09nW00030000002OY`00WjL000H000000`2O<`000`000000Wc<009lc000200000080Wc<000<00000
09lc002O<`000P2O<`04000000<0Wc<000<0000009lc002O<`000P2O<`03000000<0Wc<00P000005
09nW00<000000`2OY`000`000000WjL00000000208;700@000000P22a`02000000<00<LN10000004
0037]@0300000000akD00000008000000P00YO@00`0000007`3d01l0m00201l0m0D0000000@0<@1?
000000000000<@1?1@000000100a04l000000000000a04l3000000030340C`000000000000P0oooo
1P3Ao`020?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3oool0oooo0P0000020?oo
o`060000003oool0oooo0000003oool000000P3oool01@000000oooo0?ooo`3oool0000001`0oooo
000=0?ooo`050000000I07`06@1l01T0O00000000P0I07`4000000807`3d0P00000401l0m0<00000
00D07`3d0000000000000:Gd00000002002Um080000000@00:Gd00000000YO@00:Gd0P0000001000
akD000000037]@00akD2000000800<Ne0`00000200377P@000000P00aah3000000<0P/L010000002
08;700@0000000<0WjL00000000000000`00000209nW008000000`2OY`04000000<0Wc<00P000003
09lc00<00000102O<`000`000000Wc<009lc000200000080Wc<000<0000009lc002O<`000P2O<`00
0`000000Wc<009lc000200000080Wc<000<0000009lc002O<`000P2O<`0500000080WjL000@00000
09nW002OY`00WjL01P00000208;7000400000022a`00P/L008;700D000000`00aah2000000<00<Ne
0P0000000`00akD00000002Um002002Um0030000000O0?@07`3d008000000P0O0?@3000000060340
C`00000000000340C`000000<@1?3@0000080?ooo`H0omL00P3oool010000000oooo0?ooo`000007
0?ooo`030000003oool000000080oooo00<000000?ooo`0000000P0000030?ooo`8000001@3oool0
0`000000oooo0?ooo`0I0?ooo`003@3oool0100000006@1l01T0O00I07`3000000807`3d0P000003
01l0m0D000000P0O0?@2000000<00:Gd0`000004002Um08000000`00akD3000000<00<Ne00<00000
00377P0000000P00aah20000000400377P0000000<LN00377P<000000P22a`0200000080P/L000<0
000008;70022a`000P000000102OY`00000000000000000309nW00040000002OY`00WjL009nW00D0
00000P2O<`02000000<0Wc<01@00000209lc008000000`2O<`03000000D0Wc<000@0000009lc002O
<`00Wc<00`00000409lc00030000002O<`00Wc<0008000000P2O<`03000000<0WjL00`00000309nW
00040000002OY`00000000000080P/L00`00000308;7000300000000aah00<LN00<00<LN10000002
0037]@8000000`00YO@3000000@07`3d20000000100a04l000000000000a04l2000000030340C`00
000000000080000000<0<@1?000000000000203oool60?oG0080oooo00@000000?ooo`3oool00000
103oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000001/0oooo000=0?ooo`060000000I07`00000
0000000O0?@000001@0O0?@3000000<07`3d00<0000001l0m00O0?@01P000002002Um080000000<0
0:Gd0000000000001@0000020037]@80000000<00<Ne00000000aah01000000400377P8000000P22
a`03000000D0P/L00P0000001@2OY`0000000000002OY`00000000D0WjL01@0000000`2O<`000000
09lc000409lc00<000000`2O<`0010000000Wc<009lc002O<`0500000080Wc<00P00000509lc00<0
00000P2O<`02000000<0Wc<00`00000409lc00030000002O<`00Wc<000<0000000<0WjL00000002O
Y`000`2OY`000`000000WjL009nW00030000000308;700000000P/L000<0P/L01000000300377P80
00000`00akD5000000800:Gd00@0000001l0m00O0?@07`3d100000001P0a04l000000000000a04l0
00000340C`80000000@0<@1?000000000000<@1?1`0000080?ooo`H0omL00`3oool2000000H0oooo
0P0000030?ooo`8000000`3oool2000000P0oooo0P00000L0?ooo`003@3oool2000000@07`3d00<0
000001l0m00O0?@00P0000000`0O0?@0000001l0m00401l0m0@000000P00YO@2000000<00:Gd1000
00030037]@8000001000akD3000000<00<LN00<0000000377P00aah01P00000208;7008000000`22
a`04000000@0WjL000<0000009nW002OY`000P0000000`2OY`0000000000000409lc00030000002O
<`00Wc<00080000000<0Wc<00000002O<`00102O<`030000000309lc00000000000000T000000P2O
<`000`000000Wc<009lc000409lc00<000000P2O<`02000000<0Wc<00`00000209lc00030000002O
Y`00000000<0WjL01000000209nW000300000022a`0000000080P/L00P00000208;7000300000000
aah00<LN00800<LN1@0000020037]@8000000`00YO@4000000<07`3d2@000000100a04l000000000
000a04l3000000030340C`0000000000008000001`3oool60?oG03d0oooo000>0?ooo`8000000`0O
0?@3000000@07`3d0P00000201l0m080000000<00:Gd00000000YO@01000YO@4000000030037]@00
00000<Ne00D00<Ne100000000`00aah000000000000300377PD000000P22a`02000000<0P/L01@00
000209nW00040000002OY`00WjL009nW00@0000000D0WjL0000000000000Wc<00000000309lc00@0
0000102O<`000`000000Wc<009lc0006000000<0W`2B0`00000309l0TP030000002O0980000000L0
00000P2O<`000`000000Wc<009lc000309lc00<000000P2O<`02000000<0Wc<01000000309nW0003
0000002OY`00WjL000D000001022a`000`0000000<LN00377P02000000<00<LN00<000000037]@00
akD00P00akD4000000800:Gd00@0000001l0m00O0?@07`3d5P0000070?ooo`H0omL0?@3oool00100
oooo0`00000201l0m08000000`0O0?@40000000501l0m00000000:Gd002Um00000000P00YO@20000
0004002Um00000000:Gd000000800<Ne0P0000020037]@80000000<00<Ne00000000aah01000aah3
0000000300377P000000P/L000@0P/L01P0000000`2OY`0000000000000309nW00@000000`2OY`02
000000<0Wc<01000000309lc00040000002O<`00Wc<009lc00D000000`2O09800`000000W`2B09l0
TP020000000309l0TP000000W`2B00@0W`2B0`00000309l0TP030000002O0980W`2B00H000000`2O
<`0010000000Wc<009lc002O<`0500000080Wc<00P00000309nW00<000000P2OY`000`000000P/L0
0000000308;700@000001000aah2000000800<Ne0P0000020037]@0400000000YO@00:Gd002Um0@0
00000P0O0?@2000000030340C`000000<@1?00<0000000@0<@1?000000000000<@1?0P000000100a
04l000000000000a04l2000000L0oooo1P3oe`0m0?ooo`004@3oool2000000<07`3d1000000301l0
m08000000`00YO@3000000@00:Gd00@000000037]@00akD00<Ne100000020037]@0300000000aah0
000000800<LN0P0000001000aah0000000377P00000308;700<000000`22a`000`000000WjL009nW
000309nW00<000000P2OY`000`000000WjL009nW000700000080Wc<00P00000309lc00H0000000<0
W`2B0000002O09800P2O0984000000@0W`2B00<0000009l0TP2O09800P0000000`2O0980000009l0
TP0309l0TP030000002O0980W`2B008000000P2O0982000000<0Wc<01000000309lc00040000002O
<`00Wc<009lc00D000000P2OY`0200000080WjL01@00000308;7000400000000aah00<LN00377PD0
00000`00akD2000000<00:Gd0`00000401l0m0030000000a04l00000010000001`3oool60?oG03d0
oooo000C0?ooo`<000000P0O0?@2000000<07`3d1@000002002Um08000000P00YO@5000000<00<Ne
00D000000037]@00akD0000000377P03000000@00<LN00<0000008;70022a`000P0000000`22a`00
000008;7000208;700030000002OY`0000000080WjL00P0000000`2OY`00000009nW000309nW00@0
00000`2O<`0010000000Wc<009lc002O<`0500000080Wc<00P00000309l0TP@000000`2O09801000
0000W`2B09l0TP2O0984000000@0W`2B00@0000009l0TP2O0980W`2B0`00000409l0TP030000002O
09800000008000000P2O<`000`000000Wc<009lc000209lc00@000000P2O<`02000000<0WjL01000
000209nW008000000`22a`05000000<00<LN0P0000030037]@D000000P00YO@0100000007`3d01l0
m00O0?@2000000030340C`000000<@1?0080000000@0<@1?000000000000<@1?0P000000100a04l0
00000000000a04l3000000L0oooo1P3oe`0m0?ooo`00503oool00`0000007`3d01l0m00301l0m0<0
00000P0O0?@3000000<00:Gd100000020037]@8000000`00akD5000000800<LN0P00000200377P@0
00001022a`000`000000P/L000000005000000@0WjL000<0000009nW002OY`000P0000000`2O<`00
000009lc000409lc00<000000P2O<`000`000000Wc<009lc000700000080W`2B0P00000309l0TP@0
00000`2O098010000000W`2B09l0TP2O098500000080W`2B0P00000309l0TP<0000000D0W`2B0000
00000000Wc<00000000209lc008000000P2O<`000`000000Wc<009lc000209lc00@000000`2OY`00
1@000000WjL009nW00000000P/L000<000000`22a`0400377PH000000P00akD2000000<00:Gd1000
000201l0m080000000<0<@1?0000000000002@000000100a04l000000000000000070?ooo`H0omL0
?@3oool001D0oooo00<0000001l0m00O0?@00P00000201l0m0040000000O0?@07`3d000000800:Gd
0`000002002Um08000000`00akD4000000800<Ne00<0000000377P00aah00P00aah4000000<0P/L0
0P00000308;700<00000102OY`0010000000WjL009nW002OY`04000000@0Wc<000<0000009lc002O
<`000P0000000`2O<`00000009lc000309lc00@000000`2O098010000000W`2B09l0TP2O09850000
0080W`2B0P00000309l0TP@000000`2O098010000000W`2B09l0TP2O098500000080W`2B0P000002
09l0TP@00000102O<`0010000000Wc<009lc002O<`04000000@0WjL000<0000009nW002OY`000P00
00000`22a`00000008;7000408;700<000000`00aah0100000000<Ne0037]@00akD6000000800:Gd
00@0000001l0m00O0?@07`3d0P0000000`0a04l000000340C`02000000040340C`00000000000340
C`<0000000@0<@1?00000000000000001`3oool60?oG03d0oooo000F0?ooo`8000001@0O0?@00`00
00007`3d01l0m00200000003002Um00000000:Gd00<00:Gd100000020037]@0500000000akD00<Ne
0037]@00aah01000000300377P0300000022a`00P/L00080P/L01000000208;7008000000`2OY`04
00000080WjL00P00000309lc00@00000102O<`000`000000Wc<0000000020000000309l0TP000000
W`2B00@0W`2B0`00000309l0TP030000002O0980W`2B0080W`2B1000000209l0TP8000000`2O0984
000000<0W`2B00@0000009l0TP2O0980W`2B1000000209l0TP<000000`2O<`04000000<0Wc<000@0
000009nW002OY`00WjL0100000001@2OY`00000008;70022a`0000000080P/L00P0000000`22a`00
000000377P0300377P@000000`00akD0100000000:Gd002Um000YO@5000000807`3d0P000000100a
04l000000000000a04l2000000030340C`000000000000D000001`3oool60?oG03d0oooo000G0?oo
o`800000100O0?@30000000501l0m00000000:Gd002Um00000000P00YO@4000000D00<Ne0`000002
00377P8000000`00aah500000080P/L000D0000008;70022a`00000009nW000400000080WjL000D0
000009nW002OY`00000009lc0004000000<0Wc<000@0000009lc002O<`00Wc<01000000409l0TP03
0000002O0980W`2B0080000000<0W`2B0000002O09800`2O09800`000000W`2B09l0TP0200000080
W`2B00<0000009l0TP2O09800P2O098400000080W`2B0P00000309l0TP@000000`2O09800`000000
W`2B09l0TP0600000080Wc<000@0000009lc002O<`00Wc<01@00000309nW00030000002OY`00WjL0
00D000000`22a`000`0000000<LN00377P02000000800<LN00<000000037]@00akD00P00akD40000
00800:Gd0P00000301l0m080000000@0<@1?000000000000<@1?0P0000001@0a04l0000000000000
0000<@1?00@000001P3oool60?oG0080oooo0`0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P0000050?ooo`030000003oool0oooo00<0000000<0oooo0000000000000P00
000K0?ooo`006@3oool4000000807`3d0P0000000`0O0?@0000000000003000000<00:Gd0P000002
0037]@80000000<00<Ne00000000aah01000aah50000000308;700000000P/L00080P/L01@000002
09nW008000000`2OY`0400000080Wc<00P00000309lc00@0000000@0Wc<00000002O098000000`2O
0984000000@0W`2B00@0000009l0TP2O0980W`2B0`00000409l0TP030000002O0980W`2B00800000
0P2O09800`000000W`2B09l0TP0209l0TP@000000P2O098010000000W`2B09l0TP2O098400000080
W`2B00<0000009lc000000000`2O<`0400000080Wc<00P00000309nW00@0000000D0WjL000000022
a`00P/L00000000308;700<000001000aah00`0000000<Ne0037]@02000000800<Ne00<00000002U
m000YO@00P00YO@4000000807`3d3`0000060?ooo`H0omL00P3oool010000000oooo0?ooo`000007
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo00000005
0?ooo`030000003oool0oooo01/0oooo000K0?ooo`8000000`0O0?@20000000401l0m00000000:Gd
002Um08000000P00YO@4000000@00<Ne00<0000000377P00aah00P0000001000aah0000000377P00
000308;700<000000`22a`000`000000WjL009nW000209nW00@0000000<0WjL0000000000000102O
<`0400000080Wc<000<0000009lc000000000P2O0984000000<0W`2B00@0000009l0TP2O0980W`2B
1@00000209l0TP8000000`2O0983000000@0W`2B00<0000009l0TP2O09800P00000209l0TP030000
002O0980W`2B0080W`2B0`00000309l0TP040000002O0980W`2B00000080Wc<00`00000209lc0080
00000P2O<`05000000<0WjL000<0000009nW000000000P22a`040000000308;700000000000000<0
0<LN100000040037]@0300000000YO@00:Gd008000000P00YO@00`0000007`3d01l0m00201l0m080
000000<0<@1?0000000000002@0000060?ooo`H0omL00P3oool010000000oooo0?ooo`0000040?oo
o`H000000P3oool00`000000oooo00000008000000<0oooo00<000000?ooo`3oool06P3oool001d0
oooo0`00000201l0m08000000`00YO@300000003002Um00000000<Ne008000000P00akD4000000@0
0<LN00<0000000377P0000000P0000000`22a`00000008;7000308;700D000000P2OY`001@000000
WjL009nW00000000Wc<000@000000P2O<`0200000080Wc<01@00000209l0TP8000000`2O09840000
00<0W`2B00@0000009l0TP2O0980W`2B1@00000209l0TP8000000`2O0983000000@0W`2B00<00000
09l0TP2O09800P0000000`2O0980000009l0TP0409l0TPD0000000<0Wc<00000002O<`000P2O<`04
0000000409lc00000000WjL0000000<0WjL01P00000208;7000300000022a`00P/L000D000000P00
aah00`0000000<Ne0037]@020037]@@000000`00YO@2000000807`3d0P0000000`0O0?@000000000
0004000000040340C`00000000000340C`<000001P3oool60?m10080oooo00@000000?ooo`3oool0
0000103oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000703oool001h0oooo0P000003
01l0m0@000000P00YO@00`0000000:Gd000000020037]@<000000P00akD3000000<00<LN0`000004
08;7000300000022a`00P/L000<0000000<0WjL00000002OY`000`2OY`0010000000WjL000000000
000209lc00030000002O<`00Wc<000<0Wc<00P0000000`2O<`00000009l0TP02000000<0W`2B1000
000209l0TP8000000`2O0984000000<0W`2B00@0000009l0TP2O0980W`2B1@00000209l0TP040000
002O0980W`2B09l0TP@00000102O09800`000000W`2B09l0TP020000000409l0TP000000W`2B0000
0080Wc<01000000309lc00050000002O<`00Wc<00000002OY`000`00000309nW008000000`22a`03
0000000408;7000000000<LN000000<00<LN1@0000030037]@0400000000YO@00:Gd002Um0@00000
0`0O0?@=000000H0oooo1P3o@@020?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`00
0000oooo0`0000030?ooo`030000003oool000000080oooo0P0000050?ooo`030000003oool0oooo
01T0oooo000P0?ooo`<000000P0O0?@2000000<00:Gd100000020037]@8000000P00akD500000080
0<LN00<0000008;70022a`000P22a`030000000508;700000000WjL009nW000000000`2OY`040000
00@0Wc<000<0000009lc002O<`000P0000000`2O<`0000000000000309l0TP@000000P2O09820000
00<0W`2B1000000209l0TP8000000`2O0984000000<0W`2B00@0000009l0TP2O0980W`2B10000003
09l0TP040000002O0980W`2B09l0TP@000000`2O09800`000000W`2B09l0TP0200000080Wc<000<0
000009lc002O<`000P2O<`050000000309nW00000000WjL00080WjL01P00000208;7000500000022
a`00P/L000000000aah00`00000200377P8000000`00akD5000000800:Gd00@0000001l0m00O0?@0
7`3d0`0000001@0a04l00000000000000000<@1?0080000000@0<@1?00000000000000001P3oool6
0?m10080oooo00@000000?ooo`3oool000001P3oool2000000050?ooo`000000oooo0?ooo`000000
0`3oool2000000H0oooo00@000000?ooo`3oool000006`3oool00240oooo0P00000301l0m0@00000
0P00YO@2000000<00<Ne0`0000000`00akD0000000377P02000000800<LN1@00000208;700050000
0022a`00P/L00000002OY`001000000309nW00040000002O<`00Wc<009lc00@00000102O<`001000
0000W`2B00000000000209l0TP040000002O0980W`2B09l0TPD000000P2O098010000000W`2B09l0
TP2O098500000080W`2B0P00000309l0TP@000000P2O0982000000<0W`2B1000000309l0TP040000
002O0980W`2B09l0TP@000000`2O<`000`000000Wc<009lc000200000080Wc<00P00000209nW00@0
00000P2OY`02000000<0P/L01P0000000`00aah0000000377P0200377PD000000P00akD010000000
0:Gd002Um000YO@5000000<07`3d1`000000100a04l000000000000000060?ooo`H0od400`3oool2
000000P0oooo00<000000?ooo`3oool00P0000050?ooo`030000003oool0oooo00D0oooo0P00000L
0?ooo`008`3oool3000000807`3d0P000003002Um0@000000P00akD00`0000000<Ne000000020037
7P<000000P00aah3000000<0P/L01000000209nW008000000P2OY`05000000<0Wc<000@0000009lc
002O<`00Wc<00`00000509l0TP<000000`2O098010000000W`2B09l0TP2O0984000000<0W`2B00@0
000009l0TP2O0980W`2B1@00000209l0TP040000002O0980W`2B09l0TPD000000P2O098010000000
W`2B09l0TP2O098500000080W`2B00<0000009l0TP0000000P2O<`03000000@0Wc<000@0000009lc
0000000000000P2OY`000`000000WjL009nW000209nW00@000000`22a`02000000800<LN10000000
1000aah000000037]@0000030037]@@000000`00YO@0100000007`3d01l0m00O0?@4000000050340
C`00000000000000000a04l00`0000060?ooo`H0od40?@3oool002@0oooo00<0000001l0m00O0?@0
0`0O0?@3000000800:Gd0P0000030037]@@000000P00aah20000000400377P000000P/L008;700<0
00000P22a`000`000000WjL009nW000209nW00<0000000<0WjL00000002O<`000P00000309lc00@0
000000@0Wc<000000000000000000P2O09820000000309l0TP000000W`2B00@0W`2B0`00000209l0
TP8000000`2O0984000000<0W`2B00@0000009l0TP2O0980W`2B1000000309l0TP040000002O0980
W`2B09l0TP@000000`2O098010000000W`2B09l0TP2O098500000080Wc<000@0000009lc002O<`00
Wc<01000000309nW00040000002OY`00WjL009nW00@000001022a`04000000800<LN00D000000037
7P00aah000000037]@04000000030037]@000000000000<00:Gd1@00000201l0m080000000<0<@1?
0000000000001P0000050?ooo`H0od40?@3oool002D0oooo00<0000001l0m00O0?@00P0000000`0O
0?@00:Gd002Um004002Um0<000000P00akD2000000<00<LN1@0000000`22a`0000000000000208;7
00D000000P2OY`020000000309nW00000000000000@000000P2O<`0200000080Wc<01000000409l0
TP030000002O0980W`2B0080000000<0W`2B0000002O0980102O098300000080W`2B0P00000309l0
TP@000000P2O0982000000<0W`2B1000000209l0TP8000000`2O098400000080W`2B00<0000009lc
002O<`000P2O<`04000000<0Wc<000@0000009nW002OY`00WjL010000000102OY`00000008;70000
000208;70080000000<0P/L00000000000001000aah4000000800<Ne00@000000037]@00akD00<Ne
10000002002Um08000000`0O0?@2000000050340C`00000000000000000a04l00P0000000`0a04l0
00000?ooo`040?ooo`H0od40?@3oool002H0oooo0P00000401l0m0<00:Gd0P0000000`00YO@00000
0037]@030037]@@000000P00aah00`0000000<LN0000000208;700<000000P22a`03000000<0WjL0
0P000000102OY`00000009lc002O<`02000000<0Wc<00`0000000`2O<`00000009l0TP02000000<0
W`2B0`00000409l0TP030000002O0980W`2B0080000000<0W`2B0000002O09800`2O098400000080
W`2B00@0000009l0TP2O0980W`2B1@00000209l0TP040000002O0980W`2B09l0TPD000000P2O0980
1@000000W`2B09l0TP000000Wc<000@000000P2O<`0010000000Wc<009lc002O<`0500000080WjL0
00<0000009nW002OY`001@00000408;7000300000000aah00<LN0080000000<00<LN000000000000
0`00akD500000003002Um00000000:Gd00800:Gd1@00000201l0m0T000001@3oool60?m103d0oooo
000W0?ooo`8000000P0O0?@4000000@00:Gd100000020037]@0400000000aah00<LN00377PD00000
0P22a`0010000000P/L008;70000000209nW00<000000P2OY`02000000<0Wc<01000000209lc0003
0000002O<`00Wc<000H000000P2O098010000000W`2B09l0TP2O0984000000<0W`2B00<0000009l0
TP2O09800P00000209l0TP030000002O0980W`2B0080W`2B0`00000309l0TP040000002O0980W`2B
09l0TP@000000`2O098010000000W`2B09l0TP2O098500000080Wc<000@0000009lc002O<`00Wc<0
1@00000209nW00040000002OY`00WjL009nW00@000000`22a`0010000000P/L008;70022a`040000
00@00<LN100000001P00akD000000037]@00akD00000002Um0@0000000<00:Gd0000000000000`0O
0?@4000000040340C`00000000000340C`8000001@3oool60?m103d0oooo000Y0?ooo`8000000P0O
0?@3000000800:Gd0P0000000`00akD000000037]@030037]@<000000`00aah200000080P/L01P00
00000`2OY`00000009nW000209nW00D000000P2O<`0010000000Wc<009lc002O<`030000000509lc
00000000W`2B09l0TP0000000`2O0984000000<0W`2B00@0000009l0TP2O0980W`2B0`00000409l0
TP030000002O0980W`2B0080000000<0W`2B0000000000000`2O098400000080W`2B0P00000309l0
TP@000000P2O098010000000Wc<009lc002O<`0500000080Wc<000@0000009lc00000000WjL01@00
000209nW008000000P22a`060000000400377P0000000<LN00377P8000000P00aah00`0000000<Ne
0037]@020037]@@000000P00YO@0100000000:Gd002Um000YO@4000000<07`3d1`0000050?ooo`H0
od40?@3oool002X0oooo00@0000001l0m00O0?@07`3d10000002002Um08000000P00akD200000003
0037]@0000000<LN00@00<LN0`00000208;70080000000@0P/L00000002OY`00WjL00`00000209nW
008000000`2O<`0400000080Wc<000<0000009lc000000000P2O098400000080W`2B0P00000309l0
TP@000000P2O0982000000<0W`2B0`00000509l0TP<000000P2O098010000000W`2B09l0TP2O0985
000000@0W`2B1P00000309lc00040000002O<`00Wc<009lc00@000000`2OY`000`000000WjL009nW
0005000000<0P/L000<0000008;7000000001000000400377P0300000000akD00<Ne0080000000<0
0<Ne0000000000000`00YO@50000000301l0m00000007`3d00807`3d10000000100a04l000000000
000000050?ooo`H0od40?@3oool002/0oooo0`00000201l0m08000000`00YO@3000000@00<Ne00<0
000000377P00aah00P0000000`00aah000000000000308;700D0000000<0WjL00000000000000`2O
Y`0400000080Wc<00P00000309lc00@000000P2O0982000000<0W`2B1000000209l0TP040000002O
0980W`2B09l0TPD000000P2O09800`000000W`2B09l0TP0200000080W`2B00<0000009l0TP2O0980
0P2O0983000000<0W`2B00@0000009l0TP2O0980W`2B1000000209lc008000000`2O<`0500000003
09nW00000000WjL00080WjL010000000102OY`00000008;70000000308;700@000000`00aah01000
00000<LN00377P00aah4000000<00<Ne00<000000037]@0000000P000002002Um00300000000YO@0
000000807`3d0`00000301l0m0D000001@3oool60?m103d0oooo000/0?ooo`8000000`0O0?@40000
00800:Gd0P0000030037]@<000001@00aah300000080P/L000<0000008;7000000000P2OY`040000
0080WjL00P00000309lc00@000000P2O<`0300000080W`2B1000000209l0TP040000002O0980W`2B
09l0TP@000000`2O098010000000W`2B09l0TP2O0983000000@0W`2B00<0000009l0TP2O09800P00
00000`2O0980000009l0TP0209l0TPH000001@2O<`050000000409lc00000000Wc<000000080WjL0
1000000309nW008000000P22a`04000000<0P/L000@0000000377P00aah00<LN1@0000020037]@04
00000000akD00<Ne0037]@<000001000YO@50000000301l0m00000007`3d00807`3d1P0000050?oo
o`H0od400P3oool3000000<0oooo00<000000?ooo`3oool00P0000050?ooo`050000003oool0oooo
0?ooo`0000000`3oool3000000030?ooo`0000000000008000006`3oool002h0oooo0`00000201l0
m08000000`00YO@4000000800<Ne0P00000200377P80000000<00<LN0000000000000`22a`040000
0080WjL000@0000009nW002OY`00WjL01@00000209lc00040000002O<`00Wc<009lc00D000000P2O
098010000000W`2B09l0TP2O098400000080W`2B0P00000309l0TP@000000P2O0982000000<0W`2B
0`00000409l0TP<000000`2O098010000000Wc<009lc002O<`04000000<0Wc<000@0000009lc002O
<`00Wc<01000000209nW00040000002OY`00WjL009nW00D000000P22a`000`000000P/L008;70006
000000800<LN00@0000000377P0000000<Ne1@0000000`00akD0000000000002002Um080000000@0
0:Gd00000000YO@000000P0O0?@4000000807`3d1@0000040?ooo`H0od400P3oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06`3oool002l0oooo0P00000301l0
m0@000000P00YO@2000000800<Ne1000000500377P<000000P22a`0300000080WjL00`00000309nW
00040000002O<`00Wc<009lc00@000000P2O<`020000000309lc00000000000000@000000P2O0982
000000<0W`2B1000000209l0TP040000002O0980W`2B09l0TPD000000P2O09800`000000W`2B09l0
TP020000000409l0TP000000W`2B09l0TPH000000P2O<`0010000000Wc<009lc002O<`0600000003
09nW00000000WjL00080WjL01@00000208;7000400000022a`00P/L008;700<000001000aah01000
00000<LN00377P00aah4000000800<Ne00<000000037]@00akD01@000004002Um0@000000P0O0?@0
100000007`3d01l0m00O0?@3000000030340C`000000oooo00<0oooo1P3o@@020?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`000000100000020?ooo`030000003oool0oooo00@00000
0`3oool00`000000oooo0?ooo`0J0?ooo`00<@3oool3000000807`3d0P000002002Um0@000000P00
akD3000000800<LN0P0000000`00aah0000008;7000208;700D0000000<0WjL00000000000000`2O
Y`0400000080Wc<00P00000309lc00<0000000@0Wc<00000002O098000000`2O098500000080W`2B
00@0000009l0TP2O0980W`2B1000000309l0TP040000002O0980W`2B09l0TP<000000`2O09850000
0080Wc<000@0000009lc002O<`00Wc<010000000102O<`00000000000000000309nW00@000000P2O
Y`0010000000P/L008;70022a`0500000080P/L000@0000000377P00aah00<LN1P0000000`00akD0
00000037]@020037]@@000000`00YO@00`0000000:Gd002Um00200000003002Um00000007`3d0080
7`3d1@00000201l0m0<00000103oool60?l0V@80oooo00@000000?ooo`3oool00000103oool01P00
0000oooo0?ooo`000000oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool06P3oool00380oooo0P00000201l0m0@00000
0P00YO@3000000800<Ne1000000400377P<000000P22a`000`000000P/L00000000209nW00@00000
0P2OY`02000000<0Wc<01000000209lc00040000002O<`00Wc<009lc00@000000`2O098010000000
W`2B09l0TP2O098400000080W`2B0P00000309l0TP@0000000<0W`2B0000000000001000000209lc
00040000002O<`00Wc<009lc00@000000P2O<`030000000309nW00000000000000<000000P2OY`00
0`000000WjL000000005000000<0P/L000<0000008;7000000001@00000300377P0400000000akD0
0<Ne0037]@@000000P00akD0100000000:Gd002Um000YO@400000003002Um0000000000000@00000
0P0O0?@0100000007`3d01l0m00O0?@4000000@0oooo1P3o09T20?ooo`040000003oool0oooo0000
00@0oooo0`0000030?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool0oooo0P000005
0?ooo`030000003oool0oooo01T0oooo000d0?ooo`8000000P0O0?@3000000800:Gd100000020037
]@8000000P00aah20000000300377P000000000000<0P/L01000000209nW00040000002OY`00WjL0
09nW00D000000P2O<`0010000000Wc<009lc002O<`0400000080Wc<02@00000209l0TP040000002O
0980W`2B09l0TPX0000000@0Wc<000000000000000001@2O<`0300000080Wc<000<0000009lc002O
<`001@00000309nW00030000002OY`00WjL000D000000P22a`0010000000P/L008;70022a`050000
00800<LN00<0000000377P00aah01P0000020037]@0300000000akD00<Ne00D000000`00YO@40000
00807`3d00@0000001l0m00O0?@07`3d1000000201l0m0800000103oool60?l0V@80oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`8000000P3oool2000000L0oooo00@0
00000?ooo`3oool000006`3oool003D0oooo0P00000201l0m0@000000P00YO@2000000<00<Ne0`00
000500377P<000000P22a`0300000080WjL00`00000309nW008000000`2O<`0300000080Wc<00P00
000309lc00<000000`2O<`000`000000Wc<009lc0005000000<0Wc<000@0000009lc002O<`00Wc<0
1000000209lc00030000002O<`00Wc<0008000000P2O<`0010000000Wc<009lc002O<`0400000080
WjL000@0000009nW002OY`00WjL01@00000208;7000400000022a`00P/L008;700D000000P00aah0
100000000<LN00377P00aah3000000<00<Ne00@000000037]@00akD00<Ne1@000002002Um0040000
0000YO@00:Gd002Um0<000000`0O0?@5000000807`3d00@0000001l0m00O0?@07`3d0P0000040?oo
o`H0o`2I0`3oool2000000H0oooo0`0000040?ooo`050000003oool0oooo0?ooo`000000203oool2
000001`0oooo000g0?ooo`8000000P0O0?@2000000800:Gd1@0000020037]@D000000P00aah20000
0080P/L01@0000000`2OY`0000000000000309nW00D0000000<0Wc<00000002O<`000P2O<`050000
0080Wc<000@0000009lc002O<`00Wc<01000000209lc008000000`2O<`0400000080Wc<000@00000
09lc002O<`00Wc<00`00000409lc00@000000P2OY`0010000000WjL009nW002OY`040000000309nW
00000000000000@0P/L0100000000`22a`0000000000000300377PH0000000<00<Ne00000000akD0
0P00akD600000003002Um00000000:Gd00800:Gd1P000000100O0?@0000000000000000201l0m004
0000000O0?@07`3d01l0m0D000001P3oool60?l0VCd0oooo000h0?ooo`040000000O0?@07`3d01l0
m0<000000P00YO@3000000800<Ne0P0000000`00aah0000000377P0200377P@000000P22a`040000
0080WjL00`00000209nW00030000002OY`00WjL000D000000`2O<`0010000000Wc<009lc002O<`04
00000080Wc<000@0000009lc002O<`00Wc<01@00000209lc00040000002O<`00Wc<009lc00@00000
0P2O<`0500000080WjL000@0000009nW002OY`00WjL0100000000`2OY`0000000000000200000003
08;700000000000000<000000P22a`030000000300377P0000000000008000000P00aah2000000<0
0<Ne100000001000akD00000000000000002002Um0D0000000D00:Gd000000000000000001l0m002
0000000301l0m00000007`3d00807`3d1000000;0?ooo`H0o`2I?@3oool003T0oooo0`00000201l0
m08000000P00YO@4000000800<Ne1@00000200377P8000000`22a`050000000309nW00000000WjL0
0080WjL01000000209nW00800000102O<`0300000080Wc<000@0000009lc002O<`00Wc<010000003
09lc00040000002O<`00Wc<009lc00@000000P2O<`04000000<0WjL000@0000009nW002OY`00WjL0
100000000`2OY`000000000000020000000308;7000000000000008000000P22a`000`000000P/L0
08;70006000000800<LN2@0000000`00akD000000000000200000003002Um0000000000000800000
0P00YO@8000000@07`3d0`00000?0?ooo`H0o`2I?@3oool003X0oooo0P00000201l0m0@000000P00
YO@9000000<00<LN1000000208;7000300000022a`00P/L000D000000P2OY`02000000<0WjL01@00
00000`2O<`00000009lc000309lc00<000000P2O<`02000000<0Wc<0100000000`2O<`0000000000
00040000000309nW00000000000000<0WjL01000000209nW00<0000000<0P/L00000000000000P00
000208;7000400000022a`00P/L008;700D000000P00aah00`0000000<LN00377P05000000<00<Ne
200000000`00YO@0000000000007000000<07`3d0`00000D0?ooo`H0o`2I?@3oool003`0oooo0P00
000201l0m0T000000`00akD4000000800<LN0P00000208;700@000000P22a`02000000@0WjL00`00
000209nW00030000002OY`00WjL000T00000102O<`080000000409nW000000000000000000D0WjL0
0`000000102OY`00000009nW002OY`0600000080P/L000@0000008;70022a`00P/L0100000070037
7P@000000P00akD00`0000000<Ne0037]@05000000<00:Gd0`0000000`0O0?@00000000000020000
00807`3d1000000H0?ooo`H0o`2I?@3oool003h0oooo1@0000001P00YO@00000002Um000YO@00000
0037]@<000000P00akD0100000000<LN00377P00aah400000080P/L00P00000308;700@000000P2O
Y`0010000000WjL009nW002OY`0400000080WjL00P00000309nW00<000000`2OY`0010000000WjL0
09nW002OY`0400000080WjL01000000209nW00040000002OY`00WjL009nW00D000001P22a`040000
00800<LN00@0000000377P00aah00<LN1@0000020037]@0300000000akD00<Ne00D000000P00YO@0
0`0000000:Gd002Um006000000807`3d1000000L0?ooo`H0o`2I?@3oool00400oooo00@0000001l0
m00O0?@07`3d1@0000000`00akD00000000000020037]@@000000P00aah3000000<0P/L00`000002
08;700P000000P2OY`02000000<0WjL01000000209nW00040000002OY`00WjL009nW00@000000P2O
Y`040000000309nW00000000000000P000000P22a`0010000000P/L008;70022a`04000000800<LN
00@0000000377P00aah00<LN1@0000060037]@<000000`00YO@0100000000:Gd002Um000YO@40000
00807`3d00<0000001l0m00O0?@00P00000P0?ooo`H0o`2I?@3oool00440oooo0`00000201l0m080
00000P00YO@4000000<00<Ne00@0000000377P00aah00<LN1@0000000`22a`00000008;7000208;7
00<000000P22a`03000000@0WjL00`00000209nW00040000002OY`00WjL009nW00@000000P2OY`04
0000000309nW0000000000000080000000<0P/L00000000000000P00000308;7000400000022a`00
P/L008;700@000001P00aah4000000800<Ne00@000000037]@00akD00<Ne1@000002002Um0040000
0000YO@00:Gd002Um0@000000P0O0?@0100000007`3d01l0m00O0?@300000280oooo1P3o09Tm0?oo
o`00@P3oool2000000807`3d10000002002Um08000000`00akD4000000800<LN00<0000000377P00
aah01@00000208;7008000000`22a`07000000@0WjL03P0000000`22a`0000000000000200000080
P/L000<0000008;70022a`000`22a`03000000800<LN00@0000000377P00aah00<LN100000020037
]@0400000000akD00<Ne0037]@D0000000<00:Gd00000000YO@00P00YO@5000000807`3d00@00000
01l0m00O0?@07`3d1000000U0?ooo`H0o`2I?@3oool004@0oooo0P00000201l0m08000000`00YO@4
000000800<Ne0P00000200377P<000000`00aah2000000@0P/L00`00000208;7000400000022a`00
P/L008;7008000001022a`0400000080P/L000@0000008;70022a`00P/L01000000208;700040000
0022a`00P/L008;700D000000P00aah0100000000<LN00377P00aah4000000800<Ne00@000000037
]@00akD00<Ne1@0000000`00YO@00000002Um002002Um0D0000000<07`3d0000000000001`00000Y
0?ooo`H0o`2I?@3oool004D0oooo00@0000001l0m00O0?@07`3d10000002002Um08000000`00akD3
000000800<LN0P00000300377P@000000P22a`0010000000P/L008;70022a`0400000080P/L01000
000208;7000400000022a`00P/L008;700@000000P22a`0010000000P/L008;70022a`0500000080
0<LN00@0000000377P00aah00<LN100000020037]@0400000000akD00<Ne0037]@@000000P00YO@0
100000000:Gd002Um000YO@50000000301l0m0000000000000800000M@3oool004H0oooo0`000002
01l0m08000000P00YO@4000000800<Ne2@00000200377P0300000000aah0000000D000000P22a`04
00000080P/L000@0000008;70022a`00P/L0100000000`22a`00000000000007000000<00<LN00@0
000000377P00aah00<LN100000020037]@0400000000akD00<Ne0037]@@000000P00YO@010000000
0:Gd002Um000YO@4000000807`3d1000001i0?ooo`00A`3oool2000000807`3d10000002002Um0P0
000000<00<Ne0000000000001`00000300377Q<0000000<00<LN0000000000000P00000200377P80
00000`00aah4000000800<Ne00@000000037]@00akD00<Ne10000002002Um00400000000YO@00:Gd
002Um0@000000P0O0?@4000007d0oooo00190?ooo`8000000P0O0?@2000000@00:Gd0`0000020037
]@L000000`00aah4000000800<LN00@0000000377P00aah00<LN1000000200377P0400000000aah0
0<LN00377P@000000P00aah00`0000000<LN00377P0200377P@000000P00akD0100000000<Ne0037
]@00akD4000000800:Gd00@00000002Um000YO@00:Gd1000000201l0m0@00000P@3oool004X0oooo
00@0000001l0m00O0?@07`3d10000002002Um0@000000P00akD0100000000<Ne0037]@00akD50000
000300377P0000000<LN00<00<LN0`00000200377P8000000P00aah4000000800<LN200000030037
]@0400000000akD00<Ne0037]@@000000P00YO@8000000807`3d100000250?ooo`00B`3oool30000
00807`3d10000002002Um0<000000P00akD3000000800<Ne0P0000000`00akD00000000000070000
00800<LN2P0000000`00akD0000000000002000000800<Ne00@000000037]@00akD00<Ne10000002
002Um0P000000P0O0?@4000008T0oooo001=0?ooo`<000000P0O0?@2000000<00:Gd100000000`00
akD00000000000030037]@<000000P00akD2000000<00<Ne0`0000030037]@0400000000akD00<Ne
0037]@@0000000<00<Ne0000000000001`000002002Um0P000000P0O0?@4000008d0oooo001?0?oo
o`040000000O0?@07`3d01l0m0@000000P00YO@00`0000000:Gd002Um005000000800<Ne00@00000
0037]@00akD00<Ne100000020037]@0400000000akD00<Ne0037]@@0000000<00<Ne000000000000
1@000004002Um0P000000P0O0?@400000940oooo001@0?ooo`<000000P0O0?@2000000800:Gd0`00
0003002Um0P000000P00akD0100000000<Ne0037]@00akD:000000800:Gd00@00000002Um000YO@0
0:Gd1000000201l0m0040000000O0?@07`3d01l0m0@00000U@3oool00540oooo00@0000001l0m00O
0?@07`3d10000002002Um00400000000YO@00:Gd002Um0<000000P00YO@2000000@00<Ne0`000002
002Um0@000000P00YO@0100000000:Gd002Um000YO@4000000807`3d00@0000001l0m00O0?@07`3d
1000002I0?ooo`00DP3oool3000000807`3d20000002002Um0@000000P00YO@0100000000:Gd002U
m000YO@4000000800:Gd00@00000002Um000YO@00:Gd1000000201l0m0040000000O0?@07`3d01l0
m0@00000W@3oool005@0oooo0`00000201l0m080000000<07`3d0000000000000`000002002Um080
00000P00YO@400000003002Um0000000000000L000000P0O0?@0100000007`3d01l0m00O0?@40000
0:40oooo001F0?ooo`040000000O0?@07`3d01l0m0<000000P0O0?@00`0000000:Gd002Um003002U
m0L0000000<07`3d0000000000000P00000201l0m0040000000O0?@07`3d01l0m0@00000Y@3oool0
05L0oooo0`00000201l0m0040000000O0?@07`3d01l0m0<000000`0O0?@00`0000007`3d01l0m004
000000807`3d00@0000001l0m00O0?@07`3d1000002Y0?ooo`00F03oool0100000007`3d01l0m00O
0?@4000000807`3d00@0000001l0m00O0?@07`3d0`00000301l0m0L00000[@3oool005T0oooo0`00
000201l0m0P000000P0O0?@400000;@0oooo001K0?ooo`<000000P0O0?@0100000007`3d01l0m00O
0?@400000;P0oooo001M0?ooo`030000000O0?@07`3d00@00000_03oool005h0oooo0P0000300?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {245.063, 0}} -> {-0.0323039, -0.0271431, \
0.00465096, 0.00465096}, {{6.9375, 221.938}, {239.188, 5.8125}} -> \
{0.0209536, -0.0234394, 0.00398888, 0.00398888}, {{221.938, 280}, {239.188, \
5.8125}} -> {-3.82243, -0.0254768, 0.017223, 0.00428742}},
  CellTags->"b:8.1.2"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1440}, {0, 824}},
ScreenStyleEnvironment->"Brackets",
WindowSize->{497, 712},
WindowMargins->{{129, Automatic}, {27, Automatic}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "i:60"->{
    Cell[1776, 53, 76, 1, 65, "Section",
      CellTags->{"i:60", "c:44"}]},
  "c:44"->{
    Cell[1776, 53, 76, 1, 65, "Section",
      CellTags->{"i:60", "c:44"}]},
  "b:8.1.2"->{
    Cell[3330, 90, 77, 1, 39, "Subsection",
      CellTags->{"b:8.1.2", "c:47"}],
    Cell[3410, 93, 493, 14, 76, "Text",
      CellTags->"b:8.1.2"],
    Cell[3906, 109, 1029, 19, 329, "Input",
      CellTags->"b:8.1.2"],
    Cell[4938, 130, 165, 4, 49, "Input",
      CellTags->"b:8.1.2"],
    Cell[5128, 138, 178, 4, 49, "Input",
      CellTags->"b:8.1.2"],
    Cell[5309, 144, 101, 3, 27, "Output",
      CellTags->"b:8.1.2"],
    Cell[5413, 149, 111, 3, 27, "Output",
      CellTags->"b:8.1.2"],
    Cell[5561, 157, 266, 6, 69, "Input",
      CellTags->"b:8.1.2"],
    Cell[5830, 165, 1078793, 50408, 253, 941256, 48704, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"b:8.1.2"]},
  "c:47"->{
    Cell[3330, 90, 77, 1, 39, "Subsection",
      CellTags->{"b:8.1.2", "c:47"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"i:60", 1085328, 50595},
  {"c:44", 1085417, 50598},
  {"b:8.1.2", 1085509, 50601},
  {"c:47", 1086222, 50621}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 76, 1, 65, "Section",
  CellTags->{"i:60", "c:44"}],
Cell[1855, 56, 782, 15, 147, "Text"],
Cell[2640, 73, 665, 13, 135, "Text"],

Cell[CellGroupData[{
Cell[3330, 90, 77, 1, 39, "Subsection",
  CellTags->{"b:8.1.2", "c:47"}],
Cell[3410, 93, 493, 14, 76, "Text",
  CellTags->"b:8.1.2"],
Cell[3906, 109, 1029, 19, 329, "Input",
  CellTags->"b:8.1.2"],
Cell[4938, 130, 165, 4, 49, "Input",
  CellTags->"b:8.1.2"],

Cell[CellGroupData[{
Cell[5128, 138, 178, 4, 49, "Input",
  CellTags->"b:8.1.2"],
Cell[5309, 144, 101, 3, 27, "Output",
  CellTags->"b:8.1.2"],
Cell[5413, 149, 111, 3, 27, "Output",
  CellTags->"b:8.1.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5561, 157, 266, 6, 69, "Input",
  CellTags->"b:8.1.2"],
Cell[5830, 165, 1078793, 50408, 253, 941256, 48704, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"b:8.1.2"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

